
C*********************************************************************
C OWENSRAYTRA IS A MODIFICATION OF THE ANL RAYTRACERAYTRA CODE
C TO SUPPORT OWENS ATOMIC CONSTANTS
C
C ADDITIONAL CHANGES HAVE BEEN MADE TO MAKE IT MORE READABLE
C THE CODE SHOULD BE COMPARED WITH RAYTACERAYTRA IN THE ANL LIB
C=====================================================================
C     << ray tracing routine in astro-d mirror >>
      subroutine owensraytra(denergy, 
     &                       dangin, dangphi,
     &                       dphotonx, dphotony,
     &                       dphotonangle, dphotonradius,
     &                       dphotonweight,
     &                       dfocalpx, dfocalpy,
     &                       jresultcode,
     &                       jprimaryhits, jsecondaryhits)
C
C        denergy        (i) : energy of incident photon (keV)
C        dangin         (i) : Incident angle of incoming photon (deg)
C        dangphi        (i) : Rotation angle of incident photon (deg)
C        dphotonx       (i) : X position of incident photon at mirror
C                                top in millimeters
C        dphotony       (i) : Y position of incident photon at mirror 
C                                top (mm)
C        dphotonangle   (i) : Incident photon X,Y in polar angle
C        dphotonradius  (i) : Incident photon X,Y in radius
C        dphotonweight  (io): Photon weight factor, 0 for discard mode
C        dfocalpx       (o) : Focal plane X for photons that get thru
C        dfocalpy       (o) : Focal plane Y for photons that get thru
C        jresultcode    (o) : Code for end result for traced photon
C        jresultcode =   0 : normal end
C                     = 910 : hidden by primary housing
C                     = 911 : hidden by primary housing side wall
C                     = 915 : hidden by secondary housing
C                     = 916 : hidden by secondary housing side wall
C                     = 920 : hidden by 1st alignment bar
C                     = 921 : hidden by 2nd alignment bar
C                     = 923 : hidden by 3rd alignment bar
C                     = 924 : hidden by 4th alignment bar
C                     = 925 : hidden by 1&14 sector
C                     = 930 : hidden by primary foil
C                     = 935 : hidden by secondary foil
C                     = 940 : absorbed by primary inner mirror
C                     = 945 : absorbed by secondarr inner mirror
C                     = 950 : absorbed on primary foil
C                     = 955 : absorbed on secondary foil
C                     = 960 : only primary reflect
C                     = 970 : only secondary reflect
C                     = 980 : no reflect
C                     = 990 : abnormal reflected
C
C        jprimaryhits   (o) : Count of the number of times photon
C                                struck the primary mirror
C        jsecondaryhits (o): Count of the number of times photon
C                                struck the secondary mirror
C=====================================================================
      Implicit None

C Calling sequence variables
      double precision denergy
      double precision dangin
      double precision dangphi
      double precision dphotonx
      double precision dphotony
      double precision dphotonangle
      double precision dphotonradius
      double precision dphotonweight
      double precision dfocalpx
      double precision dfocalpy
      integer jresultcode
      integer jprimaryhits
      integer jsecondaryhits

C common for the Mirror constants
      double precision r, beta, z
      Common /Raytracestruct/ r(120,4),beta(120,2),z(4)
C

C Variables for Parameter constants
C     This code defaults the presence of a mask over the telescope
      Integer MASKON
      Parameter (MASKON=1)
C
      double precision MPI, M90DEG, DEG2RAD, WALBAR, SECTOR
C     The constant Pi obviously
      Parameter (MPI = 3.1415926535897932385d0)
C     Pi/2 = 90degree
      Parameter (M90DEG = MPI/2.0d0)
C     Degrees to radians conversion factor
      Parameter (DEG2RAD = 0.017453292519943295769d0)
C     Width of ALignment BAR in mm
      Parameter (WALBAR = 1.574738d0)
C     A sector is 1/56 of a circle (360/56=6.428)
      Parameter (SECTOR = 6.428d0*DEG2RAD)
C     Mirror levels
      integer PRIMARYTOP, PRIMARYBOTTOM
      integer SECONDARYTOP, SECONDARYBOTTOM
      Parameter (PRIMARYTOP=1)
      Parameter (PRIMARYBOTTOM=2)
      Parameter (SECONDARYTOP=3)
      Parameter (SECONDARYBOTTOM=4)
C     Defaulted mirror foil width in mm
      double precision FOILWIDTH
      Parameter (FOILWIDTH=0.15d0)
C     Constants for X,Y,Z positions in vector array
      integer VX, VY, VZ
      Parameter (VX=1)
      Parameter (VY=2)
      Parameter (VZ=3)
C     Raytracing defaults for indicating primary/secondary mirror
      integer PRIMARYMIRROR
      parameter (PRIMARYMIRROR=1)
      integer SECONDARYMIRROR
      parameter (SECONDARYMIRROR=2)
C     Reflection sorting codes
      integer SINGLEOUTERREFLECT
      parameter (SINGLEOUTERREFLECT=2)
      integer NOREFLECT
      parameter (NOREFLECT=0)

C local
      Integer ihit, ihitm
      double precision theeta, phi
      double precision ray0(3), rayn(3), ray0s(2)
      double precision t, dsinoftheeta
      double precision acref, aref, zcref, zref
      double precision dsectorang
      double precision dwalbarangwidth
      double precision dquadrantang
      integer jmirror
      integer jmirrordelta
      integer jhitinnermirror
      integer jhitoutermirror
        
C External functions
      double precision Raytraceran, Raytracecrefrd
      double precision owensRaytracerefrd

C-------------------------- initialization -----------------------------
C     default the result code to normal impact on focal plane
      jresultcode = 0
C     define the incident photon vector 
      ray0(VX)  = dphotonx
      ray0(VY)  = dphotony
      ray0(VZ)  = z(PRIMARYTOP)
C     default the number of mirror hits to zero
      jprimaryhits = 0
      jsecondaryhits = 0

C     Convert incident photon degree values to internal radians
      theeta   = dangin  * DEG2RAD
      phi      = dangphi * DEG2RAD

C
      dsinoftheeta = dsin(theeta)
      rayn(VX)  = dsinoftheeta * dcos(phi)
      rayn(VY)  = dsinoftheeta * dsin(phi)
      rayn(VZ)  = - dcos(theeta)

C Trace the photon thru the primary mirror
        ray0s(VX) = ray0(VX)
        ray0s(VY) = ray0(VY)

C------ Check whether the housing hides the photon
C        if the X or Y is less than 5 mm the photon is hidden
C             in which case we set the appropriate result code
        if ((dabs(ray0(VX)).lt.5.0036d0)) goto 910
        if ((dabs(ray0(VY)).lt.5.0036d0)) goto 910

C------ Check whether an alignment bar hides the photon
C        Since the alignment bar has a fixed width, its angular width
C        varies with radius
        dwalbarangwidth = WALBAR / dphotonradius
        dsectorang = dmod(dphotonangle 
     &                    + dwalbarangwidth/2.0d0, SECTOR)
        If ( dsectorang .lt. dwalbarangwidth ) then
           goto 920
        End if
C------ Determine whether the photon falls in sector 1 or 14
C        if so it is hidden by the telescope mask
        If (MASKON.eq.1) then
          dquadrantang = dmod(dphotonangle, M90DEG)
          if (dquadrantang .lt. SECTOR) goto 925
          if (dquadrantang .gt.(M90DEG - SECTOR)) goto 925
        End if
C------ Determine whether the foil end cross-section hides the photon
C        rs = radius of 1st Primary bottom
C        rs = r(1,2)
C       Do knest=1, 120
C           if the photon falls thru between 2 foils, continue tracing
C           r(knest,1) = r(knest,primarytop)
C          If ((dphotonradius.gt.rs)
C    &         .and.(dphotonradius.lt.r(knest,1))) goto 22
C          rs = r(knest,1) + 0.15d0
C       End do
C       goto 930
C
C The following will never happen because of how the photon radius
C is calculated but you never know
C        if the photon radius is less than the 1st primary bottom, 
C            discard
        if (dphotonradius .lt. r(1,PRIMARYBOTTOM)) goto 930
C        if the photon radius is greater than the 120th primary top,
C            discard
        if (dphotonradius .gt. r(120,PRIMARYTOP)) goto 930
C binary search r(mirrorspace,primarytop)
        jmirror=64
        jmirrordelta=64
20      continue
        jmirrordelta = jmirrordelta/2
C        since we binary search we have to throw away 121-128
        if (jmirror .gt. 120) then
           jmirror = jmirror - jmirrordelta
           goto 20
        endif
C
        if (dphotonradius .le. r(jmirror,PRIMARYTOP)) then
           if (jmirror .eq. 1) then
C               we already know it is greater than the primary bottom
               goto 22
           else
C              will it fall inbetween?
              if (dphotonradius .gt. 
     &                  (r(jmirror-1,PRIMARYTOP)+FOILWIDTH)) then
C                   the photon fell between 2 mirror
                   goto 22
              endif
           endif
           jmirror = jmirror - jmirrordelta
        else
           jmirror = jmirror + jmirrordelta
        endif
        if (jmirrordelta .eq. 0) then
C            the photon is hidden by a foil
            goto 930
        endif
        goto 20
 22     continue
C------ ray tracing in foil space
C       The Nagoya code uses ihitm to track what kind of reflections
C        each photon undergoes from the top of the mirror to the bottom
C       By setting ihitm to 1 on entry and multiplying it by 2 for
C        each possible reflection you can separate out the reflection
C        classes:
C        jprimaryhits   Reflections
C        0 = 0                 None (directly thru)
C        1 = 1                 Inner mirror only
C        2 = 2                 Outer mirror only
C        3 = 1 + 2         Inner+Outer mirror
C        7 = 1 + 2 + 4         Inner+Outer+Inner mirror
C        15 = 1+2+4+8         Inner+Outer+Inner+Outer mirror
C        From the above you can see WHY they use an array with 
C        (0:16,0:16) to count the reflections by class. I would not
C        have done this but it makes sense.
        ihitm = 1
        do 30 ihit = 1, 100
C            check for the photon to hit the inner mirror surface
            Call Raytracehinm(theeta,ray0,rayn,jmirror,
     &                         PRIMARYMIRROR, jhitinnermirror)
            if ( jhitinnermirror.eq.1) then
C                The photon hit the inner mirror which is carbon
C                    dominated
C                Compute reflectivity for photon off carbon
                zcref = Raytracecrefrd(dabs(theeta), denergy)
                if ( dphotonweight.gt.0d0 ) then
                   dphotonweight = dphotonweight * zcref
                   jprimaryhits = jprimaryhits + ihitm
                else
C        
                   acref = Raytraceran()
C                  ---absorbed by primary inner mirror if true
                   if ( zcref.lt.acref ) goto 940
C                   ---the photon reflected
                   jprimaryhits = jprimaryhits + ihitm
                endif
            endif
C            if the photon didn't hit an inner mirror and this is not the
C            1st pass, then continue onto the secondary mirror
            if (( jhitinnermirror.eq.0).and.(ihit.ne.1)) goto 34
C            See if the photon hit the primary mirror
            Call Raytraceraycha(denergy,theeta,ray0,rayn,
     &                           dphotonradius,dphotonangle,
     &                                 jmirror,PRIMARYMIRROR,
     &                                 jhitoutermirror)
            ihitm = ihitm * 2
            if (jhitoutermirror.eq.1) then
C               the photon hit the true mirror surface
C              Compute reflectivity for the photon off gold
               zref = owensRaytracerefrd(dabs(theeta), denergy)
               if ( dphotonweight.gt.0d0 ) then
                  dphotonweight = dphotonweight * zref
                  jprimaryhits = jprimaryhits + ihitm
               else
                  aref = Raytraceran()
C                  ---if true, the photon was absorbed
                  If ( zref.lt.aref ) goto 950
C                  ---the photon reflected
                  jprimaryhits = jprimaryhits + ihitm
               endif
            endif
C          if the photon did not hit a mirror, it must pass to the 
C          secondary mirror code
          if (jhitoutermirror.eq.0) goto 34
          ihitm = ihitm * 2
 30     continue
C bottom of the primary mirror
 34     Continue
C       
        t = -( ray0(VZ) - z(PRIMARYBOTTOM) ) / rayn(VZ)
        ray0(VX) = ray0(VX) + t * rayn(VX)
        ray0(VY) = ray0(VY) + t * rayn(VY)
        ray0(VZ) = z(PRIMARYBOTTOM)
        dphotonradius = dsqrt(ray0(VX)*ray0(VX)+ray0(VY)*ray0(VY))
        dphotonangle  = datan(ray0(VY)/ray0(VX))
        If (ray0(VX).lt.0.0d0) then
          dphotonangle   = dphotonangle + MPI
        Else if (ray0(VY).lt.0.0d0) then
          dphotonangle   = dphotonangle + 2.0d0 * MPI
        End if
C-------- Does the housing hide the photon?
C          the housing hides the photon if either X or Y is < 5mm
C          OR if the photon tries to pass thru the origin
          if((dabs(ray0(VX)).lt.5.0036d0).or.
     &       (dabs(ray0(VY)).lt.5.0036d0).or.
     &       ((ray0(VX)*ray0s(VX)).lt.0.0d0).or.
     &       ((ray0(VY)*ray0s(VY)).lt.0.0d0)) goto 911
C-------Does the lower primary alignment bar hide the photon?
        dwalbarangwidth = WALBAR / dphotonradius
        dsectorang = dmod(dphotonangle 
     &                    + dwalbarangwidth/2.0d0, SECTOR)
        If ( dsectorang .lt. dwalbarangwidth ) then
           goto 921
        endif
C END OF PRIMARY MIRROR PHOTON TRACE
C
C BEGIN TRACE OF PHOTON THRU SECONDARY MIRROR
          t = -( ray0(VZ) - z(SECONDARYTOP) ) / rayn(VZ)
          ray0(VX) = ray0(VX) + t * rayn(VX)
          ray0(VY) = ray0(VY) + t * rayn(VY)
          ray0(VZ) = z(SECONDARYTOP)
          dphotonradius = dsqrt(ray0(VX)*ray0(VX)+ray0(VY)*ray0(VY))
          dphotonangle  = datan(ray0(VY)/ray0(VX))
          If (ray0(VX).lt.0.0d0) then
            dphotonangle   = dphotonangle + MPI
          Else if (ray0(VY).lt.0.0d0) then
            dphotonangle   = dphotonangle + 2.0d0 * MPI
          End if
        ray0s(VX) = ray0(VX)
        ray0s(VY) = ray0(VY)
C-------Does the housing hide the photon?
        If ((dabs(ray0(VX)).lt.5.0036d0)) goto 915
        If ((dabs(ray0(VY)).lt.5.0036d0)) goto 915
C-------Does the seondary alignment bar hide the photon?
        dwalbarangwidth = WALBAR / dphotonradius
        dsectorang = dmod(dphotonangle 
     &                    + dwalbarangwidth/2.0d0, SECTOR)
        If ( dsectorang .lt. dwalbarangwidth ) then
           goto 923
        endif
C-------Does the photon hit a foil top?
C        rs = radius of 1st secondary bottom
C        rs = r(1,4)
C       Do knest=1, 120
C           r(knest,3) = r(knest,secondarytop)
C          If ((dphotonradius.gt.rs)
C    &         .and.(dphotonradius.lt.r(knest,3))) goto 42
C          rs = r(knest,3) + 0.15d0
C       End do
C       goto 935
C42     Continue
C        if the photon radius is less than the 1st primary bottom, 
C            discard
        if (dphotonradius .lt. r(1,SECONDARYBOTTOM)) goto 935
C        if the photon radius is greater than the 120th primary top,
C            discard
        if (dphotonradius .gt. r(120,SECONDARYTOP)) goto 935
C binary search r(mirrorspace,secondarytop)
        jmirror=64
        jmirrordelta=64
40      continue
        jmirrordelta = jmirrordelta/2
C        since we binary search we have to throw away 121-128
        if (jmirror .gt. 120) then
           jmirror = jmirror - jmirrordelta
           goto 40
        endif
C
        if (dphotonradius .le. r(jmirror,SECONDARYTOP)) then
           if (jmirror .eq. 1) then
C               we already know it is greater than the secondary bottom
               goto 42
           else
C              will it fall inbetween?
              if (dphotonradius .gt. 
     &                  (r(jmirror-1,SECONDARYTOP)+FOILWIDTH)) then
C                   the photon fell between 2 mirrors
                   goto 42
              endif
           endif
           jmirror = jmirror - jmirrordelta
        else
           jmirror = jmirror + jmirrordelta
        endif
        if (jmirrordelta .eq. 0) then
C            the photon is hidden by a foil
            goto 935
        endif
        goto 40
 42     continue
C-------ray tracing in foil space ---------------------
C       The Nagoya code uses ihitm to track what kind of reflections
C        each photon undergoes from the top of the mirror to the bottom
C       By setting ihitm to 1 on entry and multiplying it by 2 for
C        each possible reflection you can separate out the reflection
C        classes:
C        jsecondaryhits Reflections
C        0 = 0                 None (directly thru)
C        1 = 1                 Inner mirror only
C        2 = 2                 Outer mirror only
C        3 = 1 + 2         Inner+Outer mirror
C        7 = 1 + 2 + 4         Inner+Outer+Inner mirror
C        15 = 1+2+4+8         Inner+Outer+Inner+Outer mirror
C        From the above you can see WHY they use an array with 
C        (0:16,0:16) to count the reflections by class. I would not
C        have done this but it makes sense.
        ihitm = 1
        Do 50 ihit=1, 100
C           check for the photon hitting the inner mirror
           call Raytracehinm(theeta,ray0,rayn,jmirror,
     &                              SECONDARYMIRROR,jhitinnermirror)
           if (jhitinnermirror.eq.1) then
C               photon hit the inner mirror
C              Compute reflectivity for photon off carbon----------
               zcref = Raytracecrefrd(dabs(theeta), denergy)
               if ( dphotonweight.gt.0d0 ) then
                   dphotonweight = dphotonweight * zcref
                   jsecondaryhits = jsecondaryhits + ihitm
               else
                   acref = Raytraceran()
C                  ---absorbed by secondary inner mirror if true
                   if ( zcref.lt.acref ) goto 945
C                   ---photon reflected
                   jsecondaryhits = jsecondaryhits + ihitm
               endif
            endif
C            if the photon didn't hit the inner mirror and has already
C            undergone a reflection(s), then no additional tests are
C            needed
            if ((jhitinnermirror.eq.0).and.(ihit.ne.1)) goto 54
C            determine whether the photon hit the gold surface
            Call Raytraceraycha(denergy,theeta,ray0,rayn,
     &                           dphotonradius,dphotonangle,
     &                                 jmirror,SECONDARYMIRROR,
     &                                 jhitoutermirror)
            ihitm = ihitm * 2
            if (jhitoutermirror.eq.1) then
C                Photon hit the gold surface
C               Compute reflectivity for the photon off gold
                zref = owensRaytracerefrd(dabs(theeta), denergy)
                if ( dphotonweight.gt.0d0 ) then
                    dphotonweight = dphotonweight * zref
                    jsecondaryhits = jsecondaryhits + ihitm
                else
                    aref = Raytraceran()
C                    ---if true the photon was absorbed
                    if ( zref.lt.aref ) goto 955
C                    ---the photon reflected
                    jsecondaryhits = jsecondaryhits + ihitm
                endif
            endif
C            if the photon didn't hit the mirror, it made it to the
C            bottom of the mirror
            if (jhitoutermirror.eq.0) goto 54
            ihitm = ihitm * 2
 50   continue
C bottom of the secondary mirror
 54     Continue
        t = -( ray0(VZ) - z(SECONDARYBOTTOM) ) / rayn(VZ)
        ray0(VX) = ray0(VX) + t * rayn(VX)
        ray0(VY) = ray0(VY) + t * rayn(VY)
        ray0(VZ) = z(SECONDARYBOTTOM)
        dphotonradius = dsqrt(ray0(VX)*ray0(VX)+ray0(VY)*ray0(VY))
        dphotonangle  = datan(ray0(VY)/ray0(VX))
        If (ray0(VX).lt.0.0d0) then
          dphotonangle   = dphotonangle + MPI
        Else if (ray0(VY).lt.0.0d0) then
          dphotonangle   = dphotonangle + 2.0d0 * MPI
        End if
C------ Did the photon hit the housing side wall?
C        the photon is hidden if either X or Y < 5mm
C        OR the photon tries to pass thru the origin
          if((dabs(ray0(VX)).lt.5.0036d0).or.
     &       (dabs(ray0(VY)).lt.5.0036d0).or.
     &       ((ray0(VX)*ray0s(VX)).lt.0.0d0).or.
     &       ((ray0(VY)*ray0s(VY)).lt.0.0d0)) goto 916
C-------Did the photon hit the alignment bar?
        dwalbarangwidth = WALBAR / dphotonradius
        dsectorang = dmod(dphotonangle 
     &                    + dwalbarangwidth/2.0d0, SECTOR)
        If ( dsectorang .lt. dwalbarangwidth ) then
           goto 924
        endif
C END OF PHOTON TRACE THRU SECONDARY MIRROR
C
C------ calculation of the focal plane position
      t = - ray0(VZ) / rayn(VZ)
      dfocalpx     = ray0(VX) + t * rayn(VX)
      dfocalpy     = ray0(VY) + t * rayn(VY)

C     Determine the result code from the number of times each mirror
C     is hit
      if (jprimaryhits.eq.SINGLEOUTERREFLECT) then
         if (jsecondaryhits.eq.SINGLEOUTERREFLECT) then
C            Normal
            jresultcode = 0
            Return
         else if (jsecondaryhits.eq.NOREFLECT) then
C            Primary mirror only
            goto 960
         endif
      else if (jprimaryhits.eq.NOREFLECT) then
         if (jsecondaryhits.eq.SINGLEOUTERREFLECT) then
C            Secondary mirror only
            goto 970
         else if (jsecondaryhits.eq.NOREFLECT) then
C            No mirrors (direct)
            goto 980
         endif
      endif
C     FOR ANY OTHER NUMBER OF HITS THE PATH WAS ABNORMAL
      goto 990

C---- extraordinary end treatment
C910 : hidden by primary housing
 910  jresultcode   = 910
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C911 : hidden by primary housing side wall
 911  jresultcode   = 911
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C915 : hidden by secondary housing
 915  jresultcode   = 915
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C916 : hidden by secondary housing side wall
 916  jresultcode   = 916
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C920 : hidden by 1st alignment bar
 920  jresultcode   = 920
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C921 : hidden by 2nd alignment bar
 921  jresultcode   = 921
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C923 : hidden by 3rd alignment bar
 923  jresultcode   = 923
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C924 : hidden by 4th alignment bar
 924  jresultcode   = 924
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C925 : hidden by 1&14 sector
 925  jresultcode   = 925
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C930 : hidden by primary foil
 930  jresultcode   = 930
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C935 : hidden by secondary foil
 935  jresultcode   = 935
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C940 : absorbed by primary inner mirror
 940  jresultcode   = 940
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C945 : absorbed by secondarr inner mirror
 945  jresultcode   = 945
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C950 : absorbed on primary foil
 950  jresultcode   = 950
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C955 : absorbed on secondary foil
 955  jresultcode   = 955
      dphotonweight = 0d0
      dfocalpx      = 999d0
      dfocalpy      = 999d0
      return

C960 : only primary reflect
 960  jresultcode   = 960
      return

C970 : only secondary reflect
 970  jresultcode   = 970
      return

C980 : no reflect
 980  jresultcode   = 980
      return

C990 : abnormal reflected
 990  jresultcode   = 990
      return

      end


C=====================================================================
      double precision function owensRaytracerefrd (
     &       dincidentangle, denergy)
C Written by Keith Gendreau GSFC
C Modified for variable names by Richard L. Fink GSFC/631
C
C     Reflectivity for Gold-------
C                                  
C     Note- this includes a roughness correction.
C
C     << reflectivity table read >>
C     input  :  dincidentangle / incident angle (radian)
C             :  denergy         / photon energy in keV
C     output :  owensraytracerefrd   / reflectivity
C
C=====================================================================
      implicit none

C Calling sequence variables
      double precision dincidentangle
      double precision denergy

C Local variables
      integer janglebin

C Common variables
      double precision denergytable, dreflectivity
      common /refl/ denergytable(150),dreflectivity(150,0:10000)

C Variables for Parameters
      double precision DEGREES2RADIANS
      parameter (DEGREES2RADIANS=1.745329252d-2)
      
C At one time, raytracing code precomputed all possible reflections
C at all useful energies before tracing anything. This practice ended.
C Now, only one energy is computed when needed. So only element #1
C of denergytable is used/needed.

C Compute the array index for binning up the input angle
C Bin at 1/100 degree per bin
      janglebin = dnint(
     &            100.0d0*(dincidentangle/DEGREES2RADIANS)+0.5d0)

C Only the 1st 1000 entries of dreflectivity are used in current code
      if (janglebin .le. 1000) then
        owensRaytracerefrd = dreflectivity(1,janglebin)
      else
        owensRaytracerefrd =0.0
      endif
 
      return
      end


CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C  Create the reflectivity table
C=====================================================================
      subroutine refmkowens(denergy,dfilmdelta,dfilmbeta,
     &                            ddelta,dbeta,dfilmthick,
     &                            droughness,jenergytableindex)
C Written by Keith Gendreau GSFC 12 April 96 
C Variable update by Richard L. Fink GSFC/631
C
C     << reflectivity table >>
C input :  denergy        / xray energy  in keV
C        :  dfilmdelta        / Optical delta for a contamination layer
C        :  dfilmbeta        / Optical beta for a contamination layer
C         :  ddelta        / Optical delta
C        :  dbeta        / optical constant
C        :  dfilmthick  / Contamination layer thickness
C        :  droughness        / Optical surface roughness param
C        :  jenergytableindex / NO LONGER USED 
C output :  denergytable(150)        / x-ray energy set
C          :  dreflectivity(150,0:10000) / reflectivity table (0.001 deg.mesh )
C
C=====================================================================

      implicit none

C Calling sequence variables
        double precision denergy
        double precision dfilmdelta
        double precision dfilmbeta
        double precision ddelta
        double precision dbeta
        double precision dfilmthick
        double precision droughness
        integer jenergytableindex

C Local variables
        integer janglebin
        double precision dlambda
        double precision dtheta
        double precision dreal
        double precision dimaginary
        double precision dincidentangle

C Variables for COMMON
        double precision denergytable
        double precision dreflectivity
        common /refl/ denergytable(150),dreflectivity(150,0:10000)

C Variables for parameters
        double precision DEGREE2RADIAN
        parameter (DEGREE2RADIAN=1.745329252d-2)
        double precision PI
        parameter (PI=3.1415928d0)

C At one time, raytracing code precomputed all possible reflections
C at all useful energies before tracing anything. This practice ended.
C Now, only one energy is computed when needed. So only element #1
C of denergytable is used/needed.

        denergytable(1) = denergy
        dlambda = 12.39085d0 / denergy
C
C       create reflectivity table values for 1001 bins of width 1/100
C            degree
        do 20 janglebin = 0, 1000
          dincidentangle   = (0.01d0 * DEGREE2RADIAN) 
     &                         * dble(janglebin)
          dtheta = dincidentangle / DEGREE2RADIAN
          call complexfrenz(dfilmdelta,dfilmbeta,ddelta,dbeta,
     &                      dfilmthick,dtheta,dreal,dimaginary,
     &                      dlambda)
          dreflectivity(1,janglebin) = 
     &       (dreal*dreal + dimaginary*dimaginary)
     &             *exp(-(4.0d0*PI*dsin(dincidentangle)*droughness
     &                   *denergy/12.4)**2)
 20     continue
      return
      end
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC



CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     return ln(a+bi) = c+di
C
C       complex math by kcg

      subroutine natlog(a,b,c,d)
      double precision a,b,c,d
      c = dlog(dsqrt(a*a + b*b))
      d = datan(b/a)
      return
      end
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     return sqrt(a+bi) = c+di
C
C       complex math by kcg

      subroutine squareroot(a,b,c,d)
      double precision a,b,c,d
      c = 0.7071067691 * dsqrt( a + dsqrt(a*a+b*b))
      d = b/2.0/c
      return
      end
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     return asin(a+bi) = c+di
C
C       complex math by kcg

      subroutine arcsin(a,b,c,d)
      double precision a,b,c,d,w,z,t,u
      call squareroot(1.0-a*a+b*b,-2*a*b,w,z)
      call natlog(w-b,z+a,t,u)
      c = u
      d = -t
      return
      end
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     return sin(a+bi) = c+di
C
C       complex math by kcg

      subroutine complexsin(a,b,c,d)
      double precision a,b,c,d
      c = 0.5*dsin(a)*(dexp(-b)+ dexp(b))
      d = -0.5*dcos(a)*(dexp(-b) - dexp(b))
      return
      end
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     return cos(a+bi) = c+di
C
C       complex math by kcg

      subroutine complexcos(a,b,c,d)
      double precision a,b,c,d
      c = 0.5*dcos(a)*(dexp(-b)+ dexp(b))
      d = 0.5*dsin(a)*(dexp(-b) - dexp(b))
      return
      end
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     return (a+bi)/(c+di) = x + iy
C
C       complex math by kcg

      subroutine complexratio(a,b,c,d,x,y)
      double precision a,b,c,d,x,y,sum

      sum = c*c + d*d
      x = (a*c + b*d)/sum
      y = (b*c-a*d)/sum

      return
      end
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     routine to compute the complex reflectivity for an xray
C     coming from medium 1 and reflecting off a boundary
C     with media 2.  
C     User inputs delta and betas and a complex incident angle tr1,ti1
C     the program outputs rr12, ri12, tr2,ti2--> the complex
C     reflection components and the complex angle of the trasnmitted
C     wave (note to be made graze again, must have pi/2 subtraction done...)
C
C     note- this is only for s polarization
C
C     Keith Gendreau GSFC   March 1996
C
C

      subroutine complexreflect(delta1,beta1,delta2,beta2,tr1,ti1,
     &     tr2,ti2,rr12,ri12)

      implicit double precision (a-h,o-z)
      data pi/3.1415927410/
      data degtorad/0.0174532924/

      call complexsin(tr1,ti1,a,b)
      call complexratio(1.0-delta1,-beta1,1.0-delta2,-beta2,c,d)
      call arcsin(c*a-d*b,a*d+b*c,tr2,ti2)
      call complexsin(tr2-tr1,ti2-ti1,u,v)
      call complexsin(tr2+tr1,ti2+ti1,x,y)
      call complexratio(u,v,x,y,rr12,ri12)

      return
      end
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     routine to compute the complex reflectivity from a thin film with
C     delta1,beta1 and thickness thick on a substrate of delta2,beta2
C     
C     tr+i*ti = complex angle of graze
C     lambda = wavelength of xrays
C     rr,ri = complex amplitude real and imaginary
C
C     Keith Gendreau GSFC   March 1996
C
C
      subroutine complexfrenz(delta1,beta1,delta2,beta2,thick,
     &     theta,rr,ri,lambda)
      
      implicit double precision (a-h,o-z)
      double precision lambda
      data pi/3.1415927410/
      data degtorad/0.0174532924/

C     first compute the phase lost

      phi=2.0*pi/lambda*thick
      thetag = (theta)*degtorad
      x = dsin(thetag)*dsin(thetag) - 1.0 
      x = x - beta1*beta1+ (1.0-delta1)*(1.0-delta1)
      y = -2.0*(1.0-delta1)*beta1
      aa = 0.7071067691 * dsqrt( x + dsqrt(x*x+y*y))
      bb = y/2.0/aa
      er = 2.0*bb
      ei = -2.0*aa
C      write(*,*) 't', theta, er,ei,phi,lambda,'ff'
      exr = dexp(er*phi) * dcos(ei*phi)
      exi = dexp(er*phi) * dsin(ei*phi)
C
C     now compute the frenzel components

      thetag = (90.0 - theta)*degtorad
      call complexreflect(0.0d0,0.0d0,delta1,beta1,thetag,0.0d0,
     &     tr2,ti2,rr01,ri01)
C      thetag = pi/2.0 - tr2
      thetag = tr2

C      call complexcos(tr2,ti2,tr4,ti4)
C      x= tr4*(1-delta1) - ti4*

      call complexreflect(delta1,beta1,delta2,beta2,thetag,ti2,
     &     tr3,ti3,rr12,ri12)

C  now add it up
      a= rr01 + rr12*exr - ri12*exi
      b= ri01 + ri12*exr + rr12*exi
      ww = rr01*rr12 - ri01*ri12
      xx = ri01*rr12 + rr01*ri12
      c= 1.0 + ww*exr - xx*exi
      d = ww*exi + xx*exr
      sum = c*c + d*d
      rr = (a*c + b*d)/sum
      ri = (b*c-a*d)/sum

      return
      end

C 26 Nov 1996  switch in Allen Owens Gold constants into the gold tables
C Note: before this, kcg used AXAF HETG measurements as reported
C       by Henke 1994.

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C  function to return delta 
C
C    Keith Gendreau   GSFC   March 1996
C
C
C     compound(a,b) gives for componenet a:  compound(a,1) = "Z"
C                                            compound(1,2) = "Xa"
C     so for H12C6O8:
C                     compound(1,1)=1 compound(1,2)=12
C                     compound(2,1)=6 compound(2,2)=6
C                     compound(3,1)=8 compound(3,2)=8
C     elements in this case would be "3"  the number of elements
C
C     e is an energy in eV
C     
C
      function hdelta(e,compound,elements,density)
      implicit double precision (a-h,o-y)
      integer compound(10,2),elements
      integer l
      double precision lambda
      common /henke/ weight(80), henke(80,3,1000), count(80)
      lambda=12390.85/e

      hdelta=0
      sum = 0
      sum2 = 0
      do 5 l=1,elements
         sum = sum + weight(compound(l,1))*compound(l,2)
         sum2 = sum2 + compound(l,2)
 5    continue
      do 10 l=1,elements
         hdelta=hdelta+freal(compound(l,1),e)*compound(l,2)
     &        *1
 10   continue
      hdelta = hdelta *2.701e-6 *density*lambda**2 /sum
      return
      end

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C  function to return beta 
C
C    Keith Gendreau   GSFC   March 1996
C
C
C     compound(a,b) gives for componenet a:  compound(a,1) = "Z"
C                                            compound(1,2) = "Xa"
C     so for H12C6O8:
C                     compound(1,1)=1 compound(1,2)=12
C                     compound(2,1)=6 compound(2,2)=6
C                     compound(3,1)=8 compound(3,2)=8
C     elements in this case would be "3"  the number of elements
C
C     e is an energy in eV
C     

      function hbeta(e,compound,elements,density)
      implicit double precision (a-h,o-y)
      integer compound(10,2),elements
      integer l
      double precision lambda
      common /henke/ weight(80), henke(80,3,1000), count(80)
      lambda=12390.85/e

      hbeta=0
      sum = 0
      sum2 = 0
      do 5 l=1,elements
         sum = sum + weight(compound(l,1))*compound(l,2)
         sum2 = sum2 + compound(l,2)
 5    continue
      do 10 l=1,elements
         hbeta=hbeta+fimg(compound(l,1),e)*compound(l,2)
     &        *1
 10   continue
      hbeta = hbeta *2.701e-6 * density*lambda**2 /sum
      return
      end

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     function to return an interpolated value for f1
C     at energy e from element z
C
C    Keith Gendreau   GSFC   March 1996
C       This is a bit kludgy.  IT could be much more elegant
C     In particular, a better interpolation technique would be 
C     nice....
C

      function freal(z,e)
      implicit double precision (a-h,o-y)
      integer z
      integer l,m
      common /henke/ weight(80), henke(80,3,1000), count(80)
      l = 0
 10   continue
         l = l + 1
      if ((l.le.count(z)).and.(henke(z,1,l).le.e)) goto 10
 20   continue
      m = l-1
C      write(*,*) l,m,henke(z,1,m),henke(z,2,m),count(z),z
      deltax = henke(z,1,l) - henke(z,1,m)
      deltay = henke(z,2,l) - henke(z,2,m)
      freal = deltay/deltax * (e-henke(z,1,m)) + henke(z,2,m)
      return
      end
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     function to return an interpolated value for f1
C     at energy e from element z
C
C    Keith Gendreau   GSFC   March 1996
C       This is a bit kludgy.  IT could be much more elegant
C     In particular, a better interpolation technique would be 
C     nice....
C

      function fimg(z,e)
      implicit double precision (a-h,o-y)
      integer l,m,z
      common /henke/ weight(80), henke(80,3,1000), count(80)
      l = 0
 10   continue
         l = l + 1
      if ((l.le.count(z)).and.(henke(z,1,l).le.e)) goto 10
 20   continue
      m = l-1
      deltax = henke(z,1,l) - henke(z,1,m)
      deltay = henke(z,3,l) - henke(z,3,m)
      fimg = deltay/deltax * (e-henke(z,1,m)) + henke(z,3,m)
      return
      end
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCC  Read in the henke tables- but also read in the atomic weights....


      subroutine henketable()
      double precision weight, henke, count
      common /henke/ weight(80), henke(80,3,1000), count(80)

      weight(1)= 1.00794
      weight(4)= 9.01218
      weight(6) = 12.011
      weight(7) = 14.0067
      weight(8) = 15.9994
      weight(22) = 47.88
      weight(28) = 58.69
      weight(77)= 192.22
      weight(79) = 196.9665

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C        Henke data for h  z=1
C      count(1) = 501
C      henke(1,1, 1 ) = 10 
C      henke(1,2, 1 ) = -9999 
C      henke(1,3, 1 ) = 2.3954e-17 
C      henke(1,1, 2 ) = 10.1617 
C      henke(1,2, 2 ) = -9999 
C      henke(1,3, 2 ) = 2.43414e-17 
C      henke(1,1, 3 ) = 10.3261 
C      henke(1,2, 3 ) = -9999 
C      henke(1,3, 3 ) = 2.47351e-17 
C      henke(1,1, 4 ) = 10.4931 
C      henke(1,2, 4 ) = -9999 
C      henke(1,3, 4 ) = 2.51352e-17 
C      henke(1,1, 5 ) = 10.6628 
C      henke(1,2, 5 ) = -9999 
C      henke(1,3, 5 ) = 2.55417e-17 
C      henke(1,1, 6 ) = 10.8353 
C      henke(1,2, 6 ) = -9999 
C      henke(1,3, 6 ) = 2.59549e-17 
C      henke(1,1, 7 ) = 11.0106 
C      henke(1,2, 7 ) = -9999 
C      henke(1,3, 7 ) = 2.63746e-17 
C      henke(1,1, 8 ) = 11.1886 
C      henke(1,2, 8 ) = -9999 
C      henke(1,3, 8 ) = 2.68012e-17 
C      henke(1,1, 9 ) = 11.3696 
C      henke(1,2, 9 ) = -9999 
C      henke(1,3, 9 ) = 2.72347e-17 
C      henke(1,1, 10 ) = 11.5535 
C      henke(1,2, 10 ) = -9999 
C      henke(1,3, 10 ) = 2.76752e-17 
C      henke(1,1, 11 ) = 11.7404 
C      henke(1,2, 11 ) = -9999 
C      henke(1,3, 11 ) = 2.81229e-17 
C      henke(1,1, 12 ) = 11.9303 
C      henke(1,2, 12 ) = -9999 
C      henke(1,3, 12 ) = 2.85777e-17 
C      henke(1,1, 13 ) = 12.1232 
C      henke(1,2, 13 ) = -9999 
C      henke(1,3, 13 ) = 2.90399e-17 
C      henke(1,1, 14 ) = 12.3193 
C      henke(1,2, 14 ) = -9999 
C      henke(1,3, 14 ) = 2.95096e-17 
C      henke(1,1, 15 ) = 12.5186 
C      henke(1,2, 15 ) = -9999 
C      henke(1,3, 15 ) = 2.99869e-17 
C      henke(1,1, 16 ) = 12.721 
C      henke(1,2, 16 ) = -9999 
C      henke(1,3, 16 ) = 3.0472e-17 
C      henke(1,1, 17 ) = 12.9268 
C      henke(1,2, 17 ) = -9999 
C      henke(1,3, 17 ) = 3.09648e-17 
C      henke(1,1, 18 ) = 13.1359 
C      henke(1,2, 18 ) = -9999 
C      henke(1,3, 18 ) = 3.14656e-17 
C      henke(1,1, 19 ) = 13.3483 
C      henke(1,2, 19 ) = -9999 
C      henke(1,3, 19 ) = 3.19746e-17 
C      henke(1,1, 20 ) = 13.5642 
C      henke(1,2, 20 ) = -9999 
C      henke(1,3, 20 ) = 3.24917e-17 
C      henke(1,1, 21 ) = 13.7836 
C      henke(1,2, 21 ) = -9999 
C      henke(1,3, 21 ) = 3.30173e-17 
C      henke(1,1, 22 ) = 14.0066 
C      henke(1,2, 22 ) = -9999 
C      henke(1,3, 22 ) = 3.35513e-17 
C      henke(1,1, 23 ) = 14.2331 
C      henke(1,2, 23 ) = -9999 
C      henke(1,3, 23 ) = 3.4094e-17 
C      henke(1,1, 24 ) = 14.4633 
C      henke(1,2, 24 ) = -9999 
C      henke(1,3, 24 ) = 3.46454e-17 
C      henke(1,1, 25 ) = 14.6973 
C      henke(1,2, 25 ) = -9999 
C      henke(1,3, 25 ) = 3.52058e-17 
C      henke(1,1, 26 ) = 14.935 
C      henke(1,2, 26 ) = -9999 
C      henke(1,3, 26 ) = 3.57752e-17 
C      henke(1,1, 27 ) = 15.1765 
C      henke(1,2, 27 ) = -9999 
C      henke(1,3, 27 ) = 3.63538e-17 
C      henke(1,1, 28 ) = 15.422 
C      henke(1,2, 28 ) = -9999 
C      henke(1,3, 28 ) = 3.69418e-17 
C      henke(1,1, 29 ) = 15.6714 
C      henke(1,2, 29 ) = -9999 
C      henke(1,3, 29 ) = 3.75393e-17 
C      henke(1,1, 30 ) = 15.9 
C      henke(1,2, 30 ) = -9999 
C      henke(1,3, 30 ) = 3.80868e-17 
C      henke(1,1, 31 ) = 16.1 
C      henke(1,2, 31 ) = -9999 
C      henke(1,3, 31 ) = 6.11915e-15 
C      henke(1,1, 32 ) = 16.1825 
C      henke(1,2, 32 ) = -9999 
C      henke(1,3, 32 ) = 3.92474e-13 
C      henke(1,1, 33 ) = 16.4442 
C      henke(1,2, 33 ) = -9999 
C      henke(1,3, 33 ) = 1.85104e-07 
C      henke(1,1, 34 ) = 16.7102 
C      henke(1,2, 34 ) = -9999 
C      henke(1,3, 34 ) = 0.0873013 
C      henke(1,1, 35 ) = 16.9805 
C      henke(1,2, 35 ) = -9999 
C      henke(1,3, 35 ) = 0.960229 
C      henke(1,1, 36 ) = 17.2551 
C      henke(1,2, 36 ) = -9999 
C      henke(1,3, 36 ) = 0.931364 
C      henke(1,1, 37 ) = 17.5342 
C      henke(1,2, 37 ) = -9999 
C      henke(1,3, 37 ) = 0.903367 
C      henke(1,1, 38 ) = 17.8178 
C      henke(1,2, 38 ) = -9999 
C      henke(1,3, 38 ) = 0.876211 
C      henke(1,1, 39 ) = 18.106 
C      henke(1,2, 39 ) = -9999 
C      henke(1,3, 39 ) = 0.849873 
C      henke(1,1, 40 ) = 18.3989 
C      henke(1,2, 40 ) = -9999 
C      henke(1,3, 40 ) = 0.824325 
C      henke(1,1, 41 ) = 18.6964 
C      henke(1,2, 41 ) = -9999 
C      henke(1,3, 41 ) = 0.799546 
C      henke(1,1, 42 ) = 18.9988 
C      henke(1,2, 42 ) = -9999 
C      henke(1,3, 42 ) = 0.775511 
C      henke(1,1, 43 ) = 19.3061 
C      henke(1,2, 43 ) = -9999 
C      henke(1,3, 43 ) = 0.752199 
C      henke(1,1, 44 ) = 19.6184 
C      henke(1,2, 44 ) = -9999 
C      henke(1,3, 44 ) = 0.729131 
C      henke(1,1, 45 ) = 19.9357 
C      henke(1,2, 45 ) = -9999 
C      henke(1,3, 45 ) = 0.705642 
C      henke(1,1, 46 ) = 20.2582 
C      henke(1,2, 46 ) = -9999 
C      henke(1,3, 46 ) = 0.682908 
C      henke(1,1, 47 ) = 20.5858 
C      henke(1,2, 47 ) = -9999 
C      henke(1,3, 47 ) = 0.660907 
C      henke(1,1, 48 ) = 20.9188 
C      henke(1,2, 48 ) = -9999 
C      henke(1,3, 48 ) = 0.639615 
C      henke(1,1, 49 ) = 21.2571 
C      henke(1,2, 49 ) = -9999 
C      henke(1,3, 49 ) = 0.619009 
C      henke(1,1, 50 ) = 21.6009 
C      henke(1,2, 50 ) = -9999 
C      henke(1,3, 50 ) = 0.599067 
C      henke(1,1, 51 ) = 21.9503 
C      henke(1,2, 51 ) = -9999 
C      henke(1,3, 51 ) = 0.579767 
C      henke(1,1, 52 ) = 22.3053 
C      henke(1,2, 52 ) = -9999 
C      henke(1,3, 52 ) = 0.561089 
C      henke(1,1, 53 ) = 22.6661 
C      henke(1,2, 53 ) = -9999 
C      henke(1,3, 53 ) = 0.543013 
C      henke(1,1, 54 ) = 23.0327 
C      henke(1,2, 54 ) = -9999 
C      henke(1,3, 54 ) = 0.525519 
C      henke(1,1, 55 ) = 23.4053 
C      henke(1,2, 55 ) = -9999 
C      henke(1,3, 55 ) = 0.508588 
C      henke(1,1, 56 ) = 23.7838 
C      henke(1,2, 56 ) = -9999 
C      henke(1,3, 56 ) = 0.492203 
C      henke(1,1, 57 ) = 24.1685 
C      henke(1,2, 57 ) = -9999 
C      henke(1,3, 57 ) = 0.476347 
C      henke(1,1, 58 ) = 24.5594 
C      henke(1,2, 58 ) = -9999 
C      henke(1,3, 58 ) = 0.460795 
C      henke(1,1, 59 ) = 24.9566 
C      henke(1,2, 59 ) = -9999 
C      henke(1,3, 59 ) = 0.445595 
C      henke(1,1, 60 ) = 25.3603 
C      henke(1,2, 60 ) = -9999 
C      henke(1,3, 60 ) = 0.430897 
C      henke(1,1, 61 ) = 25.7705 
C      henke(1,2, 61 ) = -9999 
C      henke(1,3, 61 ) = 0.416683 
C      henke(1,1, 62 ) = 26.1873 
C      henke(1,2, 62 ) = -9999 
C      henke(1,3, 62 ) = 0.402938 
C      henke(1,1, 63 ) = 26.6109 
C      henke(1,2, 63 ) = -9999 
C      henke(1,3, 63 ) = 0.389647 
C      henke(1,1, 64 ) = 27.0413 
C      henke(1,2, 64 ) = -9999 
C      henke(1,3, 64 ) = 0.376794 
C      henke(1,1, 65 ) = 27.4786 
C      henke(1,2, 65 ) = -9999 
C      henke(1,3, 65 ) = 0.364365 
C      henke(1,1, 66 ) = 27.9231 
C      henke(1,2, 66 ) = -9999 
C      henke(1,3, 66 ) = 0.352346 
C      henke(1,1, 67 ) = 28.3747 
C      henke(1,2, 67 ) = -9999 
C      henke(1,3, 67 ) = 0.340723 
C      henke(1,1, 68 ) = 28.8337 
C      henke(1,2, 68 ) = -9999 
C      henke(1,3, 68 ) = 0.329484 
C      henke(1,1, 69 ) = 29.3 
C      henke(1,2, 69 ) = 1.07342 
C      henke(1,3, 69 ) = 0.318616 
C      henke(1,1, 70 ) = 29.7739 
C      henke(1,2, 70 ) = 1.07482 
C      henke(1,3, 70 ) = 0.308106 
C      henke(1,1, 71 ) = 30.2555 
C      henke(1,2, 71 ) = 1.07577 
C      henke(1,3, 71 ) = 0.298515 
C      henke(1,1, 72 ) = 30.7449 
C      henke(1,2, 72 ) = 1.07696 
C      henke(1,3, 72 ) = 0.289718 
C      henke(1,1, 73 ) = 31.2421 
C      henke(1,2, 73 ) = 1.07825 
C      henke(1,3, 73 ) = 0.281082 
C      henke(1,1, 74 ) = 31.7475 
C      henke(1,2, 74 ) = 1.0794 
C      henke(1,3, 74 ) = 0.2726 
C      henke(1,1, 75 ) = 32.2609 
C      henke(1,2, 75 ) = 1.08039 
C      henke(1,3, 75 ) = 0.264377 
C      henke(1,1, 76 ) = 32.7827 
C      henke(1,2, 76 ) = 1.08123 
C      henke(1,3, 76 ) = 0.256403 
C      henke(1,1, 77 ) = 33.313 
C      henke(1,2, 77 ) = 1.08195 
C      henke(1,3, 77 ) = 0.248667 
C      henke(1,1, 78 ) = 33.8518 
C      henke(1,2, 78 ) = 1.08254 
C      henke(1,3, 78 ) = 0.241163 
C      henke(1,1, 79 ) = 34.3993 
C      henke(1,2, 79 ) = 1.083 
C      henke(1,3, 79 ) = 0.233886 
C      henke(1,1, 80 ) = 34.9557 
C      henke(1,2, 80 ) = 1.08337 
C      henke(1,3, 80 ) = 0.226829 
C      henke(1,1, 81 ) = 35.5211 
C      henke(1,2, 81 ) = 1.08362 
C      henke(1,3, 81 ) = 0.21996 
C      henke(1,1, 82 ) = 36.0956 
C      henke(1,2, 82 ) = 1.08376 
C      henke(1,3, 82 ) = 0.213297 
C      henke(1,1, 83 ) = 36.6794 
C      henke(1,2, 83 ) = 1.0838 
C      henke(1,3, 83 ) = 0.206836 
C      henke(1,1, 84 ) = 37.2727 
C      henke(1,2, 84 ) = 1.08375 
C      henke(1,3, 84 ) = 0.200567 
C      henke(1,1, 85 ) = 37.8755 
C      henke(1,2, 85 ) = 1.08362 
C      henke(1,3, 85 ) = 0.194485 
C      henke(1,1, 86 ) = 38.4882 
C      henke(1,2, 86 ) = 1.08341 
C      henke(1,3, 86 ) = 0.188585 
C      henke(1,1, 87 ) = 39.1107 
C      henke(1,2, 87 ) = 1.08312 
C      henke(1,3, 87 ) = 0.182864 
C      henke(1,1, 88 ) = 39.7432 
C      henke(1,2, 88 ) = 1.08278 
C      henke(1,3, 88 ) = 0.177319 
C      henke(1,1, 89 ) = 40.3861 
C      henke(1,2, 89 ) = 1.08238 
C      henke(1,3, 89 ) = 0.171944 
C      henke(1,1, 90 ) = 41.0393 
C      henke(1,2, 90 ) = 1.08198 
C      henke(1,3, 90 ) = 0.166725 
C      henke(1,1, 91 ) = 41.7031 
C      henke(1,2, 91 ) = 1.08151 
C      henke(1,3, 91 ) = 0.161576 
C      henke(1,1, 92 ) = 42.3776 
C      henke(1,2, 92 ) = 1.08094 
C      henke(1,3, 92 ) = 0.156586 
C      henke(1,1, 93 ) = 43.063 
C      henke(1,2, 93 ) = 1.08032 
C      henke(1,3, 93 ) = 0.15175 
C      henke(1,1, 94 ) = 43.7595 
C      henke(1,2, 94 ) = 1.07964 
C      henke(1,3, 94 ) = 0.147051 
C      henke(1,1, 95 ) = 44.4673 
C      henke(1,2, 95 ) = 1.07892 
C      henke(1,3, 95 ) = 0.142495 
C      henke(1,1, 96 ) = 45.1865 
C      henke(1,2, 96 ) = 1.07815 
C      henke(1,3, 96 ) = 0.138078 
C      henke(1,1, 97 ) = 45.9174 
C      henke(1,2, 97 ) = 1.07735 
C      henke(1,3, 97 ) = 0.133798 
C      henke(1,1, 98 ) = 46.66 
C      henke(1,2, 98 ) = 1.07651 
C      henke(1,3, 98 ) = 0.12965 
C      henke(1,1, 99 ) = 47.4147 
C      henke(1,2, 99 ) = 1.07564 
C      henke(1,3, 99 ) = 0.125634 
C      henke(1,1, 100 ) = 48.1816 
C      henke(1,2, 100 ) = 1.07476 
C      henke(1,3, 100 ) = 0.121741 
C      henke(1,1, 101 ) = 48.9609 
C      henke(1,2, 101 ) = 1.07386 
C      henke(1,3, 101 ) = 0.11796 
C      henke(1,1, 102 ) = 49.7528 
C      henke(1,2, 102 ) = 1.07294 
C      henke(1,3, 102 ) = 0.114297 
C      henke(1,1, 103 ) = 50.5576 
C      henke(1,2, 103 ) = 1.07201 
C      henke(1,3, 103 ) = 0.110729 
C      henke(1,1, 104 ) = 51.3753 
C      henke(1,2, 104 ) = 1.07105 
C      henke(1,3, 104 ) = 0.107265 
C      henke(1,1, 105 ) = 52.2062 
C      henke(1,2, 105 ) = 1.07008 
C      henke(1,3, 105 ) = 0.10391 
C      henke(1,1, 106 ) = 53.0506 
C      henke(1,2, 106 ) = 1.06908 
C      henke(1,3, 106 ) = 0.100659 
C      henke(1,1, 107 ) = 53.9087 
C      henke(1,2, 107 ) = 1.06808 
C      henke(1,3, 107 ) = 0.0975106 
C      henke(1,1, 108 ) = 54.7806 
C      henke(1,2, 108 ) = 1.06708 
C      henke(1,3, 108 ) = 0.0944602 
C      henke(1,1, 109 ) = 55.6667 
C      henke(1,2, 109 ) = 1.06607 
C      henke(1,3, 109 ) = 0.0915051 
C      henke(1,1, 110 ) = 56.567 
C      henke(1,2, 110 ) = 1.06505 
C      henke(1,3, 110 ) = 0.0886427 
C      henke(1,1, 111 ) = 57.482 
C      henke(1,2, 111 ) = 1.06404 
C      henke(1,3, 111 ) = 0.0858697 
C      henke(1,1, 112 ) = 58.4117 
C      henke(1,2, 112 ) = 1.06302 
C      henke(1,3, 112 ) = 0.0831839 
C      henke(1,1, 113 ) = 59.3564 
C      henke(1,2, 113 ) = 1.06202 
C      henke(1,3, 113 ) = 0.0805822 
C      henke(1,1, 114 ) = 60.3165 
C      henke(1,2, 114 ) = 1.06102 
C      henke(1,3, 114 ) = 0.0780614 
C      henke(1,1, 115 ) = 61.2921 
C      henke(1,2, 115 ) = 1.06005 
C      henke(1,3, 115 ) = 0.0756082 
C      henke(1,1, 116 ) = 62.2834 
C      henke(1,2, 116 ) = 1.05907 
C      henke(1,3, 116 ) = 0.0732062 
C      henke(1,1, 117 ) = 63.2908 
C      henke(1,2, 117 ) = 1.05809 
C      henke(1,3, 117 ) = 0.0708702 
C      henke(1,1, 118 ) = 64.3145 
C      henke(1,2, 118 ) = 1.05711 
C      henke(1,3, 118 ) = 0.0685836 
C      henke(1,1, 119 ) = 65.3547 
C      henke(1,2, 119 ) = 1.05611 
C      henke(1,3, 119 ) = 0.0663707 
C      henke(1,1, 120 ) = 66.4118 
C      henke(1,2, 120 ) = 1.05511 
C      henke(1,3, 120 ) = 0.0642289 
C      henke(1,1, 121 ) = 67.4859 
C      henke(1,2, 121 ) = 1.05411 
C      henke(1,3, 121 ) = 0.0621564 
C      henke(1,1, 122 ) = 68.5775 
C      henke(1,2, 122 ) = 1.05312 
C      henke(1,3, 122 ) = 0.0601513 
C      henke(1,1, 123 ) = 69.6867 
C      henke(1,2, 123 ) = 1.05213 
C      henke(1,3, 123 ) = 0.0582104 
C      henke(1,1, 124 ) = 70.8138 
C      henke(1,2, 124 ) = 1.05114 
C      henke(1,3, 124 ) = 0.0563323 
C      henke(1,1, 125 ) = 71.9591 
C      henke(1,2, 125 ) = 1.05017 
C      henke(1,3, 125 ) = 0.054515 
C      henke(1,1, 126 ) = 73.123 
C      henke(1,2, 126 ) = 1.0492 
C      henke(1,3, 126 ) = 0.0527566 
C      henke(1,1, 127 ) = 74.3057 
C      henke(1,2, 127 ) = 1.04825 
C      henke(1,3, 127 ) = 0.0510546 
C      henke(1,1, 128 ) = 75.5076 
C      henke(1,2, 128 ) = 1.0473 
C      henke(1,3, 128 ) = 0.0494071 
C      henke(1,1, 129 ) = 76.7289 
C      henke(1,2, 129 ) = 1.04637 
C      henke(1,3, 129 ) = 0.0478129 
C      henke(1,1, 130 ) = 77.9699 
C      henke(1,2, 130 ) = 1.04544 
C      henke(1,3, 130 ) = 0.0462703 
C      henke(1,1, 131 ) = 79.231 
C      henke(1,2, 131 ) = 1.04453 
C      henke(1,3, 131 ) = 0.0447771 
C      henke(1,1, 132 ) = 80.5125 
C      henke(1,2, 132 ) = 1.04364 
C      henke(1,3, 132 ) = 0.043332 
C      henke(1,1, 133 ) = 81.8147 
C      henke(1,2, 133 ) = 1.04276 
C      henke(1,3, 133 ) = 0.0419309 
C      henke(1,1, 134 ) = 83.138 
C      henke(1,2, 134 ) = 1.0419 
C      henke(1,3, 134 ) = 0.0405709 
C      henke(1,1, 135 ) = 84.4827 
C      henke(1,2, 135 ) = 1.04105 
C      henke(1,3, 135 ) = 0.0392348 
C      henke(1,1, 136 ) = 85.8491 
C      henke(1,2, 136 ) = 1.0402 
C      henke(1,3, 136 ) = 0.0379426 
C      henke(1,1, 137 ) = 87.2377 
C      henke(1,2, 137 ) = 1.03936 
C      henke(1,3, 137 ) = 0.036692 
C      henke(1,1, 138 ) = 88.6487 
C      henke(1,2, 138 ) = 1.03853 
C      henke(1,3, 138 ) = 0.0354828 
C      henke(1,1, 139 ) = 90.0825 
C      henke(1,2, 139 ) = 1.0377 
C      henke(1,3, 139 ) = 0.0343137 
C      henke(1,1, 140 ) = 91.5395 
C      henke(1,2, 140 ) = 1.03689 
C      henke(1,3, 140 ) = 0.0331831 
C      henke(1,1, 141 ) = 93.0201 
C      henke(1,2, 141 ) = 1.03609 
C      henke(1,3, 141 ) = 0.0320897 
C      henke(1,1, 142 ) = 94.5246 
C      henke(1,2, 142 ) = 1.03531 
C      henke(1,3, 142 ) = 0.0310324 
C      henke(1,1, 143 ) = 96.0535 
C      henke(1,2, 143 ) = 1.03453 
C      henke(1,3, 143 ) = 0.0300101 
C      henke(1,1, 144 ) = 97.6071 
C      henke(1,2, 144 ) = 1.03377 
C      henke(1,3, 144 ) = 0.0290214 
C      henke(1,1, 145 ) = 99.1858 
C      henke(1,2, 145 ) = 1.03302 
C      henke(1,3, 145 ) = 0.0280652 
C      henke(1,1, 146 ) = 100.79 
C      henke(1,2, 146 ) = 1.03229 
C      henke(1,3, 146 ) = 0.0271368 
C      henke(1,1, 147 ) = 102.42 
C      henke(1,2, 147 ) = 1.03156 
C      henke(1,3, 147 ) = 0.0262374 
C      henke(1,1, 148 ) = 104.077 
C      henke(1,2, 148 ) = 1.03085 
C      henke(1,3, 148 ) = 0.0253737 
C      henke(1,1, 149 ) = 105.76 
C      henke(1,2, 149 ) = 1.03015 
C      henke(1,3, 149 ) = 0.0245376 
C      henke(1,1, 150 ) = 107.471 
C      henke(1,2, 150 ) = 1.02946 
C      henke(1,3, 150 ) = 0.023729 
C      henke(1,1, 151 ) = 109.209 
C      henke(1,2, 151 ) = 1.02879 
C      henke(1,3, 151 ) = 0.0229472 
C      henke(1,1, 152 ) = 110.975 
C      henke(1,2, 152 ) = 1.02813 
C      henke(1,3, 152 ) = 0.0221911 
C      henke(1,1, 153 ) = 112.77 
C      henke(1,2, 153 ) = 1.02749 
C      henke(1,3, 153 ) = 0.0214598 
C      henke(1,1, 154 ) = 114.594 
C      henke(1,2, 154 ) = 1.02685 
C      henke(1,3, 154 ) = 0.0207528 
C      henke(1,1, 155 ) = 116.448 
C      henke(1,2, 155 ) = 1.02623 
C      henke(1,3, 155 ) = 0.020069 
C      henke(1,1, 156 ) = 118.331 
C      henke(1,2, 156 ) = 1.02562 
C      henke(1,3, 156 ) = 0.0194077 
C      henke(1,1, 157 ) = 120.245 
C      henke(1,2, 157 ) = 1.02503 
C      henke(1,3, 157 ) = 0.0187681 
C      henke(1,1, 158 ) = 122.19 
C      henke(1,2, 158 ) = 1.02445 
C      henke(1,3, 158 ) = 0.0181496 
C      henke(1,1, 159 ) = 124.166 
C      henke(1,2, 159 ) = 1.02389 
C      henke(1,3, 159 ) = 0.0175503 
C      henke(1,1, 160 ) = 126.175 
C      henke(1,2, 160 ) = 1.02334 
C      henke(1,3, 160 ) = 0.016958 
C      henke(1,1, 161 ) = 128.215 
C      henke(1,2, 161 ) = 1.02279 
C      henke(1,3, 161 ) = 0.0163857 
C      henke(1,1, 162 ) = 130.289 
C      henke(1,2, 162 ) = 1.02225 
C      henke(1,3, 162 ) = 0.0158328 
C      henke(1,1, 163 ) = 132.397 
C      henke(1,2, 163 ) = 1.02172 
C      henke(1,3, 163 ) = 0.0152983 
C      henke(1,1, 164 ) = 134.538 
C      henke(1,2, 164 ) = 1.0212 
C      henke(1,3, 164 ) = 0.014782 
C      henke(1,1, 165 ) = 136.714 
C      henke(1,2, 165 ) = 1.02069 
C      henke(1,3, 165 ) = 0.0142832 
C      henke(1,1, 166 ) = 138.925 
C      henke(1,2, 166 ) = 1.02019 
C      henke(1,3, 166 ) = 0.0138012 
C      henke(1,1, 167 ) = 141.172 
C      henke(1,2, 167 ) = 1.0197 
C      henke(1,3, 167 ) = 0.0133353 
C      henke(1,1, 168 ) = 143.456 
C      henke(1,2, 168 ) = 1.01923 
C      henke(1,3, 168 ) = 0.0128851 
C      henke(1,1, 169 ) = 145.776 
C      henke(1,2, 169 ) = 1.01876 
C      henke(1,3, 169 ) = 0.0124503 
C      henke(1,1, 170 ) = 148.134 
C      henke(1,2, 170 ) = 1.0183 
C      henke(1,3, 170 ) = 0.0120301 
C      henke(1,1, 171 ) = 150.53 
C      henke(1,2, 171 ) = 1.01785 
C      henke(1,3, 171 ) = 0.011624 
C      henke(1,1, 172 ) = 152.964 
C      henke(1,2, 172 ) = 1.01741 
C      henke(1,3, 172 ) = 0.0112318 
C      henke(1,1, 173 ) = 155.439 
C      henke(1,2, 173 ) = 1.01698 
C      henke(1,3, 173 ) = 0.0108526 
C      henke(1,1, 174 ) = 157.953 
C      henke(1,2, 174 ) = 1.01657 
C      henke(1,3, 174 ) = 0.0104863 
C      henke(1,1, 175 ) = 160.507 
C      henke(1,2, 175 ) = 1.01616 
C      henke(1,3, 175 ) = 0.0101325 
C      henke(1,1, 176 ) = 163.103 
C      henke(1,2, 176 ) = 1.01576 
C      henke(1,3, 176 ) = 0.00978989 
C      henke(1,1, 177 ) = 165.742 
C      henke(1,2, 177 ) = 1.01537 
C      henke(1,3, 177 ) = 0.00945798 
C      henke(1,1, 178 ) = 168.422 
C      henke(1,2, 178 ) = 1.01499 
C      henke(1,3, 178 ) = 0.00913121 
C      henke(1,1, 179 ) = 171.146 
C      henke(1,2, 179 ) = 1.01462 
C      henke(1,3, 179 ) = 0.00881506 
C      henke(1,1, 180 ) = 173.915 
C      henke(1,2, 180 ) = 1.01425 
C      henke(1,3, 180 ) = 0.00850979 
C      henke(1,1, 181 ) = 176.727 
C      henke(1,2, 181 ) = 1.0139 
C      henke(1,3, 181 ) = 0.00821516 
C      henke(1,1, 182 ) = 179.586 
C      henke(1,2, 182 ) = 1.01354 
C      henke(1,3, 182 ) = 0.0079308 
C      henke(1,1, 183 ) = 182.491 
C      henke(1,2, 183 ) = 1.0132 
C      henke(1,3, 183 ) = 0.0076563 
C      henke(1,1, 184 ) = 185.442 
C      henke(1,2, 184 ) = 1.01286 
C      henke(1,3, 184 ) = 0.00739119 
C      henke(1,1, 185 ) = 188.442 
C      henke(1,2, 185 ) = 1.01253 
C      henke(1,3, 185 ) = 0.00713519 
C      henke(1,1, 186 ) = 191.489 
C      henke(1,2, 186 ) = 1.01221 
C      henke(1,3, 186 ) = 0.00688805 
C      henke(1,1, 187 ) = 194.587 
C      henke(1,2, 187 ) = 1.0119 
C      henke(1,3, 187 ) = 0.00664962 
C      henke(1,1, 188 ) = 197.734 
C      henke(1,2, 188 ) = 1.01159 
C      henke(1,3, 188 ) = 0.00641948 
C      henke(1,1, 189 ) = 200.932 
C      henke(1,2, 189 ) = 1.01129 
C      henke(1,3, 189 ) = 0.00619731 
C      henke(1,1, 190 ) = 204.182 
C      henke(1,2, 190 ) = 1.011 
C      henke(1,3, 190 ) = 0.00598257 
C      henke(1,1, 191 ) = 207.485 
C      henke(1,2, 191 ) = 1.01071 
C      henke(1,3, 191 ) = 0.00577539 
C      henke(1,1, 192 ) = 210.84 
C      henke(1,2, 192 ) = 1.01043 
C      henke(1,3, 192 ) = 0.00557553 
C      henke(1,1, 193 ) = 214.251 
C      henke(1,2, 193 ) = 1.01016 
C      henke(1,3, 193 ) = 0.00538225 
C      henke(1,1, 194 ) = 217.716 
C      henke(1,2, 194 ) = 1.00989 
C      henke(1,3, 194 ) = 0.00519584 
C      henke(1,1, 195 ) = 221.237 
C      henke(1,2, 195 ) = 1.00963 
C      henke(1,3, 195 ) = 0.00501608 
C      henke(1,1, 196 ) = 224.816 
C      henke(1,2, 196 ) = 1.00938 
C      henke(1,3, 196 ) = 0.00484241 
C      henke(1,1, 197 ) = 228.452 
C      henke(1,2, 197 ) = 1.00913 
C      henke(1,3, 197 ) = 0.00467475 
C      henke(1,1, 198 ) = 232.147 
C      henke(1,2, 198 ) = 1.00889 
C      henke(1,3, 198 ) = 0.00451287 
C      henke(1,1, 199 ) = 235.902 
C      henke(1,2, 199 ) = 1.00866 
C      henke(1,3, 199 ) = 0.00435661 
C      henke(1,1, 200 ) = 239.717 
C      henke(1,2, 200 ) = 1.00843 
C      henke(1,3, 200 ) = 0.00420577 
C      henke(1,1, 201 ) = 243.595 
C      henke(1,2, 201 ) = 1.00821 
C      henke(1,3, 201 ) = 0.00406014 
C      henke(1,1, 202 ) = 247.535 
C      henke(1,2, 202 ) = 1.00799 
C      henke(1,3, 202 ) = 0.00391955 
C      henke(1,1, 203 ) = 251.538 
C      henke(1,2, 203 ) = 1.00777 
C      henke(1,3, 203 ) = 0.00378382 
C      henke(1,1, 204 ) = 255.607 
C      henke(1,2, 204 ) = 1.00757 
C      henke(1,3, 204 ) = 0.00365277 
C      henke(1,1, 205 ) = 259.741 
C      henke(1,2, 205 ) = 1.00737 
C      henke(1,3, 205 ) = 0.00352625 
C      henke(1,1, 206 ) = 263.942 
C      henke(1,2, 206 ) = 1.00717 
C      henke(1,3, 206 ) = 0.00340413 
C      henke(1,1, 207 ) = 268.211 
C      henke(1,2, 207 ) = 1.00698 
C      henke(1,3, 207 ) = 0.00328624 
C      henke(1,1, 208 ) = 272.549 
C      henke(1,2, 208 ) = 1.00679 
C      henke(1,3, 208 ) = 0.0031724 
C      henke(1,1, 209 ) = 276.957 
C      henke(1,2, 209 ) = 1.00661 
C      henke(1,3, 209 ) = 0.00306252 
C      henke(1,1, 210 ) = 281.437 
C      henke(1,2, 210 ) = 1.00643 
C      henke(1,3, 210 ) = 0.00295645 
C      henke(1,1, 211 ) = 285.989 
C      henke(1,2, 211 ) = 1.00626 
C      henke(1,3, 211 ) = 0.00285407 
C      henke(1,1, 212 ) = 290.615 
C      henke(1,2, 212 ) = 1.00609 
C      henke(1,3, 212 ) = 0.00275523 
C      henke(1,1, 213 ) = 295.315 
C      henke(1,2, 213 ) = 1.00592 
C      henke(1,3, 213 ) = 0.00265984 
C      henke(1,1, 214 ) = 300.092 
C      henke(1,2, 214 ) = 1.00577 
C      henke(1,3, 214 ) = 0.00256773 
C      henke(1,1, 215 ) = 304.945 
C      henke(1,2, 215 ) = 1.00561 
C      henke(1,3, 215 ) = 0.00247864 
C      henke(1,1, 216 ) = 309.878 
C      henke(1,2, 216 ) = 1.00546 
C      henke(1,3, 216 ) = 0.00239241 
C      henke(1,1, 217 ) = 314.89 
C      henke(1,2, 217 ) = 1.00531 
C      henke(1,3, 217 ) = 0.00230717 
C      henke(1,1, 218 ) = 319.983 
C      henke(1,2, 218 ) = 1.00517 
C      henke(1,3, 218 ) = 0.0022244 
C      henke(1,1, 219 ) = 325.158 
C      henke(1,2, 219 ) = 1.00503 
C      henke(1,3, 219 ) = 0.0021446 
C      henke(1,1, 220 ) = 330.418 
C      henke(1,2, 220 ) = 1.00489 
C      henke(1,3, 220 ) = 0.00206767 
C      henke(1,1, 221 ) = 335.762 
C      henke(1,2, 221 ) = 1.00476 
C      henke(1,3, 221 ) = 0.00199351 
C      henke(1,1, 222 ) = 341.192 
C      henke(1,2, 222 ) = 1.00463 
C      henke(1,3, 222 ) = 0.00192206 
C      henke(1,1, 223 ) = 346.711 
C      henke(1,2, 223 ) = 1.0045 
C      henke(1,3, 223 ) = 0.00185312 
C      henke(1,1, 224 ) = 352.319 
C      henke(1,2, 224 ) = 1.00438 
C      henke(1,3, 224 ) = 0.00178664 
C      henke(1,1, 225 ) = 358.017 
C      henke(1,2, 225 ) = 1.00426 
C      henke(1,3, 225 ) = 0.00172253 
C      henke(1,1, 226 ) = 363.808 
C      henke(1,2, 226 ) = 1.00414 
C      henke(1,3, 226 ) = 0.00166075 
C      henke(1,1, 227 ) = 369.692 
C      henke(1,2, 227 ) = 1.00402 
C      henke(1,3, 227 ) = 0.00160119 
C      henke(1,1, 228 ) = 375.672 
C      henke(1,2, 228 ) = 1.00391 
C      henke(1,3, 228 ) = 0.00154377 
C      henke(1,1, 229 ) = 381.748 
C      henke(1,2, 229 ) = 1.0038 
C      henke(1,3, 229 ) = 0.00148837 
C      henke(1,1, 230 ) = 387.922 
C      henke(1,2, 230 ) = 1.0037 
C      henke(1,3, 230 ) = 0.00143498 
C      henke(1,1, 231 ) = 394.197 
C      henke(1,2, 231 ) = 1.00359 
C      henke(1,3, 231 ) = 0.00138356 
C      henke(1,1, 232 ) = 400.573 
C      henke(1,2, 232 ) = 1.00349 
C      henke(1,3, 232 ) = 0.00133393 
C      henke(1,1, 233 ) = 407.052 
C      henke(1,2, 233 ) = 1.0034 
C      henke(1,3, 233 ) = 0.00128607 
C      henke(1,1, 234 ) = 413.635 
C      henke(1,2, 234 ) = 1.0033 
C      henke(1,3, 234 ) = 0.00123994 
C      henke(1,1, 235 ) = 420.326 
C      henke(1,2, 235 ) = 1.00321 
C      henke(1,3, 235 ) = 0.00119547 
C      henke(1,1, 236 ) = 427.124 
C      henke(1,2, 236 ) = 1.00312 
C      henke(1,3, 236 ) = 0.00115259 
C      henke(1,1, 237 ) = 434.032 
C      henke(1,2, 237 ) = 1.00303 
C      henke(1,3, 237 ) = 0.00111124 
C      henke(1,1, 238 ) = 441.052 
C      henke(1,2, 238 ) = 1.00294 
C      henke(1,3, 238 ) = 0.00107134 
C      henke(1,1, 239 ) = 448.186 
C      henke(1,2, 239 ) = 1.00286 
C      henke(1,3, 239 ) = 0.00103287 
C      henke(1,1, 240 ) = 455.435 
C      henke(1,2, 240 ) = 1.00278 
C      henke(1,3, 240 ) = 0.000995812 
C      henke(1,1, 241 ) = 462.802 
C      henke(1,2, 241 ) = 1.0027 
C      henke(1,3, 241 ) = 0.000960079 
C      henke(1,1, 242 ) = 470.287 
C      henke(1,2, 242 ) = 1.00262 
C      henke(1,3, 242 ) = 0.000925627 
C      henke(1,1, 243 ) = 477.894 
C      henke(1,2, 243 ) = 1.00255 
C      henke(1,3, 243 ) = 0.000892416 
C      henke(1,1, 244 ) = 485.623 
C      henke(1,2, 244 ) = 1.00248 
C      henke(1,3, 244 ) = 0.000860393 
C      henke(1,1, 245 ) = 493.478 
C      henke(1,2, 245 ) = 1.00241 
C      henke(1,3, 245 ) = 0.000829518 
C      henke(1,1, 246 ) = 501.459 
C      henke(1,2, 246 ) = 1.00234 
C      henke(1,3, 246 ) = 0.000799751 
C      henke(1,1, 247 ) = 509.57 
C      henke(1,2, 247 ) = 1.00227 
C      henke(1,3, 247 ) = 0.000771052 
C      henke(1,1, 248 ) = 517.812 
C      henke(1,2, 248 ) = 1.00221 
C      henke(1,3, 248 ) = 0.000743383 
C      henke(1,1, 249 ) = 526.187 
C      henke(1,2, 249 ) = 1.00214 
C      henke(1,3, 249 ) = 0.000716714 
C      henke(1,1, 250 ) = 534.698 
C      henke(1,2, 250 ) = 1.00208 
C      henke(1,3, 250 ) = 0.000690999 
C      henke(1,1, 251 ) = 543.346 
C      henke(1,2, 251 ) = 1.00202 
C      henke(1,3, 251 ) = 0.000666203 
C      henke(1,1, 252 ) = 552.134 
C      henke(1,2, 252 ) = 1.00196 
C      henke(1,3, 252 ) = 0.000642299 
C      henke(1,1, 253 ) = 561.065 
C      henke(1,2, 253 ) = 1.00191 
C      henke(1,3, 253 ) = 0.000619249 
C      henke(1,1, 254 ) = 570.139 
C      henke(1,2, 254 ) = 1.00185 
C      henke(1,3, 254 ) = 0.000597026 
C      henke(1,1, 255 ) = 579.361 
C      henke(1,2, 255 ) = 1.0018 
C      henke(1,3, 255 ) = 0.000575597 
C      henke(1,1, 256 ) = 588.732 
C      henke(1,2, 256 ) = 1.00175 
C      henke(1,3, 256 ) = 0.000554945 
C      henke(1,1, 257 ) = 598.254 
C      henke(1,2, 257 ) = 1.0017 
C      henke(1,3, 257 ) = 0.000535035 
C      henke(1,1, 258 ) = 607.93 
C      henke(1,2, 258 ) = 1.00165 
C      henke(1,3, 258 ) = 0.000515832 
C      henke(1,1, 259 ) = 617.763 
C      henke(1,2, 259 ) = 1.0016 
C      henke(1,3, 259 ) = 0.000497219 
C      henke(1,1, 260 ) = 627.755 
C      henke(1,2, 260 ) = 1.00155 
C      henke(1,3, 260 ) = 0.000479195 
C      henke(1,1, 261 ) = 637.908 
C      henke(1,2, 261 ) = 1.00151 
C      henke(1,3, 261 ) = 0.000461657 
C      henke(1,1, 262 ) = 648.226 
C      henke(1,2, 262 ) = 1.00146 
C      henke(1,3, 262 ) = 0.000444758 
C      henke(1,1, 263 ) = 658.711 
C      henke(1,2, 263 ) = 1.00142 
C      henke(1,3, 263 ) = 0.000428477 
C      henke(1,1, 264 ) = 669.365 
C      henke(1,2, 264 ) = 1.00138 
C      henke(1,3, 264 ) = 0.000412792 
C      henke(1,1, 265 ) = 680.191 
C      henke(1,2, 265 ) = 1.00134 
C      henke(1,3, 265 ) = 0.00039768 
C      henke(1,1, 266 ) = 691.193 
C      henke(1,2, 266 ) = 1.0013 
C      henke(1,3, 266 ) = 0.00038312 
C      henke(1,1, 267 ) = 702.372 
C      henke(1,2, 267 ) = 1.00126 
C      henke(1,3, 267 ) = 0.000369094 
C      henke(1,1, 268 ) = 713.733 
C      henke(1,2, 268 ) = 1.00122 
C      henke(1,3, 268 ) = 0.000355582 
C      henke(1,1, 269 ) = 725.277 
C      henke(1,2, 269 ) = 1.00119 
C      henke(1,3, 269 ) = 0.000342565 
C      henke(1,1, 270 ) = 737.008 
C      henke(1,2, 270 ) = 1.00115 
C      henke(1,3, 270 ) = 0.000330026 
C      henke(1,1, 271 ) = 748.928 
C      henke(1,2, 271 ) = 1.00112 
C      henke(1,3, 271 ) = 0.000317945 
C      henke(1,1, 272 ) = 761.042 
C      henke(1,2, 272 ) = 1.00109 
C      henke(1,3, 272 ) = 0.000306305 
C      henke(1,1, 273 ) = 773.351 
C      henke(1,2, 273 ) = 1.00105 
C      henke(1,3, 273 ) = 0.000295082 
C      henke(1,1, 274 ) = 785.859 
C      henke(1,2, 274 ) = 1.00102 
C      henke(1,3, 274 ) = 0.000284275 
C      henke(1,1, 275 ) = 798.57 
C      henke(1,2, 275 ) = 1.00099 
C      henke(1,3, 275 ) = 0.000273869 
C      henke(1,1, 276 ) = 811.486 
C      henke(1,2, 276 ) = 1.00096 
C      henke(1,3, 276 ) = 0.000263852 
C      henke(1,1, 277 ) = 824.611 
C      henke(1,2, 277 ) = 1.00093 
C      henke(1,3, 277 ) = 0.000254197 
C      henke(1,1, 278 ) = 837.949 
C      henke(1,2, 278 ) = 1.00091 
C      henke(1,3, 278 ) = 0.00024489 
C      henke(1,1, 279 ) = 851.502 
C      henke(1,2, 279 ) = 1.00088 
C      henke(1,3, 279 ) = 0.000235924 
C      henke(1,1, 280 ) = 865.274 
C      henke(1,2, 280 ) = 1.00085 
C      henke(1,3, 280 ) = 0.000227288 
C      henke(1,1, 281 ) = 879.269 
C      henke(1,2, 281 ) = 1.00083 
C      henke(1,3, 281 ) = 0.000218969 
C      henke(1,1, 282 ) = 893.491 
C      henke(1,2, 282 ) = 1.0008 
C      henke(1,3, 282 ) = 0.000210948 
C      henke(1,1, 283 ) = 907.943 
C      henke(1,2, 283 ) = 1.00078 
C      henke(1,3, 283 ) = 0.000203223 
C      henke(1,1, 284 ) = 922.628 
C      henke(1,2, 284 ) = 1.00075 
C      henke(1,3, 284 ) = 0.000195782 
C      henke(1,1, 285 ) = 937.551 
C      henke(1,2, 285 ) = 1.00073 
C      henke(1,3, 285 ) = 0.000188614 
C      henke(1,1, 286 ) = 952.715 
C      henke(1,2, 286 ) = 1.00071 
C      henke(1,3, 286 ) = 0.000181709 
C      henke(1,1, 287 ) = 968.124 
C      henke(1,2, 287 ) = 1.00069 
C      henke(1,3, 287 ) = 0.000175057 
C      henke(1,1, 288 ) = 983.783 
C      henke(1,2, 288 ) = 1.00067 
C      henke(1,3, 288 ) = 0.000168649 
C      henke(1,1, 289 ) = 999.695 
C      henke(1,2, 289 ) = 1.00065 
C      henke(1,3, 289 ) = 0.000162475 
C      henke(1,1, 290 ) = 1015.86 
C      henke(1,2, 290 ) = 1.00063 
C      henke(1,3, 290 ) = 0.000156527 
C      henke(1,1, 291 ) = 1032.29 
C      henke(1,2, 291 ) = 1.00061 
C      henke(1,3, 291 ) = 0.000150796 
C      henke(1,1, 292 ) = 1048.99 
C      henke(1,2, 292 ) = 1.00059 
C      henke(1,3, 292 ) = 0.000145275 
C      henke(1,1, 293 ) = 1065.96 
C      henke(1,2, 293 ) = 1.00057 
C      henke(1,3, 293 ) = 0.000139956 
C      henke(1,1, 294 ) = 1083.2 
C      henke(1,2, 294 ) = 1.00055 
C      henke(1,3, 294 ) = 0.000134833 
C      henke(1,1, 295 ) = 1100.72 
C      henke(1,2, 295 ) = 1.00054 
C      henke(1,3, 295 ) = 0.000129897 
C      henke(1,1, 296 ) = 1118.52 
C      henke(1,2, 296 ) = 1.00052 
C      henke(1,3, 296 ) = 0.00012514 
C      henke(1,1, 297 ) = 1136.61 
C      henke(1,2, 297 ) = 1.0005 
C      henke(1,3, 297 ) = 0.000120559 
C      henke(1,1, 298 ) = 1155 
C      henke(1,2, 298 ) = 1.00049 
C      henke(1,3, 298 ) = 0.000116145 
C      henke(1,1, 299 ) = 1173.68 
C      henke(1,2, 299 ) = 1.00047 
C      henke(1,3, 299 ) = 0.000111894 
C      henke(1,1, 300 ) = 1192.66 
C      henke(1,2, 300 ) = 1.00046 
C      henke(1,3, 300 ) = 0.000107798 
C      henke(1,1, 301 ) = 1211.95 
C      henke(1,2, 301 ) = 1.00044 
C      henke(1,3, 301 ) = 0.000103851 
C      henke(1,1, 302 ) = 1231.55 
C      henke(1,2, 302 ) = 1.00043 
C      henke(1,3, 302 ) = 0.000100048 
C      henke(1,1, 303 ) = 1251.47 
C      henke(1,2, 303 ) = 1.00042 
C      henke(1,3, 303 ) = 9.63431e-05 
C      henke(1,1, 304 ) = 1271.72 
C      henke(1,2, 304 ) = 1.0004 
C      henke(1,3, 304 ) = 9.27658e-05 
C      henke(1,1, 305 ) = 1292.29 
C      henke(1,2, 305 ) = 1.00039 
C      henke(1,3, 305 ) = 8.93136e-05 
C      henke(1,1, 306 ) = 1313.19 
C      henke(1,2, 306 ) = 1.00038 
C      henke(1,3, 306 ) = 8.59897e-05 
C      henke(1,1, 307 ) = 1334.43 
C      henke(1,2, 307 ) = 1.00037 
C      henke(1,3, 307 ) = 8.2789e-05 
C      henke(1,1, 308 ) = 1356.01 
C      henke(1,2, 308 ) = 1.00035 
C      henke(1,3, 308 ) = 7.97065e-05 
C      henke(1,1, 309 ) = 1377.94 
C      henke(1,2, 309 ) = 1.00034 
C      henke(1,3, 309 ) = 7.67399e-05 
C      henke(1,1, 310 ) = 1400.23 
C      henke(1,2, 310 ) = 1.00033 
C      henke(1,3, 310 ) = 7.38845e-05 
C      henke(1,1, 311 ) = 1422.88 
C      henke(1,2, 311 ) = 1.00032 
C      henke(1,3, 311 ) = 7.11367e-05 
C      henke(1,1, 312 ) = 1445.89 
C      henke(1,2, 312 ) = 1.00031 
C      henke(1,3, 312 ) = 6.8489e-05 
C      henke(1,1, 313 ) = 1469.28 
C      henke(1,2, 313 ) = 1.0003 
C      henke(1,3, 313 ) = 6.59394e-05 
C      henke(1,1, 314 ) = 1493.04 
C      henke(1,2, 314 ) = 1.00029 
C      henke(1,3, 314 ) = 6.34846e-05 
C      henke(1,1, 315 ) = 1517.19 
C      henke(1,2, 315 ) = 1.00028 
C      henke(1,3, 315 ) = 6.11222e-05 
C      henke(1,1, 316 ) = 1541.73 
C      henke(1,2, 316 ) = 1.00027 
C      henke(1,3, 316 ) = 5.88497e-05 
C      henke(1,1, 317 ) = 1566.67 
C      henke(1,2, 317 ) = 1.00026 
C      henke(1,3, 317 ) = 5.66648e-05 
C      henke(1,1, 318 ) = 1592.01 
C      henke(1,2, 318 ) = 1.00025 
C      henke(1,3, 318 ) = 5.4565e-05 
C      henke(1,1, 319 ) = 1617.76 
C      henke(1,2, 319 ) = 1.00025 
C      henke(1,3, 319 ) = 5.25439e-05 
C      henke(1,1, 320 ) = 1643.92 
C      henke(1,2, 320 ) = 1.00024 
C      henke(1,3, 320 ) = 5.05984e-05 
C      henke(1,1, 321 ) = 1670.51 
C      henke(1,2, 321 ) = 1.00023 
C      henke(1,3, 321 ) = 4.87229e-05 
C      henke(1,1, 322 ) = 1697.53 
C      henke(1,2, 322 ) = 1.00022 
C      henke(1,3, 322 ) = 4.69171e-05 
C      henke(1,1, 323 ) = 1724.99 
C      henke(1,2, 323 ) = 1.00021 
C      henke(1,3, 323 ) = 4.51791e-05 
C      henke(1,1, 324 ) = 1752.89 
C      henke(1,2, 324 ) = 1.00021 
C      henke(1,3, 324 ) = 4.34988e-05 
C      henke(1,1, 325 ) = 1781.24 
C      henke(1,2, 325 ) = 1.0002 
C      henke(1,3, 325 ) = 4.18788e-05 
C      henke(1,1, 326 ) = 1810.05 
C      henke(1,2, 326 ) = 1.00019 
C      henke(1,3, 326 ) = 4.03175e-05 
C      henke(1,1, 327 ) = 1839.32 
C      henke(1,2, 327 ) = 1.00019 
C      henke(1,3, 327 ) = 3.88144e-05 
C      henke(1,1, 328 ) = 1869.07 
C      henke(1,2, 328 ) = 1.00018 
C      henke(1,3, 328 ) = 3.73672e-05 
C      henke(1,1, 329 ) = 1899.3 
C      henke(1,2, 329 ) = 1.00017 
C      henke(1,3, 329 ) = 3.59738e-05 
C      henke(1,1, 330 ) = 1930.02 
C      henke(1,2, 330 ) = 1.00017 
C      henke(1,3, 330 ) = 3.46325e-05 
C      henke(1,1, 331 ) = 1961.24 
C      henke(1,2, 331 ) = 1.00016 
C      henke(1,3, 331 ) = 3.33413e-05 
C      henke(1,1, 332 ) = 1992.96 
C      henke(1,2, 332 ) = 1.00016 
C      henke(1,3, 332 ) = 3.20983e-05 
C      henke(1,1, 333 ) = 2025.2 
C      henke(1,2, 333 ) = 1.00015 
C      henke(1,3, 333 ) = 3.09117e-05 
C      henke(1,1, 334 ) = 2057.95 
C      henke(1,2, 334 ) = 1.00015 
C      henke(1,3, 334 ) = 2.97548e-05 
C      henke(1,1, 335 ) = 2091.24 
C      henke(1,2, 335 ) = 1.00014 
C      henke(1,3, 335 ) = 2.86399e-05 
C      henke(1,1, 336 ) = 2125.06 
C      henke(1,2, 336 ) = 1.00014 
C      henke(1,3, 336 ) = 2.75656e-05 
C      henke(1,1, 337 ) = 2159.43 
C      henke(1,2, 337 ) = 1.00013 
C      henke(1,3, 337 ) = 2.65311e-05 
C      henke(1,1, 338 ) = 2194.36 
C      henke(1,2, 338 ) = 1.00013 
C      henke(1,3, 338 ) = 2.5534e-05 
C      henke(1,1, 339 ) = 2229.85 
C      henke(1,2, 339 ) = 1.00012 
C      henke(1,3, 339 ) = 2.45737e-05 
C      henke(1,1, 340 ) = 2265.92 
C      henke(1,2, 340 ) = 1.00012 
C      henke(1,3, 340 ) = 2.36488e-05 
C      henke(1,1, 341 ) = 2302.57 
C      henke(1,2, 341 ) = 1.00011 
C      henke(1,3, 341 ) = 2.27578e-05 
C      henke(1,1, 342 ) = 2339.81 
C      henke(1,2, 342 ) = 1.00011 
C      henke(1,3, 342 ) = 2.18996e-05 
C      henke(1,1, 343 ) = 2377.66 
C      henke(1,2, 343 ) = 1.0001 
C      henke(1,3, 343 ) = 2.10728e-05 
C      henke(1,1, 344 ) = 2416.11 
C      henke(1,2, 344 ) = 1.0001 
C      henke(1,3, 344 ) = 2.02763e-05 
C      henke(1,1, 345 ) = 2455.19 
C      henke(1,2, 345 ) = 1.0001 
C      henke(1,3, 345 ) = 1.95099e-05 
C      henke(1,1, 346 ) = 2494.9 
C      henke(1,2, 346 ) = 1.00009 
C      henke(1,3, 346 ) = 1.87711e-05 
C      henke(1,1, 347 ) = 2535.26 
C      henke(1,2, 347 ) = 1.00009 
C      henke(1,3, 347 ) = 1.80601e-05 
C      henke(1,1, 348 ) = 2576.26 
C      henke(1,2, 348 ) = 1.00008 
C      henke(1,3, 348 ) = 1.73752e-05 
C      henke(1,1, 349 ) = 2617.93 
C      henke(1,2, 349 ) = 1.00008 
C      henke(1,3, 349 ) = 1.67157e-05 
C      henke(1,1, 350 ) = 2660.27 
C      henke(1,2, 350 ) = 1.00008 
C      henke(1,3, 350 ) = 1.60808e-05 
C      henke(1,1, 351 ) = 2703.3 
C      henke(1,2, 351 ) = 1.00007 
C      henke(1,3, 351 ) = 1.54691e-05 
C      henke(1,1, 352 ) = 2747.03 
C      henke(1,2, 352 ) = 1.00007 
C      henke(1,3, 352 ) = 1.48806e-05 
C      henke(1,1, 353 ) = 2791.46 
C      henke(1,2, 353 ) = 1.00007 
C      henke(1,3, 353 ) = 1.43137e-05 
C      henke(1,1, 354 ) = 2836.61 
C      henke(1,2, 354 ) = 1.00007 
C      henke(1,3, 354 ) = 1.37685e-05 
C      henke(1,1, 355 ) = 2882.49 
C      henke(1,2, 355 ) = 1.00006 
C      henke(1,3, 355 ) = 1.32435e-05 
C      henke(1,1, 356 ) = 2929.11 
C      henke(1,2, 356 ) = 1.00006 
C      henke(1,3, 356 ) = 1.27377e-05 
C      henke(1,1, 357 ) = 2976.48 
C      henke(1,2, 357 ) = 1.00006 
C      henke(1,3, 357 ) = 1.2251e-05 
C      henke(1,1, 358 ) = 3024.63 
C      henke(1,2, 358 ) = 1.00005 
C      henke(1,3, 358 ) = 1.17831e-05 
C      henke(1,1, 359 ) = 3073.55 
C      henke(1,2, 359 ) = 1.00005 
C      henke(1,3, 359 ) = 1.13326e-05 
C      henke(1,1, 360 ) = 3123.26 
C      henke(1,2, 360 ) = 1.00005 
C      henke(1,3, 360 ) = 1.08987e-05 
C      henke(1,1, 361 ) = 3173.78 
C      henke(1,2, 361 ) = 1.00005 
C      henke(1,3, 361 ) = 1.04815e-05 
C      henke(1,1, 362 ) = 3225.11 
C      henke(1,2, 362 ) = 1.00005 
C      henke(1,3, 362 ) = 1.00803e-05 
C      henke(1,1, 363 ) = 3277.27 
C      henke(1,2, 363 ) = 1.00004 
C      henke(1,3, 363 ) = 9.69407e-06 
C      henke(1,1, 364 ) = 3330.28 
C      henke(1,2, 364 ) = 1.00004 
C      henke(1,3, 364 ) = 9.3228e-06 
C      henke(1,1, 365 ) = 3384.15 
C      henke(1,2, 365 ) = 1.00004 
C      henke(1,3, 365 ) = 8.9657e-06 
C      henke(1,1, 366 ) = 3438.88 
C      henke(1,2, 366 ) = 1.00004 
C      henke(1,3, 366 ) = 8.62159e-06 
C      henke(1,1, 367 ) = 3494.5 
C      henke(1,2, 367 ) = 1.00003 
C      henke(1,3, 367 ) = 8.29117e-06 
C      henke(1,1, 368 ) = 3551.02 
C      henke(1,2, 368 ) = 1.00003 
C      henke(1,3, 368 ) = 7.97348e-06 
C      henke(1,1, 369 ) = 3608.46 
C      henke(1,2, 369 ) = 1.00003 
C      henke(1,3, 369 ) = 7.66792e-06 
C      henke(1,1, 370 ) = 3666.82 
C      henke(1,2, 370 ) = 1.00003 
C      henke(1,3, 370 ) = 7.37417e-06 
C      henke(1,1, 371 ) = 3726.13 
C      henke(1,2, 371 ) = 1.00003 
C      henke(1,3, 371 ) = 7.09177e-06 
C      henke(1,1, 372 ) = 3786.4 
C      henke(1,2, 372 ) = 1.00003 
C      henke(1,3, 372 ) = 6.8204e-06 
C      henke(1,1, 373 ) = 3847.64 
C      henke(1,2, 373 ) = 1.00002 
C      henke(1,3, 373 ) = 6.55955e-06 
C      henke(1,1, 374 ) = 3909.87 
C      henke(1,2, 374 ) = 1.00002 
C      henke(1,3, 374 ) = 6.30887e-06 
C      henke(1,1, 375 ) = 3973.11 
C      henke(1,2, 375 ) = 1.00002 
C      henke(1,3, 375 ) = 6.06802e-06 
C      henke(1,1, 376 ) = 4037.38 
C      henke(1,2, 376 ) = 1.00002 
C      henke(1,3, 376 ) = 5.83417e-06 
C      henke(1,1, 377 ) = 4102.68 
C      henke(1,2, 377 ) = 1.00002 
C      henke(1,3, 377 ) = 5.61182e-06 
C      henke(1,1, 378 ) = 4169.03 
C      henke(1,2, 378 ) = 1.00002 
C      henke(1,3, 378 ) = 5.39804e-06 
C      henke(1,1, 379 ) = 4236.46 
C      henke(1,2, 379 ) = 1.00001 
C      henke(1,3, 379 ) = 5.19262e-06 
C      henke(1,1, 380 ) = 4304.98 
C      henke(1,2, 380 ) = 1.00001 
C      henke(1,3, 380 ) = 4.99505e-06 
C      henke(1,1, 381 ) = 4374.62 
C      henke(1,2, 381 ) = 1.00001 
C      henke(1,3, 381 ) = 4.80512e-06 
C      henke(1,1, 382 ) = 4445.37 
C      henke(1,2, 382 ) = 1.00001 
C      henke(1,3, 382 ) = 4.62252e-06 
C      henke(1,1, 383 ) = 4517.27 
C      henke(1,2, 383 ) = 1.00001 
C      henke(1,3, 383 ) = 4.44693e-06 
C      henke(1,1, 384 ) = 4590.33 
C      henke(1,2, 384 ) = 1.00001 
C      henke(1,3, 384 ) = 4.27824e-06 
C      henke(1,1, 385 ) = 4664.58 
C      henke(1,2, 385 ) = 1.00001 
C      henke(1,3, 385 ) = 4.11592e-06 
C      henke(1,1, 386 ) = 4740.03 
C      henke(1,2, 386 ) = 1.00001 
C      henke(1,3, 386 ) = 3.9598e-06 
C      henke(1,1, 387 ) = 4816.69 
C      henke(1,2, 387 ) = 1.00001 
C      henke(1,3, 387 ) = 3.80971e-06 
C      henke(1,1, 388 ) = 4894.6 
C      henke(1,2, 388 ) = 1 
C      henke(1,3, 388 ) = 3.66534e-06 
C      henke(1,1, 389 ) = 4973.77 
C      henke(1,2, 389 ) = 1 
C      henke(1,3, 389 ) = 3.52656e-06 
C      henke(1,1, 390 ) = 5054.21 
C      henke(1,2, 390 ) = 1 
C      henke(1,3, 390 ) = 3.39308e-06 
C      henke(1,1, 391 ) = 5135.96 
C      henke(1,2, 391 ) = 1 
C      henke(1,3, 391 ) = 3.26467e-06 
C      henke(1,1, 392 ) = 5219.03 
C      henke(1,2, 392 ) = 1 
C      henke(1,3, 392 ) = 3.14122e-06 
C      henke(1,1, 393 ) = 5303.44 
C      henke(1,2, 393 ) = 1 
C      henke(1,3, 393 ) = 3.0224e-06 
C      henke(1,1, 394 ) = 5389.22 
C      henke(1,2, 394 ) = 0.999999 
C      henke(1,3, 394 ) = 2.90811e-06 
C      henke(1,1, 395 ) = 5476.39 
C      henke(1,2, 395 ) = 0.999998 
C      henke(1,3, 395 ) = 2.7982e-06 
C      henke(1,1, 396 ) = 5564.97 
C      henke(1,2, 396 ) = 0.999997 
C      henke(1,3, 396 ) = 2.69252e-06 
C      henke(1,1, 397 ) = 5654.98 
C      henke(1,2, 397 ) = 0.999996 
C      henke(1,3, 397 ) = 2.5908e-06 
C      henke(1,1, 398 ) = 5746.44 
C      henke(1,2, 398 ) = 0.999995 
C      henke(1,3, 398 ) = 2.49292e-06 
C      henke(1,1, 399 ) = 5839.39 
C      henke(1,2, 399 ) = 0.999995 
C      henke(1,3, 399 ) = 2.39878e-06 
C      henke(1,1, 400 ) = 5933.83 
C      henke(1,2, 400 ) = 0.999994 
C      henke(1,3, 400 ) = 2.30825e-06 
C      henke(1,1, 401 ) = 6029.81 
C      henke(1,2, 401 ) = 0.999993 
C      henke(1,3, 401 ) = 2.22111e-06 
C      henke(1,1, 402 ) = 6127.33 
C      henke(1,2, 402 ) = 0.999993 
C      henke(1,3, 402 ) = 2.13725e-06 
C      henke(1,1, 403 ) = 6226.44 
C      henke(1,2, 403 ) = 0.999992 
C      henke(1,3, 403 ) = 2.05662e-06 
C      henke(1,1, 404 ) = 6327.15 
C      henke(1,2, 404 ) = 0.999991 
C      henke(1,3, 404 ) = 1.97895e-06 
C      henke(1,1, 405 ) = 6429.48 
C      henke(1,2, 405 ) = 0.999991 
C      henke(1,3, 405 ) = 1.90427e-06 
C      henke(1,1, 406 ) = 6533.48 
C      henke(1,2, 406 ) = 0.99999 
C      henke(1,3, 406 ) = 1.83248e-06 
C      henke(1,1, 407 ) = 6639.15 
C      henke(1,2, 407 ) = 0.99999 
C      henke(1,3, 407 ) = 1.76329e-06 
C      henke(1,1, 408 ) = 6746.54 
C      henke(1,2, 408 ) = 0.999989 
C      henke(1,3, 408 ) = 1.6967e-06 
C      henke(1,1, 409 ) = 6855.65 
C      henke(1,2, 409 ) = 0.999988 
C      henke(1,3, 409 ) = 1.63268e-06 
C      henke(1,1, 410 ) = 6966.54 
C      henke(1,2, 410 ) = 0.999988 
C      henke(1,3, 410 ) = 1.57105e-06 
C      henke(1,1, 411 ) = 7079.22 
C      henke(1,2, 411 ) = 0.999987 
C      henke(1,3, 411 ) = 1.51173e-06 
C      henke(1,1, 412 ) = 7193.72 
C      henke(1,2, 412 ) = 0.999987 
C      henke(1,3, 412 ) = 1.45464e-06 
C      henke(1,1, 413 ) = 7310.07 
C      henke(1,2, 413 ) = 0.999986 
C      henke(1,3, 413 ) = 1.3997e-06 
C      henke(1,1, 414 ) = 7428.31 
C      henke(1,2, 414 ) = 0.999986 
C      henke(1,3, 414 ) = 1.34683e-06 
C      henke(1,1, 415 ) = 7548.45 
C      henke(1,2, 415 ) = 0.999985 
C      henke(1,3, 415 ) = 1.29594e-06 
C      henke(1,1, 416 ) = 7670.54 
C      henke(1,2, 416 ) = 0.999985 
C      henke(1,3, 416 ) = 1.24696e-06 
C      henke(1,1, 417 ) = 7794.61 
C      henke(1,2, 417 ) = 0.999985 
C      henke(1,3, 417 ) = 1.19981e-06 
C      henke(1,1, 418 ) = 7920.68 
C      henke(1,2, 418 ) = 0.999984 
C      henke(1,3, 418 ) = 1.15443e-06 
C      henke(1,1, 419 ) = 8048.79 
C      henke(1,2, 419 ) = 0.999984 
C      henke(1,3, 419 ) = 1.11076e-06 
C      henke(1,1, 420 ) = 8178.98 
C      henke(1,2, 420 ) = 0.999983 
C      henke(1,3, 420 ) = 1.06872e-06 
C      henke(1,1, 421 ) = 8311.26 
C      henke(1,2, 421 ) = 0.999983 
C      henke(1,3, 421 ) = 1.02826e-06 
C      henke(1,1, 422 ) = 8445.69 
C      henke(1,2, 422 ) = 0.999983 
C      henke(1,3, 422 ) = 9.89303e-07 
C      henke(1,1, 423 ) = 8582.29 
C      henke(1,2, 423 ) = 0.999982 
C      henke(1,3, 423 ) = 9.51814e-07 
C      henke(1,1, 424 ) = 8721.11 
C      henke(1,2, 424 ) = 0.999982 
C      henke(1,3, 424 ) = 9.15734e-07 
C      henke(1,1, 425 ) = 8862.16 
C      henke(1,2, 425 ) = 0.999982 
C      henke(1,3, 425 ) = 8.80992e-07 
C      henke(1,1, 426 ) = 9005.5 
C      henke(1,2, 426 ) = 0.999981 
C      henke(1,3, 426 ) = 8.47563e-07 
C      henke(1,1, 427 ) = 9151.16 
C      henke(1,2, 427 ) = 0.999981 
C      henke(1,3, 427 ) = 8.15359e-07 
C      henke(1,1, 428 ) = 9299.17 
C      henke(1,2, 428 ) = 0.999981 
C      henke(1,3, 428 ) = 7.84388e-07 
C      henke(1,1, 429 ) = 9449.58 
C      henke(1,2, 429 ) = 0.99998 
C      henke(1,3, 429 ) = 7.54553e-07 
C      henke(1,1, 430 ) = 9602.42 
C      henke(1,2, 430 ) = 0.99998 
C      henke(1,3, 430 ) = 7.25847e-07 
C      henke(1,1, 431 ) = 9757.73 
C      henke(1,2, 431 ) = 0.99998 
C      henke(1,3, 431 ) = 6.98223e-07 
C      henke(1,1, 432 ) = 9915.55 
C      henke(1,2, 432 ) = 0.99998 
C      henke(1,3, 432 ) = 6.71626e-07 
C      henke(1,1, 433 ) = 10075.9 
C      henke(1,2, 433 ) = 0.999979 
C      henke(1,3, 433 ) = 6.46075e-07 
C      henke(1,1, 434 ) = 10238.9 
C      henke(1,2, 434 ) = 0.999979 
C      henke(1,3, 434 ) = 6.21481e-07 
C      henke(1,1, 435 ) = 10404.5 
C      henke(1,2, 435 ) = 0.999979 
C      henke(1,3, 435 ) = 5.97806e-07 
C      henke(1,1, 436 ) = 10572.8 
C      henke(1,2, 436 ) = 0.999979 
C      henke(1,3, 436 ) = 5.75016e-07 
C      henke(1,1, 437 ) = 10743.8 
C      henke(1,2, 437 ) = 0.999978 
C      henke(1,3, 437 ) = 5.53081e-07 
C      henke(1,1, 438 ) = 10917.6 
C      henke(1,2, 438 ) = 0.999978 
C      henke(1,3, 438 ) = 5.31965e-07 
C      henke(1,1, 439 ) = 11094.2 
C      henke(1,2, 439 ) = 0.999978 
C      henke(1,3, 439 ) = 5.11641e-07 
C      henke(1,1, 440 ) = 11273.6 
C      henke(1,2, 440 ) = 0.999978 
C      henke(1,3, 440 ) = 4.92077e-07 
C      henke(1,1, 441 ) = 11455.9 
C      henke(1,2, 441 ) = 0.999978 
C      henke(1,3, 441 ) = 4.73248e-07 
C      henke(1,1, 442 ) = 11641.2 
C      henke(1,2, 442 ) = 0.999977 
C      henke(1,3, 442 ) = 4.55123e-07 
C      henke(1,1, 443 ) = 11829.5 
C      henke(1,2, 443 ) = 0.999977 
C      henke(1,3, 443 ) = 4.37678e-07 
C      henke(1,1, 444 ) = 12020.8 
C      henke(1,2, 444 ) = 0.999977 
C      henke(1,3, 444 ) = 4.20889e-07 
C      henke(1,1, 445 ) = 12215.3 
C      henke(1,2, 445 ) = 0.999977 
C      henke(1,3, 445 ) = 4.04728e-07 
C      henke(1,1, 446 ) = 12412.8 
C      henke(1,2, 446 ) = 0.999977 
C      henke(1,3, 446 ) = 3.89176e-07 
C      henke(1,1, 447 ) = 12613.6 
C      henke(1,2, 447 ) = 0.999977 
C      henke(1,3, 447 ) = 3.74207e-07 
C      henke(1,1, 448 ) = 12817.6 
C      henke(1,2, 448 ) = 0.999976 
C      henke(1,3, 448 ) = 3.59802e-07 
C      henke(1,1, 449 ) = 13025 
C      henke(1,2, 449 ) = 0.999976 
C      henke(1,3, 449 ) = 3.45939e-07 
C      henke(1,1, 450 ) = 13235.6 
C      henke(1,2, 450 ) = 0.999976 
C      henke(1,3, 450 ) = 3.32598e-07 
C      henke(1,1, 451 ) = 13449.7 
C      henke(1,2, 451 ) = 0.999976 
C      henke(1,3, 451 ) = 3.1976e-07 
C      henke(1,1, 452 ) = 13667.2 
C      henke(1,2, 452 ) = 0.999976 
C      henke(1,3, 452 ) = 3.07406e-07 
C      henke(1,1, 453 ) = 13888.3 
C      henke(1,2, 453 ) = 0.999976 
C      henke(1,3, 453 ) = 2.95519e-07 
C      henke(1,1, 454 ) = 14112.9 
C      henke(1,2, 454 ) = 0.999975 
C      henke(1,3, 454 ) = 2.84081e-07 
C      henke(1,1, 455 ) = 14341.2 
C      henke(1,2, 455 ) = 0.999975 
C      henke(1,3, 455 ) = 2.73076e-07 
C      henke(1,1, 456 ) = 14573.1 
C      henke(1,2, 456 ) = 0.999975 
C      henke(1,3, 456 ) = 2.62488e-07 
C      henke(1,1, 457 ) = 14808.9 
C      henke(1,2, 457 ) = 0.999975 
C      henke(1,3, 457 ) = 2.52302e-07 
C      henke(1,1, 458 ) = 15048.4 
C      henke(1,2, 458 ) = 0.999975 
C      henke(1,3, 458 ) = 2.42502e-07 
C      henke(1,1, 459 ) = 15291.8 
C      henke(1,2, 459 ) = 0.999975 
C      henke(1,3, 459 ) = 2.33075e-07 
C      henke(1,1, 460 ) = 15539.1 
C      henke(1,2, 460 ) = 0.999975 
C      henke(1,3, 460 ) = 2.24007e-07 
C      henke(1,1, 461 ) = 15790.4 
C      henke(1,2, 461 ) = 0.999975 
C      henke(1,3, 461 ) = 2.15284e-07 
C      henke(1,1, 462 ) = 16045.8 
C      henke(1,2, 462 ) = 0.999974 
C      henke(1,3, 462 ) = 2.06894e-07 
C      henke(1,1, 463 ) = 16305.4 
C      henke(1,2, 463 ) = 0.999974 
C      henke(1,3, 463 ) = 1.98825e-07 
C      henke(1,1, 464 ) = 16569.1 
C      henke(1,2, 464 ) = 0.999974 
C      henke(1,3, 464 ) = 1.91065e-07 
C      henke(1,1, 465 ) = 16837.1 
C      henke(1,2, 465 ) = 0.999974 
C      henke(1,3, 465 ) = 1.83603e-07 
C      henke(1,1, 466 ) = 17109.4 
C      henke(1,2, 466 ) = 0.999974 
C      henke(1,3, 466 ) = 1.76428e-07 
C      henke(1,1, 467 ) = 17386.1 
C      henke(1,2, 467 ) = 0.999974 
C      henke(1,3, 467 ) = 1.69528e-07 
C      henke(1,1, 468 ) = 17667.4 
C      henke(1,2, 468 ) = 0.999974 
C      henke(1,3, 468 ) = 1.62895e-07 
C      henke(1,1, 469 ) = 17953.1 
C      henke(1,2, 469 ) = 0.999974 
C      henke(1,3, 469 ) = 1.56518e-07 
C      henke(1,1, 470 ) = 18243.5 
C      henke(1,2, 470 ) = 0.999974 
C      henke(1,3, 470 ) = 1.50387e-07 
C      henke(1,1, 471 ) = 18538.6 
C      henke(1,2, 471 ) = 0.999974 
C      henke(1,3, 471 ) = 1.44495e-07 
C      henke(1,1, 472 ) = 18838.4 
C      henke(1,2, 472 ) = 0.999974 
C      henke(1,3, 472 ) = 1.38831e-07 
C      henke(1,1, 473 ) = 19143.1 
C      henke(1,2, 473 ) = 0.999974 
C      henke(1,3, 473 ) = 1.33389e-07 
C      henke(1,1, 474 ) = 19452.7 
C      henke(1,2, 474 ) = 0.999974 
C      henke(1,3, 474 ) = 1.28159e-07 
C      henke(1,1, 475 ) = 19767.4 
C      henke(1,2, 475 ) = 0.999973 
C      henke(1,3, 475 ) = 1.23133e-07 
C      henke(1,1, 476 ) = 20087.1 
C      henke(1,2, 476 ) = 0.999973 
C      henke(1,3, 476 ) = 1.18381e-07 
C      henke(1,1, 477 ) = 20412 
C      henke(1,2, 477 ) = 0.999973 
C      henke(1,3, 477 ) = 1.13744e-07 
C      henke(1,1, 478 ) = 20742.1 
C      henke(1,2, 478 ) = 0.999973 
C      henke(1,3, 478 ) = 1.09292e-07 
C      henke(1,1, 479 ) = 21077.6 
C      henke(1,2, 479 ) = 0.999973 
C      henke(1,3, 479 ) = 1.05019e-07 
C      henke(1,1, 480 ) = 21418.5 
C      henke(1,2, 480 ) = 0.999973 
C      henke(1,3, 480 ) = 1.00917e-07 
C      henke(1,1, 481 ) = 21765 
C      henke(1,2, 481 ) = 0.999973 
C      henke(1,3, 481 ) = 9.69783e-08 
C      henke(1,1, 482 ) = 22117 
C      henke(1,2, 482 ) = 0.999973 
C      henke(1,3, 482 ) = 9.31972e-08 
C      henke(1,1, 483 ) = 22474.7 
C      henke(1,2, 483 ) = 0.999973 
C      henke(1,3, 483 ) = 8.95669e-08 
C      henke(1,1, 484 ) = 22838.2 
C      henke(1,2, 484 ) = 0.999973 
C      henke(1,3, 484 ) = 8.6081e-08 
C      henke(1,1, 485 ) = 23207.6 
C      henke(1,2, 485 ) = 0.999973 
C      henke(1,3, 485 ) = 8.27338e-08 
C      henke(1,1, 486 ) = 23583 
C      henke(1,2, 486 ) = 0.999973 
C      henke(1,3, 486 ) = 7.95195e-08 
C      henke(1,1, 487 ) = 23964.4 
C      henke(1,2, 487 ) = 0.999973 
C      henke(1,3, 487 ) = 7.64328e-08 
C      henke(1,1, 488 ) = 24352 
C      henke(1,2, 488 ) = 0.999973 
C      henke(1,3, 488 ) = 7.34683e-08 
C      henke(1,1, 489 ) = 24745.9 
C      henke(1,2, 489 ) = 0.999973 
C      henke(1,3, 489 ) = 7.06213e-08 
C      henke(1,1, 490 ) = 25146.2 
C      henke(1,2, 490 ) = 0.999973 
C      henke(1,3, 490 ) = 6.78867e-08 
C      henke(1,1, 491 ) = 25552.9 
C      henke(1,2, 491 ) = 0.999973 
C      henke(1,3, 491 ) = 6.52602e-08 
C      henke(1,1, 492 ) = 25966.2 
C      henke(1,2, 492 ) = 0.999973 
C      henke(1,3, 492 ) = 6.27372e-08 
C      henke(1,1, 493 ) = 26386.1 
C      henke(1,2, 493 ) = 0.999972 
C      henke(1,3, 493 ) = 6.03136e-08 
C      henke(1,1, 494 ) = 26812.9 
C      henke(1,2, 494 ) = 0.999972 
C      henke(1,3, 494 ) = 5.79854e-08 
C      henke(1,1, 495 ) = 27246.6 
C      henke(1,2, 495 ) = 0.999972 
C      henke(1,3, 495 ) = 5.57487e-08 
C      henke(1,1, 496 ) = 27687.3 
C      henke(1,2, 496 ) = 0.999972 
C      henke(1,3, 496 ) = 5.35999e-08 
C      henke(1,1, 497 ) = 28135.1 
C      henke(1,2, 497 ) = 0.999972 
C      henke(1,3, 497 ) = 5.15352e-08 
C      henke(1,1, 498 ) = 28590.2 
C      henke(1,2, 498 ) = 0.999972 
C      henke(1,3, 498 ) = 4.95516e-08 
C      henke(1,1, 499 ) = 29052.6 
C      henke(1,2, 499 ) = 0.999972 
C      henke(1,3, 499 ) = 4.76455e-08 
C      henke(1,1, 500 ) = 29522.5 
C      henke(1,2, 500 ) = 0.999972 
C      henke(1,3, 500 ) = 4.58139e-08 
C      henke(1,1, 501 ) = 30000 
C      henke(1,2, 501 ) = 0.999972 
C      henke(1,3, 501 ) = 4.40539e-08 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C        Henke data for c  z=6
       count(6) = 502
       henke(6,1, 1 ) = 10 
       henke(6,2, 1 ) = -9999 
       henke(6,3, 1 ) = 0.806885 
       henke(6,1, 2 ) = 10.1617 
       henke(6,2, 2 ) = -9999 
       henke(6,3, 2 ) = 0.851522 
       henke(6,1, 3 ) = 10.3261 
       henke(6,2, 3 ) = -9999 
       henke(6,3, 3 ) = 0.898628 
       henke(6,1, 4 ) = 10.4931 
       henke(6,2, 4 ) = -9999 
       henke(6,3, 4 ) = 0.948341 
       henke(6,1, 5 ) = 10.6628 
       henke(6,2, 5 ) = -9999 
       henke(6,3, 5 ) = 1.0008 
       henke(6,1, 6 ) = 10.8353 
       henke(6,2, 6 ) = -9999 
       henke(6,3, 6 ) = 1.05755 
       henke(6,1, 7 ) = 11.0106 
       henke(6,2, 7 ) = -9999 
       henke(6,3, 7 ) = 1.12167 
       henke(6,1, 8 ) = 11.1886 
       henke(6,2, 8 ) = -9999 
       henke(6,3, 8 ) = 1.18968 
       henke(6,1, 9 ) = 11.3696 
       henke(6,2, 9 ) = -9999 
       henke(6,3, 9 ) = 1.26181 
       henke(6,1, 10 ) = 11.5535 
       henke(6,2, 10 ) = -9999 
       henke(6,3, 10 ) = 1.33832 
       henke(6,1, 11 ) = 11.7404 
       henke(6,2, 11 ) = -9999 
       henke(6,3, 11 ) = 1.41946 
       henke(6,1, 12 ) = 11.9303 
       henke(6,2, 12 ) = -9999 
       henke(6,3, 12 ) = 1.50553 
       henke(6,1, 13 ) = 12.1232 
       henke(6,2, 13 ) = -9999 
       henke(6,3, 13 ) = 1.58971 
       henke(6,1, 14 ) = 12.3193 
       henke(6,2, 14 ) = -9999 
       henke(6,3, 14 ) = 1.6782 
       henke(6,1, 15 ) = 12.5186 
       henke(6,2, 15 ) = -9999 
       henke(6,3, 15 ) = 1.77161 
       henke(6,1, 16 ) = 12.721 
       henke(6,2, 16 ) = -9999 
       henke(6,3, 16 ) = 1.87023 
       henke(6,1, 17 ) = 12.9268 
       henke(6,2, 17 ) = -9999 
       henke(6,3, 17 ) = 1.97433 
       henke(6,1, 18 ) = 13.1359 
       henke(6,2, 18 ) = -9999 
       henke(6,3, 18 ) = 2.08423 
       henke(6,1, 19 ) = 13.3483 
       henke(6,2, 19 ) = -9999 
       henke(6,3, 19 ) = 2.20025 
       henke(6,1, 20 ) = 13.5642 
       henke(6,2, 20 ) = -9999 
       henke(6,3, 20 ) = 2.29235 
       henke(6,1, 21 ) = 13.7836 
       henke(6,2, 21 ) = -9999 
       henke(6,3, 21 ) = 2.38287 
       henke(6,1, 22 ) = 14.0066 
       henke(6,2, 22 ) = -9999 
       henke(6,3, 22 ) = 2.47696 
       henke(6,1, 23 ) = 14.2331 
       henke(6,2, 23 ) = -9999 
       henke(6,3, 23 ) = 2.57477 
       henke(6,1, 24 ) = 14.4633 
       henke(6,2, 24 ) = -9999 
       henke(6,3, 24 ) = 2.67645 
       henke(6,1, 25 ) = 14.6973 
       henke(6,2, 25 ) = -9999 
       henke(6,3, 25 ) = 2.77114 
       henke(6,1, 26 ) = 14.935 
       henke(6,2, 26 ) = -9999 
       henke(6,3, 26 ) = 2.84605 
       henke(6,1, 27 ) = 15.1765 
       henke(6,2, 27 ) = -9999 
       henke(6,3, 27 ) = 2.92298 
       henke(6,1, 28 ) = 15.422 
       henke(6,2, 28 ) = -9999 
       henke(6,3, 28 ) = 3.00199 
       henke(6,1, 29 ) = 15.6714 
       henke(6,2, 29 ) = -9999 
       henke(6,3, 29 ) = 3.08313 
       henke(6,1, 30 ) = 15.9249 
       henke(6,2, 30 ) = -9999 
       henke(6,3, 30 ) = 3.16647 
       henke(6,1, 31 ) = 16.1825 
       henke(6,2, 31 ) = -9999 
       henke(6,3, 31 ) = 3.24213 
       henke(6,1, 32 ) = 16.4442 
       henke(6,2, 32 ) = -9999 
       henke(6,3, 32 ) = 3.28778 
       henke(6,1, 33 ) = 16.7102 
       henke(6,2, 33 ) = -9999 
       henke(6,3, 33 ) = 3.33408 
       henke(6,1, 34 ) = 16.9805 
       henke(6,2, 34 ) = -9999 
       henke(6,3, 34 ) = 3.38103 
       henke(6,1, 35 ) = 17.2551 
       henke(6,2, 35 ) = -9999 
       henke(6,3, 35 ) = 3.42863 
       henke(6,1, 36 ) = 17.5342 
       henke(6,2, 36 ) = -9999 
       henke(6,3, 36 ) = 3.47691 
       henke(6,1, 37 ) = 17.8178 
       henke(6,2, 37 ) = -9999 
       henke(6,3, 37 ) = 3.52041 
       henke(6,1, 38 ) = 18.106 
       henke(6,2, 38 ) = -9999 
       henke(6,3, 38 ) = 3.54277 
       henke(6,1, 39 ) = 18.3989 
       henke(6,2, 39 ) = -9999 
       henke(6,3, 39 ) = 3.56528 
       henke(6,1, 40 ) = 18.6964 
       henke(6,2, 40 ) = -9999 
       henke(6,3, 40 ) = 3.58793 
       henke(6,1, 41 ) = 18.9988 
       henke(6,2, 41 ) = -9999 
       henke(6,3, 41 ) = 3.61072 
       henke(6,1, 42 ) = 19.3061 
       henke(6,2, 42 ) = -9999 
       henke(6,3, 42 ) = 3.63366 
       henke(6,1, 43 ) = 19.6184 
       henke(6,2, 43 ) = -9999 
       henke(6,3, 43 ) = 3.65674 
       henke(6,1, 44 ) = 19.9357 
       henke(6,2, 44 ) = -9999 
       henke(6,3, 44 ) = 3.67997 
       henke(6,1, 45 ) = 20.2582 
       henke(6,2, 45 ) = -9999 
       henke(6,3, 45 ) = 3.70335 
       henke(6,1, 46 ) = 20.5858 
       henke(6,2, 46 ) = -9999 
       henke(6,3, 46 ) = 3.69489 
       henke(6,1, 47 ) = 20.9188 
       henke(6,2, 47 ) = -9999 
       henke(6,3, 47 ) = 3.67204 
       henke(6,1, 48 ) = 21.2571 
       henke(6,2, 48 ) = -9999 
       henke(6,3, 48 ) = 3.64934 
       henke(6,1, 49 ) = 21.6009 
       henke(6,2, 49 ) = -9999 
       henke(6,3, 49 ) = 3.62677 
       henke(6,1, 50 ) = 21.9503 
       henke(6,2, 50 ) = -9999 
       henke(6,3, 50 ) = 3.60434 
       henke(6,1, 51 ) = 22.3053 
       henke(6,2, 51 ) = -9999 
       henke(6,3, 51 ) = 3.58205 
       henke(6,1, 52 ) = 22.6661 
       henke(6,2, 52 ) = -9999 
       henke(6,3, 52 ) = 3.5599 
       henke(6,1, 53 ) = 23.0327 
       henke(6,2, 53 ) = -9999 
       henke(6,3, 53 ) = 3.5332 
       henke(6,1, 54 ) = 23.4053 
       henke(6,2, 54 ) = -9999 
       henke(6,3, 54 ) = 3.47892 
       henke(6,1, 55 ) = 23.7838 
       henke(6,2, 55 ) = -9999 
       henke(6,3, 55 ) = 3.42547 
       henke(6,1, 56 ) = 24.1685 
       henke(6,2, 56 ) = -9999 
       henke(6,3, 56 ) = 3.37285 
       henke(6,1, 57 ) = 24.5594 
       henke(6,2, 57 ) = -9999 
       henke(6,3, 57 ) = 3.32103 
       henke(6,1, 58 ) = 24.9566 
       henke(6,2, 58 ) = -9999 
       henke(6,3, 58 ) = 3.27 
       henke(6,1, 59 ) = 25.3603 
       henke(6,2, 59 ) = -9999 
       henke(6,3, 59 ) = 3.21977 
       henke(6,1, 60 ) = 25.7705 
       henke(6,2, 60 ) = -9999 
       henke(6,3, 60 ) = 3.1703 
       henke(6,1, 61 ) = 26.1873 
       henke(6,2, 61 ) = -9999 
       henke(6,3, 61 ) = 3.12096 
       henke(6,1, 62 ) = 26.6109 
       henke(6,2, 62 ) = -9999 
       henke(6,3, 62 ) = 3.0635 
       henke(6,1, 63 ) = 27.0413 
       henke(6,2, 63 ) = -9999 
       henke(6,3, 63 ) = 3.00708 
       henke(6,1, 64 ) = 27.4786 
       henke(6,2, 64 ) = -9999 
       henke(6,3, 64 ) = 2.95171 
       henke(6,1, 65 ) = 27.9231 
       henke(6,2, 65 ) = -9999 
       henke(6,3, 65 ) = 2.89736 
       henke(6,1, 66 ) = 28.3747 
       henke(6,2, 66 ) = -9999 
       henke(6,3, 66 ) = 2.84401 
       henke(6,1, 67 ) = 28.8337 
       henke(6,2, 67 ) = -9999 
       henke(6,3, 67 ) = 2.79164 
       henke(6,1, 68 ) = 29.3 
       henke(6,2, 68 ) = 3.63318 
       henke(6,3, 68 ) = 2.74024 
       henke(6,1, 69 ) = 29.7739 
       henke(6,2, 69 ) = 3.67378 
       henke(6,3, 69 ) = 2.68978 
       henke(6,1, 70 ) = 30.2555 
       henke(6,2, 70 ) = 3.7127 
       henke(6,3, 70 ) = 2.63618 
       henke(6,1, 71 ) = 30.7449 
       henke(6,2, 71 ) = 3.74753 
       henke(6,3, 71 ) = 2.5836 
       henke(6,1, 72 ) = 31.2421 
       henke(6,2, 72 ) = 3.77973 
       henke(6,3, 72 ) = 2.53206 
       henke(6,1, 73 ) = 31.7475 
       henke(6,2, 73 ) = 3.80969 
       henke(6,3, 73 ) = 2.48155 
       henke(6,1, 74 ) = 32.2609 
       henke(6,2, 74 ) = 3.83764 
       henke(6,3, 74 ) = 2.43205 
       henke(6,1, 75 ) = 32.7827 
       henke(6,2, 75 ) = 3.86374 
       henke(6,3, 75 ) = 2.38354 
       henke(6,1, 76 ) = 33.313 
       henke(6,2, 76 ) = 3.88807 
       henke(6,3, 76 ) = 2.33599 
       henke(6,1, 77 ) = 33.8518 
       henke(6,2, 77 ) = 3.91071 
       henke(6,3, 77 ) = 2.2894 
       henke(6,1, 78 ) = 34.3993 
       henke(6,2, 78 ) = 3.93156 
       henke(6,3, 78 ) = 2.24373 
       henke(6,1, 79 ) = 34.9557 
       henke(6,2, 79 ) = 3.95026 
       henke(6,3, 79 ) = 2.19898 
       henke(6,1, 80 ) = 35.5211 
       henke(6,2, 80 ) = 3.96709 
       henke(6,3, 80 ) = 2.15799 
       henke(6,1, 81 ) = 36.0956 
       henke(6,2, 81 ) = 3.98488 
       henke(6,3, 81 ) = 2.11827 
       henke(6,1, 82 ) = 36.6794 
       henke(6,2, 82 ) = 4.00253 
       henke(6,3, 82 ) = 2.07928 
       henke(6,1, 83 ) = 37.2727 
       henke(6,2, 83 ) = 4.01992 
       henke(6,3, 83 ) = 2.04101 
       henke(6,1, 84 ) = 37.8755 
       henke(6,2, 84 ) = 4.03712 
       henke(6,3, 84 ) = 2.00344 
       henke(6,1, 85 ) = 38.4882 
       henke(6,2, 85 ) = 4.05432 
       henke(6,3, 85 ) = 1.96657 
       henke(6,1, 86 ) = 39.1107 
       henke(6,2, 86 ) = 4.0736 
       henke(6,3, 86 ) = 1.93037 
       henke(6,1, 87 ) = 39.7432 
       henke(6,2, 87 ) = 4.09449 
       henke(6,3, 87 ) = 1.89011 
       henke(6,1, 88 ) = 40.3861 
       henke(6,2, 88 ) = 4.1101 
       henke(6,3, 88 ) = 1.8465 
       henke(6,1, 89 ) = 41.0393 
       henke(6,2, 89 ) = 4.12229 
       henke(6,3, 89 ) = 1.8039 
       henke(6,1, 90 ) = 41.7031 
       henke(6,2, 90 ) = 4.13211 
       henke(6,3, 90 ) = 1.76228 
       henke(6,1, 91 ) = 42.3776 
       henke(6,2, 91 ) = 4.13985 
       henke(6,3, 91 ) = 1.72163 
       henke(6,1, 92 ) = 43.063 
       henke(6,2, 92 ) = 4.14559 
       henke(6,3, 92 ) = 1.68191 
       henke(6,1, 93 ) = 43.7595 
       henke(6,2, 93 ) = 4.14925 
       henke(6,3, 93 ) = 1.6431 
       henke(6,1, 94 ) = 44.4673 
       henke(6,2, 94 ) = 4.14955 
       henke(6,3, 94 ) = 1.6052 
       henke(6,1, 95 ) = 45.1865 
       henke(6,2, 95 ) = 4.14584 
       henke(6,3, 95 ) = 1.56917 
       henke(6,1, 96 ) = 45.9174 
       henke(6,2, 96 ) = 4.14175 
       henke(6,3, 96 ) = 1.54376 
       henke(6,1, 97 ) = 46.66 
       henke(6,2, 97 ) = 4.14174 
       henke(6,3, 97 ) = 1.51876 
       henke(6,1, 98 ) = 47.4147 
       henke(6,2, 98 ) = 4.143 
       henke(6,3, 98 ) = 1.49417 
       henke(6,1, 99 ) = 48.1816 
       henke(6,2, 99 ) = 4.14486 
       henke(6,3, 99 ) = 1.46998 
       henke(6,1, 100 ) = 48.9609 
       henke(6,2, 100 ) = 4.14698 
       henke(6,3, 100 ) = 1.44618 
       henke(6,1, 101 ) = 49.7528 
       henke(6,2, 101 ) = 4.14913 
       henke(6,3, 101 ) = 1.42276 
       henke(6,1, 102 ) = 50.5576 
       henke(6,2, 102 ) = 4.15113 
       henke(6,3, 102 ) = 1.39972 
       henke(6,1, 103 ) = 51.3753 
       henke(6,2, 103 ) = 4.15277 
       henke(6,3, 103 ) = 1.37705 
       henke(6,1, 104 ) = 52.2062 
       henke(6,2, 104 ) = 4.15371 
       henke(6,3, 104 ) = 1.35475 
       henke(6,1, 105 ) = 53.0506 
       henke(6,2, 105 ) = 4.15307 
       henke(6,3, 105 ) = 1.33282 
       henke(6,1, 106 ) = 53.9087 
       henke(6,2, 106 ) = 4.1496 
       henke(6,3, 106 ) = 1.31546 
       henke(6,1, 107 ) = 54.7806 
       henke(6,2, 107 ) = 4.14997 
       henke(6,3, 107 ) = 1.30168 
       henke(6,1, 108 ) = 55.6667 
       henke(6,2, 108 ) = 4.1527 
       henke(6,3, 108 ) = 1.28804 
       henke(6,1, 109 ) = 56.567 
       henke(6,2, 109 ) = 4.15681 
       henke(6,3, 109 ) = 1.27454 
       henke(6,1, 110 ) = 57.482 
       henke(6,2, 110 ) = 4.16209 
       henke(6,3, 110 ) = 1.26118 
       henke(6,1, 111 ) = 58.4117 
       henke(6,2, 111 ) = 4.16851 
       henke(6,3, 111 ) = 1.24797 
       henke(6,1, 112 ) = 59.3564 
       henke(6,2, 112 ) = 4.17625 
       henke(6,3, 112 ) = 1.23489 
       henke(6,1, 113 ) = 60.3165 
       henke(6,2, 113 ) = 4.186 
       henke(6,3, 113 ) = 1.22195 
       henke(6,1, 114 ) = 61.2921 
       henke(6,2, 114 ) = 4.19949 
       henke(6,3, 114 ) = 1.20654 
       henke(6,1, 115 ) = 62.2834 
       henke(6,2, 115 ) = 4.21096 
       henke(6,3, 115 ) = 1.18498 
       henke(6,1, 116 ) = 63.2908 
       henke(6,2, 116 ) = 4.2191 
       henke(6,3, 116 ) = 1.16381 
       henke(6,1, 117 ) = 64.3145 
       henke(6,2, 117 ) = 4.22582 
       henke(6,3, 117 ) = 1.14301 
       henke(6,1, 118 ) = 65.3547 
       henke(6,2, 118 ) = 4.23161 
       henke(6,3, 118 ) = 1.12258 
       henke(6,1, 119 ) = 66.4118 
       henke(6,2, 119 ) = 4.23666 
       henke(6,3, 119 ) = 1.10252 
       henke(6,1, 120 ) = 67.4859 
       henke(6,2, 120 ) = 4.24111 
       henke(6,3, 120 ) = 1.08282 
       henke(6,1, 121 ) = 68.5775 
       henke(6,2, 121 ) = 4.24504 
       henke(6,3, 121 ) = 1.06347 
       henke(6,1, 122 ) = 69.6867 
       henke(6,2, 122 ) = 4.24852 
       henke(6,3, 122 ) = 1.04447 
       henke(6,1, 123 ) = 70.8138 
       henke(6,2, 123 ) = 4.2516 
       henke(6,3, 123 ) = 1.0258 
       henke(6,1, 124 ) = 71.9591 
       henke(6,2, 124 ) = 4.2543 
       henke(6,3, 124 ) = 1.00747 
       henke(6,1, 125 ) = 73.123 
       henke(6,2, 125 ) = 4.25667 
       henke(6,3, 125 ) = 0.98947 
       henke(6,1, 126 ) = 74.3057 
       henke(6,2, 126 ) = 4.25872 
       henke(6,3, 126 ) = 0.971788 
       henke(6,1, 127 ) = 75.5076 
       henke(6,2, 127 ) = 4.26047 
       henke(6,3, 127 ) = 0.954423 
       henke(6,1, 128 ) = 76.7289 
       henke(6,2, 128 ) = 4.26194 
       henke(6,3, 128 ) = 0.937369 
       henke(6,1, 129 ) = 77.9699 
       henke(6,2, 129 ) = 4.26314 
       henke(6,3, 129 ) = 0.920617 
       henke(6,1, 130 ) = 79.231 
       henke(6,2, 130 ) = 4.26408 
       henke(6,3, 130 ) = 0.904167 
       henke(6,1, 131 ) = 80.5125 
       henke(6,2, 131 ) = 4.26478 
       henke(6,3, 131 ) = 0.888009 
       henke(6,1, 132 ) = 81.8147 
       henke(6,2, 132 ) = 4.26524 
       henke(6,3, 132 ) = 0.872141 
       henke(6,1, 133 ) = 83.138 
       henke(6,2, 133 ) = 4.26546 
       henke(6,3, 133 ) = 0.856556 
       henke(6,1, 134 ) = 84.4827 
       henke(6,2, 134 ) = 4.26547 
       henke(6,3, 134 ) = 0.84125 
       henke(6,1, 135 ) = 85.8491 
       henke(6,2, 135 ) = 4.26525 
       henke(6,3, 135 ) = 0.826217 
       henke(6,1, 136 ) = 87.2377 
       henke(6,2, 136 ) = 4.26481 
       henke(6,3, 136 ) = 0.811453 
       henke(6,1, 137 ) = 88.6487 
       henke(6,2, 137 ) = 4.26417 
       henke(6,3, 137 ) = 0.796952 
       henke(6,1, 138 ) = 90.0825 
       henke(6,2, 138 ) = 4.26332 
       henke(6,3, 138 ) = 0.782711 
       henke(6,1, 139 ) = 91.5395 
       henke(6,2, 139 ) = 4.26226 
       henke(6,3, 139 ) = 0.768724 
       henke(6,1, 140 ) = 93.0201 
       henke(6,2, 140 ) = 4.261 
       henke(6,3, 140 ) = 0.754987 
       henke(6,1, 141 ) = 94.5246 
       henke(6,2, 141 ) = 4.25953 
       henke(6,3, 141 ) = 0.741496 
       henke(6,1, 142 ) = 96.0535 
       henke(6,2, 142 ) = 4.25787 
       henke(6,3, 142 ) = 0.728246 
       henke(6,1, 143 ) = 97.6071 
       henke(6,2, 143 ) = 4.256 
       henke(6,3, 143 ) = 0.715232 
       henke(6,1, 144 ) = 99.1858 
       henke(6,2, 144 ) = 4.25393 
       henke(6,3, 144 ) = 0.702451 
       henke(6,1, 145 ) = 100.79 
       henke(6,2, 145 ) = 4.25166 
       henke(6,3, 145 ) = 0.689898 
       henke(6,1, 146 ) = 102.42 
       henke(6,2, 146 ) = 4.24919 
       henke(6,3, 146 ) = 0.67757 
       henke(6,1, 147 ) = 104.077 
       henke(6,2, 147 ) = 4.24651 
       henke(6,3, 147 ) = 0.665462 
       henke(6,1, 148 ) = 105.76 
       henke(6,2, 148 ) = 4.24363 
       henke(6,3, 148 ) = 0.65357 
       henke(6,1, 149 ) = 107.471 
       henke(6,2, 149 ) = 4.24054 
       henke(6,3, 149 ) = 0.641891 
       henke(6,1, 150 ) = 109.209 
       henke(6,2, 150 ) = 4.23724 
       henke(6,3, 150 ) = 0.630421 
       henke(6,1, 151 ) = 110.975 
       henke(6,2, 151 ) = 4.23373 
       henke(6,3, 151 ) = 0.619156 
       henke(6,1, 152 ) = 112.77 
       henke(6,2, 152 ) = 4.23 
       henke(6,3, 152 ) = 0.608091 
       henke(6,1, 153 ) = 114.594 
       henke(6,2, 153 ) = 4.22606 
       henke(6,3, 153 ) = 0.597224 
       henke(6,1, 154 ) = 116.448 
       henke(6,2, 154 ) = 4.22189 
       henke(6,3, 154 ) = 0.586552 
       henke(6,1, 155 ) = 118.331 
       henke(6,2, 155 ) = 4.21751 
       henke(6,3, 155 ) = 0.576071 
       henke(6,1, 156 ) = 120.245 
       henke(6,2, 156 ) = 4.21289 
       henke(6,3, 156 ) = 0.565777 
       henke(6,1, 157 ) = 122.19 
       henke(6,2, 157 ) = 4.20806 
       henke(6,3, 157 ) = 0.555666 
       henke(6,1, 158 ) = 124.166 
       henke(6,2, 158 ) = 4.20299 
       henke(6,3, 158 ) = 0.545737 
       henke(6,1, 159 ) = 126.175 
       henke(6,2, 159 ) = 4.19772 
       henke(6,3, 159 ) = 0.535985 
       henke(6,1, 160 ) = 128.215 
       henke(6,2, 160 ) = 4.19225 
       henke(6,3, 160 ) = 0.526406 
       henke(6,1, 161 ) = 130.289 
       henke(6,2, 161 ) = 4.18666 
       henke(6,3, 161 ) = 0.517 
       henke(6,1, 162 ) = 132.397 
       henke(6,2, 162 ) = 4.18122 
       henke(6,3, 162 ) = 0.507761 
       henke(6,1, 163 ) = 134.538 
       henke(6,2, 163 ) = 4.17533 
       henke(6,3, 163 ) = 0.497457 
       henke(6,1, 164 ) = 136.714 
       henke(6,2, 164 ) = 4.1686 
       henke(6,3, 164 ) = 0.487361 
       henke(6,1, 165 ) = 138.925 
       henke(6,2, 165 ) = 4.16122 
       henke(6,3, 165 ) = 0.477469 
       henke(6,1, 166 ) = 141.172 
       henke(6,2, 166 ) = 4.15329 
       henke(6,3, 166 ) = 0.467777 
       henke(6,1, 167 ) = 143.456 
       henke(6,2, 167 ) = 4.14484 
       henke(6,3, 167 ) = 0.458283 
       henke(6,1, 168 ) = 145.776 
       henke(6,2, 168 ) = 4.13587 
       henke(6,3, 168 ) = 0.448981 
       henke(6,1, 169 ) = 148.134 
       henke(6,2, 169 ) = 4.12638 
       henke(6,3, 169 ) = 0.439868 
       henke(6,1, 170 ) = 150.53 
       henke(6,2, 170 ) = 4.11636 
       henke(6,3, 170 ) = 0.430941 
       henke(6,1, 171 ) = 152.964 
       henke(6,2, 171 ) = 4.10578 
       henke(6,3, 171 ) = 0.422193 
       henke(6,1, 172 ) = 155.439 
       henke(6,2, 172 ) = 4.09464 
       henke(6,3, 172 ) = 0.413624 
       henke(6,1, 173 ) = 157.953 
       henke(6,2, 173 ) = 4.0829 
       henke(6,3, 173 ) = 0.405229 
       henke(6,1, 174 ) = 160.507 
       henke(6,2, 174 ) = 4.07054 
       henke(6,3, 174 ) = 0.397004 
       henke(6,1, 175 ) = 163.103 
       henke(6,2, 175 ) = 4.05754 
       henke(6,3, 175 ) = 0.388946 
       henke(6,1, 176 ) = 165.742 
       henke(6,2, 176 ) = 4.04385 
       henke(6,3, 176 ) = 0.381052 
       henke(6,1, 177 ) = 168.422 
       henke(6,2, 177 ) = 4.02945 
       henke(6,3, 177 ) = 0.373318 
       henke(6,1, 178 ) = 171.146 
       henke(6,2, 178 ) = 4.01429 
       henke(6,3, 178 ) = 0.365741 
       henke(6,1, 179 ) = 173.915 
       henke(6,2, 179 ) = 3.99834 
       henke(6,3, 179 ) = 0.358317 
       henke(6,1, 180 ) = 176.727 
       henke(6,2, 180 ) = 3.98158 
       henke(6,3, 180 ) = 0.351045 
       henke(6,1, 181 ) = 179.586 
       henke(6,2, 181 ) = 3.96398 
       henke(6,3, 181 ) = 0.343919 
       henke(6,1, 182 ) = 182.491 
       henke(6,2, 182 ) = 3.94558 
       henke(6,3, 182 ) = 0.336939 
       henke(6,1, 183 ) = 185.442 
       henke(6,2, 183 ) = 3.92716 
       henke(6,3, 183 ) = 0.3301 
       henke(6,1, 184 ) = 188.442 
       henke(6,2, 184 ) = 3.90705 
       henke(6,3, 184 ) = 0.320995 
       henke(6,1, 185 ) = 191.489 
       henke(6,2, 185 ) = 3.88443 
       henke(6,3, 185 ) = 0.312096 
       henke(6,1, 186 ) = 194.587 
       henke(6,2, 186 ) = 3.85977 
       henke(6,3, 186 ) = 0.303443 
       henke(6,1, 187 ) = 197.734 
       henke(6,2, 187 ) = 3.83308 
       henke(6,3, 187 ) = 0.295031 
       henke(6,1, 188 ) = 200.932 
       henke(6,2, 188 ) = 3.80428 
       henke(6,3, 188 ) = 0.286851 
       henke(6,1, 189 ) = 204.182 
       henke(6,2, 189 ) = 3.77323 
       henke(6,3, 189 ) = 0.278898 
       henke(6,1, 190 ) = 207.485 
       henke(6,2, 190 ) = 3.73972 
       henke(6,3, 190 ) = 0.271166 
       henke(6,1, 191 ) = 210.84 
       henke(6,2, 191 ) = 3.70351 
       henke(6,3, 191 ) = 0.263648 
       henke(6,1, 192 ) = 214.251 
       henke(6,2, 192 ) = 3.66428 
       henke(6,3, 192 ) = 0.256338 
       henke(6,1, 193 ) = 217.716 
       henke(6,2, 193 ) = 3.62164 
       henke(6,3, 193 ) = 0.249231 
       henke(6,1, 194 ) = 221.237 
       henke(6,2, 194 ) = 3.57499 
       henke(6,3, 194 ) = 0.242516 
       henke(6,1, 195 ) = 224.816 
       henke(6,2, 195 ) = 3.52435 
       henke(6,3, 195 ) = 0.236381 
       henke(6,1, 196 ) = 228.452 
       henke(6,2, 196 ) = 3.46902 
       henke(6,3, 196 ) = 0.230402 
       henke(6,1, 197 ) = 232.147 
       henke(6,2, 197 ) = 3.40812 
       henke(6,3, 197 ) = 0.224573 
       henke(6,1, 198 ) = 235.902 
       henke(6,2, 198 ) = 3.34061 
       henke(6,3, 198 ) = 0.218892 
       henke(6,1, 199 ) = 239.717 
       henke(6,2, 199 ) = 3.26522 
       henke(6,3, 199 ) = 0.213355 
       henke(6,1, 200 ) = 243.595 
       henke(6,2, 200 ) = 3.18027 
       henke(6,3, 200 ) = 0.207958 
       henke(6,1, 201 ) = 247.535 
       henke(6,2, 201 ) = 3.08474 
       henke(6,3, 201 ) = 0.202179 
       henke(6,1, 202 ) = 251.538 
       henke(6,2, 202 ) = 2.97293 
       henke(6,3, 202 ) = 0.194683 
       henke(6,1, 203 ) = 255.607 
       henke(6,2, 203 ) = 2.84002 
       henke(6,3, 203 ) = 0.187465 
       henke(6,1, 204 ) = 259.741 
       henke(6,2, 204 ) = 2.67985 
       henke(6,3, 204 ) = 0.180514 
       henke(6,1, 205 ) = 263.942 
       henke(6,2, 205 ) = 2.48138 
       henke(6,3, 205 ) = 0.173821 
       henke(6,1, 206 ) = 268.211 
       henke(6,2, 206 ) = 2.22505 
       henke(6,3, 206 ) = 0.167377 
       henke(6,1, 207 ) = 272.549 
       henke(6,2, 207 ) = 1.87159 
       henke(6,3, 207 ) = 0.161171 
       henke(6,1, 208 ) = 276.957 
       henke(6,2, 208 ) = 1.32192 
       henke(6,3, 208 ) = 0.155195 
       henke(6,1, 209 ) = 281.437 
       henke(6,2, 209 ) = 0.158573 
       henke(6,3, 209 ) = 0.149441 
       henke(6,1, 210 ) = 284.1 
       henke(6,2, 210 ) = -4.04882 
       henke(6,3, 210 ) = 0.146163 
       henke(6,1, 211 ) = 284.3 
       henke(6,2, 211 ) = -4.04031 
       henke(6,3, 211 ) = 4.18872 
       henke(6,1, 212 ) = 285.989 
       henke(6,2, 212 ) = -0.28333 
       henke(6,3, 212 ) = 4.15857 
       henke(6,1, 213 ) = 290.615 
       henke(6,2, 213 ) = 1.43967 
       henke(6,3, 213 ) = 4.07798 
       henke(6,1, 214 ) = 295.315 
       henke(6,2, 214 ) = 2.20576 
       henke(6,3, 214 ) = 3.99896 
       henke(6,1, 215 ) = 300.092 
       henke(6,2, 215 ) = 2.71286 
       henke(6,3, 215 ) = 3.92146 
       henke(6,1, 216 ) = 304.945 
       henke(6,2, 216 ) = 3.09475 
       henke(6,3, 216 ) = 3.84546 
       henke(6,1, 217 ) = 309.878 
       henke(6,2, 217 ) = 3.40186 
       henke(6,3, 217 ) = 3.77095 
       henke(6,1, 218 ) = 314.89 
       henke(6,2, 218 ) = 3.65884 
       henke(6,3, 218 ) = 3.69787 
       henke(6,1, 219 ) = 319.983 
       henke(6,2, 219 ) = 3.87969 
       henke(6,3, 219 ) = 3.6262 
       henke(6,1, 220 ) = 325.158 
       henke(6,2, 220 ) = 4.07315 
       henke(6,3, 220 ) = 3.55593 
       henke(6,1, 221 ) = 330.418 
       henke(6,2, 221 ) = 4.2451 
       henke(6,3, 221 ) = 3.48703 
       henke(6,1, 222 ) = 335.762 
       henke(6,2, 222 ) = 4.39967 
       henke(6,3, 222 ) = 3.41945 
       henke(6,1, 223 ) = 341.192 
       henke(6,2, 223 ) = 4.53993 
       henke(6,3, 223 ) = 3.35318 
       henke(6,1, 224 ) = 346.711 
       henke(6,2, 224 ) = 4.66823 
       henke(6,3, 224 ) = 3.2882 
       henke(6,1, 225 ) = 352.319 
       henke(6,2, 225 ) = 4.78642 
       henke(6,3, 225 ) = 3.22448 
       henke(6,1, 226 ) = 358.017 
       henke(6,2, 226 ) = 4.89606 
       henke(6,3, 226 ) = 3.162 
       henke(6,1, 227 ) = 363.808 
       henke(6,2, 227 ) = 4.99852 
       henke(6,3, 227 ) = 3.10072 
       henke(6,1, 228 ) = 369.692 
       henke(6,2, 228 ) = 5.09524 
       henke(6,3, 228 ) = 3.04063 
       henke(6,1, 229 ) = 375.672 
       henke(6,2, 229 ) = 5.1891 
       henke(6,3, 229 ) = 2.9817 
       henke(6,1, 230 ) = 381.748 
       henke(6,2, 230 ) = 5.27926 
       henke(6,3, 230 ) = 2.91649 
       henke(6,1, 231 ) = 387.922 
       henke(6,2, 231 ) = 5.36049 
       henke(6,3, 231 ) = 2.84817 
       henke(6,1, 232 ) = 394.197 
       henke(6,2, 232 ) = 5.43267 
       henke(6,3, 232 ) = 2.78144 
       henke(6,1, 233 ) = 400.573 
       henke(6,2, 233 ) = 5.49897 
       henke(6,3, 233 ) = 2.71628 
       henke(6,1, 234 ) = 407.052 
       henke(6,2, 234 ) = 5.5601 
       henke(6,3, 234 ) = 2.65264 
       henke(6,1, 235 ) = 413.635 
       henke(6,2, 235 ) = 5.61669 
       henke(6,3, 235 ) = 2.5905 
       henke(6,1, 236 ) = 420.326 
       henke(6,2, 236 ) = 5.6692 
       henke(6,3, 236 ) = 2.52981 
       henke(6,1, 237 ) = 427.124 
       henke(6,2, 237 ) = 5.71803 
       henke(6,3, 237 ) = 2.47054 
       henke(6,1, 238 ) = 434.032 
       henke(6,2, 238 ) = 5.76351 
       henke(6,3, 238 ) = 2.41266 
       henke(6,1, 239 ) = 441.052 
       henke(6,2, 239 ) = 5.80593 
       henke(6,3, 239 ) = 2.35614 
       henke(6,1, 240 ) = 448.186 
       henke(6,2, 240 ) = 5.84557 
       henke(6,3, 240 ) = 2.30094 
       henke(6,1, 241 ) = 455.435 
       henke(6,2, 241 ) = 5.88264 
       henke(6,3, 241 ) = 2.24703 
       henke(6,1, 242 ) = 462.802 
       henke(6,2, 242 ) = 5.91737 
       henke(6,3, 242 ) = 2.19439 
       henke(6,1, 243 ) = 470.287 
       henke(6,2, 243 ) = 5.94998 
       henke(6,3, 243 ) = 2.14298 
       henke(6,1, 244 ) = 477.894 
       henke(6,2, 244 ) = 5.98074 
       henke(6,3, 244 ) = 2.09278 
       henke(6,1, 245 ) = 485.623 
       henke(6,2, 245 ) = 6.01022 
       henke(6,3, 245 ) = 2.04367 
       henke(6,1, 246 ) = 493.478 
       henke(6,2, 246 ) = 6.03767 
       henke(6,3, 246 ) = 1.99418 
       henke(6,1, 247 ) = 501.459 
       henke(6,2, 247 ) = 6.06268 
       henke(6,3, 247 ) = 1.94589 
       henke(6,1, 248 ) = 509.57 
       henke(6,2, 248 ) = 6.08579 
       henke(6,3, 248 ) = 1.89876 
       henke(6,1, 249 ) = 517.812 
       henke(6,2, 249 ) = 6.10721 
       henke(6,3, 249 ) = 1.85278 
       henke(6,1, 250 ) = 526.187 
       henke(6,2, 250 ) = 6.12709 
       henke(6,3, 250 ) = 1.80791 
       henke(6,1, 251 ) = 534.698 
       henke(6,2, 251 ) = 6.14556 
       henke(6,3, 251 ) = 1.76412 
       henke(6,1, 252 ) = 543.346 
       henke(6,2, 252 ) = 6.16271 
       henke(6,3, 252 ) = 1.7214 
       henke(6,1, 253 ) = 552.134 
       henke(6,2, 253 ) = 6.17864 
       henke(6,3, 253 ) = 1.67971 
       henke(6,1, 254 ) = 561.065 
       henke(6,2, 254 ) = 6.19344 
       henke(6,3, 254 ) = 1.63903 
       henke(6,1, 255 ) = 570.139 
       henke(6,2, 255 ) = 6.20717 
       henke(6,3, 255 ) = 1.59933 
       henke(6,1, 256 ) = 579.361 
       henke(6,2, 256 ) = 6.21992 
       henke(6,3, 256 ) = 1.5606 
       henke(6,1, 257 ) = 588.732 
       henke(6,2, 257 ) = 6.23174 
       henke(6,3, 257 ) = 1.52281 
       henke(6,1, 258 ) = 598.254 
       henke(6,2, 258 ) = 6.24271 
       henke(6,3, 258 ) = 1.48593 
       henke(6,1, 259 ) = 607.93 
       henke(6,2, 259 ) = 6.25287 
       henke(6,3, 259 ) = 1.44994 
       henke(6,1, 260 ) = 617.763 
       henke(6,2, 260 ) = 6.26227 
       henke(6,3, 260 ) = 1.41483 
       henke(6,1, 261 ) = 627.755 
       henke(6,2, 261 ) = 6.27097 
       henke(6,3, 261 ) = 1.38056 
       henke(6,1, 262 ) = 637.908 
       henke(6,2, 262 ) = 6.279 
       henke(6,3, 262 ) = 1.34713 
       henke(6,1, 263 ) = 648.226 
       henke(6,2, 263 ) = 6.28639 
       henke(6,3, 263 ) = 1.3145 
       henke(6,1, 264 ) = 658.711 
       henke(6,2, 264 ) = 6.29312 
       henke(6,3, 264 ) = 1.28267 
       henke(6,1, 265 ) = 669.365 
       henke(6,2, 265 ) = 6.29901 
       henke(6,3, 265 ) = 1.2516 
       henke(6,1, 266 ) = 680.191 
       henke(6,2, 266 ) = 6.30406 
       henke(6,3, 266 ) = 1.22249 
       henke(6,1, 267 ) = 691.193 
       henke(6,2, 267 ) = 6.30972 
       henke(6,3, 267 ) = 1.19523 
       henke(6,1, 268 ) = 702.372 
       henke(6,2, 268 ) = 6.31822 
       henke(6,3, 268 ) = 1.16897 
       henke(6,1, 269 ) = 713.733 
       henke(6,2, 269 ) = 6.32783 
       henke(6,3, 269 ) = 1.13958 
       henke(6,1, 270 ) = 725.277 
       henke(6,2, 270 ) = 6.33449 
       henke(6,3, 270 ) = 1.10844 
       henke(6,1, 271 ) = 737.008 
       henke(6,2, 271 ) = 6.33933 
       henke(6,3, 271 ) = 1.07816 
       henke(6,1, 272 ) = 748.928 
       henke(6,2, 272 ) = 6.34306 
       henke(6,3, 272 ) = 1.04871 
       henke(6,1, 273 ) = 761.042 
       henke(6,2, 273 ) = 6.34594 
       henke(6,3, 273 ) = 1.02006 
       henke(6,1, 274 ) = 773.351 
       henke(6,2, 274 ) = 6.34813 
       henke(6,3, 274 ) = 0.992182 
       henke(6,1, 275 ) = 785.859 
       henke(6,2, 275 ) = 6.34973 
       henke(6,3, 275 ) = 0.965046 
       henke(6,1, 276 ) = 798.57 
       henke(6,2, 276 ) = 6.3508 
       henke(6,3, 276 ) = 0.938635 
       henke(6,1, 277 ) = 811.486 
       henke(6,2, 277 ) = 6.3514 
       henke(6,3, 277 ) = 0.912939 
       henke(6,1, 278 ) = 824.611 
       henke(6,2, 278 ) = 6.3516 
       henke(6,3, 278 ) = 0.887954 
       henke(6,1, 279 ) = 837.949 
       henke(6,2, 279 ) = 6.35148 
       henke(6,3, 279 ) = 0.863661 
       henke(6,1, 280 ) = 851.502 
       henke(6,2, 280 ) = 6.35111 
       henke(6,3, 280 ) = 0.839923 
       henke(6,1, 281 ) = 865.274 
       henke(6,2, 281 ) = 6.35042 
       henke(6,3, 281 ) = 0.816714 
       henke(6,1, 282 ) = 879.269 
       henke(6,2, 282 ) = 6.34934 
       henke(6,3, 282 ) = 0.794041 
       henke(6,1, 283 ) = 893.491 
       henke(6,2, 283 ) = 6.34793 
       henke(6,3, 283 ) = 0.772006 
       henke(6,1, 284 ) = 907.943 
       henke(6,2, 284 ) = 6.34628 
       henke(6,3, 284 ) = 0.750584 
       henke(6,1, 285 ) = 922.628 
       henke(6,2, 285 ) = 6.34445 
       henke(6,3, 285 ) = 0.729761 
       henke(6,1, 286 ) = 937.551 
       henke(6,2, 286 ) = 6.34244 
       henke(6,3, 286 ) = 0.709358 
       henke(6,1, 287 ) = 952.715 
       henke(6,2, 287 ) = 6.34016 
       henke(6,3, 287 ) = 0.6895 
       henke(6,1, 288 ) = 968.124 
       henke(6,2, 288 ) = 6.33768 
       henke(6,3, 288 ) = 0.670177 
       henke(6,1, 289 ) = 983.783 
       henke(6,2, 289 ) = 6.33503 
       henke(6,3, 289 ) = 0.651378 
       henke(6,1, 290 ) = 999.695 
       henke(6,2, 290 ) = 6.33222 
       henke(6,3, 290 ) = 0.633116 
       henke(6,1, 291 ) = 1015.86 
       henke(6,2, 291 ) = 6.3293 
       henke(6,3, 291 ) = 0.615377 
       henke(6,1, 292 ) = 1032.29 
       henke(6,2, 292 ) = 6.32643 
       henke(6,3, 292 ) = 0.598194 
       henke(6,1, 293 ) = 1048.99 
       henke(6,2, 293 ) = 6.32362 
       henke(6,3, 293 ) = 0.581226 
       henke(6,1, 294 ) = 1065.96 
       henke(6,2, 294 ) = 6.32048 
       henke(6,3, 294 ) = 0.564459 
       henke(6,1, 295 ) = 1083.2 
       henke(6,2, 295 ) = 6.3171 
       henke(6,3, 295 ) = 0.548198 
       henke(6,1, 296 ) = 1100.72 
       henke(6,2, 296 ) = 6.31359 
       henke(6,3, 296 ) = 0.532391 
       henke(6,1, 297 ) = 1118.52 
       henke(6,2, 297 ) = 6.30996 
       henke(6,3, 297 ) = 0.51702 
       henke(6,1, 298 ) = 1136.61 
       henke(6,2, 298 ) = 6.30622 
       henke(6,3, 298 ) = 0.502116 
       henke(6,1, 299 ) = 1155 
       henke(6,2, 299 ) = 6.30242 
       henke(6,3, 299 ) = 0.48764 
       henke(6,1, 300 ) = 1173.68 
       henke(6,2, 300 ) = 6.29857 
       henke(6,3, 300 ) = 0.473579 
       henke(6,1, 301 ) = 1192.66 
       henke(6,2, 301 ) = 6.29469 
       henke(6,3, 301 ) = 0.459933 
       henke(6,1, 302 ) = 1211.95 
       henke(6,2, 302 ) = 6.29081 
       henke(6,3, 302 ) = 0.446675 
       henke(6,1, 303 ) = 1231.55 
       henke(6,2, 303 ) = 6.28694 
       henke(6,3, 303 ) = 0.433794 
       henke(6,1, 304 ) = 1251.47 
       henke(6,2, 304 ) = 6.28313 
       henke(6,3, 304 ) = 0.421175 
       henke(6,1, 305 ) = 1271.72 
       henke(6,2, 305 ) = 6.27931 
       henke(6,3, 305 ) = 0.408804 
       henke(6,1, 306 ) = 1292.29 
       henke(6,2, 306 ) = 6.27534 
       henke(6,3, 306 ) = 0.396652 
       henke(6,1, 307 ) = 1313.19 
       henke(6,2, 307 ) = 6.27127 
       henke(6,3, 307 ) = 0.384872 
       henke(6,1, 308 ) = 1334.43 
       henke(6,2, 308 ) = 6.26716 
       henke(6,3, 308 ) = 0.373439 
       henke(6,1, 309 ) = 1356.01 
       henke(6,2, 309 ) = 6.26302 
       henke(6,3, 309 ) = 0.362342 
       henke(6,1, 310 ) = 1377.94 
       henke(6,2, 310 ) = 6.25886 
       henke(6,3, 310 ) = 0.351578 
       henke(6,1, 311 ) = 1400.23 
       henke(6,2, 311 ) = 6.25469 
       henke(6,3, 311 ) = 0.341132 
       henke(6,1, 312 ) = 1422.88 
       henke(6,2, 312 ) = 6.25054 
       henke(6,3, 312 ) = 0.330994 
       henke(6,1, 313 ) = 1445.89 
       henke(6,2, 313 ) = 6.2464 
       henke(6,3, 313 ) = 0.321159 
       henke(6,1, 314 ) = 1469.28 
       henke(6,2, 314 ) = 6.2423 
       henke(6,3, 314 ) = 0.311605 
       henke(6,1, 315 ) = 1493.04 
       henke(6,2, 315 ) = 6.23822 
       henke(6,3, 315 ) = 0.302316 
       henke(6,1, 316 ) = 1517.19 
       henke(6,2, 316 ) = 6.23418 
       henke(6,3, 316 ) = 0.29323 
       henke(6,1, 317 ) = 1541.73 
       henke(6,2, 317 ) = 6.2301 
       henke(6,3, 317 ) = 0.284407 
       henke(6,1, 318 ) = 1566.67 
       henke(6,2, 318 ) = 6.22604 
       henke(6,3, 318 ) = 0.275847 
       henke(6,1, 319 ) = 1592.01 
       henke(6,2, 319 ) = 6.222 
       henke(6,3, 319 ) = 0.267545 
       henke(6,1, 320 ) = 1617.76 
       henke(6,2, 320 ) = 6.21798 
       henke(6,3, 320 ) = 0.259493 
       henke(6,1, 321 ) = 1643.92 
       henke(6,2, 321 ) = 6.214 
       henke(6,3, 321 ) = 0.251684 
       henke(6,1, 322 ) = 1670.51 
       henke(6,2, 322 ) = 6.21005 
       henke(6,3, 322 ) = 0.24411 
       henke(6,1, 323 ) = 1697.53 
       henke(6,2, 323 ) = 6.20616 
       henke(6,3, 323 ) = 0.236764 
       henke(6,1, 324 ) = 1724.99 
       henke(6,2, 324 ) = 6.20233 
       henke(6,3, 324 ) = 0.229642 
       henke(6,1, 325 ) = 1752.89 
       henke(6,2, 325 ) = 6.19857 
       henke(6,3, 325 ) = 0.222665 
       henke(6,1, 326 ) = 1781.24 
       henke(6,2, 326 ) = 6.1948 
       henke(6,3, 326 ) = 0.215877 
       henke(6,1, 327 ) = 1810.05 
       henke(6,2, 327 ) = 6.19106 
       henke(6,3, 327 ) = 0.209279 
       henke(6,1, 328 ) = 1839.32 
       henke(6,2, 328 ) = 6.18734 
       henke(6,3, 328 ) = 0.202884 
       henke(6,1, 329 ) = 1869.07 
       henke(6,2, 329 ) = 6.18366 
       henke(6,3, 329 ) = 0.196685 
       henke(6,1, 330 ) = 1899.3 
       henke(6,2, 330 ) = 6.18003 
       henke(6,3, 330 ) = 0.190676 
       henke(6,1, 331 ) = 1930.02 
       henke(6,2, 331 ) = 6.17643 
       henke(6,3, 331 ) = 0.18485 
       henke(6,1, 332 ) = 1961.24 
       henke(6,2, 332 ) = 6.17288 
       henke(6,3, 332 ) = 0.179202 
       henke(6,1, 333 ) = 1992.96 
       henke(6,2, 333 ) = 6.16938 
       henke(6,3, 333 ) = 0.173726 
       henke(6,1, 334 ) = 2025.2 
       henke(6,2, 334 ) = 6.16594 
       henke(6,3, 334 ) = 0.168474 
       henke(6,1, 335 ) = 2057.95 
       henke(6,2, 335 ) = 6.16261 
       henke(6,3, 335 ) = 0.163292 
       henke(6,1, 336 ) = 2091.24 
       henke(6,2, 336 ) = 6.15928 
       henke(6,3, 336 ) = 0.158263 
       henke(6,1, 337 ) = 2125.06 
       henke(6,2, 337 ) = 6.156 
       henke(6,3, 337 ) = 0.153384 
       henke(6,1, 338 ) = 2159.43 
       henke(6,2, 338 ) = 6.15276 
       henke(6,3, 338 ) = 0.148648 
       henke(6,1, 339 ) = 2194.36 
       henke(6,2, 339 ) = 6.14957 
       henke(6,3, 339 ) = 0.144053 
       henke(6,1, 340 ) = 2229.85 
       henke(6,2, 340 ) = 6.14643 
       henke(6,3, 340 ) = 0.139593 
       henke(6,1, 341 ) = 2265.92 
       henke(6,2, 341 ) = 6.14334 
       henke(6,3, 341 ) = 0.135267 
       henke(6,1, 342 ) = 2302.57 
       henke(6,2, 342 ) = 6.14028 
       henke(6,3, 342 ) = 0.131069 
       henke(6,1, 343 ) = 2339.81 
       henke(6,2, 343 ) = 6.13729 
       henke(6,3, 343 ) = 0.126998 
       henke(6,1, 344 ) = 2377.66 
       henke(6,2, 344 ) = 6.13433 
       henke(6,3, 344 ) = 0.123042 
       henke(6,1, 345 ) = 2416.11 
       henke(6,2, 345 ) = 6.13143 
       henke(6,3, 345 ) = 0.11921 
       henke(6,1, 346 ) = 2455.19 
       henke(6,2, 346 ) = 6.12857 
       henke(6,3, 346 ) = 0.115492 
       henke(6,1, 347 ) = 2494.9 
       henke(6,2, 347 ) = 6.12576 
       henke(6,3, 347 ) = 0.111882 
       henke(6,1, 348 ) = 2535.26 
       henke(6,2, 348 ) = 6.123 
       henke(6,3, 348 ) = 0.108383 
       henke(6,1, 349 ) = 2576.26 
       henke(6,2, 349 ) = 6.12028 
       henke(6,3, 349 ) = 0.10499 
       henke(6,1, 350 ) = 2617.93 
       henke(6,2, 350 ) = 6.11762 
       henke(6,3, 350 ) = 0.101694 
       henke(6,1, 351 ) = 2660.27 
       henke(6,2, 351 ) = 6.115 
       henke(6,3, 351 ) = 0.0985042 
       henke(6,1, 352 ) = 2703.3 
       henke(6,2, 352 ) = 6.11243 
       henke(6,3, 352 ) = 0.0954028 
       henke(6,1, 353 ) = 2747.03 
       henke(6,2, 353 ) = 6.1099 
       henke(6,3, 353 ) = 0.0923971 
       henke(6,1, 354 ) = 2791.46 
       henke(6,2, 354 ) = 6.10742 
       henke(6,3, 354 ) = 0.0894832 
       henke(6,1, 355 ) = 2836.61 
       henke(6,2, 355 ) = 6.10498 
       henke(6,3, 355 ) = 0.0866617 
       henke(6,1, 356 ) = 2882.49 
       henke(6,2, 356 ) = 6.10259 
       henke(6,3, 356 ) = 0.0839148 
       henke(6,1, 357 ) = 2929.11 
       henke(6,2, 357 ) = 6.10024 
       henke(6,3, 357 ) = 0.0812599 
       henke(6,1, 358 ) = 2976.48 
       henke(6,2, 358 ) = 6.09794 
       henke(6,3, 358 ) = 0.0786821 
       henke(6,1, 359 ) = 3024.63 
       henke(6,2, 359 ) = 6.09569 
       henke(6,3, 359 ) = 0.0761825 
       henke(6,1, 360 ) = 3073.55 
       henke(6,2, 360 ) = 6.09347 
       henke(6,3, 360 ) = 0.0737584 
       henke(6,1, 361 ) = 3123.26 
       henke(6,2, 361 ) = 6.0913 
       henke(6,3, 361 ) = 0.071408 
       henke(6,1, 362 ) = 3173.78 
       henke(6,2, 362 ) = 6.08917 
       henke(6,3, 362 ) = 0.0691288 
       henke(6,1, 363 ) = 3225.11 
       henke(6,2, 363 ) = 6.08708 
       henke(6,3, 363 ) = 0.0669194 
       henke(6,1, 364 ) = 3277.27 
       henke(6,2, 364 ) = 6.08503 
       henke(6,3, 364 ) = 0.0647767 
       henke(6,1, 365 ) = 3330.28 
       henke(6,2, 365 ) = 6.08302 
       henke(6,3, 365 ) = 0.0626991 
       henke(6,1, 366 ) = 3384.15 
       henke(6,2, 366 ) = 6.08105 
       henke(6,3, 366 ) = 0.0606853 
       henke(6,1, 367 ) = 3438.88 
       henke(6,2, 367 ) = 6.07912 
       henke(6,3, 367 ) = 0.0587327 
       henke(6,1, 368 ) = 3494.5 
       henke(6,2, 368 ) = 6.07723 
       henke(6,3, 368 ) = 0.0568396 
       henke(6,1, 369 ) = 3551.02 
       henke(6,2, 369 ) = 6.07538 
       henke(6,3, 369 ) = 0.0550042 
       henke(6,1, 370 ) = 3608.46 
       henke(6,2, 370 ) = 6.07357 
       henke(6,3, 370 ) = 0.0532244 
       henke(6,1, 371 ) = 3666.82 
       henke(6,2, 371 ) = 6.07179 
       henke(6,3, 371 ) = 0.0514997 
       henke(6,1, 372 ) = 3726.13 
       henke(6,2, 372 ) = 6.07005 
       henke(6,3, 372 ) = 0.0498278 
       henke(6,1, 373 ) = 3786.4 
       henke(6,2, 373 ) = 6.06834 
       henke(6,3, 373 ) = 0.0482071 
       henke(6,1, 374 ) = 3847.64 
       henke(6,2, 374 ) = 6.06667 
       henke(6,3, 374 ) = 0.0466352 
       henke(6,1, 375 ) = 3909.87 
       henke(6,2, 375 ) = 6.06504 
       henke(6,3, 375 ) = 0.0451127 
       henke(6,1, 376 ) = 3973.11 
       henke(6,2, 376 ) = 6.06343 
       henke(6,3, 376 ) = 0.0436367 
       henke(6,1, 377 ) = 4037.38 
       henke(6,2, 377 ) = 6.06186 
       henke(6,3, 377 ) = 0.0422212 
       henke(6,1, 378 ) = 4102.68 
       henke(6,2, 378 ) = 6.06033 
       henke(6,3, 378 ) = 0.0408351 
       henke(6,1, 379 ) = 4169.03 
       henke(6,2, 379 ) = 6.05883 
       henke(6,3, 379 ) = 0.0394919 
       henke(6,1, 380 ) = 4236.46 
       henke(6,2, 380 ) = 6.05736 
       henke(6,3, 380 ) = 0.0381921 
       henke(6,1, 381 ) = 4304.98 
       henke(6,2, 381 ) = 6.05592 
       henke(6,3, 381 ) = 0.0369324 
       henke(6,1, 382 ) = 4374.62 
       henke(6,2, 382 ) = 6.05451 
       henke(6,3, 382 ) = 0.035713 
       henke(6,1, 383 ) = 4445.37 
       henke(6,2, 383 ) = 6.05313 
       henke(6,3, 383 ) = 0.0345329 
       henke(6,1, 384 ) = 4517.27 
       henke(6,2, 384 ) = 6.05178 
       henke(6,3, 384 ) = 0.0333896 
       henke(6,1, 385 ) = 4590.33 
       henke(6,2, 385 ) = 6.05046 
       henke(6,3, 385 ) = 0.0322825 
       henke(6,1, 386 ) = 4664.58 
       henke(6,2, 386 ) = 6.04917 
       henke(6,3, 386 ) = 0.03121 
       henke(6,1, 387 ) = 4740.03 
       henke(6,2, 387 ) = 6.04791 
       henke(6,3, 387 ) = 0.0301723 
       henke(6,1, 388 ) = 4816.69 
       henke(6,2, 388 ) = 6.04667 
       henke(6,3, 388 ) = 0.0291678 
       henke(6,1, 389 ) = 4894.6 
       henke(6,2, 389 ) = 6.04547 
       henke(6,3, 389 ) = 0.0281953 
       henke(6,1, 390 ) = 4973.77 
       henke(6,2, 390 ) = 6.04429 
       henke(6,3, 390 ) = 0.0272539 
       henke(6,1, 391 ) = 5054.21 
       henke(6,2, 391 ) = 6.04313 
       henke(6,3, 391 ) = 0.0263428 
       henke(6,1, 392 ) = 5135.96 
       henke(6,2, 392 ) = 6.042 
       henke(6,3, 392 ) = 0.0254606 
       henke(6,1, 393 ) = 5219.03 
       henke(6,2, 393 ) = 6.0409 
       henke(6,3, 393 ) = 0.0246074 
       henke(6,1, 394 ) = 5303.44 
       henke(6,2, 394 ) = 6.03983 
       henke(6,3, 394 ) = 0.023781 
       henke(6,1, 395 ) = 5389.22 
       henke(6,2, 395 ) = 6.03877 
       henke(6,3, 395 ) = 0.0229809 
       henke(6,1, 396 ) = 5476.39 
       henke(6,2, 396 ) = 6.03774 
       henke(6,3, 396 ) = 0.0222063 
       henke(6,1, 397 ) = 5564.97 
       henke(6,2, 397 ) = 6.03674 
       henke(6,3, 397 ) = 0.0214569 
       henke(6,1, 398 ) = 5654.98 
       henke(6,2, 398 ) = 6.03576 
       henke(6,3, 398 ) = 0.0207329 
       henke(6,1, 399 ) = 5746.44 
       henke(6,2, 399 ) = 6.0348 
       henke(6,3, 399 ) = 0.0200314 
       henke(6,1, 400 ) = 5839.39 
       henke(6,2, 400 ) = 6.03386 
       henke(6,3, 400 ) = 0.0193522 
       henke(6,1, 401 ) = 5933.83 
       henke(6,2, 401 ) = 6.03295 
       henke(6,3, 401 ) = 0.0186948 
       henke(6,1, 402 ) = 6029.81 
       henke(6,2, 402 ) = 6.03205 
       henke(6,3, 402 ) = 0.0180595 
       henke(6,1, 403 ) = 6127.33 
       henke(6,2, 403 ) = 6.03118 
       henke(6,3, 403 ) = 0.0174453 
       henke(6,1, 404 ) = 6226.44 
       henke(6,2, 404 ) = 6.03033 
       henke(6,3, 404 ) = 0.0168501 
       henke(6,1, 405 ) = 6327.15 
       henke(6,2, 405 ) = 6.0295 
       henke(6,3, 405 ) = 0.0162746 
       henke(6,1, 406 ) = 6429.48 
       henke(6,2, 406 ) = 6.02869 
       henke(6,3, 406 ) = 0.015718 
       henke(6,1, 407 ) = 6533.48 
       henke(6,2, 407 ) = 6.02789 
       henke(6,3, 407 ) = 0.0151795 
       henke(6,1, 408 ) = 6639.15 
       henke(6,2, 408 ) = 6.02712 
       henke(6,3, 408 ) = 0.0146587 
       henke(6,1, 409 ) = 6746.54 
       henke(6,2, 409 ) = 6.02637 
       henke(6,3, 409 ) = 0.0141549 
       henke(6,1, 410 ) = 6855.65 
       henke(6,2, 410 ) = 6.02563 
       henke(6,3, 410 ) = 0.0136678 
       henke(6,1, 411 ) = 6966.54 
       henke(6,2, 411 ) = 6.02491 
       henke(6,3, 411 ) = 0.0131966 
       henke(6,1, 412 ) = 7079.22 
       henke(6,2, 412 ) = 6.02421 
       henke(6,3, 412 ) = 0.0127407 
       henke(6,1, 413 ) = 7193.72 
       henke(6,2, 413 ) = 6.02352 
       henke(6,3, 413 ) = 0.0123 
       henke(6,1, 414 ) = 7310.07 
       henke(6,2, 414 ) = 6.02285 
       henke(6,3, 414 ) = 0.0118738 
       henke(6,1, 415 ) = 7428.31 
       henke(6,2, 415 ) = 6.0222 
       henke(6,3, 415 ) = 0.0114619 
       henke(6,1, 416 ) = 7548.45 
       henke(6,2, 416 ) = 6.02156 
       henke(6,3, 416 ) = 0.0110634 
       henke(6,1, 417 ) = 7670.54 
       henke(6,2, 417 ) = 6.02094 
       henke(6,3, 417 ) = 0.0106782 
       henke(6,1, 418 ) = 7794.61 
       henke(6,2, 418 ) = 6.02034 
       henke(6,3, 418 ) = 0.0103059 
       henke(6,1, 419 ) = 7920.68 
       henke(6,2, 419 ) = 6.01975 
       henke(6,3, 419 ) = 0.00994583 
       henke(6,1, 420 ) = 8048.79 
       henke(6,2, 420 ) = 6.01917 
       henke(6,3, 420 ) = 0.00959775 
       henke(6,1, 421 ) = 8178.98 
       henke(6,2, 421 ) = 6.01861 
       henke(6,3, 421 ) = 0.00926134 
       henke(6,1, 422 ) = 8311.26 
       henke(6,2, 422 ) = 6.01806 
       henke(6,3, 422 ) = 0.00893624 
       henke(6,1, 423 ) = 8445.69 
       henke(6,2, 423 ) = 6.01753 
       henke(6,3, 423 ) = 0.0086219 
       henke(6,1, 424 ) = 8582.29 
       henke(6,2, 424 ) = 6.017 
       henke(6,3, 424 ) = 0.0083182 
       henke(6,1, 425 ) = 8721.11 
       henke(6,2, 425 ) = 6.0165 
       henke(6,3, 425 ) = 0.00802475 
       henke(6,1, 426 ) = 8862.16 
       henke(6,2, 426 ) = 6.016 
       henke(6,3, 426 ) = 0.00774104 
       henke(6,1, 427 ) = 9005.5 
       henke(6,2, 427 ) = 6.01552 
       henke(6,3, 427 ) = 0.00746686 
       henke(6,1, 428 ) = 9151.16 
       henke(6,2, 428 ) = 6.01505 
       henke(6,3, 428 ) = 0.00720204 
       henke(6,1, 429 ) = 9299.17 
       henke(6,2, 429 ) = 6.01459 
       henke(6,3, 429 ) = 0.00694614 
       henke(6,1, 430 ) = 9449.58 
       henke(6,2, 430 ) = 6.01414 
       henke(6,3, 430 ) = 0.00669902 
       henke(6,1, 431 ) = 9602.42 
       henke(6,2, 431 ) = 6.0137 
       henke(6,3, 431 ) = 0.00646026 
       henke(6,1, 432 ) = 9757.73 
       henke(6,2, 432 ) = 6.01328 
       henke(6,3, 432 ) = 0.00622938 
       henke(6,1, 433 ) = 9915.55 
       henke(6,2, 433 ) = 6.01286 
       henke(6,3, 433 ) = 0.00600659 
       henke(6,1, 434 ) = 10075.9 
       henke(6,2, 434 ) = 6.01246 
       henke(6,3, 434 ) = 0.00579136 
       henke(6,1, 435 ) = 10238.9 
       henke(6,2, 435 ) = 6.01206 
       henke(6,3, 435 ) = 0.0055835 
       henke(6,1, 436 ) = 10404.5 
       henke(6,2, 436 ) = 6.01168 
       henke(6,3, 436 ) = 0.00538276 
       henke(6,1, 437 ) = 10572.8 
       henke(6,2, 437 ) = 6.01131 
       henke(6,3, 437 ) = 0.00518891 
       henke(6,1, 438 ) = 10743.8 
       henke(6,2, 438 ) = 6.01094 
       henke(6,3, 438 ) = 0.00500173 
       henke(6,1, 439 ) = 10917.6 
       henke(6,2, 439 ) = 6.01059 
       henke(6,3, 439 ) = 0.00482101 
       henke(6,1, 440 ) = 11094.2 
       henke(6,2, 440 ) = 6.01024 
       henke(6,3, 440 ) = 0.00464654 
       henke(6,1, 441 ) = 11273.6 
       henke(6,2, 441 ) = 6.00991 
       henke(6,3, 441 ) = 0.0044781 
       henke(6,1, 442 ) = 11455.9 
       henke(6,2, 442 ) = 6.00958 
       henke(6,3, 442 ) = 0.00431552 
       henke(6,1, 443 ) = 11641.2 
       henke(6,2, 443 ) = 6.00926 
       henke(6,3, 443 ) = 0.00415859 
       henke(6,1, 444 ) = 11829.5 
       henke(6,2, 444 ) = 6.00895 
       henke(6,3, 444 ) = 0.00400712 
       henke(6,1, 445 ) = 12020.8 
       henke(6,2, 445 ) = 6.00864 
       henke(6,3, 445 ) = 0.00386096 
       henke(6,1, 446 ) = 12215.3 
       henke(6,2, 446 ) = 6.00835 
       henke(6,3, 446 ) = 0.00371991 
       henke(6,1, 447 ) = 12412.8 
       henke(6,2, 447 ) = 6.00806 
       henke(6,3, 447 ) = 0.00358382 
       henke(6,1, 448 ) = 12613.6 
       henke(6,2, 448 ) = 6.00778 
       henke(6,3, 448 ) = 0.00345251 
       henke(6,1, 449 ) = 12817.6 
       henke(6,2, 449 ) = 6.00751 
       henke(6,3, 449 ) = 0.00332584 
       henke(6,1, 450 ) = 13025 
       henke(6,2, 450 ) = 6.00724 
       henke(6,3, 450 ) = 0.00320365 
       henke(6,1, 451 ) = 13235.6 
       henke(6,2, 451 ) = 6.00698 
       henke(6,3, 451 ) = 0.0030858 
       henke(6,1, 452 ) = 13449.7 
       henke(6,2, 452 ) = 6.00673 
       henke(6,3, 452 ) = 0.00297213 
       henke(6,1, 453 ) = 13667.2 
       henke(6,2, 453 ) = 6.00648 
       henke(6,3, 453 ) = 0.00286252 
       henke(6,1, 454 ) = 13888.3 
       henke(6,2, 454 ) = 6.00625 
       henke(6,3, 454 ) = 0.00275683 
       henke(6,1, 455 ) = 14112.9 
       henke(6,2, 455 ) = 6.00601 
       henke(6,3, 455 ) = 0.00265492 
       henke(6,1, 456 ) = 14341.2 
       henke(6,2, 456 ) = 6.00579 
       henke(6,3, 456 ) = 0.00255668 
       henke(6,1, 457 ) = 14573.1 
       henke(6,2, 457 ) = 6.00557 
       henke(6,3, 457 ) = 0.00246198 
       henke(6,1, 458 ) = 14808.9 
       henke(6,2, 458 ) = 6.00535 
       henke(6,3, 458 ) = 0.00237071 
       henke(6,1, 459 ) = 15048.4 
       henke(6,2, 459 ) = 6.00514 
       henke(6,3, 459 ) = 0.00228275 
       henke(6,1, 460 ) = 15291.8 
       henke(6,2, 460 ) = 6.00494 
       henke(6,3, 460 ) = 0.00219799 
       henke(6,1, 461 ) = 15539.1 
       henke(6,2, 461 ) = 6.00474 
       henke(6,3, 461 ) = 0.00211632 
       henke(6,1, 462 ) = 15790.4 
       henke(6,2, 462 ) = 6.00455 
       henke(6,3, 462 ) = 0.00203764 
       henke(6,1, 463 ) = 16045.8 
       henke(6,2, 463 ) = 6.00436 
       henke(6,3, 463 ) = 0.00196186 
       henke(6,1, 464 ) = 16305.4 
       henke(6,2, 464 ) = 6.00418 
       henke(6,3, 464 ) = 0.00188887 
       henke(6,1, 465 ) = 16569.1 
       henke(6,2, 465 ) = 6.004 
       henke(6,3, 465 ) = 0.00181858 
       henke(6,1, 466 ) = 16837.1 
       henke(6,2, 466 ) = 6.00383 
       henke(6,3, 466 ) = 0.00175089 
       henke(6,1, 467 ) = 17109.4 
       henke(6,2, 467 ) = 6.00366 
       henke(6,3, 467 ) = 0.00168574 
       henke(6,1, 468 ) = 17386.1 
       henke(6,2, 468 ) = 6.0035 
       henke(6,3, 468 ) = 0.00162301 
       henke(6,1, 469 ) = 17667.4 
       henke(6,2, 469 ) = 6.00334 
       henke(6,3, 469 ) = 0.00156265 
       henke(6,1, 470 ) = 17953.1 
       henke(6,2, 470 ) = 6.00319 
       henke(6,3, 470 ) = 0.00150455 
       henke(6,1, 471 ) = 18243.5 
       henke(6,2, 471 ) = 6.00304 
       henke(6,3, 471 ) = 0.00144866 
       henke(6,1, 472 ) = 18538.6 
       henke(6,2, 472 ) = 6.00289 
       henke(6,3, 472 ) = 0.00139489 
       henke(6,1, 473 ) = 18838.4 
       henke(6,2, 473 ) = 6.00275 
       henke(6,3, 473 ) = 0.00134317 
       henke(6,1, 474 ) = 19143.1 
       henke(6,2, 474 ) = 6.00261 
       henke(6,3, 474 ) = 0.00129343 
       henke(6,1, 475 ) = 19452.7 
       henke(6,2, 475 ) = 6.00248 
       henke(6,3, 475 ) = 0.00124561 
       henke(6,1, 476 ) = 19767.4 
       henke(6,2, 476 ) = 6.00235 
       henke(6,3, 476 ) = 0.00119964 
       henke(6,1, 477 ) = 20087.1 
       henke(6,2, 477 ) = 6.00222 
       henke(6,3, 477 ) = 0.00116295 
       henke(6,1, 478 ) = 20412 
       henke(6,2, 478 ) = 6.00211 
       henke(6,3, 478 ) = 0.00111818 
       henke(6,1, 479 ) = 20742.1 
       henke(6,2, 479 ) = 6.00199 
       henke(6,3, 479 ) = 0.00107519 
       henke(6,1, 480 ) = 21077.6 
       henke(6,2, 480 ) = 6.00187 
       henke(6,3, 480 ) = 0.00103391 
       henke(6,1, 481 ) = 21418.5 
       henke(6,2, 481 ) = 6.00176 
       henke(6,3, 481 ) = 0.000994268 
       henke(6,1, 482 ) = 21765 
       henke(6,2, 482 ) = 6.00165 
       henke(6,3, 482 ) = 0.000956195 
       henke(6,1, 483 ) = 22117 
       henke(6,2, 483 ) = 6.00154 
       henke(6,3, 483 ) = 0.000919629 
       henke(6,1, 484 ) = 22474.7 
       henke(6,2, 484 ) = 6.00144 
       henke(6,3, 484 ) = 0.000884508 
       henke(6,1, 485 ) = 22838.2 
       henke(6,2, 485 ) = 6.00134 
       henke(6,3, 485 ) = 0.000850771 
       henke(6,1, 486 ) = 23207.6 
       henke(6,2, 486 ) = 6.00124 
       henke(6,3, 486 ) = 0.000818364 
       henke(6,1, 487 ) = 23583 
       henke(6,2, 487 ) = 6.00115 
       henke(6,3, 487 ) = 0.00078723 
       henke(6,1, 488 ) = 23964.4 
       henke(6,2, 488 ) = 6.00105 
       henke(6,3, 488 ) = 0.00075732 
       henke(6,1, 489 ) = 24352 
       henke(6,2, 489 ) = 6.00096 
       henke(6,3, 489 ) = 0.000728582 
       henke(6,1, 490 ) = 24745.9 
       henke(6,2, 490 ) = 6.00088 
       henke(6,3, 490 ) = 0.000700971 
       henke(6,1, 491 ) = 25146.2 
       henke(6,2, 491 ) = 6.00079 
       henke(6,3, 491 ) = 0.000674438 
       henke(6,1, 492 ) = 25552.9 
       henke(6,2, 492 ) = 6.00071 
       henke(6,3, 492 ) = 0.000648942 
       henke(6,1, 493 ) = 25966.2 
       henke(6,2, 493 ) = 6.00063 
       henke(6,3, 493 ) = 0.000624439 
       henke(6,1, 494 ) = 26386.1 
       henke(6,2, 494 ) = 6.00055 
       henke(6,3, 494 ) = 0.00060089 
       henke(6,1, 495 ) = 26812.9 
       henke(6,2, 495 ) = 6.00048 
       henke(6,3, 495 ) = 0.000578257 
       henke(6,1, 496 ) = 27246.6 
       henke(6,2, 496 ) = 6.0004 
       henke(6,3, 496 ) = 0.000556501 
       henke(6,1, 497 ) = 27687.3 
       henke(6,2, 497 ) = 6.00033 
       henke(6,3, 497 ) = 0.00053559 
       henke(6,1, 498 ) = 28135.1 
       henke(6,2, 498 ) = 6.00026 
       henke(6,3, 498 ) = 0.000515487 
       henke(6,1, 499 ) = 28590.2 
       henke(6,2, 499 ) = 6.0002 
       henke(6,3, 499 ) = 0.000496161 
       henke(6,1, 500 ) = 29052.6 
       henke(6,2, 500 ) = 6.00013 
       henke(6,3, 500 ) = 0.000477581 
       henke(6,1, 501 ) = 29522.5 
       henke(6,2, 501 ) = 6.00007 
       henke(6,3, 501 ) = 0.000459716 
       henke(6,1, 502 ) = 30000 
       henke(6,2, 502 ) = 6 
       henke(6,3, 502 ) = 0.00044254 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C        Henke data for n  z=7
C      count(7) = 503
C      henke(7,1, 1 ) = 10 
C      henke(7,2, 1 ) = -9999 
C      henke(7,3, 1 ) = 0.677847 
C      henke(7,1, 2 ) = 10.1617 
C      henke(7,2, 2 ) = -9999 
C      henke(7,3, 2 ) = 0.689631 
C      henke(7,1, 3 ) = 10.3261 
C      henke(7,2, 3 ) = -9999 
C      henke(7,3, 3 ) = 0.70162 
C      henke(7,1, 4 ) = 10.4931 
C      henke(7,2, 4 ) = -9999 
C      henke(7,3, 4 ) = 0.713817 
C      henke(7,1, 5 ) = 10.6628 
C      henke(7,2, 5 ) = -9999 
C      henke(7,3, 5 ) = 0.726227 
C      henke(7,1, 6 ) = 10.8353 
C      henke(7,2, 6 ) = -9999 
C      henke(7,3, 6 ) = 0.738852 
C      henke(7,1, 7 ) = 11.0106 
C      henke(7,2, 7 ) = -9999 
C      henke(7,3, 7 ) = 0.751697 
C      henke(7,1, 8 ) = 11.1886 
C      henke(7,2, 8 ) = -9999 
C      henke(7,3, 8 ) = 0.765839 
C      henke(7,1, 9 ) = 11.3696 
C      henke(7,2, 9 ) = -9999 
C      henke(7,3, 9 ) = 0.786026 
C      henke(7,1, 10 ) = 11.5535 
C      henke(7,2, 10 ) = -9999 
C      henke(7,3, 10 ) = 0.806743 
C      henke(7,1, 11 ) = 11.7404 
C      henke(7,2, 11 ) = -9999 
C      henke(7,3, 11 ) = 0.828008 
C      henke(7,1, 12 ) = 11.9303 
C      henke(7,2, 12 ) = -9999 
C      henke(7,3, 12 ) = 0.849833 
C      henke(7,1, 13 ) = 12.1232 
C      henke(7,2, 13 ) = -9999 
C      henke(7,3, 13 ) = 0.872233 
C      henke(7,1, 14 ) = 12.3193 
C      henke(7,2, 14 ) = -9999 
C      henke(7,3, 14 ) = 0.895223 
C      henke(7,1, 15 ) = 12.5186 
C      henke(7,2, 15 ) = -9999 
C      henke(7,3, 15 ) = 0.91928 
C      henke(7,1, 16 ) = 12.721 
C      henke(7,2, 16 ) = -9999 
C      henke(7,3, 16 ) = 0.954622 
C      henke(7,1, 17 ) = 12.9268 
C      henke(7,2, 17 ) = -9999 
C      henke(7,3, 17 ) = 0.991323 
C      henke(7,1, 18 ) = 13.1359 
C      henke(7,2, 18 ) = -9999 
C      henke(7,3, 18 ) = 1.02943 
C      henke(7,1, 19 ) = 13.3483 
C      henke(7,2, 19 ) = -9999 
C      henke(7,3, 19 ) = 1.06901 
C      henke(7,1, 20 ) = 13.5642 
C      henke(7,2, 20 ) = -9999 
C      henke(7,3, 20 ) = 1.11011 
C      henke(7,1, 21 ) = 13.7836 
C      henke(7,2, 21 ) = -9999 
C      henke(7,3, 21 ) = 1.15279 
C      henke(7,1, 22 ) = 14.0066 
C      henke(7,2, 22 ) = -9999 
C      henke(7,3, 22 ) = 1.22432 
C      henke(7,1, 23 ) = 14.2331 
C      henke(7,2, 23 ) = -9999 
C      henke(7,3, 23 ) = 1.30424 
C      henke(7,1, 24 ) = 14.4633 
C      henke(7,2, 24 ) = -9999 
C      henke(7,3, 24 ) = 1.38938 
C      henke(7,1, 25 ) = 14.6973 
C      henke(7,2, 25 ) = -9999 
C      henke(7,3, 25 ) = 1.48008 
C      henke(7,1, 26 ) = 14.935 
C      henke(7,2, 26 ) = -9999 
C      henke(7,3, 26 ) = 1.5767 
C      henke(7,1, 27 ) = 15.1765 
C      henke(7,2, 27 ) = -9999 
C      henke(7,3, 27 ) = 1.68655 
C      henke(7,1, 28 ) = 15.422 
C      henke(7,2, 28 ) = -9999 
C      henke(7,3, 28 ) = 1.80625 
C      henke(7,1, 29 ) = 15.6714 
C      henke(7,2, 29 ) = -9999 
C      henke(7,3, 29 ) = 1.93445 
C      henke(7,1, 30 ) = 15.9249 
C      henke(7,2, 30 ) = -9999 
C      henke(7,3, 30 ) = 2.07175 
C      henke(7,1, 31 ) = 16.1825 
C      henke(7,2, 31 ) = -9999 
C      henke(7,3, 31 ) = 2.21879 
C      henke(7,1, 32 ) = 16.4442 
C      henke(7,2, 32 ) = -9999 
C      henke(7,3, 32 ) = 2.37627 
C      henke(7,1, 33 ) = 16.7102 
C      henke(7,2, 33 ) = -9999 
C      henke(7,3, 33 ) = 2.54492 
C      henke(7,1, 34 ) = 16.9805 
C      henke(7,2, 34 ) = -9999 
C      henke(7,3, 34 ) = 2.68091 
C      henke(7,1, 35 ) = 17.2551 
C      henke(7,2, 35 ) = -9999 
C      henke(7,3, 35 ) = 2.82044 
C      henke(7,1, 36 ) = 17.5342 
C      henke(7,2, 36 ) = -9999 
C      henke(7,3, 36 ) = 2.96724 
C      henke(7,1, 37 ) = 17.8178 
C      henke(7,2, 37 ) = -9999 
C      henke(7,3, 37 ) = 3.12169 
C      henke(7,1, 38 ) = 18.106 
C      henke(7,2, 38 ) = -9999 
C      henke(7,3, 38 ) = 3.28417 
C      henke(7,1, 39 ) = 18.3989 
C      henke(7,2, 39 ) = -9999 
C      henke(7,3, 39 ) = 3.45511 
C      henke(7,1, 40 ) = 18.6964 
C      henke(7,2, 40 ) = -9999 
C      henke(7,3, 40 ) = 3.63494 
C      henke(7,1, 41 ) = 18.9988 
C      henke(7,2, 41 ) = -9999 
C      henke(7,3, 41 ) = 3.79196 
C      henke(7,1, 42 ) = 19.3061 
C      henke(7,2, 42 ) = -9999 
C      henke(7,3, 42 ) = 3.94069 
C      henke(7,1, 43 ) = 19.6184 
C      henke(7,2, 43 ) = -9999 
C      henke(7,3, 43 ) = 4.09526 
C      henke(7,1, 44 ) = 19.9357 
C      henke(7,2, 44 ) = -9999 
C      henke(7,3, 44 ) = 4.25588 
C      henke(7,1, 45 ) = 20.2582 
C      henke(7,2, 45 ) = -9999 
C      henke(7,3, 45 ) = 4.42281 
C      henke(7,1, 46 ) = 20.5858 
C      henke(7,2, 46 ) = -9999 
C      henke(7,3, 46 ) = 4.54192 
C      henke(7,1, 47 ) = 20.9188 
C      henke(7,2, 47 ) = -9999 
C      henke(7,3, 47 ) = 4.62172 
C      henke(7,1, 48 ) = 21.2571 
C      henke(7,2, 48 ) = -9999 
C      henke(7,3, 48 ) = 4.70292 
C      henke(7,1, 49 ) = 21.6009 
C      henke(7,2, 49 ) = -9999 
C      henke(7,3, 49 ) = 4.78554 
C      henke(7,1, 50 ) = 21.9503 
C      henke(7,2, 50 ) = -9999 
C      henke(7,3, 50 ) = 4.86963 
C      henke(7,1, 51 ) = 22.3053 
C      henke(7,2, 51 ) = -9999 
C      henke(7,3, 51 ) = 4.92315 
C      henke(7,1, 52 ) = 22.6661 
C      henke(7,2, 52 ) = -9999 
C      henke(7,3, 52 ) = 4.94757 
C      henke(7,1, 53 ) = 23.0327 
C      henke(7,2, 53 ) = -9999 
C      henke(7,3, 53 ) = 4.97211 
C      henke(7,1, 54 ) = 23.4053 
C      henke(7,2, 54 ) = -9999 
C      henke(7,3, 54 ) = 4.99678 
C      henke(7,1, 55 ) = 23.7838 
C      henke(7,2, 55 ) = -9999 
C      henke(7,3, 55 ) = 5.02156 
C      henke(7,1, 56 ) = 24.1685 
C      henke(7,2, 56 ) = -9999 
C      henke(7,3, 56 ) = 5.02138 
C      henke(7,1, 57 ) = 24.5594 
C      henke(7,2, 57 ) = -9999 
C      henke(7,3, 57 ) = 4.99215 
C      henke(7,1, 58 ) = 24.9566 
C      henke(7,2, 58 ) = -9999 
C      henke(7,3, 58 ) = 4.96309 
C      henke(7,1, 59 ) = 25.3603 
C      henke(7,2, 59 ) = -9999 
C      henke(7,3, 59 ) = 4.9342 
C      henke(7,1, 60 ) = 25.7705 
C      henke(7,2, 60 ) = -9999 
C      henke(7,3, 60 ) = 4.90547 
C      henke(7,1, 61 ) = 26.1873 
C      henke(7,2, 61 ) = -9999 
C      henke(7,3, 61 ) = 4.87692 
C      henke(7,1, 62 ) = 26.6109 
C      henke(7,2, 62 ) = -9999 
C      henke(7,3, 62 ) = 4.84853 
C      henke(7,1, 63 ) = 27.0413 
C      henke(7,2, 63 ) = -9999 
C      henke(7,3, 63 ) = 4.8203 
C      henke(7,1, 64 ) = 27.4786 
C      henke(7,2, 64 ) = -9999 
C      henke(7,3, 64 ) = 4.77252 
C      henke(7,1, 65 ) = 27.9231 
C      henke(7,2, 65 ) = -9999 
C      henke(7,3, 65 ) = 4.69687 
C      henke(7,1, 66 ) = 28.3747 
C      henke(7,2, 66 ) = -9999 
C      henke(7,3, 66 ) = 4.62241 
C      henke(7,1, 67 ) = 28.8337 
C      henke(7,2, 67 ) = -9999 
C      henke(7,3, 67 ) = 4.54913 
C      henke(7,1, 68 ) = 29.3 
C      henke(7,2, 68 ) = 3.0967 
C      henke(7,3, 68 ) = 4.47701 
C      henke(7,1, 69 ) = 29.7739 
C      henke(7,2, 69 ) = 3.18574 
C      henke(7,3, 69 ) = 4.40604 
C      henke(7,1, 70 ) = 30.2555 
C      henke(7,2, 70 ) = 3.26861 
C      henke(7,3, 70 ) = 4.33619 
C      henke(7,1, 71 ) = 30.7449 
C      henke(7,2, 71 ) = 3.34589 
C      henke(7,3, 71 ) = 4.26745 
C      henke(7,1, 72 ) = 31.2421 
C      henke(7,2, 72 ) = 3.41793 
C      henke(7,3, 72 ) = 4.1998 
C      henke(7,1, 73 ) = 31.7475 
C      henke(7,2, 73 ) = 3.48497 
C      henke(7,3, 73 ) = 4.13322 
C      henke(7,1, 74 ) = 32.2609 
C      henke(7,2, 74 ) = 3.54521 
C      henke(7,3, 74 ) = 4.0677 
C      henke(7,1, 75 ) = 32.7827 
C      henke(7,2, 75 ) = 3.60004 
C      henke(7,3, 75 ) = 4.00711 
C      henke(7,1, 76 ) = 33.313 
C      henke(7,2, 76 ) = 3.65406 
C      henke(7,3, 76 ) = 3.95223 
C      henke(7,1, 77 ) = 33.8518 
C      henke(7,2, 77 ) = 3.70766 
C      henke(7,3, 77 ) = 3.8981 
C      henke(7,1, 78 ) = 34.3993 
C      henke(7,2, 78 ) = 3.75942 
C      henke(7,3, 78 ) = 3.84471 
C      henke(7,1, 79 ) = 34.9557 
C      henke(7,2, 79 ) = 3.80887 
C      henke(7,3, 79 ) = 3.79205 
C      henke(7,1, 80 ) = 35.5211 
C      henke(7,2, 80 ) = 3.85551 
C      henke(7,3, 80 ) = 3.74012 
C      henke(7,1, 81 ) = 36.0956 
C      henke(7,2, 81 ) = 3.89834 
C      henke(7,3, 81 ) = 3.68889 
C      henke(7,1, 82 ) = 36.6794 
C      henke(7,2, 82 ) = 3.93428 
C      henke(7,3, 82 ) = 3.63837 
C      henke(7,1, 83 ) = 37.2 
C      henke(7,2, 83 ) = 3.93988 
C      henke(7,3, 83 ) = 3.59457 
C      henke(7,1, 84 ) = 37.4 
C      henke(7,2, 84 ) = 3.95594 
C      henke(7,3, 84 ) = 3.64104 
C      henke(7,1, 85 ) = 37.8755 
C      henke(7,2, 85 ) = 4.02773 
C      henke(7,3, 85 ) = 3.6015 
C      henke(7,1, 86 ) = 38.4882 
C      henke(7,2, 86 ) = 4.0871 
C      henke(7,3, 86 ) = 3.55191 
C      henke(7,1, 87 ) = 39.1107 
C      henke(7,2, 87 ) = 4.13881 
C      henke(7,3, 87 ) = 3.503 
C      henke(7,1, 88 ) = 39.7432 
C      henke(7,2, 88 ) = 4.18663 
C      henke(7,3, 88 ) = 3.45476 
C      henke(7,1, 89 ) = 40.3861 
C      henke(7,2, 89 ) = 4.23179 
C      henke(7,3, 89 ) = 3.40719 
C      henke(7,1, 90 ) = 41.0393 
C      henke(7,2, 90 ) = 4.27486 
C      henke(7,3, 90 ) = 3.36027 
C      henke(7,1, 91 ) = 41.7031 
C      henke(7,2, 91 ) = 4.31619 
C      henke(7,3, 91 ) = 3.314 
C      henke(7,1, 92 ) = 42.3776 
C      henke(7,2, 92 ) = 4.35601 
C      henke(7,3, 92 ) = 3.26836 
C      henke(7,1, 93 ) = 43.063 
C      henke(7,2, 93 ) = 4.39451 
C      henke(7,3, 93 ) = 3.22336 
C      henke(7,1, 94 ) = 43.7595 
C      henke(7,2, 94 ) = 4.43188 
C      henke(7,3, 94 ) = 3.17897 
C      henke(7,1, 95 ) = 44.4673 
C      henke(7,2, 95 ) = 4.46832 
C      henke(7,3, 95 ) = 3.1352 
C      henke(7,1, 96 ) = 45.1865 
C      henke(7,2, 96 ) = 4.504 
C      henke(7,3, 96 ) = 3.09203 
C      henke(7,1, 97 ) = 45.9174 
C      henke(7,2, 97 ) = 4.54124 
C      henke(7,3, 97 ) = 3.04945 
C      henke(7,1, 98 ) = 46.66 
C      henke(7,2, 98 ) = 4.57806 
C      henke(7,3, 98 ) = 3.00283 
C      henke(7,1, 99 ) = 47.4147 
C      henke(7,2, 99 ) = 4.61022 
C      henke(7,3, 99 ) = 2.95442 
C      henke(7,1, 100 ) = 48.1816 
C      henke(7,2, 100 ) = 4.6391 
C      henke(7,3, 100 ) = 2.90678 
C      henke(7,1, 101 ) = 48.9609 
C      henke(7,2, 101 ) = 4.66531 
C      henke(7,3, 101 ) = 2.85992 
C      henke(7,1, 102 ) = 49.7528 
C      henke(7,2, 102 ) = 4.68891 
C      henke(7,3, 102 ) = 2.81381 
C      henke(7,1, 103 ) = 50.5576 
C      henke(7,2, 103 ) = 4.70963 
C      henke(7,3, 103 ) = 2.76844 
C      henke(7,1, 104 ) = 51.3753 
C      henke(7,2, 104 ) = 4.72672 
C      henke(7,3, 104 ) = 2.72381 
C      henke(7,1, 105 ) = 52.2062 
C      henke(7,2, 105 ) = 4.73743 
C      henke(7,3, 105 ) = 2.67989 
C      henke(7,1, 106 ) = 53.0506 
C      henke(7,2, 106 ) = 4.72873 
C      henke(7,3, 106 ) = 2.63668 
C      henke(7,1, 107 ) = 53.9087 
C      henke(7,2, 107 ) = 4.74381 
C      henke(7,3, 107 ) = 2.65841 
C      henke(7,1, 108 ) = 54.7806 
C      henke(7,2, 108 ) = 4.79551 
C      henke(7,3, 108 ) = 2.63101 
C      henke(7,1, 109 ) = 55.6667 
C      henke(7,2, 109 ) = 4.82377 
C      henke(7,3, 109 ) = 2.59803 
C      henke(7,1, 110 ) = 56.567 
C      henke(7,2, 110 ) = 4.85174 
C      henke(7,3, 110 ) = 2.56546 
C      henke(7,1, 111 ) = 57.482 
C      henke(7,2, 111 ) = 4.87868 
C      henke(7,3, 111 ) = 2.53328 
C      henke(7,1, 112 ) = 58.4117 
C      henke(7,2, 112 ) = 4.90536 
C      henke(7,3, 112 ) = 2.5015 
C      henke(7,1, 113 ) = 59.3564 
C      henke(7,2, 113 ) = 4.93244 
C      henke(7,3, 113 ) = 2.46913 
C      henke(7,1, 114 ) = 60.3165 
C      henke(7,2, 114 ) = 4.95892 
C      henke(7,3, 114 ) = 2.43557 
C      henke(7,1, 115 ) = 61.2921 
C      henke(7,2, 115 ) = 4.98466 
C      henke(7,3, 115 ) = 2.40164 
C      henke(7,1, 116 ) = 62.2834 
C      henke(7,2, 116 ) = 5.00922 
C      henke(7,3, 116 ) = 2.3663 
C      henke(7,1, 117 ) = 63.2908 
C      henke(7,2, 117 ) = 5.03169 
C      henke(7,3, 117 ) = 2.33146 
C      henke(7,1, 118 ) = 64.3145 
C      henke(7,2, 118 ) = 5.05325 
C      henke(7,3, 118 ) = 2.2971 
C      henke(7,1, 119 ) = 65.3547 
C      henke(7,2, 119 ) = 5.07398 
C      henke(7,3, 119 ) = 2.26327 
C      henke(7,1, 120 ) = 66.4118 
C      henke(7,2, 120 ) = 5.09412 
C      henke(7,3, 120 ) = 2.22997 
C      henke(7,1, 121 ) = 67.4859 
C      henke(7,2, 121 ) = 5.11385 
C      henke(7,3, 121 ) = 2.19716 
C      henke(7,1, 122 ) = 68.5775 
C      henke(7,2, 122 ) = 5.1335 
C      henke(7,3, 122 ) = 2.16482 
C      henke(7,1, 123 ) = 69.6867 
C      henke(7,2, 123 ) = 5.15315 
C      henke(7,3, 123 ) = 2.13196 
C      henke(7,1, 124 ) = 70.8138 
C      henke(7,2, 124 ) = 5.17222 
C      henke(7,3, 124 ) = 2.09899 
C      henke(7,1, 125 ) = 71.9591 
C      henke(7,2, 125 ) = 5.19044 
C      henke(7,3, 125 ) = 2.06521 
C      henke(7,1, 126 ) = 73.123 
C      henke(7,2, 126 ) = 5.20726 
C      henke(7,3, 126 ) = 2.03172 
C      henke(7,1, 127 ) = 74.3057 
C      henke(7,2, 127 ) = 5.22311 
C      henke(7,3, 127 ) = 1.99878 
C      henke(7,1, 128 ) = 75.5076 
C      henke(7,2, 128 ) = 5.23827 
C      henke(7,3, 128 ) = 1.96635 
C      henke(7,1, 129 ) = 76.7289 
C      henke(7,2, 129 ) = 5.25289 
C      henke(7,3, 129 ) = 1.93446 
C      henke(7,1, 130 ) = 77.9699 
C      henke(7,2, 130 ) = 5.26721 
C      henke(7,3, 130 ) = 1.90309 
C      henke(7,1, 131 ) = 79.231 
C      henke(7,2, 131 ) = 5.28116 
C      henke(7,3, 131 ) = 1.87156 
C      henke(7,1, 132 ) = 80.5125 
C      henke(7,2, 132 ) = 5.29458 
C      henke(7,3, 132 ) = 1.84053 
C      henke(7,1, 133 ) = 81.8147 
C      henke(7,2, 133 ) = 5.30767 
C      henke(7,3, 133 ) = 1.80919 
C      henke(7,1, 134 ) = 83.138 
C      henke(7,2, 134 ) = 5.31977 
C      henke(7,3, 134 ) = 1.77788 
C      henke(7,1, 135 ) = 84.4827 
C      henke(7,2, 135 ) = 5.3309 
C      henke(7,3, 135 ) = 1.74711 
C      henke(7,1, 136 ) = 85.8491 
C      henke(7,2, 136 ) = 5.34142 
C      henke(7,3, 136 ) = 1.71687 
C      henke(7,1, 137 ) = 87.2377 
C      henke(7,2, 137 ) = 5.35147 
C      henke(7,3, 137 ) = 1.68715 
C      henke(7,1, 138 ) = 88.6487 
C      henke(7,2, 138 ) = 5.36108 
C      henke(7,3, 138 ) = 1.65784 
C      henke(7,1, 139 ) = 90.0825 
C      henke(7,2, 139 ) = 5.3703 
C      henke(7,3, 139 ) = 1.62891 
C      henke(7,1, 140 ) = 91.5395 
C      henke(7,2, 140 ) = 5.37913 
C      henke(7,3, 140 ) = 1.60031 
C      henke(7,1, 141 ) = 93.0201 
C      henke(7,2, 141 ) = 5.3874 
C      henke(7,3, 141 ) = 1.5719 
C      henke(7,1, 142 ) = 94.5246 
C      henke(7,2, 142 ) = 5.39514 
C      henke(7,3, 142 ) = 1.544 
C      henke(7,1, 143 ) = 96.0535 
C      henke(7,2, 143 ) = 5.4025 
C      henke(7,3, 143 ) = 1.51661 
C      henke(7,1, 144 ) = 97.6071 
C      henke(7,2, 144 ) = 5.40957 
C      henke(7,3, 144 ) = 1.48969 
C      henke(7,1, 145 ) = 99.1858 
C      henke(7,2, 145 ) = 5.41689 
C      henke(7,3, 145 ) = 1.46326 
C      henke(7,1, 146 ) = 100.79 
C      henke(7,2, 146 ) = 5.42415 
C      henke(7,3, 146 ) = 1.43628 
C      henke(7,1, 147 ) = 102.42 
C      henke(7,2, 147 ) = 5.43019 
C      henke(7,3, 147 ) = 1.40887 
C      henke(7,1, 148 ) = 104.077 
C      henke(7,2, 148 ) = 5.4353 
C      henke(7,3, 148 ) = 1.38222 
C      henke(7,1, 149 ) = 105.76 
C      henke(7,2, 149 ) = 5.43994 
C      henke(7,3, 149 ) = 1.35606 
C      henke(7,1, 150 ) = 107.471 
C      henke(7,2, 150 ) = 5.44406 
C      henke(7,3, 150 ) = 1.33039 
C      henke(7,1, 151 ) = 109.209 
C      henke(7,2, 151 ) = 5.44773 
C      henke(7,3, 151 ) = 1.30519 
C      henke(7,1, 152 ) = 110.975 
C      henke(7,2, 152 ) = 5.45099 
C      henke(7,3, 152 ) = 1.28048 
C      henke(7,1, 153 ) = 112.77 
C      henke(7,2, 153 ) = 5.45389 
C      henke(7,3, 153 ) = 1.25624 
C      henke(7,1, 154 ) = 114.594 
C      henke(7,2, 154 ) = 5.45644 
C      henke(7,3, 154 ) = 1.23245 
C      henke(7,1, 155 ) = 116.448 
C      henke(7,2, 155 ) = 5.45866 
C      henke(7,3, 155 ) = 1.20914 
C      henke(7,1, 156 ) = 118.331 
C      henke(7,2, 156 ) = 5.46061 
C      henke(7,3, 156 ) = 1.18627 
C      henke(7,1, 157 ) = 120.245 
C      henke(7,2, 157 ) = 5.4623 
C      henke(7,3, 157 ) = 1.16381 
C      henke(7,1, 158 ) = 122.19 
C      henke(7,2, 158 ) = 5.46373 
C      henke(7,3, 158 ) = 1.14177 
C      henke(7,1, 159 ) = 124.166 
C      henke(7,2, 159 ) = 5.46493 
C      henke(7,3, 159 ) = 1.12014 
C      henke(7,1, 160 ) = 126.175 
C      henke(7,2, 160 ) = 5.46595 
C      henke(7,3, 160 ) = 1.09894 
C      henke(7,1, 161 ) = 128.215 
C      henke(7,2, 161 ) = 5.46695 
C      henke(7,3, 161 ) = 1.07815 
C      henke(7,1, 162 ) = 130.289 
C      henke(7,2, 162 ) = 5.46801 
C      henke(7,3, 162 ) = 1.0576 
C      henke(7,1, 163 ) = 132.397 
C      henke(7,2, 163 ) = 5.46877 
C      henke(7,3, 163 ) = 1.03651 
C      henke(7,1, 164 ) = 134.538 
C      henke(7,2, 164 ) = 5.46881 
C      henke(7,3, 164 ) = 1.01582 
C      henke(7,1, 165 ) = 136.714 
C      henke(7,2, 165 ) = 5.46841 
C      henke(7,3, 165 ) = 0.995549 
C      henke(7,1, 166 ) = 138.925 
C      henke(7,2, 166 ) = 5.46766 
C      henke(7,3, 166 ) = 0.975693 
C      henke(7,1, 167 ) = 141.172 
C      henke(7,2, 167 ) = 5.46663 
C      henke(7,3, 167 ) = 0.956241 
C      henke(7,1, 168 ) = 143.456 
C      henke(7,2, 168 ) = 5.46534 
C      henke(7,3, 168 ) = 0.937174 
C      henke(7,1, 169 ) = 145.776 
C      henke(7,2, 169 ) = 5.46382 
C      henke(7,3, 169 ) = 0.918471 
C      henke(7,1, 170 ) = 148.134 
C      henke(7,2, 170 ) = 5.46208 
C      henke(7,3, 170 ) = 0.900155 
C      henke(7,1, 171 ) = 150.53 
C      henke(7,2, 171 ) = 5.4602 
C      henke(7,3, 171 ) = 0.882212 
C      henke(7,1, 172 ) = 152.964 
C      henke(7,2, 172 ) = 5.4582 
C      henke(7,3, 172 ) = 0.86461 
C      henke(7,1, 173 ) = 155.439 
C      henke(7,2, 173 ) = 5.45616 
C      henke(7,3, 173 ) = 0.847362 
C      henke(7,1, 174 ) = 157.953 
C      henke(7,2, 174 ) = 5.45421 
C      henke(7,3, 174 ) = 0.830458 
C      henke(7,1, 175 ) = 160.507 
C      henke(7,2, 175 ) = 5.45304 
C      henke(7,3, 175 ) = 0.813567 
C      henke(7,1, 176 ) = 163.103 
C      henke(7,2, 176 ) = 5.45202 
C      henke(7,3, 176 ) = 0.795548 
C      henke(7,1, 177 ) = 165.742 
C      henke(7,2, 177 ) = 5.44957 
C      henke(7,3, 177 ) = 0.77626 
C      henke(7,1, 178 ) = 168.422 
C      henke(7,2, 178 ) = 5.44577 
C      henke(7,3, 178 ) = 0.757438 
C      henke(7,1, 179 ) = 171.146 
C      henke(7,2, 179 ) = 5.44112 
C      henke(7,3, 179 ) = 0.739074 
C      henke(7,1, 180 ) = 173.915 
C      henke(7,2, 180 ) = 5.4358 
C      henke(7,3, 180 ) = 0.721154 
C      henke(7,1, 181 ) = 176.727 
C      henke(7,2, 181 ) = 5.42989 
C      henke(7,3, 181 ) = 0.70367 
C      henke(7,1, 182 ) = 179.586 
C      henke(7,2, 182 ) = 5.42343 
C      henke(7,3, 182 ) = 0.686608 
C      henke(7,1, 183 ) = 182.491 
C      henke(7,2, 183 ) = 5.41647 
C      henke(7,3, 183 ) = 0.669961 
C      henke(7,1, 184 ) = 185.442 
C      henke(7,2, 184 ) = 5.40903 
C      henke(7,3, 184 ) = 0.653718 
C      henke(7,1, 185 ) = 188.442 
C      henke(7,2, 185 ) = 5.40111 
C      henke(7,3, 185 ) = 0.637868 
C      henke(7,1, 186 ) = 191.489 
C      henke(7,2, 186 ) = 5.39274 
C      henke(7,3, 186 ) = 0.622402 
C      henke(7,1, 187 ) = 194.587 
C      henke(7,2, 187 ) = 5.38392 
C      henke(7,3, 187 ) = 0.607312 
C      henke(7,1, 188 ) = 197.734 
C      henke(7,2, 188 ) = 5.37465 
C      henke(7,3, 188 ) = 0.592587 
C      henke(7,1, 189 ) = 200.932 
C      henke(7,2, 189 ) = 5.36494 
C      henke(7,3, 189 ) = 0.578219 
C      henke(7,1, 190 ) = 204.182 
C      henke(7,2, 190 ) = 5.35477 
C      henke(7,3, 190 ) = 0.5642 
C      henke(7,1, 191 ) = 207.485 
C      henke(7,2, 191 ) = 5.34415 
C      henke(7,3, 191 ) = 0.550521 
C      henke(7,1, 192 ) = 210.84 
C      henke(7,2, 192 ) = 5.33308 
C      henke(7,3, 192 ) = 0.537173 
C      henke(7,1, 193 ) = 214.251 
C      henke(7,2, 193 ) = 5.32155 
C      henke(7,3, 193 ) = 0.524149 
C      henke(7,1, 194 ) = 217.716 
C      henke(7,2, 194 ) = 5.30957 
C      henke(7,3, 194 ) = 0.51144 
C      henke(7,1, 195 ) = 221.237 
C      henke(7,2, 195 ) = 5.29733 
C      henke(7,3, 195 ) = 0.498997 
C      henke(7,1, 196 ) = 224.816 
C      henke(7,2, 196 ) = 5.2845 
C      henke(7,3, 196 ) = 0.486268 
C      henke(7,1, 197 ) = 228.452 
C      henke(7,2, 197 ) = 5.27067 
C      henke(7,3, 197 ) = 0.473865 
C      henke(7,1, 198 ) = 232.147 
C      henke(7,2, 198 ) = 5.25612 
C      henke(7,3, 198 ) = 0.461778 
C      henke(7,1, 199 ) = 235.902 
C      henke(7,2, 199 ) = 5.24084 
C      henke(7,3, 199 ) = 0.449999 
C      henke(7,1, 200 ) = 239.717 
C      henke(7,2, 200 ) = 5.2248 
C      henke(7,3, 200 ) = 0.438521 
C      henke(7,1, 201 ) = 243.595 
C      henke(7,2, 201 ) = 5.20796 
C      henke(7,3, 201 ) = 0.427335 
C      henke(7,1, 202 ) = 247.535 
C      henke(7,2, 202 ) = 5.19029 
C      henke(7,3, 202 ) = 0.416435 
C      henke(7,1, 203 ) = 251.538 
C      henke(7,2, 203 ) = 5.17175 
C      henke(7,3, 203 ) = 0.405812 
C      henke(7,1, 204 ) = 255.607 
C      henke(7,2, 204 ) = 5.15227 
C      henke(7,3, 204 ) = 0.395461 
C      henke(7,1, 205 ) = 259.741 
C      henke(7,2, 205 ) = 5.13178 
C      henke(7,3, 205 ) = 0.385374 
C      henke(7,1, 206 ) = 263.942 
C      henke(7,2, 206 ) = 5.11023 
C      henke(7,3, 206 ) = 0.375544 
C      henke(7,1, 207 ) = 268.211 
C      henke(7,2, 207 ) = 5.08753 
C      henke(7,3, 207 ) = 0.365965 
C      henke(7,1, 208 ) = 272.549 
C      henke(7,2, 208 ) = 5.06357 
C      henke(7,3, 208 ) = 0.35663 
C      henke(7,1, 209 ) = 276.957 
C      henke(7,2, 209 ) = 5.03826 
C      henke(7,3, 209 ) = 0.347533 
C      henke(7,1, 210 ) = 281.437 
C      henke(7,2, 210 ) = 5.01147 
C      henke(7,3, 210 ) = 0.338668 
C      henke(7,1, 211 ) = 285.989 
C      henke(7,2, 211 ) = 4.98307 
C      henke(7,3, 211 ) = 0.33003 
C      henke(7,1, 212 ) = 290.615 
C      henke(7,2, 212 ) = 4.95292 
C      henke(7,3, 212 ) = 0.321611 
C      henke(7,1, 213 ) = 295.315 
C      henke(7,2, 213 ) = 4.92083 
C      henke(7,3, 213 ) = 0.313408 
C      henke(7,1, 214 ) = 300.092 
C      henke(7,2, 214 ) = 4.88664 
C      henke(7,3, 214 ) = 0.305413 
C      henke(7,1, 215 ) = 304.945 
C      henke(7,2, 215 ) = 4.85017 
C      henke(7,3, 215 ) = 0.297623 
C      henke(7,1, 216 ) = 309.878 
C      henke(7,2, 216 ) = 4.81152 
C      henke(7,3, 216 ) = 0.290032 
C      henke(7,1, 217 ) = 314.89 
C      henke(7,2, 217 ) = 4.77024 
C      henke(7,3, 217 ) = 0.280969 
C      henke(7,1, 218 ) = 319.983 
C      henke(7,2, 218 ) = 4.7242 
C      henke(7,3, 218 ) = 0.271097 
C      henke(7,1, 219 ) = 325.158 
C      henke(7,2, 219 ) = 4.67285 
C      henke(7,3, 219 ) = 0.261571 
C      henke(7,1, 220 ) = 330.418 
C      henke(7,2, 220 ) = 4.61616 
C      henke(7,3, 220 ) = 0.25238 
C      henke(7,1, 221 ) = 335.762 
C      henke(7,2, 221 ) = 4.55339 
C      henke(7,3, 221 ) = 0.243512 
C      henke(7,1, 222 ) = 341.192 
C      henke(7,2, 222 ) = 4.48353 
C      henke(7,3, 222 ) = 0.234956 
C      henke(7,1, 223 ) = 346.711 
C      henke(7,2, 223 ) = 4.40525 
C      henke(7,3, 223 ) = 0.2267 
C      henke(7,1, 224 ) = 352.319 
C      henke(7,2, 224 ) = 4.31681 
C      henke(7,3, 224 ) = 0.218734 
C      henke(7,1, 225 ) = 358.017 
C      henke(7,2, 225 ) = 4.21577 
C      henke(7,3, 225 ) = 0.211049 
C      henke(7,1, 226 ) = 363.808 
C      henke(7,2, 226 ) = 4.09877 
C      henke(7,3, 226 ) = 0.203644 
C      henke(7,1, 227 ) = 369.692 
C      henke(7,2, 227 ) = 3.96099 
C      henke(7,3, 227 ) = 0.196614 
C      henke(7,1, 228 ) = 375.672 
C      henke(7,2, 228 ) = 3.79504 
C      henke(7,3, 228 ) = 0.189827 
C      henke(7,1, 229 ) = 381.748 
C      henke(7,2, 229 ) = 3.58874 
C      henke(7,3, 229 ) = 0.183275 
C      henke(7,1, 230 ) = 387.922 
C      henke(7,2, 230 ) = 3.32035 
C      henke(7,3, 230 ) = 0.176948 
C      henke(7,1, 231 ) = 394.197 
C      henke(7,2, 231 ) = 2.94481 
C      henke(7,3, 231 ) = 0.17084 
C      henke(7,1, 232 ) = 400.573 
C      henke(7,2, 232 ) = 2.34175 
C      henke(7,3, 232 ) = 0.164943 
C      henke(7,1, 233 ) = 407.052 
C      henke(7,2, 233 ) = 0.902755 
C      henke(7,3, 233 ) = 0.159249 
C      henke(7,1, 234 ) = 409.8 
C      henke(7,2, 234 ) = -3.34729 
C      henke(7,3, 234 ) = 0.156919 
C      henke(7,1, 235 ) = 410 
C      henke(7,2, 235 ) = -3.3407 
C      henke(7,3, 235 ) = 4.19145 
C      henke(7,1, 236 ) = 413.635 
C      henke(7,2, 236 ) = 1.37475 
C      henke(7,3, 236 ) = 4.14308 
C      henke(7,1, 237 ) = 420.326 
C      henke(7,2, 237 ) = 2.76993 
C      henke(7,3, 237 ) = 4.05657 
C      henke(7,1, 238 ) = 427.124 
C      henke(7,2, 238 ) = 3.4718 
C      henke(7,3, 238 ) = 3.97187 
C      henke(7,1, 239 ) = 434.032 
C      henke(7,2, 239 ) = 3.9503 
C      henke(7,3, 239 ) = 3.88894 
C      henke(7,1, 240 ) = 441.052 
C      henke(7,2, 240 ) = 4.31518 
C      henke(7,3, 240 ) = 3.80774 
C      henke(7,1, 241 ) = 448.186 
C      henke(7,2, 241 ) = 4.61038 
C      henke(7,3, 241 ) = 3.72824 
C      henke(7,1, 242 ) = 455.435 
C      henke(7,2, 242 ) = 4.85808 
C      henke(7,3, 242 ) = 3.65039 
C      henke(7,1, 243 ) = 462.802 
C      henke(7,2, 243 ) = 5.07115 
C      henke(7,3, 243 ) = 3.57417 
C      henke(7,1, 244 ) = 470.287 
C      henke(7,2, 244 ) = 5.25773 
C      henke(7,3, 244 ) = 3.49954 
C      henke(7,1, 245 ) = 477.894 
C      henke(7,2, 245 ) = 5.42335 
C      henke(7,3, 245 ) = 3.42648 
C      henke(7,1, 246 ) = 485.623 
C      henke(7,2, 246 ) = 5.57192 
C      henke(7,3, 246 ) = 3.35493 
C      henke(7,1, 247 ) = 493.478 
C      henke(7,2, 247 ) = 5.70635 
C      henke(7,3, 247 ) = 3.28488 
C      henke(7,1, 248 ) = 501.459 
C      henke(7,2, 248 ) = 5.82888 
C      henke(7,3, 248 ) = 3.21629 
C      henke(7,1, 249 ) = 509.57 
C      henke(7,2, 249 ) = 5.94124 
C      henke(7,3, 249 ) = 3.14914 
C      henke(7,1, 250 ) = 517.812 
C      henke(7,2, 250 ) = 6.04487 
C      henke(7,3, 250 ) = 3.08339 
C      henke(7,1, 251 ) = 526.187 
C      henke(7,2, 251 ) = 6.14095 
C      henke(7,3, 251 ) = 3.01901 
C      henke(7,1, 252 ) = 534.698 
C      henke(7,2, 252 ) = 6.23051 
C      henke(7,3, 252 ) = 2.95597 
C      henke(7,1, 253 ) = 543.346 
C      henke(7,2, 253 ) = 6.31452 
C      henke(7,3, 253 ) = 2.89425 
C      henke(7,1, 254 ) = 552.134 
C      henke(7,2, 254 ) = 6.39405 
C      henke(7,3, 254 ) = 2.83382 
C      henke(7,1, 255 ) = 561.065 
C      henke(7,2, 255 ) = 6.47106 
C      henke(7,3, 255 ) = 2.77465 
C      henke(7,1, 256 ) = 570.139 
C      henke(7,2, 256 ) = 6.54609 
C      henke(7,3, 256 ) = 2.71065 
C      henke(7,1, 257 ) = 579.361 
C      henke(7,2, 257 ) = 6.61317 
C      henke(7,3, 257 ) = 2.64396 
C      henke(7,1, 258 ) = 588.732 
C      henke(7,2, 258 ) = 6.67262 
C      henke(7,3, 258 ) = 2.5789 
C      henke(7,1, 259 ) = 598.254 
C      henke(7,2, 259 ) = 6.72717 
C      henke(7,3, 259 ) = 2.51545 
C      henke(7,1, 260 ) = 607.93 
C      henke(7,2, 260 ) = 6.77737 
C      henke(7,3, 260 ) = 2.45355 
C      henke(7,1, 261 ) = 617.763 
C      henke(7,2, 261 ) = 6.82373 
C      henke(7,3, 261 ) = 2.39319 
C      henke(7,1, 262 ) = 627.755 
C      henke(7,2, 262 ) = 6.86664 
C      henke(7,3, 262 ) = 2.3343 
C      henke(7,1, 263 ) = 637.908 
C      henke(7,2, 263 ) = 6.90643 
C      henke(7,3, 263 ) = 2.27687 
C      henke(7,1, 264 ) = 648.226 
C      henke(7,2, 264 ) = 6.94337 
C      henke(7,3, 264 ) = 2.22084 
C      henke(7,1, 265 ) = 658.711 
C      henke(7,2, 265 ) = 6.97771 
C      henke(7,3, 265 ) = 2.1662 
C      henke(7,1, 266 ) = 669.365 
C      henke(7,2, 266 ) = 7.00967 
C      henke(7,3, 266 ) = 2.1129 
C      henke(7,1, 267 ) = 680.191 
C      henke(7,2, 267 ) = 7.03943 
C      henke(7,3, 267 ) = 2.06091 
C      henke(7,1, 268 ) = 691.193 
C      henke(7,2, 268 ) = 7.06718 
C      henke(7,3, 268 ) = 2.01021 
C      henke(7,1, 269 ) = 702.372 
C      henke(7,2, 269 ) = 7.09308 
C      henke(7,3, 269 ) = 1.96074 
C      henke(7,1, 270 ) = 713.733 
C      henke(7,2, 270 ) = 7.11728 
C      henke(7,3, 270 ) = 1.9125 
C      henke(7,1, 271 ) = 725.277 
C      henke(7,2, 271 ) = 7.13995 
C      henke(7,3, 271 ) = 1.86544 
C      henke(7,1, 272 ) = 737.008 
C      henke(7,2, 272 ) = 7.16124 
C      henke(7,3, 272 ) = 1.81954 
C      henke(7,1, 273 ) = 748.928 
C      henke(7,2, 273 ) = 7.18132 
C      henke(7,3, 273 ) = 1.77478 
C      henke(7,1, 274 ) = 761.042 
C      henke(7,2, 274 ) = 7.20082 
C      henke(7,3, 274 ) = 1.73111 
C      henke(7,1, 275 ) = 773.351 
C      henke(7,2, 275 ) = 7.21973 
C      henke(7,3, 275 ) = 1.68755 
C      henke(7,1, 276 ) = 785.859 
C      henke(7,2, 276 ) = 7.2371 
C      henke(7,3, 276 ) = 1.64348 
C      henke(7,1, 277 ) = 798.57 
C      henke(7,2, 277 ) = 7.2523 
C      henke(7,3, 277 ) = 1.5998 
C      henke(7,1, 278 ) = 811.486 
C      henke(7,2, 278 ) = 7.2655 
C      henke(7,3, 278 ) = 1.55727 
C      henke(7,1, 279 ) = 824.611 
C      henke(7,2, 279 ) = 7.27724 
C      henke(7,3, 279 ) = 1.51588 
C      henke(7,1, 280 ) = 837.949 
C      henke(7,2, 280 ) = 7.28754 
C      henke(7,3, 280 ) = 1.47559 
C      henke(7,1, 281 ) = 851.502 
C      henke(7,2, 281 ) = 7.29659 
C      henke(7,3, 281 ) = 1.43672 
C      henke(7,1, 282 ) = 865.274 
C      henke(7,2, 282 ) = 7.30472 
C      henke(7,3, 282 ) = 1.39924 
C      henke(7,1, 283 ) = 879.269 
C      henke(7,2, 283 ) = 7.31226 
C      henke(7,3, 283 ) = 1.36305 
C      henke(7,1, 284 ) = 893.491 
C      henke(7,2, 284 ) = 7.31934 
C      henke(7,3, 284 ) = 1.32778 
C      henke(7,1, 285 ) = 907.943 
C      henke(7,2, 285 ) = 7.32586 
C      henke(7,3, 285 ) = 1.29344 
C      henke(7,1, 286 ) = 922.628 
C      henke(7,2, 286 ) = 7.33212 
C      henke(7,3, 286 ) = 1.26 
C      henke(7,1, 287 ) = 937.551 
C      henke(7,2, 287 ) = 7.33793 
C      henke(7,3, 287 ) = 1.22669 
C      henke(7,1, 288 ) = 952.715 
C      henke(7,2, 288 ) = 7.34274 
C      henke(7,3, 288 ) = 1.1941 
C      henke(7,1, 289 ) = 968.124 
C      henke(7,2, 289 ) = 7.34685 
C      henke(7,3, 289 ) = 1.16223 
C      henke(7,1, 290 ) = 983.783 
C      henke(7,2, 290 ) = 7.35026 
C      henke(7,3, 290 ) = 1.13121 
C      henke(7,1, 291 ) = 999.695 
C      henke(7,2, 291 ) = 7.35311 
C      henke(7,3, 291 ) = 1.10104 
C      henke(7,1, 292 ) = 1015.86 
C      henke(7,2, 292 ) = 7.35545 
C      henke(7,3, 292 ) = 1.07169 
C      henke(7,1, 293 ) = 1032.29 
C      henke(7,2, 293 ) = 7.35753 
C      henke(7,3, 293 ) = 1.0434 
C      henke(7,1, 294 ) = 1048.99 
C      henke(7,2, 294 ) = 7.35965 
C      henke(7,3, 294 ) = 1.01539 
C      henke(7,1, 295 ) = 1065.96 
C      henke(7,2, 295 ) = 7.36113 
C      henke(7,3, 295 ) = 0.987635 
C      henke(7,1, 296 ) = 1083.2 
C      henke(7,2, 296 ) = 7.36187 
C      henke(7,3, 296 ) = 0.960644 
C      henke(7,1, 297 ) = 1100.72 
C      henke(7,2, 297 ) = 7.36219 
C      henke(7,3, 297 ) = 0.934382 
C      henke(7,1, 298 ) = 1118.52 
C      henke(7,2, 298 ) = 7.36212 
C      henke(7,3, 298 ) = 0.908828 
C      henke(7,1, 299 ) = 1136.61 
C      henke(7,2, 299 ) = 7.36171 
C      henke(7,3, 299 ) = 0.883967 
C      henke(7,1, 300 ) = 1155 
C      henke(7,2, 300 ) = 7.36099 
C      henke(7,3, 300 ) = 0.859792 
C      henke(7,1, 301 ) = 1173.68 
C      henke(7,2, 301 ) = 7.36002 
C      henke(7,3, 301 ) = 0.836289 
C      henke(7,1, 302 ) = 1192.66 
C      henke(7,2, 302 ) = 7.35885 
C      henke(7,3, 302 ) = 0.813426 
C      henke(7,1, 303 ) = 1211.95 
C      henke(7,2, 303 ) = 7.35751 
C      henke(7,3, 303 ) = 0.791189 
C      henke(7,1, 304 ) = 1231.55 
C      henke(7,2, 304 ) = 7.35616 
C      henke(7,3, 304 ) = 0.769561 
C      henke(7,1, 305 ) = 1251.47 
C      henke(7,2, 305 ) = 7.35479 
C      henke(7,3, 305 ) = 0.74822 
C      henke(7,1, 306 ) = 1271.72 
C      henke(7,2, 306 ) = 7.35321 
C      henke(7,3, 306 ) = 0.727154 
C      henke(7,1, 307 ) = 1292.29 
C      henke(7,2, 307 ) = 7.35124 
C      henke(7,3, 307 ) = 0.706299 
C      henke(7,1, 308 ) = 1313.19 
C      henke(7,2, 308 ) = 7.34877 
C      henke(7,3, 308 ) = 0.686031 
C      henke(7,1, 309 ) = 1334.43 
C      henke(7,2, 309 ) = 7.34603 
C      henke(7,3, 309 ) = 0.666348 
C      henke(7,1, 310 ) = 1356.01 
C      henke(7,2, 310 ) = 7.34309 
C      henke(7,3, 310 ) = 0.647237 
C      henke(7,1, 311 ) = 1377.94 
C      henke(7,2, 311 ) = 7.33996 
C      henke(7,3, 311 ) = 0.62864 
C      henke(7,1, 312 ) = 1400.23 
C      henke(7,2, 312 ) = 7.33664 
C      henke(7,3, 312 ) = 0.610591 
C      henke(7,1, 313 ) = 1422.88 
C      henke(7,2, 313 ) = 7.33321 
C      henke(7,3, 313 ) = 0.593089 
C      henke(7,1, 314 ) = 1445.89 
C      henke(7,2, 314 ) = 7.32971 
C      henke(7,3, 314 ) = 0.576061 
C      henke(7,1, 315 ) = 1469.28 
C      henke(7,2, 315 ) = 7.32611 
C      henke(7,3, 315 ) = 0.559505 
C      henke(7,1, 316 ) = 1493.04 
C      henke(7,2, 316 ) = 7.3225 
C      henke(7,3, 316 ) = 0.543407 
C      henke(7,1, 317 ) = 1517.19 
C      henke(7,2, 317 ) = 7.31883 
C      henke(7,3, 317 ) = 0.527586 
C      henke(7,1, 318 ) = 1541.73 
C      henke(7,2, 318 ) = 7.31491 
C      henke(7,3, 318 ) = 0.512213 
C      henke(7,1, 319 ) = 1566.67 
C      henke(7,2, 319 ) = 7.31092 
C      henke(7,3, 319 ) = 0.49731 
C      henke(7,1, 320 ) = 1592.01 
C      henke(7,2, 320 ) = 7.30688 
C      henke(7,3, 320 ) = 0.482831 
C      henke(7,1, 321 ) = 1617.76 
C      henke(7,2, 321 ) = 7.30279 
C      henke(7,3, 321 ) = 0.468772 
C      henke(7,1, 322 ) = 1643.92 
C      henke(7,2, 322 ) = 7.29866 
C      henke(7,3, 322 ) = 0.45512 
C      henke(7,1, 323 ) = 1670.51 
C      henke(7,2, 323 ) = 7.29452 
C      henke(7,3, 323 ) = 0.441867 
C      henke(7,1, 324 ) = 1697.53 
C      henke(7,2, 324 ) = 7.29037 
C      henke(7,3, 324 ) = 0.429 
C      henke(7,1, 325 ) = 1724.99 
C      henke(7,2, 325 ) = 7.28628 
C      henke(7,3, 325 ) = 0.416509 
C      henke(7,1, 326 ) = 1752.89 
C      henke(7,2, 326 ) = 7.28224 
C      henke(7,3, 326 ) = 0.404201 
C      henke(7,1, 327 ) = 1781.24 
C      henke(7,2, 327 ) = 7.27808 
C      henke(7,3, 327 ) = 0.392198 
C      henke(7,1, 328 ) = 1810.05 
C      henke(7,2, 328 ) = 7.27386 
C      henke(7,3, 328 ) = 0.380508 
C      henke(7,1, 329 ) = 1839.32 
C      henke(7,2, 329 ) = 7.26959 
C      henke(7,3, 329 ) = 0.369169 
C      henke(7,1, 330 ) = 1869.07 
C      henke(7,2, 330 ) = 7.2653 
C      henke(7,3, 330 ) = 0.358167 
C      henke(7,1, 331 ) = 1899.3 
C      henke(7,2, 331 ) = 7.26101 
C      henke(7,3, 331 ) = 0.347492 
C      henke(7,1, 332 ) = 1930.02 
C      henke(7,2, 332 ) = 7.25672 
C      henke(7,3, 332 ) = 0.337134 
C      henke(7,1, 333 ) = 1961.24 
C      henke(7,2, 333 ) = 7.25245 
C      henke(7,3, 333 ) = 0.327086 
C      henke(7,1, 334 ) = 1992.96 
C      henke(7,2, 334 ) = 7.24817 
C      henke(7,3, 334 ) = 0.31734 
C      henke(7,1, 335 ) = 2025.2 
C      henke(7,2, 335 ) = 7.24396 
C      henke(7,3, 335 ) = 0.307997 
C      henke(7,1, 336 ) = 2057.95 
C      henke(7,2, 336 ) = 7.2399 
C      henke(7,3, 336 ) = 0.298733 
C      henke(7,1, 337 ) = 2091.24 
C      henke(7,2, 337 ) = 7.23578 
C      henke(7,3, 337 ) = 0.289725 
C      henke(7,1, 338 ) = 2125.06 
C      henke(7,2, 338 ) = 7.23167 
C      henke(7,3, 338 ) = 0.280975 
C      henke(7,1, 339 ) = 2159.43 
C      henke(7,2, 339 ) = 7.22757 
C      henke(7,3, 339 ) = 0.272469 
C      henke(7,1, 340 ) = 2194.36 
C      henke(7,2, 340 ) = 7.2235 
C      henke(7,3, 340 ) = 0.26421 
C      henke(7,1, 341 ) = 2229.85 
C      henke(7,2, 341 ) = 7.21945 
C      henke(7,3, 341 ) = 0.256185 
C      henke(7,1, 342 ) = 2265.92 
C      henke(7,2, 342 ) = 7.21543 
C      henke(7,3, 342 ) = 0.248394 
C      henke(7,1, 343 ) = 2302.57 
C      henke(7,2, 343 ) = 7.21145 
C      henke(7,3, 343 ) = 0.240822 
C      henke(7,1, 344 ) = 2339.81 
C      henke(7,2, 344 ) = 7.2075 
C      henke(7,3, 344 ) = 0.233471 
C      henke(7,1, 345 ) = 2377.66 
C      henke(7,2, 345 ) = 7.20358 
C      henke(7,3, 345 ) = 0.226326 
C      henke(7,1, 346 ) = 2416.11 
C      henke(7,2, 346 ) = 7.1997 
C      henke(7,3, 346 ) = 0.21939 
C      henke(7,1, 347 ) = 2455.19 
C      henke(7,2, 347 ) = 7.19586 
C      henke(7,3, 347 ) = 0.212656 
C      henke(7,1, 348 ) = 2494.9 
C      henke(7,2, 348 ) = 7.19206 
C      henke(7,3, 348 ) = 0.20612 
C      henke(7,1, 349 ) = 2535.26 
C      henke(7,2, 349 ) = 7.18831 
C      henke(7,3, 349 ) = 0.199772 
C      henke(7,1, 350 ) = 2576.26 
C      henke(7,2, 350 ) = 7.18459 
C      henke(7,3, 350 ) = 0.193608 
C      henke(7,1, 351 ) = 2617.93 
C      henke(7,2, 351 ) = 7.18093 
C      henke(7,3, 351 ) = 0.18763 
C      henke(7,1, 352 ) = 2660.27 
C      henke(7,2, 352 ) = 7.1773 
C      henke(7,3, 352 ) = 0.181816 
C      henke(7,1, 353 ) = 2703.3 
C      henke(7,2, 353 ) = 7.17372 
C      henke(7,3, 353 ) = 0.176182 
C      henke(7,1, 354 ) = 2747.03 
C      henke(7,2, 354 ) = 7.17019 
C      henke(7,3, 354 ) = 0.170711 
C      henke(7,1, 355 ) = 2791.46 
C      henke(7,2, 355 ) = 7.1667 
C      henke(7,3, 355 ) = 0.165399 
C      henke(7,1, 356 ) = 2836.61 
C      henke(7,2, 356 ) = 7.16327 
C      henke(7,3, 356 ) = 0.16025 
C      henke(7,1, 357 ) = 2882.49 
C      henke(7,2, 357 ) = 7.15988 
C      henke(7,3, 357 ) = 0.155248 
C      henke(7,1, 358 ) = 2929.11 
C      henke(7,2, 358 ) = 7.15654 
C      henke(7,3, 358 ) = 0.150389 
C      henke(7,1, 359 ) = 2976.48 
C      henke(7,2, 359 ) = 7.15324 
C      henke(7,3, 359 ) = 0.14568 
C      henke(7,1, 360 ) = 3024.63 
C      henke(7,2, 360 ) = 7.15 
C      henke(7,3, 360 ) = 0.14111 
C      henke(7,1, 361 ) = 3073.55 
C      henke(7,2, 361 ) = 7.1468 
C      henke(7,3, 361 ) = 0.136673 
C      henke(7,1, 362 ) = 3123.26 
C      henke(7,2, 362 ) = 7.14365 
C      henke(7,3, 362 ) = 0.13237 
C      henke(7,1, 363 ) = 3173.78 
C      henke(7,2, 363 ) = 7.14055 
C      henke(7,3, 363 ) = 0.128195 
C      henke(7,1, 364 ) = 3225.11 
C      henke(7,2, 364 ) = 7.1375 
C      henke(7,3, 364 ) = 0.124153 
C      henke(7,1, 365 ) = 3277.27 
C      henke(7,2, 365 ) = 7.13451 
C      henke(7,3, 365 ) = 0.120219 
C      henke(7,1, 366 ) = 3330.28 
C      henke(7,2, 366 ) = 7.13155 
C      henke(7,3, 366 ) = 0.116411 
C      henke(7,1, 367 ) = 3384.15 
C      henke(7,2, 367 ) = 7.12865 
C      henke(7,3, 367 ) = 0.112717 
C      henke(7,1, 368 ) = 3438.88 
C      henke(7,2, 368 ) = 7.12579 
C      henke(7,3, 368 ) = 0.109134 
C      henke(7,1, 369 ) = 3494.5 
C      henke(7,2, 369 ) = 7.12299 
C      henke(7,3, 369 ) = 0.105658 
C      henke(7,1, 370 ) = 3551.02 
C      henke(7,2, 370 ) = 7.12023 
C      henke(7,3, 370 ) = 0.102286 
C      henke(7,1, 371 ) = 3608.46 
C      henke(7,2, 371 ) = 7.11752 
C      henke(7,3, 371 ) = 0.0990161 
C      henke(7,1, 372 ) = 3666.82 
C      henke(7,2, 372 ) = 7.11486 
C      henke(7,3, 372 ) = 0.0958453 
C      henke(7,1, 373 ) = 3726.13 
C      henke(7,2, 373 ) = 7.11224 
C      henke(7,3, 373 ) = 0.092771 
C      henke(7,1, 374 ) = 3786.4 
C      henke(7,2, 374 ) = 7.10967 
C      henke(7,3, 374 ) = 0.089789 
C      henke(7,1, 375 ) = 3847.64 
C      henke(7,2, 375 ) = 7.10714 
C      henke(7,3, 375 ) = 0.0868981 
C      henke(7,1, 376 ) = 3909.87 
C      henke(7,2, 376 ) = 7.10467 
C      henke(7,3, 376 ) = 0.0840951 
C      henke(7,1, 377 ) = 3973.11 
C      henke(7,2, 377 ) = 7.10224 
C      henke(7,3, 377 ) = 0.0813777 
C      henke(7,1, 378 ) = 4037.38 
C      henke(7,2, 378 ) = 7.09985 
C      henke(7,3, 378 ) = 0.0787312 
C      henke(7,1, 379 ) = 4102.68 
C      henke(7,2, 379 ) = 7.09749 
C      henke(7,3, 379 ) = 0.0761794 
C      henke(7,1, 380 ) = 4169.03 
C      henke(7,2, 380 ) = 7.09518 
C      henke(7,3, 380 ) = 0.0737062 
C      henke(7,1, 381 ) = 4236.46 
C      henke(7,2, 381 ) = 7.09292 
C      henke(7,3, 381 ) = 0.071312 
C      henke(7,1, 382 ) = 4304.98 
C      henke(7,2, 382 ) = 7.0907 
C      henke(7,3, 382 ) = 0.0689915 
C      henke(7,1, 383 ) = 4374.62 
C      henke(7,2, 383 ) = 7.08853 
C      henke(7,3, 383 ) = 0.066744 
C      henke(7,1, 384 ) = 4445.37 
C      henke(7,2, 384 ) = 7.0864 
C      henke(7,3, 384 ) = 0.0645673 
C      henke(7,1, 385 ) = 4517.27 
C      henke(7,2, 385 ) = 7.0843 
C      henke(7,3, 385 ) = 0.0624588 
C      henke(7,1, 386 ) = 4590.33 
C      henke(7,2, 386 ) = 7.08226 
C      henke(7,3, 386 ) = 0.0604167 
C      henke(7,1, 387 ) = 4664.58 
C      henke(7,2, 387 ) = 7.08025 
C      henke(7,3, 387 ) = 0.058439 
C      henke(7,1, 388 ) = 4740.03 
C      henke(7,2, 388 ) = 7.07828 
C      henke(7,3, 388 ) = 0.056523 
C      henke(7,1, 389 ) = 4816.69 
C      henke(7,2, 389 ) = 7.07635 
C      henke(7,3, 389 ) = 0.0546688 
C      henke(7,1, 390 ) = 4894.6 
C      henke(7,2, 390 ) = 7.07446 
C      henke(7,3, 390 ) = 0.0528719 
C      henke(7,1, 391 ) = 4973.77 
C      henke(7,2, 391 ) = 7.07262 
C      henke(7,3, 391 ) = 0.0511327 
C      henke(7,1, 392 ) = 5054.21 
C      henke(7,2, 392 ) = 7.07081 
C      henke(7,3, 392 ) = 0.0494484 
C      henke(7,1, 393 ) = 5135.96 
C      henke(7,2, 393 ) = 7.06903 
C      henke(7,3, 393 ) = 0.0478178 
C      henke(7,1, 394 ) = 5219.03 
C      henke(7,2, 394 ) = 7.0673 
C      henke(7,3, 394 ) = 0.0462392 
C      henke(7,1, 395 ) = 5303.44 
C      henke(7,2, 395 ) = 7.0656 
C      henke(7,3, 395 ) = 0.0447096 
C      henke(7,1, 396 ) = 5389.22 
C      henke(7,2, 396 ) = 7.06394 
C      henke(7,3, 396 ) = 0.0432299 
C      henke(7,1, 397 ) = 5476.39 
C      henke(7,2, 397 ) = 7.06231 
C      henke(7,3, 397 ) = 0.0417965 
C      henke(7,1, 398 ) = 5564.97 
C      henke(7,2, 398 ) = 7.06072 
C      henke(7,3, 398 ) = 0.0404085 
C      henke(7,1, 399 ) = 5654.98 
C      henke(7,2, 399 ) = 7.05916 
C      henke(7,3, 399 ) = 0.0390665 
C      henke(7,1, 400 ) = 5746.44 
C      henke(7,2, 400 ) = 7.05764 
C      henke(7,3, 400 ) = 0.0377663 
C      henke(7,1, 401 ) = 5839.39 
C      henke(7,2, 401 ) = 7.05615 
C      henke(7,3, 401 ) = 0.0365079 
C      henke(7,1, 402 ) = 5933.83 
C      henke(7,2, 402 ) = 7.0547 
C      henke(7,3, 402 ) = 0.035289 
C      henke(7,1, 403 ) = 6029.81 
C      henke(7,2, 403 ) = 7.05327 
C      henke(7,3, 403 ) = 0.0341103 
C      henke(7,1, 404 ) = 6127.33 
C      henke(7,2, 404 ) = 7.05188 
C      henke(7,3, 404 ) = 0.0329685 
C      henke(7,1, 405 ) = 6226.44 
C      henke(7,2, 405 ) = 7.05052 
C      henke(7,3, 405 ) = 0.031864 
C      henke(7,1, 406 ) = 6327.15 
C      henke(7,2, 406 ) = 7.04918 
C      henke(7,3, 406 ) = 0.0307956 
C      henke(7,1, 407 ) = 6429.48 
C      henke(7,2, 407 ) = 7.04788 
C      henke(7,3, 407 ) = 0.0297618 
C      henke(7,1, 408 ) = 6533.48 
C      henke(7,2, 408 ) = 7.04661 
C      henke(7,3, 408 ) = 0.0287609 
C      henke(7,1, 409 ) = 6639.15 
C      henke(7,2, 409 ) = 7.04537 
C      henke(7,3, 409 ) = 0.0277916 
C      henke(7,1, 410 ) = 6746.54 
C      henke(7,2, 410 ) = 7.04415 
C      henke(7,3, 410 ) = 0.0268536 
C      henke(7,1, 411 ) = 6855.65 
C      henke(7,2, 411 ) = 7.04296 
C      henke(7,3, 411 ) = 0.0259475 
C      henke(7,1, 412 ) = 6966.54 
C      henke(7,2, 412 ) = 7.04181 
C      henke(7,3, 412 ) = 0.02507 
C      henke(7,1, 413 ) = 7079.22 
C      henke(7,2, 413 ) = 7.04067 
C      henke(7,3, 413 ) = 0.0242218 
C      henke(7,1, 414 ) = 7193.72 
C      henke(7,2, 414 ) = 7.03957 
C      henke(7,3, 414 ) = 0.0234003 
C      henke(7,1, 415 ) = 7310.07 
C      henke(7,2, 415 ) = 7.03848 
C      henke(7,3, 415 ) = 0.0226054 
C      henke(7,1, 416 ) = 7428.31 
C      henke(7,2, 416 ) = 7.03743 
C      henke(7,3, 416 ) = 0.0218367 
C      henke(7,1, 417 ) = 7548.45 
C      henke(7,2, 417 ) = 7.0364 
C      henke(7,3, 417 ) = 0.0210932 
C      henke(7,1, 418 ) = 7670.54 
C      henke(7,2, 418 ) = 7.03539 
C      henke(7,3, 418 ) = 0.0203739 
C      henke(7,1, 419 ) = 7794.61 
C      henke(7,2, 419 ) = 7.03441 
C      henke(7,3, 419 ) = 0.0196782 
C      henke(7,1, 420 ) = 7920.68 
C      henke(7,2, 420 ) = 7.03345 
C      henke(7,3, 420 ) = 0.0190053 
C      henke(7,1, 421 ) = 8048.79 
C      henke(7,2, 421 ) = 7.03251 
C      henke(7,3, 421 ) = 0.0183546 
C      henke(7,1, 422 ) = 8178.98 
C      henke(7,2, 422 ) = 7.03159 
C      henke(7,3, 422 ) = 0.0177251 
C      henke(7,1, 423 ) = 8311.26 
C      henke(7,2, 423 ) = 7.0307 
C      henke(7,3, 423 ) = 0.0171163 
C      henke(7,1, 424 ) = 8445.69 
C      henke(7,2, 424 ) = 7.02983 
C      henke(7,3, 424 ) = 0.0165279 
C      henke(7,1, 425 ) = 8582.29 
C      henke(7,2, 425 ) = 7.02898 
C      henke(7,3, 425 ) = 0.0159585 
C      henke(7,1, 426 ) = 8721.11 
C      henke(7,2, 426 ) = 7.02814 
C      henke(7,3, 426 ) = 0.0154081 
C      henke(7,1, 427 ) = 8862.16 
C      henke(7,2, 427 ) = 7.02733 
C      henke(7,3, 427 ) = 0.014876 
C      henke(7,1, 428 ) = 9005.5 
C      henke(7,2, 428 ) = 7.02654 
C      henke(7,3, 428 ) = 0.0143614 
C      henke(7,1, 429 ) = 9151.16 
C      henke(7,2, 429 ) = 7.02577 
C      henke(7,3, 429 ) = 0.013864 
C      henke(7,1, 430 ) = 9299.17 
C      henke(7,2, 430 ) = 7.02502 
C      henke(7,3, 430 ) = 0.0133831 
C      henke(7,1, 431 ) = 9449.58 
C      henke(7,2, 431 ) = 7.02428 
C      henke(7,3, 431 ) = 0.0129181 
C      henke(7,1, 432 ) = 9602.42 
C      henke(7,2, 432 ) = 7.02356 
C      henke(7,3, 432 ) = 0.0124689 
C      henke(7,1, 433 ) = 9757.73 
C      henke(7,2, 433 ) = 7.02286 
C      henke(7,3, 433 ) = 0.0120344 
C      henke(7,1, 434 ) = 9915.55 
C      henke(7,2, 434 ) = 7.02218 
C      henke(7,3, 434 ) = 0.0116146 
C      henke(7,1, 435 ) = 10075.9 
C      henke(7,2, 435 ) = 7.02152 
C      henke(7,3, 435 ) = 0.0112088 
C      henke(7,1, 436 ) = 10238.9 
C      henke(7,2, 436 ) = 7.02087 
C      henke(7,3, 436 ) = 0.0108166 
C      henke(7,1, 437 ) = 10404.5 
C      henke(7,2, 437 ) = 7.02023 
C      henke(7,3, 437 ) = 0.0104376 
C      henke(7,1, 438 ) = 10572.8 
C      henke(7,2, 438 ) = 7.01962 
C      henke(7,3, 438 ) = 0.0100714 
C      henke(7,1, 439 ) = 10743.8 
C      henke(7,2, 439 ) = 7.01901 
C      henke(7,3, 439 ) = 0.00971753 
C      henke(7,1, 440 ) = 10917.6 
C      henke(7,2, 440 ) = 7.01843 
C      henke(7,3, 440 ) = 0.0093756 
C      henke(7,1, 441 ) = 11094.2 
C      henke(7,2, 441 ) = 7.01785 
C      henke(7,3, 441 ) = 0.00904524 
C      henke(7,1, 442 ) = 11273.6 
C      henke(7,2, 442 ) = 7.0173 
C      henke(7,3, 442 ) = 0.00872607 
C      henke(7,1, 443 ) = 11455.9 
C      henke(7,2, 443 ) = 7.01675 
C      henke(7,3, 443 ) = 0.00841776 
C      henke(7,1, 444 ) = 11641.2 
C      henke(7,2, 444 ) = 7.01622 
C      henke(7,3, 444 ) = 0.00811993 
C      henke(7,1, 445 ) = 11829.5 
C      henke(7,2, 445 ) = 7.0157 
C      henke(7,3, 445 ) = 0.00783223 
C      henke(7,1, 446 ) = 12020.8 
C      henke(7,2, 446 ) = 7.0152 
C      henke(7,3, 446 ) = 0.00755438 
C      henke(7,1, 447 ) = 12215.3 
C      henke(7,2, 447 ) = 7.01471 
C      henke(7,3, 447 ) = 0.00728601 
C      henke(7,1, 448 ) = 12412.8 
C      henke(7,2, 448 ) = 7.01423 
C      henke(7,3, 448 ) = 0.00702685 
C      henke(7,1, 449 ) = 12613.6 
C      henke(7,2, 449 ) = 7.01376 
C      henke(7,3, 449 ) = 0.00677659 
C      henke(7,1, 450 ) = 12817.6 
C      henke(7,2, 450 ) = 7.01331 
C      henke(7,3, 450 ) = 0.00653494 
C      henke(7,1, 451 ) = 13025 
C      henke(7,2, 451 ) = 7.01287 
C      henke(7,3, 451 ) = 0.00630162 
C      henke(7,1, 452 ) = 13235.6 
C      henke(7,2, 452 ) = 7.01243 
C      henke(7,3, 452 ) = 0.00607636 
C      henke(7,1, 453 ) = 13449.7 
C      henke(7,2, 453 ) = 7.01201 
C      henke(7,3, 453 ) = 0.0058589 
C      henke(7,1, 454 ) = 13667.2 
C      henke(7,2, 454 ) = 7.0116 
C      henke(7,3, 454 ) = 0.00564898 
C      henke(7,1, 455 ) = 13888.3 
C      henke(7,2, 455 ) = 7.0112 
C      henke(7,3, 455 ) = 0.00544636 
C      henke(7,1, 456 ) = 14112.9 
C      henke(7,2, 456 ) = 7.01082 
C      henke(7,3, 456 ) = 0.0052508 
C      henke(7,1, 457 ) = 14341.2 
C      henke(7,2, 457 ) = 7.01044 
C      henke(7,3, 457 ) = 0.00506207 
C      henke(7,1, 458 ) = 14573.1 
C      henke(7,2, 458 ) = 7.01007 
C      henke(7,3, 458 ) = 0.00487994 
C      henke(7,1, 459 ) = 14808.9 
C      henke(7,2, 459 ) = 7.00971 
C      henke(7,3, 459 ) = 0.00470421 
C      henke(7,1, 460 ) = 15048.4 
C      henke(7,2, 460 ) = 7.00936 
C      henke(7,3, 460 ) = 0.00453465 
C      henke(7,1, 461 ) = 15291.8 
C      henke(7,2, 461 ) = 7.00902 
C      henke(7,3, 461 ) = 0.00437107 
C      henke(7,1, 462 ) = 15539.1 
C      henke(7,2, 462 ) = 7.00868 
C      henke(7,3, 462 ) = 0.00421328 
C      henke(7,1, 463 ) = 15790.4 
C      henke(7,2, 463 ) = 7.00836 
C      henke(7,3, 463 ) = 0.00406106 
C      henke(7,1, 464 ) = 16045.8 
C      henke(7,2, 464 ) = 7.00805 
C      henke(7,3, 464 ) = 0.00391426 
C      henke(7,1, 465 ) = 16305.4 
C      henke(7,2, 465 ) = 7.00774 
C      henke(7,3, 465 ) = 0.00377268 
C      henke(7,1, 466 ) = 16569.1 
C      henke(7,2, 466 ) = 7.00744 
C      henke(7,3, 466 ) = 0.00363616 
C      henke(7,1, 467 ) = 16837.1 
C      henke(7,2, 467 ) = 7.00715 
C      henke(7,3, 467 ) = 0.00350453 
C      henke(7,1, 468 ) = 17109.4 
C      henke(7,2, 468 ) = 7.00687 
C      henke(7,3, 468 ) = 0.00337762 
C      henke(7,1, 469 ) = 17386.1 
C      henke(7,2, 469 ) = 7.00659 
C      henke(7,3, 469 ) = 0.00325528 
C      henke(7,1, 470 ) = 17667.4 
C      henke(7,2, 470 ) = 7.00632 
C      henke(7,3, 470 ) = 0.00313736 
C      henke(7,1, 471 ) = 17953.1 
C      henke(7,2, 471 ) = 7.00606 
C      henke(7,3, 471 ) = 0.0030237 
C      henke(7,1, 472 ) = 18243.5 
C      henke(7,2, 472 ) = 7.00581 
C      henke(7,3, 472 ) = 0.00291418 
C      henke(7,1, 473 ) = 18538.6 
C      henke(7,2, 473 ) = 7.00556 
C      henke(7,3, 473 ) = 0.00280864 
C      henke(7,1, 474 ) = 18838.4 
C      henke(7,2, 474 ) = 7.00532 
C      henke(7,3, 474 ) = 0.00270697 
C      henke(7,1, 475 ) = 19143.1 
C      henke(7,2, 475 ) = 7.00509 
C      henke(7,3, 475 ) = 0.00260902 
C      henke(7,1, 476 ) = 19452.7 
C      henke(7,2, 476 ) = 7.00486 
C      henke(7,3, 476 ) = 0.00251467 
C      henke(7,1, 477 ) = 19767.4 
C      henke(7,2, 477 ) = 7.00464 
C      henke(7,3, 477 ) = 0.0024238 
C      henke(7,1, 478 ) = 20087.1 
C      henke(7,2, 478 ) = 7.00442 
C      henke(7,3, 478 ) = 0.00233706 
C      henke(7,1, 479 ) = 20412 
C      henke(7,2, 479 ) = 7.00422 
C      henke(7,3, 479 ) = 0.00225277 
C      henke(7,1, 480 ) = 20742.1 
C      henke(7,2, 480 ) = 7.00401 
C      henke(7,3, 480 ) = 0.00217158 
C      henke(7,1, 481 ) = 21077.6 
C      henke(7,2, 481 ) = 7.00381 
C      henke(7,3, 481 ) = 0.00209337 
C      henke(7,1, 482 ) = 21418.5 
C      henke(7,2, 482 ) = 7.00362 
C      henke(7,3, 482 ) = 0.00201803 
C      henke(7,1, 483 ) = 21765 
C      henke(7,2, 483 ) = 7.00344 
C      henke(7,3, 483 ) = 0.00194545 
C      henke(7,1, 484 ) = 22117 
C      henke(7,2, 484 ) = 7.00325 
C      henke(7,3, 484 ) = 0.00187552 
C      henke(7,1, 485 ) = 22474.7 
C      henke(7,2, 485 ) = 7.00308 
C      henke(7,3, 485 ) = 0.00180815 
C      henke(7,1, 486 ) = 22838.2 
C      henke(7,2, 486 ) = 7.00291 
C      henke(7,3, 486 ) = 0.00174324 
C      henke(7,1, 487 ) = 23207.6 
C      henke(7,2, 487 ) = 7.00274 
C      henke(7,3, 487 ) = 0.00168069 
C      henke(7,1, 488 ) = 23583 
C      henke(7,2, 488 ) = 7.00258 
C      henke(7,3, 488 ) = 0.00162043 
C      henke(7,1, 489 ) = 23964.4 
C      henke(7,2, 489 ) = 7.00242 
C      henke(7,3, 489 ) = 0.00156235 
C      henke(7,1, 490 ) = 24352 
C      henke(7,2, 490 ) = 7.00227 
C      henke(7,3, 490 ) = 0.00150639 
C      henke(7,1, 491 ) = 24745.9 
C      henke(7,2, 491 ) = 7.00212 
C      henke(7,3, 491 ) = 0.00145246 
C      henke(7,1, 492 ) = 25146.2 
C      henke(7,2, 492 ) = 7.00197 
C      henke(7,3, 492 ) = 0.00140048 
C      henke(7,1, 493 ) = 25552.9 
C      henke(7,2, 493 ) = 7.00183 
C      henke(7,3, 493 ) = 0.00135039 
C      henke(7,1, 494 ) = 25966.2 
C      henke(7,2, 494 ) = 7.0017 
C      henke(7,3, 494 ) = 0.00130212 
C      henke(7,1, 495 ) = 26386.1 
C      henke(7,2, 495 ) = 7.00156 
C      henke(7,3, 495 ) = 0.00125559 
C      henke(7,1, 496 ) = 26812.9 
C      henke(7,2, 496 ) = 7.00143 
C      henke(7,3, 496 ) = 0.00121074 
C      henke(7,1, 497 ) = 27246.6 
C      henke(7,2, 497 ) = 7.00131 
C      henke(7,3, 497 ) = 0.00116751 
C      henke(7,1, 498 ) = 27687.3 
C      henke(7,2, 498 ) = 7.00119 
C      henke(7,3, 498 ) = 0.00112584 
C      henke(7,1, 499 ) = 28135.1 
C      henke(7,2, 499 ) = 7.00107 
C      henke(7,3, 499 ) = 0.00108567 
C      henke(7,1, 500 ) = 28590.2 
C      henke(7,2, 500 ) = 7.00095 
C      henke(7,3, 500 ) = 0.00104695 
C      henke(7,1, 501 ) = 29052.6 
C      henke(7,2, 501 ) = 7.00084 
C      henke(7,3, 501 ) = 0.00100962 
C      henke(7,1, 502 ) = 29522.5 
C      henke(7,2, 502 ) = 7.00073 
C      henke(7,3, 502 ) = 0.000973629 
C      henke(7,1, 503 ) = 30000 
C      henke(7,2, 503 ) = 7.00063 
C      henke(7,3, 503 ) = 0.000938934 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C        Henke data for o  z=8
C      count(8) = 502
C      henke(8,1, 1 ) = 10 
C      henke(8,2, 1 ) = -9999 
C      henke(8,3, 1 ) = 0.70328 
C      henke(8,1, 2 ) = 10.1617 
C      henke(8,2, 2 ) = -9999 
C      henke(8,3, 2 ) = 0.707226 
C      henke(8,1, 3 ) = 10.3261 
C      henke(8,2, 3 ) = -9999 
C      henke(8,3, 3 ) = 0.707377 
C      henke(8,1, 4 ) = 10.4931 
C      henke(8,2, 4 ) = -9999 
C      henke(8,3, 4 ) = 0.707528 
C      henke(8,1, 5 ) = 10.6628 
C      henke(8,2, 5 ) = -9999 
C      henke(8,3, 5 ) = 0.707678 
C      henke(8,1, 6 ) = 10.8353 
C      henke(8,2, 6 ) = -9999 
C      henke(8,3, 6 ) = 0.70783 
C      henke(8,1, 7 ) = 11.0106 
C      henke(8,2, 7 ) = -9999 
C      henke(8,3, 7 ) = 0.70798 
C      henke(8,1, 8 ) = 11.1886 
C      henke(8,2, 8 ) = -9999 
C      henke(8,3, 8 ) = 0.708131 
C      henke(8,1, 9 ) = 11.3696 
C      henke(8,2, 9 ) = -9999 
C      henke(8,3, 9 ) = 0.708282 
C      henke(8,1, 10 ) = 11.5535 
C      henke(8,2, 10 ) = -9999 
C      henke(8,3, 10 ) = 0.708433 
C      henke(8,1, 11 ) = 11.7404 
C      henke(8,2, 11 ) = -9999 
C      henke(8,3, 11 ) = 0.708584 
C      henke(8,1, 12 ) = 11.9303 
C      henke(8,2, 12 ) = -9999 
C      henke(8,3, 12 ) = 0.710169 
C      henke(8,1, 13 ) = 12.1232 
C      henke(8,2, 13 ) = -9999 
C      henke(8,3, 13 ) = 0.712421 
C      henke(8,1, 14 ) = 12.3193 
C      henke(8,2, 14 ) = -9999 
C      henke(8,3, 14 ) = 0.71468 
C      henke(8,1, 15 ) = 12.5186 
C      henke(8,2, 15 ) = -9999 
C      henke(8,3, 15 ) = 0.716947 
C      henke(8,1, 16 ) = 12.721 
C      henke(8,2, 16 ) = -9999 
C      henke(8,3, 16 ) = 0.719221 
C      henke(8,1, 17 ) = 12.9268 
C      henke(8,2, 17 ) = -9999 
C      henke(8,3, 17 ) = 0.721502 
C      henke(8,1, 18 ) = 13.1359 
C      henke(8,2, 18 ) = -9999 
C      henke(8,3, 18 ) = 0.72379 
C      henke(8,1, 19 ) = 13.3483 
C      henke(8,2, 19 ) = -9999 
C      henke(8,3, 19 ) = 0.726085 
C      henke(8,1, 20 ) = 13.5642 
C      henke(8,2, 20 ) = -9999 
C      henke(8,3, 20 ) = 0.73364 
C      henke(8,1, 21 ) = 13.7836 
C      henke(8,2, 21 ) = -9999 
C      henke(8,3, 21 ) = 0.746066 
C      henke(8,1, 22 ) = 14.0066 
C      henke(8,2, 22 ) = -9999 
C      henke(8,3, 22 ) = 0.758702 
C      henke(8,1, 23 ) = 14.2331 
C      henke(8,2, 23 ) = -9999 
C      henke(8,3, 23 ) = 0.771553 
C      henke(8,1, 24 ) = 14.4633 
C      henke(8,2, 24 ) = -9999 
C      henke(8,3, 24 ) = 0.784622 
C      henke(8,1, 25 ) = 14.6973 
C      henke(8,2, 25 ) = -9999 
C      henke(8,3, 25 ) = 0.801406 
C      henke(8,1, 26 ) = 14.935 
C      henke(8,2, 26 ) = -9999 
C      henke(8,3, 26 ) = 0.832915 
C      henke(8,1, 27 ) = 15.1765 
C      henke(8,2, 27 ) = -9999 
C      henke(8,3, 27 ) = 0.865663 
C      henke(8,1, 28 ) = 15.422 
C      henke(8,2, 28 ) = -9999 
C      henke(8,3, 28 ) = 0.899699 
C      henke(8,1, 29 ) = 15.6714 
C      henke(8,2, 29 ) = -9999 
C      henke(8,3, 29 ) = 0.973496 
C      henke(8,1, 30 ) = 15.9249 
C      henke(8,2, 30 ) = -9999 
C      henke(8,3, 30 ) = 1.07691 
C      henke(8,1, 31 ) = 16.1825 
C      henke(8,2, 31 ) = -9999 
C      henke(8,3, 31 ) = 1.19131 
C      henke(8,1, 32 ) = 16.4442 
C      henke(8,2, 32 ) = -9999 
C      henke(8,3, 32 ) = 1.31787 
C      henke(8,1, 33 ) = 16.7102 
C      henke(8,2, 33 ) = -9999 
C      henke(8,3, 33 ) = 1.45787 
C      henke(8,1, 34 ) = 16.9805 
C      henke(8,2, 34 ) = -9999 
C      henke(8,3, 34 ) = 1.61274 
C      henke(8,1, 35 ) = 17.2551 
C      henke(8,2, 35 ) = -9999 
C      henke(8,3, 35 ) = 1.78407 
C      henke(8,1, 36 ) = 17.5342 
C      henke(8,2, 36 ) = -9999 
C      henke(8,3, 36 ) = 1.97359 
C      henke(8,1, 37 ) = 17.8178 
C      henke(8,2, 37 ) = -9999 
C      henke(8,3, 37 ) = 2.19084 
C      henke(8,1, 38 ) = 18.106 
C      henke(8,2, 38 ) = -9999 
C      henke(8,3, 38 ) = 2.44589 
C      henke(8,1, 39 ) = 18.3989 
C      henke(8,2, 39 ) = -9999 
C      henke(8,3, 39 ) = 2.73065 
C      henke(8,1, 40 ) = 18.6964 
C      henke(8,2, 40 ) = -9999 
C      henke(8,3, 40 ) = 3.04856 
C      henke(8,1, 41 ) = 18.9988 
C      henke(8,2, 41 ) = -9999 
C      henke(8,3, 41 ) = 3.31541 
C      henke(8,1, 42 ) = 19.3061 
C      henke(8,2, 42 ) = -9999 
C      henke(8,3, 42 ) = 3.47952 
C      henke(8,1, 43 ) = 19.6184 
C      henke(8,2, 43 ) = -9999 
C      henke(8,3, 43 ) = 3.65175 
C      henke(8,1, 44 ) = 19.9357 
C      henke(8,2, 44 ) = -9999 
C      henke(8,3, 44 ) = 3.77879 
C      henke(8,1, 45 ) = 20.2582 
C      henke(8,2, 45 ) = -9999 
C      henke(8,3, 45 ) = 3.8365 
C      henke(8,1, 46 ) = 20.5858 
C      henke(8,2, 46 ) = -9999 
C      henke(8,3, 46 ) = 3.89509 
C      henke(8,1, 47 ) = 20.9188 
C      henke(8,2, 47 ) = -9999 
C      henke(8,3, 47 ) = 3.95457 
C      henke(8,1, 48 ) = 21.2571 
C      henke(8,2, 48 ) = -9999 
C      henke(8,3, 48 ) = 4.01497 
C      henke(8,1, 49 ) = 21.6009 
C      henke(8,2, 49 ) = -9999 
C      henke(8,3, 49 ) = 4.07078 
C      henke(8,1, 50 ) = 21.9503 
C      henke(8,2, 50 ) = -9999 
C      henke(8,3, 50 ) = 4.11386 
C      henke(8,1, 51 ) = 22.3053 
C      henke(8,2, 51 ) = -9999 
C      henke(8,3, 51 ) = 4.15739 
C      henke(8,1, 52 ) = 22.6661 
C      henke(8,2, 52 ) = -9999 
C      henke(8,3, 52 ) = 4.20138 
C      henke(8,1, 53 ) = 23.0327 
C      henke(8,2, 53 ) = -9999 
C      henke(8,3, 53 ) = 4.24585 
C      henke(8,1, 54 ) = 23.4053 
C      henke(8,2, 54 ) = -9999 
C      henke(8,3, 54 ) = 4.29077 
C      henke(8,1, 55 ) = 23.7838 
C      henke(8,2, 55 ) = -9999 
C      henke(8,3, 55 ) = 4.33618 
C      henke(8,1, 56 ) = 24.1685 
C      henke(8,2, 56 ) = -9999 
C      henke(8,3, 56 ) = 4.37108 
C      henke(8,1, 57 ) = 24.5594 
C      henke(8,2, 57 ) = -9999 
C      henke(8,3, 57 ) = 4.39198 
C      henke(8,1, 58 ) = 24.9566 
C      henke(8,2, 58 ) = -9999 
C      henke(8,3, 58 ) = 4.41297 
C      henke(8,1, 59 ) = 25.3603 
C      henke(8,2, 59 ) = -9999 
C      henke(8,3, 59 ) = 4.43407 
C      henke(8,1, 60 ) = 25.7705 
C      henke(8,2, 60 ) = -9999 
C      henke(8,3, 60 ) = 4.45527 
C      henke(8,1, 61 ) = 26.1873 
C      henke(8,2, 61 ) = -9999 
C      henke(8,3, 61 ) = 4.47657 
C      henke(8,1, 62 ) = 26.6109 
C      henke(8,2, 62 ) = -9999 
C      henke(8,3, 62 ) = 4.49797 
C      henke(8,1, 63 ) = 27.0413 
C      henke(8,2, 63 ) = -9999 
C      henke(8,3, 63 ) = 4.51948 
C      henke(8,1, 64 ) = 27.4786 
C      henke(8,2, 64 ) = -9999 
C      henke(8,3, 64 ) = 4.54108 
C      henke(8,1, 65 ) = 27.9231 
C      henke(8,2, 65 ) = -9999 
C      henke(8,3, 65 ) = 4.5628 
C      henke(8,1, 66 ) = 28.3747 
C      henke(8,2, 66 ) = -9999 
C      henke(8,3, 66 ) = 4.58461 
C      henke(8,1, 67 ) = 28.8337 
C      henke(8,2, 67 ) = -9999 
C      henke(8,3, 67 ) = 4.60653 
C      henke(8,1, 68 ) = 29.3 
C      henke(8,2, 68 ) = 1.29108 
C      henke(8,3, 68 ) = 4.62855 
C      henke(8,1, 69 ) = 29.7739 
C      henke(8,2, 69 ) = 1.3753 
C      henke(8,3, 69 ) = 4.65068 
C      henke(8,1, 70 ) = 30.2555 
C      henke(8,2, 70 ) = 1.45987 
C      henke(8,3, 70 ) = 4.67292 
C      henke(8,1, 71 ) = 30.7449 
C      henke(8,2, 71 ) = 1.545 
C      henke(8,3, 71 ) = 4.69526 
C      henke(8,1, 72 ) = 31.2421 
C      henke(8,2, 72 ) = 1.63089 
C      henke(8,3, 72 ) = 4.7177 
C      henke(8,1, 73 ) = 31.7475 
C      henke(8,2, 73 ) = 1.71782 
C      henke(8,3, 73 ) = 4.74026 
C      henke(8,1, 74 ) = 32.2609 
C      henke(8,2, 74 ) = 1.80604 
C      henke(8,3, 74 ) = 4.76292 
C      henke(8,1, 75 ) = 32.7827 
C      henke(8,2, 75 ) = 1.89591 
C      henke(8,3, 75 ) = 4.78569 
C      henke(8,1, 76 ) = 33.313 
C      henke(8,2, 76 ) = 1.98784 
C      henke(8,3, 76 ) = 4.80857 
C      henke(8,1, 77 ) = 33.8518 
C      henke(8,2, 77 ) = 2.0824 
C      henke(8,3, 77 ) = 4.83156 
C      henke(8,1, 78 ) = 34.3993 
C      henke(8,2, 78 ) = 2.18037 
C      henke(8,3, 78 ) = 4.85466 
C      henke(8,1, 79 ) = 34.9557 
C      henke(8,2, 79 ) = 2.28303 
C      henke(8,3, 79 ) = 4.87787 
C      henke(8,1, 80 ) = 35.5211 
C      henke(8,2, 80 ) = 2.3936 
C      henke(8,3, 80 ) = 4.90119 
C      henke(8,1, 81 ) = 36.0956 
C      henke(8,2, 81 ) = 2.51838 
C      henke(8,3, 81 ) = 4.92462 
C      henke(8,1, 82 ) = 36.6794 
C      henke(8,2, 82 ) = 2.6594 
C      henke(8,3, 82 ) = 4.90853 
C      henke(8,1, 83 ) = 37.2727 
C      henke(8,2, 83 ) = 2.77356 
C      henke(8,3, 83 ) = 4.88177 
C      henke(8,1, 84 ) = 37.8755 
C      henke(8,2, 84 ) = 2.87789 
C      henke(8,3, 84 ) = 4.85515 
C      henke(8,1, 85 ) = 38.4882 
C      henke(8,2, 85 ) = 2.9762 
C      henke(8,3, 85 ) = 4.82868 
C      henke(8,1, 86 ) = 39.1107 
C      henke(8,2, 86 ) = 3.0702 
C      henke(8,3, 86 ) = 4.80235 
C      henke(8,1, 87 ) = 39.7432 
C      henke(8,2, 87 ) = 3.16085 
C      henke(8,3, 87 ) = 4.77617 
C      henke(8,1, 88 ) = 40.3861 
C      henke(8,2, 88 ) = 3.24882 
C      henke(8,3, 88 ) = 4.75012 
C      henke(8,1, 89 ) = 41.0393 
C      henke(8,2, 89 ) = 3.33461 
C      henke(8,3, 89 ) = 4.72423 
C      henke(8,1, 90 ) = 41.7031 
C      henke(8,2, 90 ) = 3.4186 
C      henke(8,3, 90 ) = 4.69846 
C      henke(8,1, 91 ) = 42.3776 
C      henke(8,2, 91 ) = 3.50113 
C      henke(8,3, 91 ) = 4.67285 
C      henke(8,1, 92 ) = 43.063 
C      henke(8,2, 92 ) = 3.58251 
C      henke(8,3, 92 ) = 4.64737 
C      henke(8,1, 93 ) = 43.7595 
C      henke(8,2, 93 ) = 3.66302 
C      henke(8,3, 93 ) = 4.62203 
C      henke(8,1, 94 ) = 44.4673 
C      henke(8,2, 94 ) = 3.74299 
C      henke(8,3, 94 ) = 4.59683 
C      henke(8,1, 95 ) = 45.1865 
C      henke(8,2, 95 ) = 3.82277 
C      henke(8,3, 95 ) = 4.57176 
C      henke(8,1, 96 ) = 45.9174 
C      henke(8,2, 96 ) = 3.90281 
C      henke(8,3, 96 ) = 4.54683 
C      henke(8,1, 97 ) = 46.66 
C      henke(8,2, 97 ) = 3.98375 
C      henke(8,3, 97 ) = 4.52204 
C      henke(8,1, 98 ) = 47.4147 
C      henke(8,2, 98 ) = 4.06668 
C      henke(8,3, 98 ) = 4.49738 
C      henke(8,1, 99 ) = 48.1816 
C      henke(8,2, 99 ) = 4.15435 
C      henke(8,3, 99 ) = 4.47286 
C      henke(8,1, 100 ) = 48.9609 
C      henke(8,2, 100 ) = 4.25303 
C      henke(8,3, 100 ) = 4.43924 
C      henke(8,1, 101 ) = 49.7528 
C      henke(8,2, 101 ) = 4.34278 
C      henke(8,3, 101 ) = 4.3853 
C      henke(8,1, 102 ) = 50.5576 
C      henke(8,2, 102 ) = 4.42066 
C      henke(8,3, 102 ) = 4.33201 
C      henke(8,1, 103 ) = 51.3753 
C      henke(8,2, 103 ) = 4.4926 
C      henke(8,3, 103 ) = 4.27937 
C      henke(8,1, 104 ) = 52.2062 
C      henke(8,2, 104 ) = 4.56033 
C      henke(8,3, 104 ) = 4.22737 
C      henke(8,1, 105 ) = 53.0506 
C      henke(8,2, 105 ) = 4.6246 
C      henke(8,3, 105 ) = 4.17601 
C      henke(8,1, 106 ) = 53.9087 
C      henke(8,2, 106 ) = 4.68591 
C      henke(8,3, 106 ) = 4.12526 
C      henke(8,1, 107 ) = 54.7806 
C      henke(8,2, 107 ) = 4.74464 
C      henke(8,3, 107 ) = 4.07514 
C      henke(8,1, 108 ) = 55.6667 
C      henke(8,2, 108 ) = 4.80103 
C      henke(8,3, 108 ) = 4.02562 
C      henke(8,1, 109 ) = 56.567 
C      henke(8,2, 109 ) = 4.85533 
C      henke(8,3, 109 ) = 3.9767 
C      henke(8,1, 110 ) = 57.482 
C      henke(8,2, 110 ) = 4.90769 
C      henke(8,3, 110 ) = 3.92838 
C      henke(8,1, 111 ) = 58.4117 
C      henke(8,2, 111 ) = 4.95827 
C      henke(8,3, 111 ) = 3.88065 
C      henke(8,1, 112 ) = 59.3564 
C      henke(8,2, 112 ) = 5.0072 
C      henke(8,3, 112 ) = 3.83349 
C      henke(8,1, 113 ) = 60.3165 
C      henke(8,2, 113 ) = 5.05457 
C      henke(8,3, 113 ) = 3.78691 
C      henke(8,1, 114 ) = 61.2921 
C      henke(8,2, 114 ) = 5.10049 
C      henke(8,3, 114 ) = 3.7409 
C      henke(8,1, 115 ) = 62.2834 
C      henke(8,2, 115 ) = 5.14504 
C      henke(8,3, 115 ) = 3.69544 
C      henke(8,1, 116 ) = 63.2908 
C      henke(8,2, 116 ) = 5.18829 
C      henke(8,3, 116 ) = 3.65054 
C      henke(8,1, 117 ) = 64.3145 
C      henke(8,2, 117 ) = 5.23031 
C      henke(8,3, 117 ) = 3.60618 
C      henke(8,1, 118 ) = 65.3547 
C      henke(8,2, 118 ) = 5.27115 
C      henke(8,3, 118 ) = 3.56236 
C      henke(8,1, 119 ) = 66.4118 
C      henke(8,2, 119 ) = 5.31086 
C      henke(8,3, 119 ) = 3.51907 
C      henke(8,1, 120 ) = 67.4859 
C      henke(8,2, 120 ) = 5.34947 
C      henke(8,3, 120 ) = 3.47631 
C      henke(8,1, 121 ) = 68.5775 
C      henke(8,2, 121 ) = 5.38698 
C      henke(8,3, 121 ) = 3.43407 
C      henke(8,1, 122 ) = 69.6867 
C      henke(8,2, 122 ) = 5.42322 
C      henke(8,3, 122 ) = 3.39234 
C      henke(8,1, 123 ) = 70.8138 
C      henke(8,2, 123 ) = 5.45837 
C      henke(8,3, 123 ) = 3.35206 
C      henke(8,1, 124 ) = 71.9591 
C      henke(8,2, 124 ) = 5.49332 
C      henke(8,3, 124 ) = 3.31248 
C      henke(8,1, 125 ) = 73.123 
C      henke(8,2, 125 ) = 5.52779 
C      henke(8,3, 125 ) = 3.27336 
C      henke(8,1, 126 ) = 74.3057 
C      henke(8,2, 126 ) = 5.5617 
C      henke(8,3, 126 ) = 3.2347 
C      henke(8,1, 127 ) = 75.5076 
C      henke(8,2, 127 ) = 5.59505 
C      henke(8,3, 127 ) = 3.19651 
C      henke(8,1, 128 ) = 76.7289 
C      henke(8,2, 128 ) = 5.62788 
C      henke(8,3, 128 ) = 3.15877 
C      henke(8,1, 129 ) = 77.9699 
C      henke(8,2, 129 ) = 5.6602 
C      henke(8,3, 129 ) = 3.12146 
C      henke(8,1, 130 ) = 79.231 
C      henke(8,2, 130 ) = 5.69205 
C      henke(8,3, 130 ) = 3.0846 
C      henke(8,1, 131 ) = 80.5125 
C      henke(8,2, 131 ) = 5.72347 
C      henke(8,3, 131 ) = 3.04818 
C      henke(8,1, 132 ) = 81.8147 
C      henke(8,2, 132 ) = 5.7545 
C      henke(8,3, 132 ) = 3.01218 
C      henke(8,1, 133 ) = 83.138 
C      henke(8,2, 133 ) = 5.78519 
C      henke(8,3, 133 ) = 2.97661 
C      henke(8,1, 134 ) = 84.4827 
C      henke(8,2, 134 ) = 5.81559 
C      henke(8,3, 134 ) = 2.94146 
C      henke(8,1, 135 ) = 85.8491 
C      henke(8,2, 135 ) = 5.84576 
C      henke(8,3, 135 ) = 2.90673 
C      henke(8,1, 136 ) = 87.2377 
C      henke(8,2, 136 ) = 5.87577 
C      henke(8,3, 136 ) = 2.8724 
C      henke(8,1, 137 ) = 88.6487 
C      henke(8,2, 137 ) = 5.90572 
C      henke(8,3, 137 ) = 2.83848 
C      henke(8,1, 138 ) = 90.0825 
C      henke(8,2, 138 ) = 5.9357 
C      henke(8,3, 138 ) = 2.80496 
C      henke(8,1, 139 ) = 91.5395 
C      henke(8,2, 139 ) = 5.96588 
C      henke(8,3, 139 ) = 2.77184 
C      henke(8,1, 140 ) = 93.0201 
C      henke(8,2, 140 ) = 5.99646 
C      henke(8,3, 140 ) = 2.73911 
C      henke(8,1, 141 ) = 94.5246 
C      henke(8,2, 141 ) = 6.02776 
C      henke(8,3, 141 ) = 2.70676 
C      henke(8,1, 142 ) = 96.0535 
C      henke(8,2, 142 ) = 6.06038 
C      henke(8,3, 142 ) = 2.6748 
C      henke(8,1, 143 ) = 97.6071 
C      henke(8,2, 143 ) = 6.09575 
C      henke(8,3, 143 ) = 2.64321 
C      henke(8,1, 144 ) = 99.1858 
C      henke(8,2, 144 ) = 6.13917 
C      henke(8,3, 144 ) = 2.60698 
C      henke(8,1, 145 ) = 100.79 
C      henke(8,2, 145 ) = 6.17528 
C      henke(8,3, 145 ) = 2.55821 
C      henke(8,1, 146 ) = 102.42 
C      henke(8,2, 146 ) = 6.2052 
C      henke(8,3, 146 ) = 2.51035 
C      henke(8,1, 147 ) = 104.077 
C      henke(8,2, 147 ) = 6.23136 
C      henke(8,3, 147 ) = 2.46339 
C      henke(8,1, 148 ) = 105.76 
C      henke(8,2, 148 ) = 6.25498 
C      henke(8,3, 148 ) = 2.4173 
C      henke(8,1, 149 ) = 107.471 
C      henke(8,2, 149 ) = 6.27656 
C      henke(8,3, 149 ) = 2.37208 
C      henke(8,1, 150 ) = 109.209 
C      henke(8,2, 150 ) = 6.2964 
C      henke(8,3, 150 ) = 2.3277 
C      henke(8,1, 151 ) = 110.975 
C      henke(8,2, 151 ) = 6.31474 
C      henke(8,3, 151 ) = 2.28416 
C      henke(8,1, 152 ) = 112.77 
C      henke(8,2, 152 ) = 6.33175 
C      henke(8,3, 152 ) = 2.24143 
C      henke(8,1, 153 ) = 114.594 
C      henke(8,2, 153 ) = 6.34755 
C      henke(8,3, 153 ) = 2.19949 
C      henke(8,1, 154 ) = 116.448 
C      henke(8,2, 154 ) = 6.36224 
C      henke(8,3, 154 ) = 2.15834 
C      henke(8,1, 155 ) = 118.331 
C      henke(8,2, 155 ) = 6.37593 
C      henke(8,3, 155 ) = 2.11797 
C      henke(8,1, 156 ) = 120.245 
C      henke(8,2, 156 ) = 6.38867 
C      henke(8,3, 156 ) = 2.07834 
C      henke(8,1, 157 ) = 122.19 
C      henke(8,2, 157 ) = 6.40053 
C      henke(8,3, 157 ) = 2.03946 
C      henke(8,1, 158 ) = 124.166 
C      henke(8,2, 158 ) = 6.41155 
C      henke(8,3, 158 ) = 2.00131 
C      henke(8,1, 159 ) = 126.175 
C      henke(8,2, 159 ) = 6.42176 
C      henke(8,3, 159 ) = 1.96387 
C      henke(8,1, 160 ) = 128.215 
C      henke(8,2, 160 ) = 6.43119 
C      henke(8,3, 160 ) = 1.92713 
C      henke(8,1, 161 ) = 130.289 
C      henke(8,2, 161 ) = 6.43983 
C      henke(8,3, 161 ) = 1.89108 
C      henke(8,1, 162 ) = 132.397 
C      henke(8,2, 162 ) = 6.44761 
C      henke(8,3, 162 ) = 1.8557 
C      henke(8,1, 163 ) = 134.538 
C      henke(8,2, 163 ) = 6.45377 
C      henke(8,3, 163 ) = 1.82102 
C      henke(8,1, 164 ) = 136.714 
C      henke(8,2, 164 ) = 6.45983 
C      henke(8,3, 164 ) = 1.78919 
C      henke(8,1, 165 ) = 138.925 
C      henke(8,2, 165 ) = 6.4664 
C      henke(8,3, 165 ) = 1.75791 
C      henke(8,1, 166 ) = 141.172 
C      henke(8,2, 166 ) = 6.47299 
C      henke(8,3, 166 ) = 1.72717 
C      henke(8,1, 167 ) = 143.456 
C      henke(8,2, 167 ) = 6.47949 
C      henke(8,3, 167 ) = 1.69698 
C      henke(8,1, 168 ) = 145.776 
C      henke(8,2, 168 ) = 6.48585 
C      henke(8,3, 168 ) = 1.66731 
C      henke(8,1, 169 ) = 148.134 
C      henke(8,2, 169 ) = 6.49207 
C      henke(8,3, 169 ) = 1.63816 
C      henke(8,1, 170 ) = 150.53 
C      henke(8,2, 170 ) = 6.49816 
C      henke(8,3, 170 ) = 1.60952 
C      henke(8,1, 171 ) = 152.964 
C      henke(8,2, 171 ) = 6.50413 
C      henke(8,3, 171 ) = 1.58138 
C      henke(8,1, 172 ) = 155.439 
C      henke(8,2, 172 ) = 6.51001 
C      henke(8,3, 172 ) = 1.55374 
C      henke(8,1, 173 ) = 157.953 
C      henke(8,2, 173 ) = 6.51583 
C      henke(8,3, 173 ) = 1.52657 
C      henke(8,1, 174 ) = 160.507 
C      henke(8,2, 174 ) = 6.52164 
C      henke(8,3, 174 ) = 1.49989 
C      henke(8,1, 175 ) = 163.103 
C      henke(8,2, 175 ) = 6.52749 
C      henke(8,3, 175 ) = 1.47366 
C      henke(8,1, 176 ) = 165.742 
C      henke(8,2, 176 ) = 6.53347 
C      henke(8,3, 176 ) = 1.4479 
C      henke(8,1, 177 ) = 168.422 
C      henke(8,2, 177 ) = 6.53968 
C      henke(8,3, 177 ) = 1.42259 
C      henke(8,1, 178 ) = 171.146 
C      henke(8,2, 178 ) = 6.54628 
C      henke(8,3, 178 ) = 1.39772 
C      henke(8,1, 179 ) = 173.915 
C      henke(8,2, 179 ) = 6.55353 
C      henke(8,3, 179 ) = 1.37328 
C      henke(8,1, 180 ) = 176.727 
C      henke(8,2, 180 ) = 6.56188 
C      henke(8,3, 180 ) = 1.34927 
C      henke(8,1, 181 ) = 179.586 
C      henke(8,2, 181 ) = 6.57285 
C      henke(8,3, 181 ) = 1.32568 
C      henke(8,1, 182 ) = 182.491 
C      henke(8,2, 182 ) = 6.59062 
C      henke(8,3, 182 ) = 1.29775 
C      henke(8,1, 183 ) = 185.442 
C      henke(8,2, 183 ) = 6.60126 
C      henke(8,3, 183 ) = 1.25985 
C      henke(8,1, 184 ) = 188.442 
C      henke(8,2, 184 ) = 6.60656 
C      henke(8,3, 184 ) = 1.22306 
C      henke(8,1, 185 ) = 191.489 
C      henke(8,2, 185 ) = 6.6089 
C      henke(8,3, 185 ) = 1.18734 
C      henke(8,1, 186 ) = 194.587 
C      henke(8,2, 186 ) = 6.60909 
C      henke(8,3, 186 ) = 1.15266 
C      henke(8,1, 187 ) = 197.734 
C      henke(8,2, 187 ) = 6.60756 
C      henke(8,3, 187 ) = 1.119 
C      henke(8,1, 188 ) = 200.932 
C      henke(8,2, 188 ) = 6.60459 
C      henke(8,3, 188 ) = 1.08632 
C      henke(8,1, 189 ) = 204.182 
C      henke(8,2, 189 ) = 6.60037 
C      henke(8,3, 189 ) = 1.05459 
C      henke(8,1, 190 ) = 207.485 
C      henke(8,2, 190 ) = 6.59504 
C      henke(8,3, 190 ) = 1.02379 
C      henke(8,1, 191 ) = 210.84 
C      henke(8,2, 191 ) = 6.58869 
C      henke(8,3, 191 ) = 0.993894 
C      henke(8,1, 192 ) = 214.251 
C      henke(8,2, 192 ) = 6.58141 
C      henke(8,3, 192 ) = 0.964869 
C      henke(8,1, 193 ) = 217.716 
C      henke(8,2, 193 ) = 6.57324 
C      henke(8,3, 193 ) = 0.93669 
C      henke(8,1, 194 ) = 221.237 
C      henke(8,2, 194 ) = 6.56421 
C      henke(8,3, 194 ) = 0.909335 
C      henke(8,1, 195 ) = 224.816 
C      henke(8,2, 195 ) = 6.55434 
C      henke(8,3, 195 ) = 0.882777 
C      henke(8,1, 196 ) = 228.452 
C      henke(8,2, 196 ) = 6.54358 
C      henke(8,3, 196 ) = 0.856997 
C      henke(8,1, 197 ) = 232.147 
C      henke(8,2, 197 ) = 6.53186 
C      henke(8,3, 197 ) = 0.831968 
C      henke(8,1, 198 ) = 235.902 
C      henke(8,2, 198 ) = 6.5191 
C      henke(8,3, 198 ) = 0.807672 
C      henke(8,1, 199 ) = 239.717 
C      henke(8,2, 199 ) = 6.50289 
C      henke(8,3, 199 ) = 0.785141 
C      henke(8,1, 200 ) = 243.595 
C      henke(8,2, 200 ) = 6.4878 
C      henke(8,3, 200 ) = 0.76705 
C      henke(8,1, 201 ) = 247.535 
C      henke(8,2, 201 ) = 6.47469 
C      henke(8,3, 201 ) = 0.749377 
C      henke(8,1, 202 ) = 251.538 
C      henke(8,2, 202 ) = 6.46187 
C      henke(8,3, 202 ) = 0.732111 
C      henke(8,1, 203 ) = 255.607 
C      henke(8,2, 203 ) = 6.44917 
C      henke(8,3, 203 ) = 0.715246 
C      henke(8,1, 204 ) = 259.741 
C      henke(8,2, 204 ) = 6.43647 
C      henke(8,3, 204 ) = 0.698766 
C      henke(8,1, 205 ) = 263.942 
C      henke(8,2, 205 ) = 6.4237 
C      henke(8,3, 205 ) = 0.682666 
C      henke(8,1, 206 ) = 268.211 
C      henke(8,2, 206 ) = 6.41077 
C      henke(8,3, 206 ) = 0.666936 
C      henke(8,1, 207 ) = 272.549 
C      henke(8,2, 207 ) = 6.39774 
C      henke(8,3, 207 ) = 0.651568 
C      henke(8,1, 208 ) = 276.957 
C      henke(8,2, 208 ) = 6.38453 
C      henke(8,3, 208 ) = 0.63639 
C      henke(8,1, 209 ) = 281.437 
C      henke(8,2, 209 ) = 6.37093 
C      henke(8,3, 209 ) = 0.62136 
C      henke(8,1, 210 ) = 285.989 
C      henke(8,2, 210 ) = 6.35684 
C      henke(8,3, 210 ) = 0.606567 
C      henke(8,1, 211 ) = 290.615 
C      henke(8,2, 211 ) = 6.34223 
C      henke(8,3, 211 ) = 0.592106 
C      henke(8,1, 212 ) = 295.315 
C      henke(8,2, 212 ) = 6.3271 
C      henke(8,3, 212 ) = 0.577987 
C      henke(8,1, 213 ) = 300.092 
C      henke(8,2, 213 ) = 6.31143 
C      henke(8,3, 213 ) = 0.564206 
C      henke(8,1, 214 ) = 304.945 
C      henke(8,2, 214 ) = 6.29521 
C      henke(8,3, 214 ) = 0.550756 
C      henke(8,1, 215 ) = 309.878 
C      henke(8,2, 215 ) = 6.27839 
C      henke(8,3, 215 ) = 0.537625 
C      henke(8,1, 216 ) = 314.89 
C      henke(8,2, 216 ) = 6.26093 
C      henke(8,3, 216 ) = 0.524809 
C      henke(8,1, 217 ) = 319.983 
C      henke(8,2, 217 ) = 6.24279 
C      henke(8,3, 217 ) = 0.512296 
C      henke(8,1, 218 ) = 325.158 
C      henke(8,2, 218 ) = 6.22392 
C      henke(8,3, 218 ) = 0.500078 
C      henke(8,1, 219 ) = 330.418 
C      henke(8,2, 219 ) = 6.20424 
C      henke(8,3, 219 ) = 0.488156 
C      henke(8,1, 220 ) = 335.762 
C      henke(8,2, 220 ) = 6.18372 
C      henke(8,3, 220 ) = 0.476518 
C      henke(8,1, 221 ) = 341.192 
C      henke(8,2, 221 ) = 6.16227 
C      henke(8,3, 221 ) = 0.46516 
C      henke(8,1, 222 ) = 346.711 
C      henke(8,2, 222 ) = 6.13982 
C      henke(8,3, 222 ) = 0.454068 
C      henke(8,1, 223 ) = 352.319 
C      henke(8,2, 223 ) = 6.11627 
C      henke(8,3, 223 ) = 0.44324 
C      henke(8,1, 224 ) = 358.017 
C      henke(8,2, 224 ) = 6.09153 
C      henke(8,3, 224 ) = 0.432677 
C      henke(8,1, 225 ) = 363.808 
C      henke(8,2, 225 ) = 6.0655 
C      henke(8,3, 225 ) = 0.422359 
C      henke(8,1, 226 ) = 369.692 
C      henke(8,2, 226 ) = 6.03805 
C      henke(8,3, 226 ) = 0.412287 
C      henke(8,1, 227 ) = 375.672 
C      henke(8,2, 227 ) = 6.00904 
C      henke(8,3, 227 ) = 0.402455 
C      henke(8,1, 228 ) = 381.748 
C      henke(8,2, 228 ) = 5.97834 
C      henke(8,3, 228 ) = 0.392859 
C      henke(8,1, 229 ) = 387.922 
C      henke(8,2, 229 ) = 5.94581 
C      henke(8,3, 229 ) = 0.383399 
C      henke(8,1, 230 ) = 394.197 
C      henke(8,2, 230 ) = 5.91108 
C      henke(8,3, 230 ) = 0.373965 
C      henke(8,1, 231 ) = 400.573 
C      henke(8,2, 231 ) = 5.87378 
C      henke(8,3, 231 ) = 0.364734 
C      henke(8,1, 232 ) = 407.052 
C      henke(8,2, 232 ) = 5.83371 
C      henke(8,3, 232 ) = 0.355718 
C      henke(8,1, 233 ) = 413.635 
C      henke(8,2, 233 ) = 5.79051 
C      henke(8,3, 233 ) = 0.346911 
C      henke(8,1, 234 ) = 420.326 
C      henke(8,2, 234 ) = 5.74378 
C      henke(8,3, 234 ) = 0.338332 
C      henke(8,1, 235 ) = 427.124 
C      henke(8,2, 235 ) = 5.69301 
C      henke(8,3, 235 ) = 0.329966 
C      henke(8,1, 236 ) = 434.032 
C      henke(8,2, 236 ) = 5.6376 
C      henke(8,3, 236 ) = 0.321805 
C      henke(8,1, 237 ) = 441.052 
C      henke(8,2, 237 ) = 5.57677 
C      henke(8,3, 237 ) = 0.313842 
C      henke(8,1, 238 ) = 448.186 
C      henke(8,2, 238 ) = 5.50955 
C      henke(8,3, 238 ) = 0.306078 
C      henke(8,1, 239 ) = 455.435 
C      henke(8,2, 239 ) = 5.43473 
C      henke(8,3, 239 ) = 0.298525 
C      henke(8,1, 240 ) = 462.802 
C      henke(8,2, 240 ) = 5.35075 
C      henke(8,3, 240 ) = 0.291171 
C      henke(8,1, 241 ) = 470.287 
C      henke(8,2, 241 ) = 5.25548 
C      henke(8,3, 241 ) = 0.284004 
C      henke(8,1, 242 ) = 477.894 
C      henke(8,2, 242 ) = 5.14604 
C      henke(8,3, 242 ) = 0.277005 
C      henke(8,1, 243 ) = 485.623 
C      henke(8,2, 243 ) = 5.01831 
C      henke(8,3, 243 ) = 0.270184 
C      henke(8,1, 244 ) = 493.478 
C      henke(8,2, 244 ) = 4.86623 
C      henke(8,3, 244 ) = 0.263535 
C      henke(8,1, 245 ) = 501.459 
C      henke(8,2, 245 ) = 4.68029 
C      henke(8,3, 245 ) = 0.257056 
C      henke(8,1, 246 ) = 509.57 
C      henke(8,2, 246 ) = 4.44433 
C      henke(8,3, 246 ) = 0.250722 
C      henke(8,1, 247 ) = 517.812 
C      henke(8,2, 247 ) = 4.12757 
C      henke(8,3, 247 ) = 0.244542 
C      henke(8,1, 248 ) = 526.187 
C      henke(8,2, 248 ) = 3.65977 
C      henke(8,3, 248 ) = 0.238528 
C      henke(8,1, 249 ) = 534.698 
C      henke(8,2, 249 ) = 2.81057 
C      henke(8,3, 249 ) = 0.232662 
C      henke(8,1, 250 ) = 543 
C      henke(8,2, 250 ) = -2.97417 
C      henke(8,3, 250 ) = 0.227165 
C      henke(8,1, 251 ) = 543.2 
C      henke(8,2, 251 ) = -2.9682 
C      henke(8,3, 251 ) = 4.41017 
C      henke(8,1, 252 ) = 543.346 
C      henke(8,2, 252 ) = -1.76427 
C      henke(8,3, 252 ) = 4.40843 
C      henke(8,1, 253 ) = 552.134 
C      henke(8,2, 253 ) = 3.14873 
C      henke(8,3, 253 ) = 4.30605 
C      henke(8,1, 254 ) = 561.065 
C      henke(8,2, 254 ) = 4.13655 
C      henke(8,3, 254 ) = 4.20603 
C      henke(8,1, 255 ) = 570.139 
C      henke(8,2, 255 ) = 4.73493 
C      henke(8,3, 255 ) = 4.10874 
C      henke(8,1, 256 ) = 579.361 
C      henke(8,2, 256 ) = 5.16768 
C      henke(8,3, 256 ) = 4.01631 
C      henke(8,1, 257 ) = 588.732 
C      henke(8,2, 257 ) = 5.50836 
C      henke(8,3, 257 ) = 3.92668 
C      henke(8,1, 258 ) = 598.254 
C      henke(8,2, 258 ) = 5.78966 
C      henke(8,3, 258 ) = 3.83948 
C      henke(8,1, 259 ) = 607.93 
C      henke(8,2, 259 ) = 6.02905 
C      henke(8,3, 259 ) = 3.75417 
C      henke(8,1, 260 ) = 617.763 
C      henke(8,2, 260 ) = 6.23761 
C      henke(8,3, 260 ) = 3.67071 
C      henke(8,1, 261 ) = 627.755 
C      henke(8,2, 261 ) = 6.4227 
C      henke(8,3, 261 ) = 3.58878 
C      henke(8,1, 262 ) = 637.908 
C      henke(8,2, 262 ) = 6.59031 
C      henke(8,3, 262 ) = 3.50519 
C      henke(8,1, 263 ) = 648.226 
C      henke(8,2, 263 ) = 6.74023 
C      henke(8,3, 263 ) = 3.41851 
C      henke(8,1, 264 ) = 658.711 
C      henke(8,2, 264 ) = 6.87017 
C      henke(8,3, 264 ) = 3.33072 
C      henke(8,1, 265 ) = 669.365 
C      henke(8,2, 265 ) = 6.98234 
C      henke(8,3, 265 ) = 3.24518 
C      henke(8,1, 266 ) = 680.191 
C      henke(8,2, 266 ) = 7.079 
C      henke(8,3, 266 ) = 3.17061 
C      henke(8,1, 267 ) = 691.193 
C      henke(8,2, 267 ) = 7.17176 
C      henke(8,3, 267 ) = 3.1044 
C      henke(8,1, 268 ) = 702.372 
C      henke(8,2, 268 ) = 7.26537 
C      henke(8,3, 268 ) = 3.04097 
C      henke(8,1, 269 ) = 713.733 
C      henke(8,2, 269 ) = 7.35632 
C      henke(8,3, 269 ) = 2.97253 
C      henke(8,1, 270 ) = 725.277 
C      henke(8,2, 270 ) = 7.43725 
C      henke(8,3, 270 ) = 2.90138 
C      henke(8,1, 271 ) = 737.008 
C      henke(8,2, 271 ) = 7.51096 
C      henke(8,3, 271 ) = 2.8321 
C      henke(8,1, 272 ) = 748.928 
C      henke(8,2, 272 ) = 7.57923 
C      henke(8,3, 272 ) = 2.76441 
C      henke(8,1, 273 ) = 761.042 
C      henke(8,2, 273 ) = 7.64278 
C      henke(8,3, 273 ) = 2.69824 
C      henke(8,1, 274 ) = 773.351 
C      henke(8,2, 274 ) = 7.70301 
C      henke(8,3, 274 ) = 2.63299 
C      henke(8,1, 275 ) = 785.859 
C      henke(8,2, 275 ) = 7.75952 
C      henke(8,3, 275 ) = 2.56707 
C      henke(8,1, 276 ) = 798.57 
C      henke(8,2, 276 ) = 7.81002 
C      henke(8,3, 276 ) = 2.50097 
C      henke(8,1, 277 ) = 811.486 
C      henke(8,2, 277 ) = 7.8556 
C      henke(8,3, 277 ) = 2.43656 
C      henke(8,1, 278 ) = 824.611 
C      henke(8,2, 278 ) = 7.89685 
C      henke(8,3, 278 ) = 2.37381 
C      henke(8,1, 279 ) = 837.949 
C      henke(8,2, 279 ) = 7.934 
C      henke(8,3, 279 ) = 2.31267 
C      henke(8,1, 280 ) = 851.502 
C      henke(8,2, 280 ) = 7.96689 
C      henke(8,3, 280 ) = 2.2549 
C      henke(8,1, 281 ) = 865.274 
C      henke(8,2, 281 ) = 7.99727 
C      henke(8,3, 281 ) = 2.20048 
C      henke(8,1, 282 ) = 879.269 
C      henke(8,2, 282 ) = 8.02738 
C      henke(8,3, 282 ) = 2.14904 
C      henke(8,1, 283 ) = 893.491 
C      henke(8,2, 283 ) = 8.05676 
C      henke(8,3, 283 ) = 2.0988 
C      henke(8,1, 284 ) = 907.943 
C      henke(8,2, 284 ) = 8.08546 
C      henke(8,3, 284 ) = 2.04974 
C      henke(8,1, 285 ) = 922.628 
C      henke(8,2, 285 ) = 8.11385 
C      henke(8,3, 285 ) = 2.00183 
C      henke(8,1, 286 ) = 937.551 
C      henke(8,2, 286 ) = 8.14164 
C      henke(8,3, 286 ) = 1.95125 
C      henke(8,1, 287 ) = 952.715 
C      henke(8,2, 287 ) = 8.16639 
C      henke(8,3, 287 ) = 1.90102 
C      henke(8,1, 288 ) = 968.124 
C      henke(8,2, 288 ) = 8.18822 
C      henke(8,3, 288 ) = 1.85129 
C      henke(8,1, 289 ) = 983.783 
C      henke(8,2, 289 ) = 8.20773 
C      henke(8,3, 289 ) = 1.80284 
C      henke(8,1, 290 ) = 999.695 
C      henke(8,2, 290 ) = 8.22524 
C      henke(8,3, 290 ) = 1.75575 
C      henke(8,1, 291 ) = 1015.86 
C      henke(8,2, 291 ) = 8.2411 
C      henke(8,3, 291 ) = 1.71001 
C      henke(8,1, 292 ) = 1032.29 
C      henke(8,2, 292 ) = 8.25591 
C      henke(8,3, 292 ) = 1.66625 
C      henke(8,1, 293 ) = 1048.99 
C      henke(8,2, 293 ) = 8.27017 
C      henke(8,3, 293 ) = 1.62304 
C      henke(8,1, 294 ) = 1065.96 
C      henke(8,2, 294 ) = 8.28286 
C      henke(8,3, 294 ) = 1.58035 
C      henke(8,1, 295 ) = 1083.2 
C      henke(8,2, 295 ) = 8.29421 
C      henke(8,3, 295 ) = 1.53877 
C      henke(8,1, 296 ) = 1100.72 
C      henke(8,2, 296 ) = 8.30443 
C      henke(8,3, 296 ) = 1.49828 
C      henke(8,1, 297 ) = 1118.52 
C      henke(8,2, 297 ) = 8.31363 
C      henke(8,3, 297 ) = 1.45885 
C      henke(8,1, 298 ) = 1136.61 
C      henke(8,2, 298 ) = 8.32191 
C      henke(8,3, 298 ) = 1.42048 
C      henke(8,1, 299 ) = 1155 
C      henke(8,2, 299 ) = 8.32937 
C      henke(8,3, 299 ) = 1.38311 
C      henke(8,1, 300 ) = 1173.68 
C      henke(8,2, 300 ) = 8.33606 
C      henke(8,3, 300 ) = 1.34671 
C      henke(8,1, 301 ) = 1192.66 
C      henke(8,2, 301 ) = 8.34205 
C      henke(8,3, 301 ) = 1.31127 
C      henke(8,1, 302 ) = 1211.95 
C      henke(8,2, 302 ) = 8.34741 
C      henke(8,3, 302 ) = 1.27676 
C      henke(8,1, 303 ) = 1231.55 
C      henke(8,2, 303 ) = 8.35226 
C      henke(8,3, 303 ) = 1.24316 
C      henke(8,1, 304 ) = 1251.47 
C      henke(8,2, 304 ) = 8.3567 
C      henke(8,3, 304 ) = 1.21022 
C      henke(8,1, 305 ) = 1271.72 
C      henke(8,2, 305 ) = 8.36065 
C      henke(8,3, 305 ) = 1.17789 
C      henke(8,1, 306 ) = 1292.29 
C      henke(8,2, 306 ) = 8.36377 
C      henke(8,3, 306 ) = 1.14609 
C      henke(8,1, 307 ) = 1313.19 
C      henke(8,2, 307 ) = 8.3662 
C      henke(8,3, 307 ) = 1.11516 
C      henke(8,1, 308 ) = 1334.43 
C      henke(8,2, 308 ) = 8.36809 
C      henke(8,3, 308 ) = 1.08507 
C      henke(8,1, 309 ) = 1356.01 
C      henke(8,2, 309 ) = 8.36949 
C      henke(8,3, 309 ) = 1.05579 
C      henke(8,1, 310 ) = 1377.94 
C      henke(8,2, 310 ) = 8.37047 
C      henke(8,3, 310 ) = 1.02732 
C      henke(8,1, 311 ) = 1400.23 
C      henke(8,2, 311 ) = 8.37109 
C      henke(8,3, 311 ) = 0.999604 
C      henke(8,1, 312 ) = 1422.88 
C      henke(8,2, 312 ) = 8.37136 
C      henke(8,3, 312 ) = 0.972611 
C      henke(8,1, 313 ) = 1445.89 
C      henke(8,2, 313 ) = 8.37135 
C      henke(8,3, 313 ) = 0.94638 
C      henke(8,1, 314 ) = 1469.28 
C      henke(8,2, 314 ) = 8.37123 
C      henke(8,3, 314 ) = 0.920766 
C      henke(8,1, 315 ) = 1493.04 
C      henke(8,2, 315 ) = 8.37088 
C      henke(8,3, 315 ) = 0.895701 
C      henke(8,1, 316 ) = 1517.19 
C      henke(8,2, 316 ) = 8.37025 
C      henke(8,3, 316 ) = 0.870806 
C      henke(8,1, 317 ) = 1541.73 
C      henke(8,2, 317 ) = 8.36901 
C      henke(8,3, 317 ) = 0.846549 
C      henke(8,1, 318 ) = 1566.67 
C      henke(8,2, 318 ) = 8.36742 
C      henke(8,3, 318 ) = 0.822997 
C      henke(8,1, 319 ) = 1592.01 
C      henke(8,2, 319 ) = 8.36555 
C      henke(8,3, 319 ) = 0.800062 
C      henke(8,1, 320 ) = 1617.76 
C      henke(8,2, 320 ) = 8.3634 
C      henke(8,3, 320 ) = 0.777767 
C      henke(8,1, 321 ) = 1643.92 
C      henke(8,2, 321 ) = 8.36104 
C      henke(8,3, 321 ) = 0.756111 
C      henke(8,1, 322 ) = 1670.51 
C      henke(8,2, 322 ) = 8.35851 
C      henke(8,3, 322 ) = 0.735037 
C      henke(8,1, 323 ) = 1697.53 
C      henke(8,2, 323 ) = 8.35582 
C      henke(8,3, 323 ) = 0.714548 
C      henke(8,1, 324 ) = 1724.99 
C      henke(8,2, 324 ) = 8.35305 
C      henke(8,3, 324 ) = 0.694627 
C      henke(8,1, 325 ) = 1752.89 
C      henke(8,2, 325 ) = 8.35021 
C      henke(8,3, 325 ) = 0.67503 
C      henke(8,1, 326 ) = 1781.24 
C      henke(8,2, 326 ) = 8.3471 
C      henke(8,3, 326 ) = 0.655908 
C      henke(8,1, 327 ) = 1810.05 
C      henke(8,2, 327 ) = 8.34378 
C      henke(8,3, 327 ) = 0.63727 
C      henke(8,1, 328 ) = 1839.32 
C      henke(8,2, 328 ) = 8.34028 
C      henke(8,3, 328 ) = 0.619158 
C      henke(8,1, 329 ) = 1869.07 
C      henke(8,2, 329 ) = 8.33665 
C      henke(8,3, 329 ) = 0.60156 
C      henke(8,1, 330 ) = 1899.3 
C      henke(8,2, 330 ) = 8.33291 
C      henke(8,3, 330 ) = 0.584462 
C      henke(8,1, 331 ) = 1930.02 
C      henke(8,2, 331 ) = 8.32907 
C      henke(8,3, 331 ) = 0.567849 
C      henke(8,1, 332 ) = 1961.24 
C      henke(8,2, 332 ) = 8.32516 
C      henke(8,3, 332 ) = 0.551708 
C      henke(8,1, 333 ) = 1992.96 
C      henke(8,2, 333 ) = 8.32116 
C      henke(8,3, 333 ) = 0.536027 
C      henke(8,1, 334 ) = 2025.2 
C      henke(8,2, 334 ) = 8.31719 
C      henke(8,3, 334 ) = 0.52098 
C      henke(8,1, 335 ) = 2057.95 
C      henke(8,2, 335 ) = 8.31332 
C      henke(8,3, 335 ) = 0.506059 
C      henke(8,1, 336 ) = 2091.24 
C      henke(8,2, 336 ) = 8.30931 
C      henke(8,3, 336 ) = 0.491524 
C      henke(8,1, 337 ) = 2125.06 
C      henke(8,2, 337 ) = 8.30523 
C      henke(8,3, 337 ) = 0.477384 
C      henke(8,1, 338 ) = 2159.43 
C      henke(8,2, 338 ) = 8.30109 
C      henke(8,3, 338 ) = 0.463634 
C      henke(8,1, 339 ) = 2194.36 
C      henke(8,2, 339 ) = 8.29692 
C      henke(8,3, 339 ) = 0.450251 
C      henke(8,1, 340 ) = 2229.85 
C      henke(8,2, 340 ) = 8.29272 
C      henke(8,3, 340 ) = 0.437232 
C      henke(8,1, 341 ) = 2265.92 
C      henke(8,2, 341 ) = 8.28851 
C      henke(8,3, 341 ) = 0.424568 
C      henke(8,1, 342 ) = 2302.57 
C      henke(8,2, 342 ) = 8.28427 
C      henke(8,3, 342 ) = 0.412245 
C      henke(8,1, 343 ) = 2339.81 
C      henke(8,2, 343 ) = 8.28002 
C      henke(8,3, 343 ) = 0.400261 
C      henke(8,1, 344 ) = 2377.66 
C      henke(8,2, 344 ) = 8.27576 
C      henke(8,3, 344 ) = 0.388605 
C      henke(8,1, 345 ) = 2416.11 
C      henke(8,2, 345 ) = 8.27151 
C      henke(8,3, 345 ) = 0.377269 
C      henke(8,1, 346 ) = 2455.19 
C      henke(8,2, 346 ) = 8.26726 
C      henke(8,3, 346 ) = 0.366239 
C      henke(8,1, 347 ) = 2494.9 
C      henke(8,2, 347 ) = 8.26301 
C      henke(8,3, 347 ) = 0.355523 
C      henke(8,1, 348 ) = 2535.26 
C      henke(8,2, 348 ) = 8.25878 
C      henke(8,3, 348 ) = 0.345085 
C      henke(8,1, 349 ) = 2576.26 
C      henke(8,2, 349 ) = 8.25456 
C      henke(8,3, 349 ) = 0.334943 
C      henke(8,1, 350 ) = 2617.93 
C      henke(8,2, 350 ) = 8.25035 
C      henke(8,3, 350 ) = 0.325079 
C      henke(8,1, 351 ) = 2660.27 
C      henke(8,2, 351 ) = 8.24617 
C      henke(8,3, 351 ) = 0.315489 
C      henke(8,1, 352 ) = 2703.3 
C      henke(8,2, 352 ) = 8.242 
C      henke(8,3, 352 ) = 0.306159 
C      henke(8,1, 353 ) = 2747.03 
C      henke(8,2, 353 ) = 8.23786 
C      henke(8,3, 353 ) = 0.297084 
C      henke(8,1, 354 ) = 2791.46 
C      henke(8,2, 354 ) = 8.23375 
C      henke(8,3, 354 ) = 0.288266 
C      henke(8,1, 355 ) = 2836.61 
C      henke(8,2, 355 ) = 8.22967 
C      henke(8,3, 355 ) = 0.279693 
C      henke(8,1, 356 ) = 2882.49 
C      henke(8,2, 356 ) = 8.22562 
C      henke(8,3, 356 ) = 0.271352 
C      henke(8,1, 357 ) = 2929.11 
C      henke(8,2, 357 ) = 8.22161 
C      henke(8,3, 357 ) = 0.263238 
C      henke(8,1, 358 ) = 2976.48 
C      henke(8,2, 358 ) = 8.21762 
C      henke(8,3, 358 ) = 0.255349 
C      henke(8,1, 359 ) = 3024.63 
C      henke(8,2, 359 ) = 8.21367 
C      henke(8,3, 359 ) = 0.247687 
C      henke(8,1, 360 ) = 3073.55 
C      henke(8,2, 360 ) = 8.20976 
C      henke(8,3, 360 ) = 0.240232 
C      henke(8,1, 361 ) = 3123.26 
C      henke(8,2, 361 ) = 8.20589 
C      henke(8,3, 361 ) = 0.232981 
C      henke(8,1, 362 ) = 3173.78 
C      henke(8,2, 362 ) = 8.20205 
C      henke(8,3, 362 ) = 0.225931 
C      henke(8,1, 363 ) = 3225.11 
C      henke(8,2, 363 ) = 8.19826 
C      henke(8,3, 363 ) = 0.219077 
C      henke(8,1, 364 ) = 3277.27 
C      henke(8,2, 364 ) = 8.1945 
C      henke(8,3, 364 ) = 0.212417 
C      henke(8,1, 365 ) = 3330.28 
C      henke(8,2, 365 ) = 8.19079 
C      henke(8,3, 365 ) = 0.205937 
C      henke(8,1, 366 ) = 3384.15 
C      henke(8,2, 366 ) = 8.18711 
C      henke(8,3, 366 ) = 0.199644 
C      henke(8,1, 367 ) = 3438.88 
C      henke(8,2, 367 ) = 8.18349 
C      henke(8,3, 367 ) = 0.193525 
C      henke(8,1, 368 ) = 3494.5 
C      henke(8,2, 368 ) = 8.17991 
C      henke(8,3, 368 ) = 0.187574 
C      henke(8,1, 369 ) = 3551.02 
C      henke(8,2, 369 ) = 8.17636 
C      henke(8,3, 369 ) = 0.181787 
C      henke(8,1, 370 ) = 3608.46 
C      henke(8,2, 370 ) = 8.17287 
C      henke(8,3, 370 ) = 0.17616 
C      henke(8,1, 371 ) = 3666.82 
C      henke(8,2, 371 ) = 8.16942 
C      henke(8,3, 371 ) = 0.170681 
C      henke(8,1, 372 ) = 3726.13 
C      henke(8,2, 372 ) = 8.16599 
C      henke(8,3, 372 ) = 0.165363 
C      henke(8,1, 373 ) = 3786.4 
C      henke(8,2, 373 ) = 8.16262 
C      henke(8,3, 373 ) = 0.160196 
C      henke(8,1, 374 ) = 3847.64 
C      henke(8,2, 374 ) = 8.15929 
C      henke(8,3, 374 ) = 0.155167 
C      henke(8,1, 375 ) = 3909.87 
C      henke(8,2, 375 ) = 8.15601 
C      henke(8,3, 375 ) = 0.150282 
C      henke(8,1, 376 ) = 3973.11 
C      henke(8,2, 376 ) = 8.15276 
C      henke(8,3, 376 ) = 0.145531 
C      henke(8,1, 377 ) = 4037.38 
C      henke(8,2, 377 ) = 8.14954 
C      henke(8,3, 377 ) = 0.140899 
C      henke(8,1, 378 ) = 4102.68 
C      henke(8,2, 378 ) = 8.14635 
C      henke(8,3, 378 ) = 0.136421 
C      henke(8,1, 379 ) = 4169.03 
C      henke(8,2, 379 ) = 8.14321 
C      henke(8,3, 379 ) = 0.132079 
C      henke(8,1, 380 ) = 4236.46 
C      henke(8,2, 380 ) = 8.14011 
C      henke(8,3, 380 ) = 0.127871 
C      henke(8,1, 381 ) = 4304.98 
C      henke(8,2, 381 ) = 8.13705 
C      henke(8,3, 381 ) = 0.123789 
C      henke(8,1, 382 ) = 4374.62 
C      henke(8,2, 382 ) = 8.13404 
C      henke(8,3, 382 ) = 0.119833 
C      henke(8,1, 383 ) = 4445.37 
C      henke(8,2, 383 ) = 8.13108 
C      henke(8,3, 383 ) = 0.115998 
C      henke(8,1, 384 ) = 4517.27 
C      henke(8,2, 384 ) = 8.12816 
C      henke(8,3, 384 ) = 0.11228 
C      henke(8,1, 385 ) = 4590.33 
C      henke(8,2, 385 ) = 8.12529 
C      henke(8,3, 385 ) = 0.108678 
C      henke(8,1, 386 ) = 4664.58 
C      henke(8,2, 386 ) = 8.12246 
C      henke(8,3, 386 ) = 0.105185 
C      henke(8,1, 387 ) = 4740.03 
C      henke(8,2, 387 ) = 8.11969 
C      henke(8,3, 387 ) = 0.1018 
C      henke(8,1, 388 ) = 4816.69 
C      henke(8,2, 388 ) = 8.11695 
C      henke(8,3, 388 ) = 0.0985193 
C      henke(8,1, 389 ) = 4894.6 
C      henke(8,2, 389 ) = 8.11427 
C      henke(8,3, 389 ) = 0.0953398 
C      henke(8,1, 390 ) = 4973.77 
C      henke(8,2, 390 ) = 8.11163 
C      henke(8,3, 390 ) = 0.0922592 
C      henke(8,1, 391 ) = 5054.21 
C      henke(8,2, 391 ) = 8.10904 
C      henke(8,3, 391 ) = 0.0892732 
C      henke(8,1, 392 ) = 5135.96 
C      henke(8,2, 392 ) = 8.10649 
C      henke(8,3, 392 ) = 0.0863801 
C      henke(8,1, 393 ) = 5219.03 
C      henke(8,2, 393 ) = 8.104 
C      henke(8,3, 393 ) = 0.0835779 
C      henke(8,1, 394 ) = 5303.44 
C      henke(8,2, 394 ) = 8.10154 
C      henke(8,3, 394 ) = 0.080862 
C      henke(8,1, 395 ) = 5389.22 
C      henke(8,2, 395 ) = 8.09913 
C      henke(8,3, 395 ) = 0.0782309 
C      henke(8,1, 396 ) = 5476.39 
C      henke(8,2, 396 ) = 8.09677 
C      henke(8,3, 396 ) = 0.0756813 
C      henke(8,1, 397 ) = 5564.97 
C      henke(8,2, 397 ) = 8.09445 
C      henke(8,3, 397 ) = 0.0732117 
C      henke(8,1, 398 ) = 5654.98 
C      henke(8,2, 398 ) = 8.09218 
C      henke(8,3, 398 ) = 0.0708205 
C      henke(8,1, 399 ) = 5746.44 
C      henke(8,2, 399 ) = 8.08995 
C      henke(8,3, 399 ) = 0.068504 
C      henke(8,1, 400 ) = 5839.39 
C      henke(8,2, 400 ) = 8.08776 
C      henke(8,3, 400 ) = 0.0662596 
C      henke(8,1, 401 ) = 5933.83 
C      henke(8,2, 401 ) = 8.08562 
C      henke(8,3, 401 ) = 0.0640857 
C      henke(8,1, 402 ) = 6029.81 
C      henke(8,2, 402 ) = 8.08351 
C      henke(8,3, 402 ) = 0.0619792 
C      henke(8,1, 403 ) = 6127.33 
C      henke(8,2, 403 ) = 8.08146 
C      henke(8,3, 403 ) = 0.0599416 
C      henke(8,1, 404 ) = 6226.44 
C      henke(8,2, 404 ) = 8.07944 
C      henke(8,3, 404 ) = 0.0579659 
C      henke(8,1, 405 ) = 6327.15 
C      henke(8,2, 405 ) = 8.07746 
C      henke(8,3, 405 ) = 0.0560545 
C      henke(8,1, 406 ) = 6429.48 
C      henke(8,2, 406 ) = 8.07552 
C      henke(8,3, 406 ) = 0.0542032 
C      henke(8,1, 407 ) = 6533.48 
C      henke(8,2, 407 ) = 8.07362 
C      henke(8,3, 407 ) = 0.0524097 
C      henke(8,1, 408 ) = 6639.15 
C      henke(8,2, 408 ) = 8.07176 
C      henke(8,3, 408 ) = 0.0506725 
C      henke(8,1, 409 ) = 6746.54 
C      henke(8,2, 409 ) = 8.06994 
C      henke(8,3, 409 ) = 0.0489916 
C      henke(8,1, 410 ) = 6855.65 
C      henke(8,2, 410 ) = 8.06816 
C      henke(8,3, 410 ) = 0.047365 
C      henke(8,1, 411 ) = 6966.54 
C      henke(8,2, 411 ) = 8.06642 
C      henke(8,3, 411 ) = 0.0457894 
C      henke(8,1, 412 ) = 7079.22 
C      henke(8,2, 412 ) = 8.06471 
C      henke(8,3, 412 ) = 0.0442644 
C      henke(8,1, 413 ) = 7193.72 
C      henke(8,2, 413 ) = 8.06304 
C      henke(8,3, 413 ) = 0.0427875 
C      henke(8,1, 414 ) = 7310.07 
C      henke(8,2, 414 ) = 8.0614 
C      henke(8,3, 414 ) = 0.0413582 
C      henke(8,1, 415 ) = 7428.31 
C      henke(8,2, 415 ) = 8.0598 
C      henke(8,3, 415 ) = 0.0399759 
C      henke(8,1, 416 ) = 7548.45 
C      henke(8,2, 416 ) = 8.05824 
C      henke(8,3, 416 ) = 0.0386359 
C      henke(8,1, 417 ) = 7670.54 
C      henke(8,2, 417 ) = 8.0567 
C      henke(8,3, 417 ) = 0.0373402 
C      henke(8,1, 418 ) = 7794.61 
C      henke(8,2, 418 ) = 8.05521 
C      henke(8,3, 418 ) = 0.0360851 
C      henke(8,1, 419 ) = 7920.68 
C      henke(8,2, 419 ) = 8.05374 
C      henke(8,3, 419 ) = 0.034871 
C      henke(8,1, 420 ) = 8048.79 
C      henke(8,2, 420 ) = 8.05231 
C      henke(8,3, 420 ) = 0.033698 
C      henke(8,1, 421 ) = 8178.98 
C      henke(8,2, 421 ) = 8.05091 
C      henke(8,3, 421 ) = 0.0325612 
C      henke(8,1, 422 ) = 8311.26 
C      henke(8,2, 422 ) = 8.04954 
C      henke(8,3, 422 ) = 0.0314612 
C      henke(8,1, 423 ) = 8445.69 
C      henke(8,2, 423 ) = 8.0482 
C      henke(8,3, 423 ) = 0.0303967 
C      henke(8,1, 424 ) = 8582.29 
C      henke(8,2, 424 ) = 8.04689 
C      henke(8,3, 424 ) = 0.029367 
C      henke(8,1, 425 ) = 8721.11 
C      henke(8,2, 425 ) = 8.04561 
C      henke(8,3, 425 ) = 0.0283707 
C      henke(8,1, 426 ) = 8862.16 
C      henke(8,2, 426 ) = 8.04436 
C      henke(8,3, 426 ) = 0.027407 
C      henke(8,1, 427 ) = 9005.5 
C      henke(8,2, 427 ) = 8.04313 
C      henke(8,3, 427 ) = 0.0264746 
C      henke(8,1, 428 ) = 9151.16 
C      henke(8,2, 428 ) = 8.04194 
C      henke(8,3, 428 ) = 0.0255728 
C      henke(8,1, 429 ) = 9299.17 
C      henke(8,2, 429 ) = 8.04077 
C      henke(8,3, 429 ) = 0.0247005 
C      henke(8,1, 430 ) = 9449.58 
C      henke(8,2, 430 ) = 8.03963 
C      henke(8,3, 430 ) = 0.0238566 
C      henke(8,1, 431 ) = 9602.42 
C      henke(8,2, 431 ) = 8.03852 
C      henke(8,3, 431 ) = 0.0230406 
C      henke(8,1, 432 ) = 9757.73 
C      henke(8,2, 432 ) = 8.03743 
C      henke(8,3, 432 ) = 0.0222513 
C      henke(8,1, 433 ) = 9915.55 
C      henke(8,2, 433 ) = 8.03637 
C      henke(8,3, 433 ) = 0.0214883 
C      henke(8,1, 434 ) = 10075.9 
C      henke(8,2, 434 ) = 8.03533 
C      henke(8,3, 434 ) = 0.0207501 
C      henke(8,1, 435 ) = 10238.9 
C      henke(8,2, 435 ) = 8.03432 
C      henke(8,3, 435 ) = 0.0200363 
C      henke(8,1, 436 ) = 10404.5 
C      henke(8,2, 436 ) = 8.03333 
C      henke(8,3, 436 ) = 0.0193461 
C      henke(8,1, 437 ) = 10572.8 
C      henke(8,2, 437 ) = 8.03236 
C      henke(8,3, 437 ) = 0.0186788 
C      henke(8,1, 438 ) = 10743.8 
C      henke(8,2, 438 ) = 8.03142 
C      henke(8,3, 438 ) = 0.0180336 
C      henke(8,1, 439 ) = 10917.6 
C      henke(8,2, 439 ) = 8.03049 
C      henke(8,3, 439 ) = 0.0174099 
C      henke(8,1, 440 ) = 11094.2 
C      henke(8,2, 440 ) = 8.0296 
C      henke(8,3, 440 ) = 0.0168069 
C      henke(8,1, 441 ) = 11273.6 
C      henke(8,2, 441 ) = 8.02872 
C      henke(8,3, 441 ) = 0.016224 
C      henke(8,1, 442 ) = 11455.9 
C      henke(8,2, 442 ) = 8.02786 
C      henke(8,3, 442 ) = 0.0156607 
C      henke(8,1, 443 ) = 11641.2 
C      henke(8,2, 443 ) = 8.02703 
C      henke(8,3, 443 ) = 0.0151161 
C      henke(8,1, 444 ) = 11829.5 
C      henke(8,2, 444 ) = 8.02621 
C      henke(8,3, 444 ) = 0.0145898 
C      henke(8,1, 445 ) = 12020.8 
C      henke(8,2, 445 ) = 8.02541 
C      henke(8,3, 445 ) = 0.0140812 
C      henke(8,1, 446 ) = 12215.3 
C      henke(8,2, 446 ) = 8.02464 
C      henke(8,3, 446 ) = 0.0135897 
C      henke(8,1, 447 ) = 12412.8 
C      henke(8,2, 447 ) = 8.02388 
C      henke(8,3, 447 ) = 0.0131147 
C      henke(8,1, 448 ) = 12613.6 
C      henke(8,2, 448 ) = 8.02314 
C      henke(8,3, 448 ) = 0.0126558 
C      henke(8,1, 449 ) = 12817.6 
C      henke(8,2, 449 ) = 8.02242 
C      henke(8,3, 449 ) = 0.0122124 
C      henke(8,1, 450 ) = 13025 
C      henke(8,2, 450 ) = 8.02172 
C      henke(8,3, 450 ) = 0.0117841 
C      henke(8,1, 451 ) = 13235.6 
C      henke(8,2, 451 ) = 8.02103 
C      henke(8,3, 451 ) = 0.0113702 
C      henke(8,1, 452 ) = 13449.7 
C      henke(8,2, 452 ) = 8.02036 
C      henke(8,3, 452 ) = 0.0109705 
C      henke(8,1, 453 ) = 13667.2 
C      henke(8,2, 453 ) = 8.01971 
C      henke(8,3, 453 ) = 0.0105844 
C      henke(8,1, 454 ) = 13888.3 
C      henke(8,2, 454 ) = 8.01907 
C      henke(8,3, 454 ) = 0.0102115 
C      henke(8,1, 455 ) = 14112.9 
C      henke(8,2, 455 ) = 8.01845 
C      henke(8,3, 455 ) = 0.00985132 
C      henke(8,1, 456 ) = 14341.2 
C      henke(8,2, 456 ) = 8.01785 
C      henke(8,3, 456 ) = 0.00950352 
C      henke(8,1, 457 ) = 14573.1 
C      henke(8,2, 457 ) = 8.01726 
C      henke(8,3, 457 ) = 0.00916766 
C      henke(8,1, 458 ) = 14808.9 
C      henke(8,2, 458 ) = 8.01668 
C      henke(8,3, 458 ) = 0.00884339 
C      henke(8,1, 459 ) = 15048.4 
C      henke(8,2, 459 ) = 8.01612 
C      henke(8,3, 459 ) = 0.0085303 
C      henke(8,1, 460 ) = 15291.8 
C      henke(8,2, 460 ) = 8.01557 
C      henke(8,3, 460 ) = 0.00822805 
C      henke(8,1, 461 ) = 15539.1 
C      henke(8,2, 461 ) = 8.01504 
C      henke(8,3, 461 ) = 0.00793628 
C      henke(8,1, 462 ) = 15790.4 
C      henke(8,2, 462 ) = 8.01452 
C      henke(8,3, 462 ) = 0.00765465 
C      henke(8,1, 463 ) = 16045.8 
C      henke(8,2, 463 ) = 8.01402 
C      henke(8,3, 463 ) = 0.00738283 
C      henke(8,1, 464 ) = 16305.4 
C      henke(8,2, 464 ) = 8.01352 
C      henke(8,3, 464 ) = 0.00712049 
C      henke(8,1, 465 ) = 16569.1 
C      henke(8,2, 465 ) = 8.01304 
C      henke(8,3, 465 ) = 0.00686735 
C      henke(8,1, 466 ) = 16837.1 
C      henke(8,2, 466 ) = 8.01257 
C      henke(8,3, 466 ) = 0.00662308 
C      henke(8,1, 467 ) = 17109.4 
C      henke(8,2, 467 ) = 8.01212 
C      henke(8,3, 467 ) = 0.00638742 
C      henke(8,1, 468 ) = 17386.1 
C      henke(8,2, 468 ) = 8.01167 
C      henke(8,3, 468 ) = 0.00616006 
C      henke(8,1, 469 ) = 17667.4 
C      henke(8,2, 469 ) = 8.01124 
C      henke(8,3, 469 ) = 0.00594073 
C      henke(8,1, 470 ) = 17953.1 
C      henke(8,2, 470 ) = 8.01082 
C      henke(8,3, 470 ) = 0.00572919 
C      henke(8,1, 471 ) = 18243.5 
C      henke(8,2, 471 ) = 8.01041 
C      henke(8,3, 471 ) = 0.00552516 
C      henke(8,1, 472 ) = 18538.6 
C      henke(8,2, 472 ) = 8.01001 
C      henke(8,3, 472 ) = 0.00532841 
C      henke(8,1, 473 ) = 18838.4 
C      henke(8,2, 473 ) = 8.00962 
C      henke(8,3, 473 ) = 0.00513869 
C      henke(8,1, 474 ) = 19143.1 
C      henke(8,2, 474 ) = 8.00924 
C      henke(8,3, 474 ) = 0.00495577 
C      henke(8,1, 475 ) = 19452.7 
C      henke(8,2, 475 ) = 8.00887 
C      henke(8,3, 475 ) = 0.00477943 
C      henke(8,1, 476 ) = 19767.4 
C      henke(8,2, 476 ) = 8.00851 
C      henke(8,3, 476 ) = 0.00460945 
C      henke(8,1, 477 ) = 20087.1 
C      henke(8,2, 477 ) = 8.00816 
C      henke(8,3, 477 ) = 0.00444652 
C      henke(8,1, 478 ) = 20412 
C      henke(8,2, 478 ) = 8.00782 
C      henke(8,3, 478 ) = 0.00428858 
C      henke(8,1, 479 ) = 20742.1 
C      henke(8,2, 479 ) = 8.00749 
C      henke(8,3, 479 ) = 0.00413632 
C      henke(8,1, 480 ) = 21077.6 
C      henke(8,2, 480 ) = 8.00717 
C      henke(8,3, 480 ) = 0.00398954 
C      henke(8,1, 481 ) = 21418.5 
C      henke(8,2, 481 ) = 8.00686 
C      henke(8,3, 481 ) = 0.00384804 
C      henke(8,1, 482 ) = 21765 
C      henke(8,2, 482 ) = 8.00655 
C      henke(8,3, 482 ) = 0.00371162 
C      henke(8,1, 483 ) = 22117 
C      henke(8,2, 483 ) = 8.00626 
C      henke(8,3, 483 ) = 0.00358009 
C      henke(8,1, 484 ) = 22474.7 
C      henke(8,2, 484 ) = 8.00597 
C      henke(8,3, 484 ) = 0.00345328 
C      henke(8,1, 485 ) = 22838.2 
C      henke(8,2, 485 ) = 8.00569 
C      henke(8,3, 485 ) = 0.003331 
C      henke(8,1, 486 ) = 23207.6 
C      henke(8,2, 486 ) = 8.00541 
C      henke(8,3, 486 ) = 0.0032131 
C      henke(8,1, 487 ) = 23583 
C      henke(8,2, 487 ) = 8.00515 
C      henke(8,3, 487 ) = 0.00309941 
C      henke(8,1, 488 ) = 23964.4 
C      henke(8,2, 488 ) = 8.00489 
C      henke(8,3, 488 ) = 0.00298978 
C      henke(8,1, 489 ) = 24352 
C      henke(8,2, 489 ) = 8.00464 
C      henke(8,3, 489 ) = 0.00288407 
C      henke(8,1, 490 ) = 24745.9 
C      henke(8,2, 490 ) = 8.00439 
C      henke(8,3, 490 ) = 0.00278212 
C      henke(8,1, 491 ) = 25146.2 
C      henke(8,2, 491 ) = 8.00416 
C      henke(8,3, 491 ) = 0.0026838 
C      henke(8,1, 492 ) = 25552.9 
C      henke(8,2, 492 ) = 8.00393 
C      henke(8,3, 492 ) = 0.00258899 
C      henke(8,1, 493 ) = 25966.2 
C      henke(8,2, 493 ) = 8.0037 
C      henke(8,3, 493 ) = 0.00249755 
C      henke(8,1, 494 ) = 26386.1 
C      henke(8,2, 494 ) = 8.00348 
C      henke(8,3, 494 ) = 0.00240935 
C      henke(8,1, 495 ) = 26812.9 
C      henke(8,2, 495 ) = 8.00327 
C      henke(8,3, 495 ) = 0.00232429 
C      henke(8,1, 496 ) = 27246.6 
C      henke(8,2, 496 ) = 8.00307 
C      henke(8,3, 496 ) = 0.00224225 
C      henke(8,1, 497 ) = 27687.3 
C      henke(8,2, 497 ) = 8.00286 
C      henke(8,3, 497 ) = 0.00216311 
C      henke(8,1, 498 ) = 28135.1 
C      henke(8,2, 498 ) = 8.00267 
C      henke(8,3, 498 ) = 0.00208678 
C      henke(8,1, 499 ) = 28590.2 
C      henke(8,2, 499 ) = 8.00248 
C      henke(8,3, 499 ) = 0.00201316 
C      henke(8,1, 500 ) = 29052.6 
C      henke(8,2, 500 ) = 8.0023 
C      henke(8,3, 500 ) = 0.00194214 
C      henke(8,1, 501 ) = 29522.5 
C      henke(8,2, 501 ) = 8.00212 
C      henke(8,3, 501 ) = 0.00187363 
C      henke(8,1, 502 ) = 30000 
C      henke(8,2, 502 ) = 8.00194 
C      henke(8,3, 502 ) = 0.00180754 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C        Henke data for al  z=13
C      count(13) = 504
C      henke(13,1, 1 ) = 10 
C      henke(13,2, 1 ) = -9999 
C      henke(13,3, 1 ) = 3.1199 
C      henke(13,1, 2 ) = 10.1617 
C      henke(13,2, 2 ) = -9999 
C      henke(13,3, 2 ) = 3.05822 
C      henke(13,1, 3 ) = 10.3261 
C      henke(13,2, 3 ) = -9999 
C      henke(13,3, 3 ) = 2.99776 
C      henke(13,1, 4 ) = 10.4931 
C      henke(13,2, 4 ) = -9999 
C      henke(13,3, 4 ) = 2.9385 
C      henke(13,1, 5 ) = 10.6628 
C      henke(13,2, 5 ) = -9999 
C      henke(13,3, 5 ) = 2.88041 
C      henke(13,1, 6 ) = 10.8353 
C      henke(13,2, 6 ) = -9999 
C      henke(13,3, 6 ) = 2.82347 
C      henke(13,1, 7 ) = 11.0106 
C      henke(13,2, 7 ) = -9999 
C      henke(13,3, 7 ) = 2.76766 
C      henke(13,1, 8 ) = 11.1886 
C      henke(13,2, 8 ) = -9999 
C      henke(13,3, 8 ) = 2.722 
C      henke(13,1, 9 ) = 11.3696 
C      henke(13,2, 9 ) = -9999 
C      henke(13,3, 9 ) = 2.69148 
C      henke(13,1, 10 ) = 11.5535 
C      henke(13,2, 10 ) = -9999 
C      henke(13,3, 10 ) = 2.66129 
C      henke(13,1, 11 ) = 11.7404 
C      henke(13,2, 11 ) = -9999 
C      henke(13,3, 11 ) = 2.63145 
C      henke(13,1, 12 ) = 11.9303 
C      henke(13,2, 12 ) = -9999 
C      henke(13,3, 12 ) = 2.60195 
C      henke(13,1, 13 ) = 12.1232 
C      henke(13,2, 13 ) = -9999 
C      henke(13,3, 13 ) = 2.57277 
C      henke(13,1, 14 ) = 12.3193 
C      henke(13,2, 14 ) = -9999 
C      henke(13,3, 14 ) = 2.54392 
C      henke(13,1, 15 ) = 12.5186 
C      henke(13,2, 15 ) = -9999 
C      henke(13,3, 15 ) = 2.51539 
C      henke(13,1, 16 ) = 12.721 
C      henke(13,2, 16 ) = -9999 
C      henke(13,3, 16 ) = 2.46668 
C      henke(13,1, 17 ) = 12.9268 
C      henke(13,2, 17 ) = -9999 
C      henke(13,3, 17 ) = 2.41373 
C      henke(13,1, 18 ) = 13.1359 
C      henke(13,2, 18 ) = -9999 
C      henke(13,3, 18 ) = 2.36192 
C      henke(13,1, 19 ) = 13.3483 
C      henke(13,2, 19 ) = -9999 
C      henke(13,3, 19 ) = 2.30898 
C      henke(13,1, 20 ) = 13.5642 
C      henke(13,2, 20 ) = -9999 
C      henke(13,3, 20 ) = 2.23405 
C      henke(13,1, 21 ) = 13.7836 
C      henke(13,2, 21 ) = -9999 
C      henke(13,3, 21 ) = 2.15356 
C      henke(13,1, 22 ) = 14.0066 
C      henke(13,2, 22 ) = -9999 
C      henke(13,3, 22 ) = 2.06069 
C      henke(13,1, 23 ) = 14.2331 
C      henke(13,2, 23 ) = -9999 
C      henke(13,3, 23 ) = 1.96756 
C      henke(13,1, 24 ) = 14.4633 
C      henke(13,2, 24 ) = -9999 
C      henke(13,3, 24 ) = 1.81305 
C      henke(13,1, 25 ) = 14.6973 
C      henke(13,2, 25 ) = -9999 
C      henke(13,3, 25 ) = 1.35947 
C      henke(13,1, 26 ) = 14.935 
C      henke(13,2, 26 ) = -9999 
C      henke(13,3, 26 ) = 0.902011 
C      henke(13,1, 27 ) = 15.1765 
C      henke(13,2, 27 ) = -9999 
C      henke(13,3, 27 ) = 0.609172 
C      henke(13,1, 28 ) = 15.422 
C      henke(13,2, 28 ) = -9999 
C      henke(13,3, 28 ) = 0.439681 
C      henke(13,1, 29 ) = 15.6714 
C      henke(13,2, 29 ) = -9999 
C      henke(13,3, 29 ) = 0.372037 
C      henke(13,1, 30 ) = 15.9249 
C      henke(13,2, 30 ) = -9999 
C      henke(13,3, 30 ) = 0.326005 
C      henke(13,1, 31 ) = 16.1825 
C      henke(13,2, 31 ) = -9999 
C      henke(13,3, 31 ) = 0.285669 
C      henke(13,1, 32 ) = 16.4442 
C      henke(13,2, 32 ) = -9999 
C      henke(13,3, 32 ) = 0.247205 
C      henke(13,1, 33 ) = 16.7102 
C      henke(13,2, 33 ) = -9999 
C      henke(13,3, 33 ) = 0.21352 
C      henke(13,1, 34 ) = 16.9805 
C      henke(13,2, 34 ) = -9999 
C      henke(13,3, 34 ) = 0.196522 
C      henke(13,1, 35 ) = 17.2551 
C      henke(13,2, 35 ) = -9999 
C      henke(13,3, 35 ) = 0.181095 
C      henke(13,1, 36 ) = 17.5342 
C      henke(13,2, 36 ) = -9999 
C      henke(13,3, 36 ) = 0.168385 
C      henke(13,1, 37 ) = 17.8178 
C      henke(13,2, 37 ) = -9999 
C      henke(13,3, 37 ) = 0.160808 
C      henke(13,1, 38 ) = 18.106 
C      henke(13,2, 38 ) = -9999 
C      henke(13,3, 38 ) = 0.153573 
C      henke(13,1, 39 ) = 18.3989 
C      henke(13,2, 39 ) = -9999 
C      henke(13,3, 39 ) = 0.146663 
C      henke(13,1, 40 ) = 18.6964 
C      henke(13,2, 40 ) = -9999 
C      henke(13,3, 40 ) = 0.140063 
C      henke(13,1, 41 ) = 18.9988 
C      henke(13,2, 41 ) = -9999 
C      henke(13,3, 41 ) = 0.133164 
C      henke(13,1, 42 ) = 19.3061 
C      henke(13,2, 42 ) = -9999 
C      henke(13,3, 42 ) = 0.126575 
C      henke(13,1, 43 ) = 19.6184 
C      henke(13,2, 43 ) = -9999 
C      henke(13,3, 43 ) = 0.120312 
C      henke(13,1, 44 ) = 19.9357 
C      henke(13,2, 44 ) = -9999 
C      henke(13,3, 44 ) = 0.11436 
C      henke(13,1, 45 ) = 20.2582 
C      henke(13,2, 45 ) = -9999 
C      henke(13,3, 45 ) = 0.109752 
C      henke(13,1, 46 ) = 20.5858 
C      henke(13,2, 46 ) = -9999 
C      henke(13,3, 46 ) = 0.11101 
C      henke(13,1, 47 ) = 20.9188 
C      henke(13,2, 47 ) = -9999 
C      henke(13,3, 47 ) = 0.112282 
C      henke(13,1, 48 ) = 21.2571 
C      henke(13,2, 48 ) = -9999 
C      henke(13,3, 48 ) = 0.113569 
C      henke(13,1, 49 ) = 21.6009 
C      henke(13,2, 49 ) = -9999 
C      henke(13,3, 49 ) = 0.11487 
C      henke(13,1, 50 ) = 21.9503 
C      henke(13,2, 50 ) = -9999 
C      henke(13,3, 50 ) = 0.116186 
C      henke(13,1, 51 ) = 22.3053 
C      henke(13,2, 51 ) = -9999 
C      henke(13,3, 51 ) = 0.117518 
C      henke(13,1, 52 ) = 22.6661 
C      henke(13,2, 52 ) = -9999 
C      henke(13,3, 52 ) = 0.118864 
C      henke(13,1, 53 ) = 23.0327 
C      henke(13,2, 53 ) = -9999 
C      henke(13,3, 53 ) = 0.120227 
C      henke(13,1, 54 ) = 23.4053 
C      henke(13,2, 54 ) = -9999 
C      henke(13,3, 54 ) = 0.122751 
C      henke(13,1, 55 ) = 23.7838 
C      henke(13,2, 55 ) = -9999 
C      henke(13,3, 55 ) = 0.126315 
C      henke(13,1, 56 ) = 24.1685 
C      henke(13,2, 56 ) = -9999 
C      henke(13,3, 56 ) = 0.129984 
C      henke(13,1, 57 ) = 24.5594 
C      henke(13,2, 57 ) = -9999 
C      henke(13,3, 57 ) = 0.133759 
C      henke(13,1, 58 ) = 24.9566 
C      henke(13,2, 58 ) = -9999 
C      henke(13,3, 58 ) = 0.137643 
C      henke(13,1, 59 ) = 25.3603 
C      henke(13,2, 59 ) = -9999 
C      henke(13,3, 59 ) = 0.14164 
C      henke(13,1, 60 ) = 25.7705 
C      henke(13,2, 60 ) = -9999 
C      henke(13,3, 60 ) = 0.145495 
C      henke(13,1, 61 ) = 26.1873 
C      henke(13,2, 61 ) = -9999 
C      henke(13,3, 61 ) = 0.148244 
C      henke(13,1, 62 ) = 26.6109 
C      henke(13,2, 62 ) = -9999 
C      henke(13,3, 62 ) = 0.151045 
C      henke(13,1, 63 ) = 27.0413 
C      henke(13,2, 63 ) = -9999 
C      henke(13,3, 63 ) = 0.153898 
C      henke(13,1, 64 ) = 27.4786 
C      henke(13,2, 64 ) = -9999 
C      henke(13,3, 64 ) = 0.156806 
C      henke(13,1, 65 ) = 27.9231 
C      henke(13,2, 65 ) = -9999 
C      henke(13,3, 65 ) = 0.159768 
C      henke(13,1, 66 ) = 28.3747 
C      henke(13,2, 66 ) = -9999 
C      henke(13,3, 66 ) = 0.162787 
C      henke(13,1, 67 ) = 28.8337 
C      henke(13,2, 67 ) = -9999 
C      henke(13,3, 67 ) = 0.165863 
C      henke(13,1, 68 ) = 29.3 
C      henke(13,2, 68 ) = 2.34285 
C      henke(13,3, 68 ) = 0.168996 
C      henke(13,1, 69 ) = 29.7739 
C      henke(13,2, 69 ) = 2.32717 
C      henke(13,3, 69 ) = 0.172189 
C      henke(13,1, 70 ) = 30.2555 
C      henke(13,2, 70 ) = 2.31139 
C      henke(13,3, 70 ) = 0.175442 
C      henke(13,1, 71 ) = 30.7449 
C      henke(13,2, 71 ) = 2.29552 
C      henke(13,3, 71 ) = 0.178757 
C      henke(13,1, 72 ) = 31.2421 
C      henke(13,2, 72 ) = 2.27956 
C      henke(13,3, 72 ) = 0.182134 
C      henke(13,1, 73 ) = 31.7475 
C      henke(13,2, 73 ) = 2.2635 
C      henke(13,3, 73 ) = 0.185575 
C      henke(13,1, 74 ) = 32.2609 
C      henke(13,2, 74 ) = 2.24754 
C      henke(13,3, 74 ) = 0.189081 
C      henke(13,1, 75 ) = 32.7827 
C      henke(13,2, 75 ) = 2.23175 
C      henke(13,3, 75 ) = 0.192378 
C      henke(13,1, 76 ) = 33.313 
C      henke(13,2, 76 ) = 2.21555 
C      henke(13,3, 76 ) = 0.194561 
C      henke(13,1, 77 ) = 33.8518 
C      henke(13,2, 77 ) = 2.19843 
C      henke(13,3, 77 ) = 0.196767 
C      henke(13,1, 78 ) = 34.3993 
C      henke(13,2, 78 ) = 2.18068 
C      henke(13,3, 78 ) = 0.198999 
C      henke(13,1, 79 ) = 34.9557 
C      henke(13,2, 79 ) = 2.16235 
C      henke(13,3, 79 ) = 0.201256 
C      henke(13,1, 80 ) = 35.5211 
C      henke(13,2, 80 ) = 2.14342 
C      henke(13,3, 80 ) = 0.203539 
C      henke(13,1, 81 ) = 36.0956 
C      henke(13,2, 81 ) = 2.12388 
C      henke(13,3, 81 ) = 0.205847 
C      henke(13,1, 82 ) = 36.6794 
C      henke(13,2, 82 ) = 2.10371 
C      henke(13,3, 82 ) = 0.208182 
C      henke(13,1, 83 ) = 37.2727 
C      henke(13,2, 83 ) = 2.08287 
C      henke(13,3, 83 ) = 0.210544 
C      henke(13,1, 84 ) = 37.8755 
C      henke(13,2, 84 ) = 2.06135 
C      henke(13,3, 84 ) = 0.212932 
C      henke(13,1, 85 ) = 38.4882 
C      henke(13,2, 85 ) = 2.03911 
C      henke(13,3, 85 ) = 0.215347 
C      henke(13,1, 86 ) = 39.1107 
C      henke(13,2, 86 ) = 2.01612 
C      henke(13,3, 86 ) = 0.217789 
C      henke(13,1, 87 ) = 39.7432 
C      henke(13,2, 87 ) = 1.99237 
C      henke(13,3, 87 ) = 0.220259 
C      henke(13,1, 88 ) = 40.3861 
C      henke(13,2, 88 ) = 1.96797 
C      henke(13,3, 88 ) = 0.222758 
C      henke(13,1, 89 ) = 41.0393 
C      henke(13,2, 89 ) = 1.94295 
C      henke(13,3, 89 ) = 0.225068 
C      henke(13,1, 90 ) = 41.7031 
C      henke(13,2, 90 ) = 1.91682 
C      henke(13,3, 90 ) = 0.22647 
C      henke(13,1, 91 ) = 42.3776 
C      henke(13,2, 91 ) = 1.88912 
C      henke(13,3, 91 ) = 0.22788 
C      henke(13,1, 92 ) = 43.063 
C      henke(13,2, 92 ) = 1.86007 
C      henke(13,3, 92 ) = 0.229299 
C      henke(13,1, 93 ) = 43.7595 
C      henke(13,2, 93 ) = 1.82966 
C      henke(13,3, 93 ) = 0.230727 
C      henke(13,1, 94 ) = 44.4673 
C      henke(13,2, 94 ) = 1.79787 
C      henke(13,3, 94 ) = 0.232164 
C      henke(13,1, 95 ) = 45.1865 
C      henke(13,2, 95 ) = 1.76466 
C      henke(13,3, 95 ) = 0.23361 
C      henke(13,1, 96 ) = 45.9174 
C      henke(13,2, 96 ) = 1.73005 
C      henke(13,3, 96 ) = 0.235064 
C      henke(13,1, 97 ) = 46.66 
C      henke(13,2, 97 ) = 1.69399 
C      henke(13,3, 97 ) = 0.236528 
C      henke(13,1, 98 ) = 47.4147 
C      henke(13,2, 98 ) = 1.65814 
C      henke(13,3, 98 ) = 0.238001 
C      henke(13,1, 99 ) = 48.1816 
C      henke(13,2, 99 ) = 1.62074 
C      henke(13,3, 99 ) = 0.235842 
C      henke(13,1, 100 ) = 48.9609 
C      henke(13,2, 100 ) = 1.57843 
C      henke(13,3, 100 ) = 0.232104 
C      henke(13,1, 101 ) = 49.7528 
C      henke(13,2, 101 ) = 1.53229 
C      henke(13,3, 101 ) = 0.228425 
C      henke(13,1, 102 ) = 50.5576 
C      henke(13,2, 102 ) = 1.48252 
C      henke(13,3, 102 ) = 0.224805 
C      henke(13,1, 103 ) = 51.3753 
C      henke(13,2, 103 ) = 1.42904 
C      henke(13,3, 103 ) = 0.221242 
C      henke(13,1, 104 ) = 52.2062 
C      henke(13,2, 104 ) = 1.37159 
C      henke(13,3, 104 ) = 0.217735 
C      henke(13,1, 105 ) = 53.0506 
C      henke(13,2, 105 ) = 1.30972 
C      henke(13,3, 105 ) = 0.214284 
C      henke(13,1, 106 ) = 53.9087 
C      henke(13,2, 106 ) = 1.24315 
C      henke(13,3, 106 ) = 0.211759 
C      henke(13,1, 107 ) = 54.7806 
C      henke(13,2, 107 ) = 1.17229 
C      henke(13,3, 107 ) = 0.209829 
C      henke(13,1, 108 ) = 55.6667 
C      henke(13,2, 108 ) = 1.09675 
C      henke(13,3, 108 ) = 0.207917 
C      henke(13,1, 109 ) = 56.567 
C      henke(13,2, 109 ) = 1.01559 
C      henke(13,3, 109 ) = 0.206022 
C      henke(13,1, 110 ) = 57.482 
C      henke(13,2, 110 ) = 0.928103 
C      henke(13,3, 110 ) = 0.204145 
C      henke(13,1, 111 ) = 58.4117 
C      henke(13,2, 111 ) = 0.833427 
C      henke(13,3, 111 ) = 0.202284 
C      henke(13,1, 112 ) = 59.3564 
C      henke(13,2, 112 ) = 0.729805 
C      henke(13,3, 112 ) = 0.200441 
C      henke(13,1, 113 ) = 60.3165 
C      henke(13,2, 113 ) = 0.61672 
C      henke(13,3, 113 ) = 0.200207 
C      henke(13,1, 114 ) = 61.2921 
C      henke(13,2, 114 ) = 0.494009 
C      henke(13,3, 114 ) = 0.200602 
C      henke(13,1, 115 ) = 62.2834 
C      henke(13,2, 115 ) = 0.359171 
C      henke(13,3, 115 ) = 0.200998 
C      henke(13,1, 116 ) = 63.2908 
C      henke(13,2, 116 ) = 0.206766 
C      henke(13,3, 116 ) = 0.201394 
C      henke(13,1, 117 ) = 64.3145 
C      henke(13,2, 117 ) = 0.0367838 
C      henke(13,3, 117 ) = 0.208215 
C      henke(13,1, 118 ) = 65.3547 
C      henke(13,2, 118 ) = -0.1501 
C      henke(13,3, 118 ) = 0.215821 
C      henke(13,1, 119 ) = 66.4118 
C      henke(13,2, 119 ) = -0.3634 
C      henke(13,3, 119 ) = 0.223705 
C      henke(13,1, 120 ) = 67.4859 
C      henke(13,2, 120 ) = -0.612251 
C      henke(13,3, 120 ) = 0.231878 
C      henke(13,1, 121 ) = 68.5775 
C      henke(13,2, 121 ) = -0.913185 
C      henke(13,3, 121 ) = 0.239512 
C      henke(13,1, 122 ) = 69.6867 
C      henke(13,2, 122 ) = -1.29772 
C      henke(13,3, 122 ) = 0.247287 
C      henke(13,1, 123 ) = 70.8138 
C      henke(13,2, 123 ) = -1.83916 
C      henke(13,3, 123 ) = 0.255315 
C      henke(13,1, 124 ) = 71.9591 
C      henke(13,2, 124 ) = -2.8264 
C      henke(13,3, 124 ) = 0.263603 
C      henke(13,1, 125 ) = 72.6 
C      henke(13,2, 125 ) = -4.7187 
C      henke(13,3, 125 ) = 0.268298 
C      henke(13,1, 126 ) = 72.8 
C      henke(13,2, 126 ) = -4.77865 
C      henke(13,3, 126 ) = 3.05391 
C      henke(13,1, 127 ) = 73.123 
C      henke(13,2, 127 ) = -3.57738 
C      henke(13,3, 127 ) = 3.10106 
C      henke(13,1, 128 ) = 74.3057 
C      henke(13,2, 128 ) = -2.58986 
C      henke(13,3, 128 ) = 3.27808 
C      henke(13,1, 129 ) = 75.5076 
C      henke(13,2, 129 ) = -2.24498 
C      henke(13,3, 129 ) = 3.46521 
C      henke(13,1, 130 ) = 76.7289 
C      henke(13,2, 130 ) = -2.04974 
C      henke(13,3, 130 ) = 3.66301 
C      henke(13,1, 131 ) = 77.9699 
C      henke(13,2, 131 ) = -1.91658 
C      henke(13,3, 131 ) = 3.87212 
C      henke(13,1, 132 ) = 79.231 
C      henke(13,2, 132 ) = -1.81173 
C      henke(13,3, 132 ) = 4.09316 
C      henke(13,1, 133 ) = 80.5125 
C      henke(13,2, 133 ) = -1.71207 
C      henke(13,3, 133 ) = 4.32681 
C      henke(13,1, 134 ) = 81.8147 
C      henke(13,2, 134 ) = -1.61278 
C      henke(13,3, 134 ) = 4.55877 
C      henke(13,1, 135 ) = 83.138 
C      henke(13,2, 135 ) = -1.51695 
C      henke(13,3, 135 ) = 4.80227 
C      henke(13,1, 136 ) = 84.4827 
C      henke(13,2, 136 ) = -1.40821 
C      henke(13,3, 136 ) = 5.05877 
C      henke(13,1, 137 ) = 85.8491 
C      henke(13,2, 137 ) = -1.24639 
C      henke(13,3, 137 ) = 5.32897 
C      henke(13,1, 138 ) = 87.2377 
C      henke(13,2, 138 ) = -1.04412 
C      henke(13,3, 138 ) = 5.54566 
C      henke(13,1, 139 ) = 88.6487 
C      henke(13,2, 139 ) = -0.869623 
C      henke(13,3, 139 ) = 5.6907 
C      henke(13,1, 140 ) = 90.0825 
C      henke(13,2, 140 ) = -0.729715 
C      henke(13,3, 140 ) = 5.83953 
C      henke(13,1, 141 ) = 91.5395 
C      henke(13,2, 141 ) = -0.602517 
C      henke(13,3, 141 ) = 5.99225 
C      henke(13,1, 142 ) = 93.0201 
C      henke(13,2, 142 ) = -0.481649 
C      henke(13,3, 142 ) = 6.14897 
C      henke(13,1, 143 ) = 94.5246 
C      henke(13,2, 143 ) = -0.363849 
C      henke(13,3, 143 ) = 6.30978 
C      henke(13,1, 144 ) = 96.0535 
C      henke(13,2, 144 ) = -0.246485 
C      henke(13,3, 144 ) = 6.4748 
C      henke(13,1, 145 ) = 97.6071 
C      henke(13,2, 145 ) = -0.127798 
C      henke(13,3, 145 ) = 6.64413 
C      henke(13,1, 146 ) = 99.1858 
C      henke(13,2, 146 ) = -0.00572152 
C      henke(13,3, 146 ) = 6.8179 
C      henke(13,1, 147 ) = 100.79 
C      henke(13,2, 147 ) = 0.121587 
C      henke(13,3, 147 ) = 6.9962 
C      henke(13,1, 148 ) = 102.42 
C      henke(13,2, 148 ) = 0.257648 
C      henke(13,3, 148 ) = 7.17918 
C      henke(13,1, 149 ) = 104.077 
C      henke(13,2, 149 ) = 0.408417 
C      henke(13,3, 149 ) = 7.36022 
C      henke(13,1, 150 ) = 105.76 
C      henke(13,2, 150 ) = 0.563135 
C      henke(13,3, 150 ) = 7.52866 
C      henke(13,1, 151 ) = 107.471 
C      henke(13,2, 151 ) = 0.713525 
C      henke(13,3, 151 ) = 7.70096 
C      henke(13,1, 152 ) = 109.209 
C      henke(13,2, 152 ) = 0.869599 
C      henke(13,3, 152 ) = 7.8772 
C      henke(13,1, 153 ) = 110.975 
C      henke(13,2, 153 ) = 1.03257 
C      henke(13,3, 153 ) = 8.05748 
C      henke(13,1, 154 ) = 112.77 
C      henke(13,2, 154 ) = 1.20465 
C      henke(13,3, 154 ) = 8.24188 
C      henke(13,1, 155 ) = 114.594 
C      henke(13,2, 155 ) = 1.38785 
C      henke(13,3, 155 ) = 8.4305 
C      henke(13,1, 156 ) = 116.448 
C      henke(13,2, 156 ) = 1.58511 
C      henke(13,3, 156 ) = 8.62344 
C      henke(13,1, 157 ) = 118.331 
C      henke(13,2, 157 ) = 1.79993 
C      henke(13,3, 157 ) = 8.8208 
C      henke(13,1, 158 ) = 120.245 
C      henke(13,2, 158 ) = 2.03832 
C      henke(13,3, 158 ) = 9.02267 
C      henke(13,1, 159 ) = 122.19 
C      henke(13,2, 159 ) = 2.31105 
C      henke(13,3, 159 ) = 9.22916 
C      henke(13,1, 160 ) = 124.166 
C      henke(13,2, 160 ) = 2.65726 
C      henke(13,3, 160 ) = 9.44037 
C      henke(13,1, 161 ) = 126.175 
C      henke(13,2, 161 ) = 3.0545 
C      henke(13,3, 161 ) = 9.49754 
C      henke(13,1, 162 ) = 128.215 
C      henke(13,2, 162 ) = 3.37636 
C      henke(13,3, 162 ) = 9.51114 
C      henke(13,1, 163 ) = 130.289 
C      henke(13,2, 163 ) = 3.65455 
C      henke(13,3, 163 ) = 9.52475 
C      henke(13,1, 164 ) = 132.397 
C      henke(13,2, 164 ) = 3.91635 
C      henke(13,3, 164 ) = 9.5384 
C      henke(13,1, 165 ) = 134.538 
C      henke(13,2, 165 ) = 4.16654 
C      henke(13,3, 165 ) = 9.55206 
C      henke(13,1, 166 ) = 136.714 
C      henke(13,2, 166 ) = 4.40886 
C      henke(13,3, 166 ) = 9.56573 
C      henke(13,1, 167 ) = 138.925 
C      henke(13,2, 167 ) = 4.64594 
C      henke(13,3, 167 ) = 9.57943 
C      henke(13,1, 168 ) = 141.172 
C      henke(13,2, 168 ) = 4.87987 
C      henke(13,3, 168 ) = 9.59315 
C      henke(13,1, 169 ) = 143.456 
C      henke(13,2, 169 ) = 5.11258 
C      henke(13,3, 169 ) = 9.60689 
C      henke(13,1, 170 ) = 145.776 
C      henke(13,2, 170 ) = 5.34618 
C      henke(13,3, 170 ) = 9.62064 
C      henke(13,1, 171 ) = 148.134 
C      henke(13,2, 171 ) = 5.58438 
C      henke(13,3, 171 ) = 9.63443 
C      henke(13,1, 172 ) = 150.53 
C      henke(13,2, 172 ) = 5.83549 
C      henke(13,3, 172 ) = 9.64822 
C      henke(13,1, 173 ) = 152.964 
C      henke(13,2, 173 ) = 6.09089 
C      henke(13,3, 173 ) = 9.6231 
C      henke(13,1, 174 ) = 155.439 
C      henke(13,2, 174 ) = 6.32655 
C      henke(13,3, 174 ) = 9.59689 
C      henke(13,1, 175 ) = 157.953 
C      henke(13,2, 175 ) = 6.55613 
C      henke(13,3, 175 ) = 9.57075 
C      henke(13,1, 176 ) = 160.507 
C      henke(13,2, 176 ) = 6.78302 
C      henke(13,3, 176 ) = 9.54468 
C      henke(13,1, 177 ) = 163.103 
C      henke(13,2, 177 ) = 7.00948 
C      henke(13,3, 177 ) = 9.51868 
C      henke(13,1, 178 ) = 165.742 
C      henke(13,2, 178 ) = 7.23759 
C      henke(13,3, 178 ) = 9.49275 
C      henke(13,1, 179 ) = 168.422 
C      henke(13,2, 179 ) = 7.4698 
C      henke(13,3, 179 ) = 9.46689 
C      henke(13,1, 180 ) = 171.146 
C      henke(13,2, 180 ) = 7.70942 
C      henke(13,3, 180 ) = 9.44111 
C      henke(13,1, 181 ) = 173.915 
C      henke(13,2, 181 ) = 7.96219 
C      henke(13,3, 181 ) = 9.4154 
C      henke(13,1, 182 ) = 176.727 
C      henke(13,2, 182 ) = 8.24313 
C      henke(13,3, 182 ) = 9.38975 
C      henke(13,1, 183 ) = 179.586 
C      henke(13,2, 183 ) = 8.57964 
C      henke(13,3, 183 ) = 9.31472 
C      henke(13,1, 184 ) = 182.491 
C      henke(13,2, 184 ) = 8.88946 
C      henke(13,3, 184 ) = 9.13115 
C      henke(13,1, 185 ) = 185.442 
C      henke(13,2, 185 ) = 9.11623 
C      henke(13,3, 185 ) = 8.95119 
C      henke(13,1, 186 ) = 188.442 
C      henke(13,2, 186 ) = 9.32069 
C      henke(13,3, 186 ) = 8.77477 
C      henke(13,1, 187 ) = 191.489 
C      henke(13,2, 187 ) = 9.50496 
C      henke(13,3, 187 ) = 8.60184 
C      henke(13,1, 188 ) = 194.587 
C      henke(13,2, 188 ) = 9.67311 
C      henke(13,3, 188 ) = 8.43231 
C      henke(13,1, 189 ) = 197.734 
C      henke(13,2, 189 ) = 9.82798 
C      henke(13,3, 189 ) = 8.26612 
C      henke(13,1, 190 ) = 200.932 
C      henke(13,2, 190 ) = 9.97197 
C      henke(13,3, 190 ) = 8.10317 
C      henke(13,1, 191 ) = 204.182 
C      henke(13,2, 191 ) = 10.1053 
C      henke(13,3, 191 ) = 7.93953 
C      henke(13,1, 192 ) = 207.485 
C      henke(13,2, 192 ) = 10.2265 
C      henke(13,3, 192 ) = 7.7792 
C      henke(13,1, 193 ) = 210.84 
C      henke(13,2, 193 ) = 10.3376 
C      henke(13,3, 193 ) = 7.6221 
C      henke(13,1, 194 ) = 214.251 
C      henke(13,2, 194 ) = 10.4388 
C      henke(13,3, 194 ) = 7.46817 
C      henke(13,1, 195 ) = 217.716 
C      henke(13,2, 195 ) = 10.5299 
C      henke(13,3, 195 ) = 7.31736 
C      henke(13,1, 196 ) = 221.237 
C      henke(13,2, 196 ) = 10.6083 
C      henke(13,3, 196 ) = 7.16959 
C      henke(13,1, 197 ) = 224.816 
C      henke(13,2, 197 ) = 10.668 
C      henke(13,3, 197 ) = 7.03532 
C      henke(13,1, 198 ) = 228.452 
C      henke(13,2, 198 ) = 10.7284 
C      henke(13,3, 198 ) = 6.92993 
C      henke(13,1, 199 ) = 232.147 
C      henke(13,2, 199 ) = 10.8042 
C      henke(13,3, 199 ) = 6.82611 
C      henke(13,1, 200 ) = 235.902 
C      henke(13,2, 200 ) = 10.8811 
C      henke(13,3, 200 ) = 6.72384 
C      henke(13,1, 201 ) = 239.717 
C      henke(13,2, 201 ) = 10.9592 
C      henke(13,3, 201 ) = 6.62312 
C      henke(13,1, 202 ) = 243.595 
C      henke(13,2, 202 ) = 11.038 
C      henke(13,3, 202 ) = 6.52389 
C      henke(13,1, 203 ) = 247.535 
C      henke(13,2, 203 ) = 11.1176 
C      henke(13,3, 203 ) = 6.42616 
C      henke(13,1, 204 ) = 251.538 
C      henke(13,2, 204 ) = 11.1983 
C      henke(13,3, 204 ) = 6.32988 
C      henke(13,1, 205 ) = 255.607 
C      henke(13,2, 205 ) = 11.2808 
C      henke(13,3, 205 ) = 6.23505 
C      henke(13,1, 206 ) = 259.741 
C      henke(13,2, 206 ) = 11.3664 
C      henke(13,3, 206 ) = 6.14164 
C      henke(13,1, 207 ) = 263.942 
C      henke(13,2, 207 ) = 11.463 
C      henke(13,3, 207 ) = 6.04964 
C      henke(13,1, 208 ) = 268.211 
C      henke(13,2, 208 ) = 11.5725 
C      henke(13,3, 208 ) = 5.94856 
C      henke(13,1, 209 ) = 272.549 
C      henke(13,2, 209 ) = 11.6747 
C      henke(13,3, 209 ) = 5.80523 
C      henke(13,1, 210 ) = 276.957 
C      henke(13,2, 210 ) = 11.7511 
C      henke(13,3, 210 ) = 5.66535 
C      henke(13,1, 211 ) = 281.437 
C      henke(13,2, 211 ) = 11.8159 
C      henke(13,3, 211 ) = 5.52884 
C      henke(13,1, 212 ) = 285.989 
C      henke(13,2, 212 ) = 11.8724 
C      henke(13,3, 212 ) = 5.39563 
C      henke(13,1, 213 ) = 290.615 
C      henke(13,2, 213 ) = 11.9222 
C      henke(13,3, 213 ) = 5.26561 
C      henke(13,1, 214 ) = 295.315 
C      henke(13,2, 214 ) = 11.9664 
C      henke(13,3, 214 ) = 5.13874 
C      henke(13,1, 215 ) = 300.092 
C      henke(13,2, 215 ) = 12.0058 
C      henke(13,3, 215 ) = 5.01492 
C      henke(13,1, 216 ) = 304.945 
C      henke(13,2, 216 ) = 12.0408 
C      henke(13,3, 216 ) = 4.89409 
C      henke(13,1, 217 ) = 309.878 
C      henke(13,2, 217 ) = 12.0718 
C      henke(13,3, 217 ) = 4.77616 
C      henke(13,1, 218 ) = 314.89 
C      henke(13,2, 218 ) = 12.0993 
C      henke(13,3, 218 ) = 4.66108 
C      henke(13,1, 219 ) = 319.983 
C      henke(13,2, 219 ) = 12.1235 
C      henke(13,3, 219 ) = 4.54877 
C      henke(13,1, 220 ) = 325.158 
C      henke(13,2, 220 ) = 12.1445 
C      henke(13,3, 220 ) = 4.43917 
C      henke(13,1, 221 ) = 330.418 
C      henke(13,2, 221 ) = 12.1625 
C      henke(13,3, 221 ) = 4.33221 
C      henke(13,1, 222 ) = 335.762 
C      henke(13,2, 222 ) = 12.1777 
C      henke(13,3, 222 ) = 4.22782 
C      henke(13,1, 223 ) = 341.192 
C      henke(13,2, 223 ) = 12.19 
C      henke(13,3, 223 ) = 4.12595 
C      henke(13,1, 224 ) = 346.711 
C      henke(13,2, 224 ) = 12.1992 
C      henke(13,3, 224 ) = 4.02654 
C      henke(13,1, 225 ) = 352.319 
C      henke(13,2, 225 ) = 12.2049 
C      henke(13,3, 225 ) = 3.92952 
C      henke(13,1, 226 ) = 358.017 
C      henke(13,2, 226 ) = 12.2045 
C      henke(13,3, 226 ) = 3.83484 
C      henke(13,1, 227 ) = 363.808 
C      henke(13,2, 227 ) = 12.1998 
C      henke(13,3, 227 ) = 3.75388 
C      henke(13,1, 228 ) = 369.692 
C      henke(13,2, 228 ) = 12.2008 
C      henke(13,3, 228 ) = 3.67818 
C      henke(13,1, 229 ) = 375.672 
C      henke(13,2, 229 ) = 12.2048 
C      henke(13,3, 229 ) = 3.604 
C      henke(13,1, 230 ) = 381.748 
C      henke(13,2, 230 ) = 12.2097 
C      henke(13,3, 230 ) = 3.53133 
C      henke(13,1, 231 ) = 387.922 
C      henke(13,2, 231 ) = 12.2152 
C      henke(13,3, 231 ) = 3.46011 
C      henke(13,1, 232 ) = 394.197 
C      henke(13,2, 232 ) = 12.221 
C      henke(13,3, 232 ) = 3.39034 
C      henke(13,1, 233 ) = 400.573 
C      henke(13,2, 233 ) = 12.227 
C      henke(13,3, 233 ) = 3.32197 
C      henke(13,1, 234 ) = 407.052 
C      henke(13,2, 234 ) = 12.2333 
C      henke(13,3, 234 ) = 3.25498 
C      henke(13,1, 235 ) = 413.635 
C      henke(13,2, 235 ) = 12.2399 
C      henke(13,3, 235 ) = 3.18934 
C      henke(13,1, 236 ) = 420.326 
C      henke(13,2, 236 ) = 12.247 
C      henke(13,3, 236 ) = 3.12502 
C      henke(13,1, 237 ) = 427.124 
C      henke(13,2, 237 ) = 12.2549 
C      henke(13,3, 237 ) = 3.06201 
C      henke(13,1, 238 ) = 434.032 
C      henke(13,2, 238 ) = 12.2652 
C      henke(13,3, 238 ) = 3.00026 
C      henke(13,1, 239 ) = 441.052 
C      henke(13,2, 239 ) = 12.2773 
C      henke(13,3, 239 ) = 2.93296 
C      henke(13,1, 240 ) = 448.186 
C      henke(13,2, 240 ) = 12.2849 
C      henke(13,3, 240 ) = 2.86424 
C      henke(13,1, 241 ) = 455.435 
C      henke(13,2, 241 ) = 12.2892 
C      henke(13,3, 241 ) = 2.7973 
C      henke(13,1, 242 ) = 462.802 
C      henke(13,2, 242 ) = 12.292 
C      henke(13,3, 242 ) = 2.73189 
C      henke(13,1, 243 ) = 470.287 
C      henke(13,2, 243 ) = 12.2937 
C      henke(13,3, 243 ) = 2.66798 
C      henke(13,1, 244 ) = 477.894 
C      henke(13,2, 244 ) = 12.2943 
C      henke(13,3, 244 ) = 2.60559 
C      henke(13,1, 245 ) = 485.623 
C      henke(13,2, 245 ) = 12.2945 
C      henke(13,3, 245 ) = 2.54463 
C      henke(13,1, 246 ) = 493.478 
C      henke(13,2, 246 ) = 12.2942 
C      henke(13,3, 246 ) = 2.4849 
C      henke(13,1, 247 ) = 501.459 
C      henke(13,2, 247 ) = 12.2939 
C      henke(13,3, 247 ) = 2.4257 
C      henke(13,1, 248 ) = 509.57 
C      henke(13,2, 248 ) = 12.2928 
C      henke(13,3, 248 ) = 2.36643 
C      henke(13,1, 249 ) = 517.812 
C      henke(13,2, 249 ) = 12.2896 
C      henke(13,3, 249 ) = 2.30801 
C      henke(13,1, 250 ) = 526.187 
C      henke(13,2, 250 ) = 12.2852 
C      henke(13,3, 250 ) = 2.25125 
C      henke(13,1, 251 ) = 534.698 
C      henke(13,2, 251 ) = 12.2801 
C      henke(13,3, 251 ) = 2.19625 
C      henke(13,1, 252 ) = 543.346 
C      henke(13,2, 252 ) = 12.2748 
C      henke(13,3, 252 ) = 2.14277 
C      henke(13,1, 253 ) = 552.134 
C      henke(13,2, 253 ) = 12.27 
C      henke(13,3, 253 ) = 2.09062 
C      henke(13,1, 254 ) = 561.065 
C      henke(13,2, 254 ) = 12.2653 
C      henke(13,3, 254 ) = 2.03805 
C      henke(13,1, 255 ) = 570.139 
C      henke(13,2, 255 ) = 12.2592 
C      henke(13,3, 255 ) = 1.98589 
C      henke(13,1, 256 ) = 579.361 
C      henke(13,2, 256 ) = 12.2522 
C      henke(13,3, 256 ) = 1.93406 
C      henke(13,1, 257 ) = 588.732 
C      henke(13,2, 257 ) = 12.2437 
C      henke(13,3, 257 ) = 1.88338 
C      henke(13,1, 258 ) = 598.254 
C      henke(13,2, 258 ) = 12.2344 
C      henke(13,3, 258 ) = 1.83389 
C      henke(13,1, 259 ) = 607.93 
C      henke(13,2, 259 ) = 12.2243 
C      henke(13,3, 259 ) = 1.78571 
C      henke(13,1, 260 ) = 617.763 
C      henke(13,2, 260 ) = 12.2138 
C      henke(13,3, 260 ) = 1.73879 
C      henke(13,1, 261 ) = 627.755 
C      henke(13,2, 261 ) = 12.2034 
C      henke(13,3, 261 ) = 1.69298 
C      henke(13,1, 262 ) = 637.908 
C      henke(13,2, 262 ) = 12.1929 
C      henke(13,3, 262 ) = 1.64704 
C      henke(13,1, 263 ) = 648.226 
C      henke(13,2, 263 ) = 12.1814 
C      henke(13,3, 263 ) = 1.60038 
C      henke(13,1, 264 ) = 658.711 
C      henke(13,2, 264 ) = 12.1674 
C      henke(13,3, 264 ) = 1.55377 
C      henke(13,1, 265 ) = 669.365 
C      henke(13,2, 265 ) = 12.1491 
C      henke(13,3, 265 ) = 1.50856 
C      henke(13,1, 266 ) = 680.191 
C      henke(13,2, 266 ) = 12.1287 
C      henke(13,3, 266 ) = 1.46882 
C      henke(13,1, 267 ) = 691.193 
C      henke(13,2, 267 ) = 12.1108 
C      henke(13,3, 267 ) = 1.43328 
C      henke(13,1, 268 ) = 702.372 
C      henke(13,2, 268 ) = 12.0954 
C      henke(13,3, 268 ) = 1.39941 
C      henke(13,1, 269 ) = 713.733 
C      henke(13,2, 269 ) = 12.082 
C      henke(13,3, 269 ) = 1.3638 
C      henke(13,1, 270 ) = 725.277 
C      henke(13,2, 270 ) = 12.0674 
C      henke(13,3, 270 ) = 1.32737 
C      henke(13,1, 271 ) = 737.008 
C      henke(13,2, 271 ) = 12.0514 
C      henke(13,3, 271 ) = 1.29193 
C      henke(13,1, 272 ) = 748.928 
C      henke(13,2, 272 ) = 12.035 
C      henke(13,3, 272 ) = 1.25742 
C      henke(13,1, 273 ) = 761.042 
C      henke(13,2, 273 ) = 12.0181 
C      henke(13,3, 273 ) = 1.22382 
C      henke(13,1, 274 ) = 773.351 
C      henke(13,2, 274 ) = 12.0009 
C      henke(13,3, 274 ) = 1.191 
C      henke(13,1, 275 ) = 785.859 
C      henke(13,2, 275 ) = 11.9834 
C      henke(13,3, 275 ) = 1.15872 
C      henke(13,1, 276 ) = 798.57 
C      henke(13,2, 276 ) = 11.9652 
C      henke(13,3, 276 ) = 1.12705 
C      henke(13,1, 277 ) = 811.486 
C      henke(13,2, 277 ) = 11.9463 
C      henke(13,3, 277 ) = 1.09624 
C      henke(13,1, 278 ) = 824.611 
C      henke(13,2, 278 ) = 11.9269 
C      henke(13,3, 278 ) = 1.06625 
C      henke(13,1, 279 ) = 837.949 
C      henke(13,2, 279 ) = 11.907 
C      henke(13,3, 279 ) = 1.03708 
C      henke(13,1, 280 ) = 851.502 
C      henke(13,2, 280 ) = 11.8866 
C      henke(13,3, 280 ) = 1.0087 
C      henke(13,1, 281 ) = 865.274 
C      henke(13,2, 281 ) = 11.8656 
C      henke(13,3, 281 ) = 0.981035 
C      henke(13,1, 282 ) = 879.269 
C      henke(13,2, 282 ) = 11.8441 
C      henke(13,3, 282 ) = 0.954065 
C      henke(13,1, 283 ) = 893.491 
C      henke(13,2, 283 ) = 11.822 
C      henke(13,3, 283 ) = 0.927842 
C      henke(13,1, 284 ) = 907.943 
C      henke(13,2, 284 ) = 11.7992 
C      henke(13,3, 284 ) = 0.902346 
C      henke(13,1, 285 ) = 922.628 
C      henke(13,2, 285 ) = 11.7759 
C      henke(13,3, 285 ) = 0.877557 
C      henke(13,1, 286 ) = 937.551 
C      henke(13,2, 286 ) = 11.7519 
C      henke(13,3, 286 ) = 0.853321 
C      henke(13,1, 287 ) = 952.715 
C      henke(13,2, 287 ) = 11.727 
C      henke(13,3, 287 ) = 0.829761 
C      henke(13,1, 288 ) = 968.124 
C      henke(13,2, 288 ) = 11.7013 
C      henke(13,3, 288 ) = 0.806859 
C      henke(13,1, 289 ) = 983.783 
C      henke(13,2, 289 ) = 11.6747 
C      henke(13,3, 289 ) = 0.784555 
C      henke(13,1, 290 ) = 999.695 
C      henke(13,2, 290 ) = 11.6472 
C      henke(13,3, 290 ) = 0.762967 
C      henke(13,1, 291 ) = 1015.86 
C      henke(13,2, 291 ) = 11.6184 
C      henke(13,3, 291 ) = 0.742081 
C      henke(13,1, 292 ) = 1032.29 
C      henke(13,2, 292 ) = 11.5888 
C      henke(13,3, 292 ) = 0.722661 
C      henke(13,1, 293 ) = 1048.99 
C      henke(13,2, 293 ) = 11.5591 
C      henke(13,3, 293 ) = 0.703173 
C      henke(13,1, 294 ) = 1065.96 
C      henke(13,2, 294 ) = 11.5278 
C      henke(13,3, 294 ) = 0.683588 
C      henke(13,1, 295 ) = 1083.2 
C      henke(13,2, 295 ) = 11.4947 
C      henke(13,3, 295 ) = 0.664537 
C      henke(13,1, 296 ) = 1100.72 
C      henke(13,2, 296 ) = 11.46 
C      henke(13,3, 296 ) = 0.646018 
C      henke(13,1, 297 ) = 1118.52 
C      henke(13,2, 297 ) = 11.4234 
C      henke(13,3, 297 ) = 0.628015 
C      henke(13,1, 298 ) = 1136.61 
C      henke(13,2, 298 ) = 11.3849 
C      henke(13,3, 298 ) = 0.610519 
C      henke(13,1, 299 ) = 1155 
C      henke(13,2, 299 ) = 11.344 
C      henke(13,3, 299 ) = 0.593506 
C      henke(13,1, 300 ) = 1173.68 
C      henke(13,2, 300 ) = 11.3007 
C      henke(13,3, 300 ) = 0.576965 
C      henke(13,1, 301 ) = 1192.66 
C      henke(13,2, 301 ) = 11.2544 
C      henke(13,3, 301 ) = 0.560888 
C      henke(13,1, 302 ) = 1211.95 
C      henke(13,2, 302 ) = 11.2049 
C      henke(13,3, 302 ) = 0.545258 
C      henke(13,1, 303 ) = 1231.55 
C      henke(13,2, 303 ) = 11.1516 
C      henke(13,3, 303 ) = 0.530064 
C      henke(13,1, 304 ) = 1251.47 
C      henke(13,2, 304 ) = 11.0938 
C      henke(13,3, 304 ) = 0.515441 
C      henke(13,1, 305 ) = 1271.72 
C      henke(13,2, 305 ) = 11.031 
C      henke(13,3, 305 ) = 0.50138 
C      henke(13,1, 306 ) = 1292.29 
C      henke(13,2, 306 ) = 10.9622 
C      henke(13,3, 306 ) = 0.487892 
C      henke(13,1, 307 ) = 1313.19 
C      henke(13,2, 307 ) = 10.8865 
C      henke(13,3, 307 ) = 0.474763 
C      henke(13,1, 308 ) = 1334.43 
C      henke(13,2, 308 ) = 10.8021 
C      henke(13,3, 308 ) = 0.461987 
C      henke(13,1, 309 ) = 1356.01 
C      henke(13,2, 309 ) = 10.7069 
C      henke(13,3, 309 ) = 0.449555 
C      henke(13,1, 310 ) = 1377.94 
C      henke(13,2, 310 ) = 10.598 
C      henke(13,3, 310 ) = 0.437459 
C      henke(13,1, 311 ) = 1400.23 
C      henke(13,2, 311 ) = 10.4713 
C      henke(13,3, 311 ) = 0.425689 
C      henke(13,1, 312 ) = 1422.88 
C      henke(13,2, 312 ) = 10.3206 
C      henke(13,3, 312 ) = 0.414239 
C      henke(13,1, 313 ) = 1445.89 
C      henke(13,2, 313 ) = 10.1361 
C      henke(13,3, 313 ) = 0.403093 
C      henke(13,1, 314 ) = 1469.28 
C      henke(13,2, 314 ) = 9.90068 
C      henke(13,3, 314 ) = 0.3921 
C      henke(13,1, 315 ) = 1493.04 
C      henke(13,2, 315 ) = 9.58044 
C      henke(13,3, 315 ) = 0.381187 
C      henke(13,1, 316 ) = 1517.19 
C      henke(13,2, 316 ) = 9.09216 
C      henke(13,3, 316 ) = 0.36968 
C      henke(13,1, 317 ) = 1541.73 
C      henke(13,2, 317 ) = 8.11537 
C      henke(13,3, 317 ) = 0.358399 
C      henke(13,1, 318 ) = 1559.5 
C      henke(13,2, 318 ) = 1.89396 
C      henke(13,3, 318 ) = 0.350553 
C      henke(13,1, 319 ) = 1559.7 
C      henke(13,2, 319 ) = 1.89589 
C      henke(13,3, 319 ) = 4.16629 
C      henke(13,1, 320 ) = 1566.67 
C      henke(13,2, 320 ) = 7.10441 
C      henke(13,3, 320 ) = 4.14105 
C      henke(13,1, 321 ) = 1592.01 
C      henke(13,2, 321 ) = 9.03572 
C      henke(13,3, 321 ) = 4.05144 
C      henke(13,1, 322 ) = 1617.76 
C      henke(13,2, 322 ) = 9.80337 
C      henke(13,3, 322 ) = 3.96379 
C      henke(13,1, 323 ) = 1643.92 
C      henke(13,2, 323 ) = 10.2995 
C      henke(13,3, 323 ) = 3.87809 
C      henke(13,1, 324 ) = 1670.51 
C      henke(13,2, 324 ) = 10.669 
C      henke(13,3, 324 ) = 3.7942 
C      henke(13,1, 325 ) = 1697.53 
C      henke(13,2, 325 ) = 10.9642 
C      henke(13,3, 325 ) = 3.71213 
C      henke(13,1, 326 ) = 1724.99 
C      henke(13,2, 326 ) = 11.2121 
C      henke(13,3, 326 ) = 3.63182 
C      henke(13,1, 327 ) = 1752.89 
C      henke(13,2, 327 ) = 11.4254 
C      henke(13,3, 327 ) = 3.54896 
C      henke(13,1, 328 ) = 1781.24 
C      henke(13,2, 328 ) = 11.6086 
C      henke(13,3, 328 ) = 3.46653 
C      henke(13,1, 329 ) = 1810.05 
C      henke(13,2, 329 ) = 11.7695 
C      henke(13,3, 329 ) = 3.38494 
C      henke(13,1, 330 ) = 1839.32 
C      henke(13,2, 330 ) = 11.9117 
C      henke(13,3, 330 ) = 3.30527 
C      henke(13,1, 331 ) = 1869.07 
C      henke(13,2, 331 ) = 12.0391 
C      henke(13,3, 331 ) = 3.22747 
C      henke(13,1, 332 ) = 1899.3 
C      henke(13,2, 332 ) = 12.154 
C      henke(13,3, 332 ) = 3.15148 
C      henke(13,1, 333 ) = 1930.02 
C      henke(13,2, 333 ) = 12.2583 
C      henke(13,3, 333 ) = 3.07731 
C      henke(13,1, 334 ) = 1961.24 
C      henke(13,2, 334 ) = 12.3536 
C      henke(13,3, 334 ) = 3.00489 
C      henke(13,1, 335 ) = 1992.96 
C      henke(13,2, 335 ) = 12.4408 
C      henke(13,3, 335 ) = 2.93417 
C      henke(13,1, 336 ) = 2025.2 
C      henke(13,2, 336 ) = 12.5226 
C      henke(13,3, 336 ) = 2.86696 
C      henke(13,1, 337 ) = 2057.95 
C      henke(13,2, 337 ) = 12.6001 
C      henke(13,3, 337 ) = 2.79699 
C      henke(13,1, 338 ) = 2091.24 
C      henke(13,2, 338 ) = 12.6695 
C      henke(13,3, 338 ) = 2.72803 
C      henke(13,1, 339 ) = 2125.06 
C      henke(13,2, 339 ) = 12.7334 
C      henke(13,3, 339 ) = 2.66035 
C      henke(13,1, 340 ) = 2159.43 
C      henke(13,2, 340 ) = 12.7923 
C      henke(13,3, 340 ) = 2.59405 
C      henke(13,1, 341 ) = 2194.36 
C      henke(13,2, 341 ) = 12.8467 
C      henke(13,3, 341 ) = 2.52881 
C      henke(13,1, 342 ) = 2229.85 
C      henke(13,2, 342 ) = 12.8969 
C      henke(13,3, 342 ) = 2.46498 
C      henke(13,1, 343 ) = 2265.92 
C      henke(13,2, 343 ) = 12.9433 
C      henke(13,3, 343 ) = 2.40235 
C      henke(13,1, 344 ) = 2302.57 
C      henke(13,2, 344 ) = 12.9861 
C      henke(13,3, 344 ) = 2.34101 
C      henke(13,1, 345 ) = 2339.81 
C      henke(13,2, 345 ) = 13.0257 
C      henke(13,3, 345 ) = 2.28095 
C      henke(13,1, 346 ) = 2377.66 
C      henke(13,2, 346 ) = 13.0622 
C      henke(13,3, 346 ) = 2.22204 
C      henke(13,1, 347 ) = 2416.11 
C      henke(13,2, 347 ) = 13.096 
C      henke(13,3, 347 ) = 2.16445 
C      henke(13,1, 348 ) = 2455.19 
C      henke(13,2, 348 ) = 13.1272 
C      henke(13,3, 348 ) = 2.1081 
C      henke(13,1, 349 ) = 2494.9 
C      henke(13,2, 349 ) = 13.156 
C      henke(13,3, 349 ) = 2.05284 
C      henke(13,1, 350 ) = 2535.26 
C      henke(13,2, 350 ) = 13.1825 
C      henke(13,3, 350 ) = 1.99885 
C      henke(13,1, 351 ) = 2576.26 
C      henke(13,2, 351 ) = 13.2068 
C      henke(13,3, 351 ) = 1.94606 
C      henke(13,1, 352 ) = 2617.93 
C      henke(13,2, 352 ) = 13.2292 
C      henke(13,3, 352 ) = 1.89447 
C      henke(13,1, 353 ) = 2660.27 
C      henke(13,2, 353 ) = 13.2498 
C      henke(13,3, 353 ) = 1.844 
C      henke(13,1, 354 ) = 2703.3 
C      henke(13,2, 354 ) = 13.2687 
C      henke(13,3, 354 ) = 1.79474 
C      henke(13,1, 355 ) = 2747.03 
C      henke(13,2, 355 ) = 13.2859 
C      henke(13,3, 355 ) = 1.74651 
C      henke(13,1, 356 ) = 2791.46 
C      henke(13,2, 356 ) = 13.3016 
C      henke(13,3, 356 ) = 1.69945 
C      henke(13,1, 357 ) = 2836.61 
C      henke(13,2, 357 ) = 13.3159 
C      henke(13,3, 357 ) = 1.6535 
C      henke(13,1, 358 ) = 2882.49 
C      henke(13,2, 358 ) = 13.3288 
C      henke(13,3, 358 ) = 1.60862 
C      henke(13,1, 359 ) = 2929.11 
C      henke(13,2, 359 ) = 13.3405 
C      henke(13,3, 359 ) = 1.56481 
C      henke(13,1, 360 ) = 2976.48 
C      henke(13,2, 360 ) = 13.351 
C      henke(13,3, 360 ) = 1.52204 
C      henke(13,1, 361 ) = 3024.63 
C      henke(13,2, 361 ) = 13.3604 
C      henke(13,3, 361 ) = 1.48033 
C      henke(13,1, 362 ) = 3073.55 
C      henke(13,2, 362 ) = 13.3688 
C      henke(13,3, 362 ) = 1.43961 
C      henke(13,1, 363 ) = 3123.26 
C      henke(13,2, 363 ) = 13.3762 
C      henke(13,3, 363 ) = 1.39989 
C      henke(13,1, 364 ) = 3173.78 
C      henke(13,2, 364 ) = 13.3827 
C      henke(13,3, 364 ) = 1.36116 
C      henke(13,1, 365 ) = 3225.11 
C      henke(13,2, 365 ) = 13.3883 
C      henke(13,3, 365 ) = 1.32339 
C      henke(13,1, 366 ) = 3277.27 
C      henke(13,2, 366 ) = 13.3932 
C      henke(13,3, 366 ) = 1.28657 
C      henke(13,1, 367 ) = 3330.28 
C      henke(13,2, 367 ) = 13.3973 
C      henke(13,3, 367 ) = 1.25064 
C      henke(13,1, 368 ) = 3384.15 
C      henke(13,2, 368 ) = 13.4007 
C      henke(13,3, 368 ) = 1.21564 
C      henke(13,1, 369 ) = 3438.88 
C      henke(13,2, 369 ) = 13.4034 
C      henke(13,3, 369 ) = 1.18154 
C      henke(13,1, 370 ) = 3494.5 
C      henke(13,2, 370 ) = 13.4055 
C      henke(13,3, 370 ) = 1.14831 
C      henke(13,1, 371 ) = 3551.02 
C      henke(13,2, 371 ) = 13.407 
C      henke(13,3, 371 ) = 1.11591 
C      henke(13,1, 372 ) = 3608.46 
C      henke(13,2, 372 ) = 13.408 
C      henke(13,3, 372 ) = 1.08436 
C      henke(13,1, 373 ) = 3666.82 
C      henke(13,2, 373 ) = 13.4085 
C      henke(13,3, 373 ) = 1.05363 
C      henke(13,1, 374 ) = 3726.13 
C      henke(13,2, 374 ) = 13.4085 
C      henke(13,3, 374 ) = 1.02369 
C      henke(13,1, 375 ) = 3786.4 
C      henke(13,2, 375 ) = 13.4081 
C      henke(13,3, 375 ) = 0.994542 
C      henke(13,1, 376 ) = 3847.64 
C      henke(13,2, 376 ) = 13.4072 
C      henke(13,3, 376 ) = 0.966167 
C      henke(13,1, 377 ) = 3909.87 
C      henke(13,2, 377 ) = 13.406 
C      henke(13,3, 377 ) = 0.938535 
C      henke(13,1, 378 ) = 3973.11 
C      henke(13,2, 378 ) = 13.4044 
C      henke(13,3, 378 ) = 0.911645 
C      henke(13,1, 379 ) = 4037.38 
C      henke(13,2, 379 ) = 13.4025 
C      henke(13,3, 379 ) = 0.885448 
C      henke(13,1, 380 ) = 4102.68 
C      henke(13,2, 380 ) = 13.4003 
C      henke(13,3, 380 ) = 0.859966 
C      henke(13,1, 381 ) = 4169.03 
C      henke(13,2, 381 ) = 13.3978 
C      henke(13,3, 381 ) = 0.835163 
C      henke(13,1, 382 ) = 4236.46 
C      henke(13,2, 382 ) = 13.395 
C      henke(13,3, 382 ) = 0.811033 
C      henke(13,1, 383 ) = 4304.98 
C      henke(13,2, 383 ) = 13.392 
C      henke(13,3, 383 ) = 0.787559 
C      henke(13,1, 384 ) = 4374.62 
C      henke(13,2, 384 ) = 13.3888 
C      henke(13,3, 384 ) = 0.764708 
C      henke(13,1, 385 ) = 4445.37 
C      henke(13,2, 385 ) = 13.3853 
C      henke(13,3, 385 ) = 0.742491 
C      henke(13,1, 386 ) = 4517.27 
C      henke(13,2, 386 ) = 13.3817 
C      henke(13,3, 386 ) = 0.720878 
C      henke(13,1, 387 ) = 4590.33 
C      henke(13,2, 387 ) = 13.3779 
C      henke(13,3, 387 ) = 0.699839 
C      henke(13,1, 388 ) = 4664.58 
C      henke(13,2, 388 ) = 13.3739 
C      henke(13,3, 388 ) = 0.679399 
C      henke(13,1, 389 ) = 4740.03 
C      henke(13,2, 389 ) = 13.3698 
C      henke(13,3, 389 ) = 0.659516 
C      henke(13,1, 390 ) = 4816.69 
C      henke(13,2, 390 ) = 13.3656 
C      henke(13,3, 390 ) = 0.640176 
C      henke(13,1, 391 ) = 4894.6 
C      henke(13,2, 391 ) = 13.3612 
C      henke(13,3, 391 ) = 0.621389 
C      henke(13,1, 392 ) = 4973.77 
C      henke(13,2, 392 ) = 13.3568 
C      henke(13,3, 392 ) = 0.603106 
C      henke(13,1, 393 ) = 5054.21 
C      henke(13,2, 393 ) = 13.3522 
C      henke(13,3, 393 ) = 0.585342 
C      henke(13,1, 394 ) = 5135.96 
C      henke(13,2, 394 ) = 13.3476 
C      henke(13,3, 394 ) = 0.56808 
C      henke(13,1, 395 ) = 5219.03 
C      henke(13,2, 395 ) = 13.3429 
C      henke(13,3, 395 ) = 0.551279 
C      henke(13,1, 396 ) = 5303.44 
C      henke(13,2, 396 ) = 13.3381 
C      henke(13,3, 396 ) = 0.534968 
C      henke(13,1, 397 ) = 5389.22 
C      henke(13,2, 397 ) = 13.3332 
C      henke(13,3, 397 ) = 0.519116 
C      henke(13,1, 398 ) = 5476.39 
C      henke(13,2, 398 ) = 13.3284 
C      henke(13,3, 398 ) = 0.503715 
C      henke(13,1, 399 ) = 5564.97 
C      henke(13,2, 399 ) = 13.3235 
C      henke(13,3, 399 ) = 0.488726 
C      henke(13,1, 400 ) = 5654.98 
C      henke(13,2, 400 ) = 13.3185 
C      henke(13,3, 400 ) = 0.474187 
C      henke(13,1, 401 ) = 5746.44 
C      henke(13,2, 401 ) = 13.3135 
C      henke(13,3, 401 ) = 0.460062 
C      henke(13,1, 402 ) = 5839.39 
C      henke(13,2, 402 ) = 13.3086 
C      henke(13,3, 402 ) = 0.446336 
C      henke(13,1, 403 ) = 5933.83 
C      henke(13,2, 403 ) = 13.3036 
C      henke(13,3, 403 ) = 0.433003 
C      henke(13,1, 404 ) = 6029.81 
C      henke(13,2, 404 ) = 13.2986 
C      henke(13,3, 404 ) = 0.420026 
C      henke(13,1, 405 ) = 6127.33 
C      henke(13,2, 405 ) = 13.2936 
C      henke(13,3, 405 ) = 0.407459 
C      henke(13,1, 406 ) = 6226.44 
C      henke(13,2, 406 ) = 13.2886 
C      henke(13,3, 406 ) = 0.395224 
C      henke(13,1, 407 ) = 6327.15 
C      henke(13,2, 407 ) = 13.2836 
C      henke(13,3, 407 ) = 0.383348 
C      henke(13,1, 408 ) = 6429.48 
C      henke(13,2, 408 ) = 13.2786 
C      henke(13,3, 408 ) = 0.371815 
C      henke(13,1, 409 ) = 6533.48 
C      henke(13,2, 409 ) = 13.2737 
C      henke(13,3, 409 ) = 0.360616 
C      henke(13,1, 410 ) = 6639.15 
C      henke(13,2, 410 ) = 13.2687 
C      henke(13,3, 410 ) = 0.349739 
C      henke(13,1, 411 ) = 6746.54 
C      henke(13,2, 411 ) = 13.2638 
C      henke(13,3, 411 ) = 0.339182 
C      henke(13,1, 412 ) = 6855.65 
C      henke(13,2, 412 ) = 13.259 
C      henke(13,3, 412 ) = 0.328927 
C      henke(13,1, 413 ) = 6966.54 
C      henke(13,2, 413 ) = 13.2541 
C      henke(13,3, 413 ) = 0.318973 
C      henke(13,1, 414 ) = 7079.22 
C      henke(13,2, 414 ) = 13.2493 
C      henke(13,3, 414 ) = 0.309309 
C      henke(13,1, 415 ) = 7193.72 
C      henke(13,2, 415 ) = 13.2446 
C      henke(13,3, 415 ) = 0.299926 
C      henke(13,1, 416 ) = 7310.07 
C      henke(13,2, 416 ) = 13.2398 
C      henke(13,3, 416 ) = 0.290817 
C      henke(13,1, 417 ) = 7428.31 
C      henke(13,2, 417 ) = 13.2352 
C      henke(13,3, 417 ) = 0.281974 
C      henke(13,1, 418 ) = 7548.45 
C      henke(13,2, 418 ) = 13.2305 
C      henke(13,3, 418 ) = 0.273391 
C      henke(13,1, 419 ) = 7670.54 
C      henke(13,2, 419 ) = 13.2259 
C      henke(13,3, 419 ) = 0.265058 
C      henke(13,1, 420 ) = 7794.61 
C      henke(13,2, 420 ) = 13.2214 
C      henke(13,3, 420 ) = 0.256972 
C      henke(13,1, 421 ) = 7920.68 
C      henke(13,2, 421 ) = 13.2169 
C      henke(13,3, 421 ) = 0.249121 
C      henke(13,1, 422 ) = 8048.79 
C      henke(13,2, 422 ) = 13.2124 
C      henke(13,3, 422 ) = 0.241506 
C      henke(13,1, 423 ) = 8178.98 
C      henke(13,2, 423 ) = 13.2081 
C      henke(13,3, 423 ) = 0.234114 
C      henke(13,1, 424 ) = 8311.26 
C      henke(13,2, 424 ) = 13.2037 
C      henke(13,3, 424 ) = 0.226938 
C      henke(13,1, 425 ) = 8445.69 
C      henke(13,2, 425 ) = 13.1994 
C      henke(13,3, 425 ) = 0.219978 
C      henke(13,1, 426 ) = 8582.29 
C      henke(13,2, 426 ) = 13.1952 
C      henke(13,3, 426 ) = 0.213218 
C      henke(13,1, 427 ) = 8721.11 
C      henke(13,2, 427 ) = 13.191 
C      henke(13,3, 427 ) = 0.206663 
C      henke(13,1, 428 ) = 8862.16 
C      henke(13,2, 428 ) = 13.1869 
C      henke(13,3, 428 ) = 0.200304 
C      henke(13,1, 429 ) = 9005.5 
C      henke(13,2, 429 ) = 13.1829 
C      henke(13,3, 429 ) = 0.194131 
C      henke(13,1, 430 ) = 9151.16 
C      henke(13,2, 430 ) = 13.1789 
C      henke(13,3, 430 ) = 0.18814 
C      henke(13,1, 431 ) = 9299.17 
C      henke(13,2, 431 ) = 13.1749 
C      henke(13,3, 431 ) = 0.182331 
C      henke(13,1, 432 ) = 9449.58 
C      henke(13,2, 432 ) = 13.1711 
C      henke(13,3, 432 ) = 0.176693 
C      henke(13,1, 433 ) = 9602.42 
C      henke(13,2, 433 ) = 13.1672 
C      henke(13,3, 433 ) = 0.171229 
C      henke(13,1, 434 ) = 9757.73 
C      henke(13,2, 434 ) = 13.1635 
C      henke(13,3, 434 ) = 0.165921 
C      henke(13,1, 435 ) = 9915.55 
C      henke(13,2, 435 ) = 13.1598 
C      henke(13,3, 435 ) = 0.16078 
C      henke(13,1, 436 ) = 10075.9 
C      henke(13,2, 436 ) = 13.1561 
C      henke(13,3, 436 ) = 0.155788 
C      henke(13,1, 437 ) = 10238.9 
C      henke(13,2, 437 ) = 13.1526 
C      henke(13,3, 437 ) = 0.150945 
C      henke(13,1, 438 ) = 10404.5 
C      henke(13,2, 438 ) = 13.149 
C      henke(13,3, 438 ) = 0.146248 
C      henke(13,1, 439 ) = 10572.8 
C      henke(13,2, 439 ) = 13.1456 
C      henke(13,3, 439 ) = 0.141693 
C      henke(13,1, 440 ) = 10743.8 
C      henke(13,2, 440 ) = 13.1422 
C      henke(13,3, 440 ) = 0.137274 
C      henke(13,1, 441 ) = 10917.6 
C      henke(13,2, 441 ) = 13.1388 
C      henke(13,3, 441 ) = 0.132988 
C      henke(13,1, 442 ) = 11094.2 
C      henke(13,2, 442 ) = 13.1355 
C      henke(13,3, 442 ) = 0.128831 
C      henke(13,1, 443 ) = 11273.6 
C      henke(13,2, 443 ) = 13.1323 
C      henke(13,3, 443 ) = 0.1248 
C      henke(13,1, 444 ) = 11455.9 
C      henke(13,2, 444 ) = 13.1291 
C      henke(13,3, 444 ) = 0.12089 
C      henke(13,1, 445 ) = 11641.2 
C      henke(13,2, 445 ) = 13.126 
C      henke(13,3, 445 ) = 0.117099 
C      henke(13,1, 446 ) = 11829.5 
C      henke(13,2, 446 ) = 13.1229 
C      henke(13,3, 446 ) = 0.113422 
C      henke(13,1, 447 ) = 12020.8 
C      henke(13,2, 447 ) = 13.1199 
C      henke(13,3, 447 ) = 0.109856 
C      henke(13,1, 448 ) = 12215.3 
C      henke(13,2, 448 ) = 13.117 
C      henke(13,3, 448 ) = 0.106398 
C      henke(13,1, 449 ) = 12412.8 
C      henke(13,2, 449 ) = 13.1141 
C      henke(13,3, 449 ) = 0.103045 
C      henke(13,1, 450 ) = 12613.6 
C      henke(13,2, 450 ) = 13.1112 
C      henke(13,3, 450 ) = 0.0997941 
C      henke(13,1, 451 ) = 12817.6 
C      henke(13,2, 451 ) = 13.1084 
C      henke(13,3, 451 ) = 0.0966416 
C      henke(13,1, 452 ) = 13025 
C      henke(13,2, 452 ) = 13.1057 
C      henke(13,3, 452 ) = 0.0935848 
C      henke(13,1, 453 ) = 13235.6 
C      henke(13,2, 453 ) = 13.103 
C      henke(13,3, 453 ) = 0.0906209 
C      henke(13,1, 454 ) = 13449.7 
C      henke(13,2, 454 ) = 13.1004 
C      henke(13,3, 454 ) = 0.0877473 
C      henke(13,1, 455 ) = 13667.2 
C      henke(13,2, 455 ) = 13.0978 
C      henke(13,3, 455 ) = 0.0849611 
C      henke(13,1, 456 ) = 13888.3 
C      henke(13,2, 456 ) = 13.0953 
C      henke(13,3, 456 ) = 0.0822598 
C      henke(13,1, 457 ) = 14112.9 
C      henke(13,2, 457 ) = 13.0928 
C      henke(13,3, 457 ) = 0.0796408 
C      henke(13,1, 458 ) = 14341.2 
C      henke(13,2, 458 ) = 13.0903 
C      henke(13,3, 458 ) = 0.0771018 
C      henke(13,1, 459 ) = 14573.1 
C      henke(13,2, 459 ) = 13.088 
C      henke(13,3, 459 ) = 0.0746402 
C      henke(13,1, 460 ) = 14808.9 
C      henke(13,2, 460 ) = 13.0856 
C      henke(13,3, 460 ) = 0.0722539 
C      henke(13,1, 461 ) = 15048.4 
C      henke(13,2, 461 ) = 13.0833 
C      henke(13,3, 461 ) = 0.0699405 
C      henke(13,1, 462 ) = 15291.8 
C      henke(13,2, 462 ) = 13.0811 
C      henke(13,3, 462 ) = 0.0676979 
C      henke(13,1, 463 ) = 15539.1 
C      henke(13,2, 463 ) = 13.0789 
C      henke(13,3, 463 ) = 0.065524 
C      henke(13,1, 464 ) = 15790.4 
C      henke(13,2, 464 ) = 13.0768 
C      henke(13,3, 464 ) = 0.0634165 
C      henke(13,1, 465 ) = 16045.8 
C      henke(13,2, 465 ) = 13.0746 
C      henke(13,3, 465 ) = 0.0613737 
C      henke(13,1, 466 ) = 16305.4 
C      henke(13,2, 466 ) = 13.0726 
C      henke(13,3, 466 ) = 0.0593935 
C      henke(13,1, 467 ) = 16569.1 
C      henke(13,2, 467 ) = 13.0706 
C      henke(13,3, 467 ) = 0.0574741 
C      henke(13,1, 468 ) = 16837.1 
C      henke(13,2, 468 ) = 13.0686 
C      henke(13,3, 468 ) = 0.0556136 
C      henke(13,1, 469 ) = 17109.4 
C      henke(13,2, 469 ) = 13.0667 
C      henke(13,3, 469 ) = 0.0538102 
C      henke(13,1, 470 ) = 17386.1 
C      henke(13,2, 470 ) = 13.0648 
C      henke(13,3, 470 ) = 0.0520623 
C      henke(13,1, 471 ) = 17667.4 
C      henke(13,2, 471 ) = 13.0629 
C      henke(13,3, 471 ) = 0.0503681 
C      henke(13,1, 472 ) = 17953.1 
C      henke(13,2, 472 ) = 13.0611 
C      henke(13,3, 472 ) = 0.048726 
C      henke(13,1, 473 ) = 18243.5 
C      henke(13,2, 473 ) = 13.0593 
C      henke(13,3, 473 ) = 0.0471345 
C      henke(13,1, 474 ) = 18538.6 
C      henke(13,2, 474 ) = 13.0576 
C      henke(13,3, 474 ) = 0.045592 
C      henke(13,1, 475 ) = 18838.4 
C      henke(13,2, 475 ) = 13.0559 
C      henke(13,3, 475 ) = 0.044097 
C      henke(13,1, 476 ) = 19143.1 
C      henke(13,2, 476 ) = 13.0542 
C      henke(13,3, 476 ) = 0.0426482 
C      henke(13,1, 477 ) = 19452.7 
C      henke(13,2, 477 ) = 13.0526 
C      henke(13,3, 477 ) = 0.041244 
C      henke(13,1, 478 ) = 19767.4 
C      henke(13,2, 478 ) = 13.051 
C      henke(13,3, 478 ) = 0.0398831 
C      henke(13,1, 479 ) = 20087.1 
C      henke(13,2, 479 ) = 13.0494 
C      henke(13,3, 479 ) = 0.0385533 
C      henke(13,1, 480 ) = 20412 
C      henke(13,2, 480 ) = 13.0479 
C      henke(13,3, 480 ) = 0.0372771 
C      henke(13,1, 481 ) = 20742.1 
C      henke(13,2, 481 ) = 13.0464 
C      henke(13,3, 481 ) = 0.0360423 
C      henke(13,1, 482 ) = 21077.6 
C      henke(13,2, 482 ) = 13.0449 
C      henke(13,3, 482 ) = 0.0348475 
C      henke(13,1, 483 ) = 21418.5 
C      henke(13,2, 483 ) = 13.0435 
C      henke(13,3, 483 ) = 0.0336915 
C      henke(13,1, 484 ) = 21765 
C      henke(13,2, 484 ) = 13.0421 
C      henke(13,3, 484 ) = 0.0325731 
C      henke(13,1, 485 ) = 22117 
C      henke(13,2, 485 ) = 13.0407 
C      henke(13,3, 485 ) = 0.0314909 
C      henke(13,1, 486 ) = 22474.7 
C      henke(13,2, 486 ) = 13.0394 
C      henke(13,3, 486 ) = 0.030444 
C      henke(13,1, 487 ) = 22838.2 
C      henke(13,2, 487 ) = 13.0381 
C      henke(13,3, 487 ) = 0.0294311 
C      henke(13,1, 488 ) = 23207.6 
C      henke(13,2, 488 ) = 13.0368 
C      henke(13,3, 488 ) = 0.0284511 
C      henke(13,1, 489 ) = 23583 
C      henke(13,2, 489 ) = 13.0356 
C      henke(13,3, 489 ) = 0.027503 
C      henke(13,1, 490 ) = 23964.4 
C      henke(13,2, 490 ) = 13.0343 
C      henke(13,3, 490 ) = 0.0265858 
C      henke(13,1, 491 ) = 24352 
C      henke(13,2, 491 ) = 13.0331 
C      henke(13,3, 491 ) = 0.0256985 
C      henke(13,1, 492 ) = 24745.9 
C      henke(13,2, 492 ) = 13.032 
C      henke(13,3, 492 ) = 0.0248401 
C      henke(13,1, 493 ) = 25146.2 
C      henke(13,2, 493 ) = 13.0308 
C      henke(13,3, 493 ) = 0.0240097 
C      henke(13,1, 494 ) = 25552.9 
C      henke(13,2, 494 ) = 13.0297 
C      henke(13,3, 494 ) = 0.0232064 
C      henke(13,1, 495 ) = 25966.2 
C      henke(13,2, 495 ) = 13.0287 
C      henke(13,3, 495 ) = 0.0224293 
C      henke(13,1, 496 ) = 26386.1 
C      henke(13,2, 496 ) = 13.0276 
C      henke(13,3, 496 ) = 0.0216776 
C      henke(13,1, 497 ) = 26812.9 
C      henke(13,2, 497 ) = 13.0266 
C      henke(13,3, 497 ) = 0.0209505 
C      henke(13,1, 498 ) = 27246.6 
C      henke(13,2, 498 ) = 13.0256 
C      henke(13,3, 498 ) = 0.0202471 
C      henke(13,1, 499 ) = 27687.3 
C      henke(13,2, 499 ) = 13.0246 
C      henke(13,3, 499 ) = 0.0195668 
C      henke(13,1, 500 ) = 28135.1 
C      henke(13,2, 500 ) = 13.0236 
C      henke(13,3, 500 ) = 0.0189087 
C      henke(13,1, 501 ) = 28590.2 
C      henke(13,2, 501 ) = 13.0227 
C      henke(13,3, 501 ) = 0.0182722 
C      henke(13,1, 502 ) = 29052.6 
C      henke(13,2, 502 ) = 13.0218 
C      henke(13,3, 502 ) = 0.0176565 
C      henke(13,1, 503 ) = 29522.5 
C      henke(13,2, 503 ) = 13.0209 
C      henke(13,3, 503 ) = 0.0170611 
C      henke(13,1, 504 ) = 30000 
C      henke(13,2, 504 ) = 13.0198 
C      henke(13,3, 504 ) = 0.0164852 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C        Henke data for si  z=14
C      count(14) = 504
C      henke(14,1, 1 ) = 10 
C      henke(14,2, 1 ) = -9999 
C      henke(14,3, 1 ) = 4.00688 
C      henke(14,1, 2 ) = 10.1617 
C      henke(14,2, 2 ) = -9999 
C      henke(14,3, 2 ) = 4.00859 
C      henke(14,1, 3 ) = 10.3261 
C      henke(14,2, 3 ) = -9999 
C      henke(14,3, 3 ) = 4.01031 
C      henke(14,1, 4 ) = 10.4931 
C      henke(14,2, 4 ) = -9999 
C      henke(14,3, 4 ) = 4.01202 
C      henke(14,1, 5 ) = 10.6628 
C      henke(14,2, 5 ) = -9999 
C      henke(14,3, 5 ) = 4.01374 
C      henke(14,1, 6 ) = 10.8353 
C      henke(14,2, 6 ) = -9999 
C      henke(14,3, 6 ) = 4.01545 
C      henke(14,1, 7 ) = 11.0106 
C      henke(14,2, 7 ) = -9999 
C      henke(14,3, 7 ) = 4.01717 
C      henke(14,1, 8 ) = 11.1886 
C      henke(14,2, 8 ) = -9999 
C      henke(14,3, 8 ) = 4.01889 
C      henke(14,1, 9 ) = 11.3696 
C      henke(14,2, 9 ) = -9999 
C      henke(14,3, 9 ) = 4.02061 
C      henke(14,1, 10 ) = 11.5535 
C      henke(14,2, 10 ) = -9999 
C      henke(14,3, 10 ) = 4.02233 
C      henke(14,1, 11 ) = 11.7404 
C      henke(14,2, 11 ) = -9999 
C      henke(14,3, 11 ) = 4.02405 
C      henke(14,1, 12 ) = 11.9303 
C      henke(14,2, 12 ) = -9999 
C      henke(14,3, 12 ) = 4.02577 
C      henke(14,1, 13 ) = 12.1232 
C      henke(14,2, 13 ) = -9999 
C      henke(14,3, 13 ) = 4.00013 
C      henke(14,1, 14 ) = 12.3193 
C      henke(14,2, 14 ) = -9999 
C      henke(14,3, 14 ) = 3.95924 
C      henke(14,1, 15 ) = 12.5186 
C      henke(14,2, 15 ) = -9999 
C      henke(14,3, 15 ) = 3.91877 
C      henke(14,1, 16 ) = 12.721 
C      henke(14,2, 16 ) = -9999 
C      henke(14,3, 16 ) = 3.8787 
C      henke(14,1, 17 ) = 12.9268 
C      henke(14,2, 17 ) = -9999 
C      henke(14,3, 17 ) = 3.83905 
C      henke(14,1, 18 ) = 13.1359 
C      henke(14,2, 18 ) = -9999 
C      henke(14,3, 18 ) = 3.79981 
C      henke(14,1, 19 ) = 13.3483 
C      henke(14,2, 19 ) = -9999 
C      henke(14,3, 19 ) = 3.76096 
C      henke(14,1, 20 ) = 13.5642 
C      henke(14,2, 20 ) = -9999 
C      henke(14,3, 20 ) = 3.72251 
C      henke(14,1, 21 ) = 13.7836 
C      henke(14,2, 21 ) = -9999 
C      henke(14,3, 21 ) = 3.68446 
C      henke(14,1, 22 ) = 14.0066 
C      henke(14,2, 22 ) = -9999 
C      henke(14,3, 22 ) = 3.64507 
C      henke(14,1, 23 ) = 14.2331 
C      henke(14,2, 23 ) = -9999 
C      henke(14,3, 23 ) = 3.55014 
C      henke(14,1, 24 ) = 14.4633 
C      henke(14,2, 24 ) = -9999 
C      henke(14,3, 24 ) = 3.45769 
C      henke(14,1, 25 ) = 14.6973 
C      henke(14,2, 25 ) = -9999 
C      henke(14,3, 25 ) = 3.36763 
C      henke(14,1, 26 ) = 14.935 
C      henke(14,2, 26 ) = -9999 
C      henke(14,3, 26 ) = 3.27993 
C      henke(14,1, 27 ) = 15.1765 
C      henke(14,2, 27 ) = -9999 
C      henke(14,3, 27 ) = 3.19451 
C      henke(14,1, 28 ) = 15.422 
C      henke(14,2, 28 ) = -9999 
C      henke(14,3, 28 ) = 3.11132 
C      henke(14,1, 29 ) = 15.6714 
C      henke(14,2, 29 ) = -9999 
C      henke(14,3, 29 ) = 3.03029 
C      henke(14,1, 30 ) = 15.9249 
C      henke(14,2, 30 ) = -9999 
C      henke(14,3, 30 ) = 2.95136 
C      henke(14,1, 31 ) = 16.1825 
C      henke(14,2, 31 ) = -9999 
C      henke(14,3, 31 ) = 2.8311 
C      henke(14,1, 32 ) = 16.4442 
C      henke(14,2, 32 ) = -9999 
C      henke(14,3, 32 ) = 2.69866 
C      henke(14,1, 33 ) = 16.7102 
C      henke(14,2, 33 ) = -9999 
C      henke(14,3, 33 ) = 2.57241 
C      henke(14,1, 34 ) = 16.9805 
C      henke(14,2, 34 ) = -9999 
C      henke(14,3, 34 ) = 2.45207 
C      henke(14,1, 35 ) = 17.2551 
C      henke(14,2, 35 ) = -9999 
C      henke(14,3, 35 ) = 2.33736 
C      henke(14,1, 36 ) = 17.5342 
C      henke(14,2, 36 ) = -9999 
C      henke(14,3, 36 ) = 2.22801 
C      henke(14,1, 37 ) = 17.8178 
C      henke(14,2, 37 ) = -9999 
C      henke(14,3, 37 ) = 2.12378 
C      henke(14,1, 38 ) = 18.106 
C      henke(14,2, 38 ) = -9999 
C      henke(14,3, 38 ) = 1.97551 
C      henke(14,1, 39 ) = 18.3989 
C      henke(14,2, 39 ) = -9999 
C      henke(14,3, 39 ) = 1.76134 
C      henke(14,1, 40 ) = 18.6964 
C      henke(14,2, 40 ) = -9999 
C      henke(14,3, 40 ) = 1.5704 
C      henke(14,1, 41 ) = 18.9988 
C      henke(14,2, 41 ) = -9999 
C      henke(14,3, 41 ) = 1.40015 
C      henke(14,1, 42 ) = 19.3061 
C      henke(14,2, 42 ) = -9999 
C      henke(14,3, 42 ) = 1.24837 
C      henke(14,1, 43 ) = 19.6184 
C      henke(14,2, 43 ) = -9999 
C      henke(14,3, 43 ) = 1.11303 
C      henke(14,1, 44 ) = 19.9357 
C      henke(14,2, 44 ) = -9999 
C      henke(14,3, 44 ) = 0.992371 
C      henke(14,1, 45 ) = 20.2582 
C      henke(14,2, 45 ) = -9999 
C      henke(14,3, 45 ) = 0.862309 
C      henke(14,1, 46 ) = 20.5858 
C      henke(14,2, 46 ) = -9999 
C      henke(14,3, 46 ) = 0.753545 
C      henke(14,1, 47 ) = 20.9188 
C      henke(14,2, 47 ) = -9999 
C      henke(14,3, 47 ) = 0.698853 
C      henke(14,1, 48 ) = 21.2571 
C      henke(14,2, 48 ) = -9999 
C      henke(14,3, 48 ) = 0.648131 
C      henke(14,1, 49 ) = 21.6009 
C      henke(14,2, 49 ) = -9999 
C      henke(14,3, 49 ) = 0.602534 
C      henke(14,1, 50 ) = 21.9503 
C      henke(14,2, 50 ) = -9999 
C      henke(14,3, 50 ) = 0.561517 
C      henke(14,1, 51 ) = 22.3053 
C      henke(14,2, 51 ) = -9999 
C      henke(14,3, 51 ) = 0.523292 
C      henke(14,1, 52 ) = 22.6661 
C      henke(14,2, 52 ) = -9999 
C      henke(14,3, 52 ) = 0.496905 
C      henke(14,1, 53 ) = 23.0327 
C      henke(14,2, 53 ) = -9999 
C      henke(14,3, 53 ) = 0.478083 
C      henke(14,1, 54 ) = 23.4053 
C      henke(14,2, 54 ) = -9999 
C      henke(14,3, 54 ) = 0.459974 
C      henke(14,1, 55 ) = 23.7838 
C      henke(14,2, 55 ) = -9999 
C      henke(14,3, 55 ) = 0.442552 
C      henke(14,1, 56 ) = 24.1685 
C      henke(14,2, 56 ) = -9999 
C      henke(14,3, 56 ) = 0.425789 
C      henke(14,1, 57 ) = 24.5594 
C      henke(14,2, 57 ) = -9999 
C      henke(14,3, 57 ) = 0.413106 
C      henke(14,1, 58 ) = 24.9566 
C      henke(14,2, 58 ) = -9999 
C      henke(14,3, 58 ) = 0.403049 
C      henke(14,1, 59 ) = 25.3603 
C      henke(14,2, 59 ) = -9999 
C      henke(14,3, 59 ) = 0.393236 
C      henke(14,1, 60 ) = 25.7705 
C      henke(14,2, 60 ) = -9999 
C      henke(14,3, 60 ) = 0.383663 
C      henke(14,1, 61 ) = 26.1873 
C      henke(14,2, 61 ) = -9999 
C      henke(14,3, 61 ) = 0.374323 
C      henke(14,1, 62 ) = 26.6109 
C      henke(14,2, 62 ) = -9999 
C      henke(14,3, 62 ) = 0.365209 
C      henke(14,1, 63 ) = 27.0413 
C      henke(14,2, 63 ) = -9999 
C      henke(14,3, 63 ) = 0.366284 
C      henke(14,1, 64 ) = 27.4786 
C      henke(14,2, 64 ) = -9999 
C      henke(14,3, 64 ) = 0.367369 
C      henke(14,1, 65 ) = 27.9231 
C      henke(14,2, 65 ) = -9999 
C      henke(14,3, 65 ) = 0.368458 
C      henke(14,1, 66 ) = 28.3747 
C      henke(14,2, 66 ) = -9999 
C      henke(14,3, 66 ) = 0.369549 
C      henke(14,1, 67 ) = 28.8337 
C      henke(14,2, 67 ) = -9999 
C      henke(14,3, 67 ) = 0.370644 
C      henke(14,1, 68 ) = 29.3 
C      henke(14,2, 68 ) = 4.04139 
C      henke(14,3, 68 ) = 0.371742 
C      henke(14,1, 69 ) = 29.7739 
C      henke(14,2, 69 ) = 4.01454 
C      henke(14,3, 69 ) = 0.372844 
C      henke(14,1, 70 ) = 30.2555 
C      henke(14,2, 70 ) = 3.98864 
C      henke(14,3, 70 ) = 0.373949 
C      henke(14,1, 71 ) = 30.7449 
C      henke(14,2, 71 ) = 3.96353 
C      henke(14,3, 71 ) = 0.375057 
C      henke(14,1, 72 ) = 31.2421 
C      henke(14,2, 72 ) = 3.93824 
C      henke(14,3, 72 ) = 0.376168 
C      henke(14,1, 73 ) = 31.7475 
C      henke(14,2, 73 ) = 3.9133 
C      henke(14,3, 73 ) = 0.378082 
C      henke(14,1, 74 ) = 32.2609 
C      henke(14,2, 74 ) = 3.88933 
C      henke(14,3, 74 ) = 0.38199 
C      henke(14,1, 75 ) = 32.7827 
C      henke(14,2, 75 ) = 3.86697 
C      henke(14,3, 75 ) = 0.38594 
C      henke(14,1, 76 ) = 33.313 
C      henke(14,2, 76 ) = 3.84562 
C      henke(14,3, 76 ) = 0.38993 
C      henke(14,1, 77 ) = 33.8518 
C      henke(14,2, 77 ) = 3.82508 
C      henke(14,3, 77 ) = 0.393962 
C      henke(14,1, 78 ) = 34.3993 
C      henke(14,2, 78 ) = 3.80523 
C      henke(14,3, 78 ) = 0.398035 
C      henke(14,1, 79 ) = 34.9557 
C      henke(14,2, 79 ) = 3.78598 
C      henke(14,3, 79 ) = 0.402151 
C      henke(14,1, 80 ) = 35.5211 
C      henke(14,2, 80 ) = 3.76728 
C      henke(14,3, 80 ) = 0.406309 
C      henke(14,1, 81 ) = 36.0956 
C      henke(14,2, 81 ) = 3.74907 
C      henke(14,3, 81 ) = 0.41051 
C      henke(14,1, 82 ) = 36.6794 
C      henke(14,2, 82 ) = 3.73131 
C      henke(14,3, 82 ) = 0.414754 
C      henke(14,1, 83 ) = 37.2727 
C      henke(14,2, 83 ) = 3.714 
C      henke(14,3, 83 ) = 0.419042 
C      henke(14,1, 84 ) = 37.8755 
C      henke(14,2, 84 ) = 3.69713 
C      henke(14,3, 84 ) = 0.423375 
C      henke(14,1, 85 ) = 38.4882 
C      henke(14,2, 85 ) = 3.68075 
C      henke(14,3, 85 ) = 0.427752 
C      henke(14,1, 86 ) = 39.1107 
C      henke(14,2, 86 ) = 3.66515 
C      henke(14,3, 86 ) = 0.432175 
C      henke(14,1, 87 ) = 39.7432 
C      henke(14,2, 87 ) = 3.65075 
C      henke(14,3, 87 ) = 0.435542 
C      henke(14,1, 88 ) = 40.3861 
C      henke(14,2, 88 ) = 3.636 
C      henke(14,3, 88 ) = 0.43714 
C      henke(14,1, 89 ) = 41.0393 
C      henke(14,2, 89 ) = 3.61975 
C      henke(14,3, 89 ) = 0.438744 
C      henke(14,1, 90 ) = 41.7031 
C      henke(14,2, 90 ) = 3.60317 
C      henke(14,3, 90 ) = 0.440353 
C      henke(14,1, 91 ) = 42.3776 
C      henke(14,2, 91 ) = 3.5862 
C      henke(14,3, 91 ) = 0.441968 
C      henke(14,1, 92 ) = 43.063 
C      henke(14,2, 92 ) = 3.56885 
C      henke(14,3, 92 ) = 0.443589 
C      henke(14,1, 93 ) = 43.7595 
C      henke(14,2, 93 ) = 3.55113 
C      henke(14,3, 93 ) = 0.445216 
C      henke(14,1, 94 ) = 44.4673 
C      henke(14,2, 94 ) = 3.53304 
C      henke(14,3, 94 ) = 0.446849 
C      henke(14,1, 95 ) = 45.1865 
C      henke(14,2, 95 ) = 3.51458 
C      henke(14,3, 95 ) = 0.448488 
C      henke(14,1, 96 ) = 45.9174 
C      henke(14,2, 96 ) = 3.49586 
C      henke(14,3, 96 ) = 0.450133 
C      henke(14,1, 97 ) = 46.66 
C      henke(14,2, 97 ) = 3.47671 
C      henke(14,3, 97 ) = 0.451191 
C      henke(14,1, 98 ) = 47.4147 
C      henke(14,2, 98 ) = 3.45675 
C      henke(14,3, 98 ) = 0.451973 
C      henke(14,1, 99 ) = 48.1816 
C      henke(14,2, 99 ) = 3.43573 
C      henke(14,3, 99 ) = 0.452756 
C      henke(14,1, 100 ) = 48.9609 
C      henke(14,2, 100 ) = 3.41387 
C      henke(14,3, 100 ) = 0.45354 
C      henke(14,1, 101 ) = 49.7528 
C      henke(14,2, 101 ) = 3.39107 
C      henke(14,3, 101 ) = 0.454326 
C      henke(14,1, 102 ) = 50.5576 
C      henke(14,2, 102 ) = 3.36726 
C      henke(14,3, 102 ) = 0.455112 
C      henke(14,1, 103 ) = 51.3753 
C      henke(14,2, 103 ) = 3.34236 
C      henke(14,3, 103 ) = 0.455901 
C      henke(14,1, 104 ) = 52.2062 
C      henke(14,2, 104 ) = 3.31547 
C      henke(14,3, 104 ) = 0.456691 
C      henke(14,1, 105 ) = 53.0506 
C      henke(14,2, 105 ) = 3.28696 
C      henke(14,3, 105 ) = 0.458296 
C      henke(14,1, 106 ) = 53.9087 
C      henke(14,2, 106 ) = 3.25789 
C      henke(14,3, 106 ) = 0.461941 
C      henke(14,1, 107 ) = 54.7806 
C      henke(14,2, 107 ) = 3.2286 
C      henke(14,3, 107 ) = 0.465616 
C      henke(14,1, 108 ) = 55.6667 
C      henke(14,2, 108 ) = 3.19848 
C      henke(14,3, 108 ) = 0.469319 
C      henke(14,1, 109 ) = 56.567 
C      henke(14,2, 109 ) = 3.16724 
C      henke(14,3, 109 ) = 0.473052 
C      henke(14,1, 110 ) = 57.482 
C      henke(14,2, 110 ) = 3.13464 
C      henke(14,3, 110 ) = 0.476815 
C      henke(14,1, 111 ) = 58.4117 
C      henke(14,2, 111 ) = 3.09985 
C      henke(14,3, 111 ) = 0.480608 
C      henke(14,1, 112 ) = 59.3564 
C      henke(14,2, 112 ) = 3.06106 
C      henke(14,3, 112 ) = 0.484431 
C      henke(14,1, 113 ) = 60.3165 
C      henke(14,2, 113 ) = 3.02161 
C      henke(14,3, 113 ) = 0.494934 
C      henke(14,1, 114 ) = 61.2921 
C      henke(14,2, 114 ) = 2.98391 
C      henke(14,3, 114 ) = 0.506494 
C      henke(14,1, 115 ) = 62.2834 
C      henke(14,2, 115 ) = 2.94697 
C      henke(14,3, 115 ) = 0.518325 
C      henke(14,1, 116 ) = 63.2908 
C      henke(14,2, 116 ) = 2.91044 
C      henke(14,3, 116 ) = 0.530432 
C      henke(14,1, 117 ) = 64.3145 
C      henke(14,2, 117 ) = 2.87467 
C      henke(14,3, 117 ) = 0.542822 
C      henke(14,1, 118 ) = 65.3547 
C      henke(14,2, 118 ) = 2.84253 
C      henke(14,3, 118 ) = 0.554883 
C      henke(14,1, 119 ) = 66.4118 
C      henke(14,2, 119 ) = 2.80778 
C      henke(14,3, 119 ) = 0.55896 
C      henke(14,1, 120 ) = 67.4859 
C      henke(14,2, 120 ) = 2.76948 
C      henke(14,3, 120 ) = 0.563068 
C      henke(14,1, 121 ) = 68.5775 
C      henke(14,2, 121 ) = 2.72973 
C      henke(14,3, 121 ) = 0.567206 
C      henke(14,1, 122 ) = 69.6867 
C      henke(14,2, 122 ) = 2.69075 
C      henke(14,3, 122 ) = 0.571374 
C      henke(14,1, 123 ) = 70.8138 
C      henke(14,2, 123 ) = 2.65359 
C      henke(14,3, 123 ) = 0.566787 
C      henke(14,1, 124 ) = 71.9591 
C      henke(14,2, 124 ) = 2.60604 
C      henke(14,3, 124 ) = 0.55295 
C      henke(14,1, 125 ) = 73.123 
C      henke(14,2, 125 ) = 2.54939 
C      henke(14,3, 125 ) = 0.539453 
C      henke(14,1, 126 ) = 74.3057 
C      henke(14,2, 126 ) = 2.48874 
C      henke(14,3, 126 ) = 0.526284 
C      henke(14,1, 127 ) = 75.5076 
C      henke(14,2, 127 ) = 2.42506 
C      henke(14,3, 127 ) = 0.504753 
C      henke(14,1, 128 ) = 76.7289 
C      henke(14,2, 128 ) = 2.34452 
C      henke(14,3, 128 ) = 0.477393 
C      henke(14,1, 129 ) = 77.9699 
C      henke(14,2, 129 ) = 2.24588 
C      henke(14,3, 129 ) = 0.451516 
C      henke(14,1, 130 ) = 79.231 
C      henke(14,2, 130 ) = 2.13308 
C      henke(14,3, 130 ) = 0.427357 
C      henke(14,1, 131 ) = 80.5125 
C      henke(14,2, 131 ) = 2.00763 
C      henke(14,3, 131 ) = 0.422615 
C      henke(14,1, 132 ) = 81.8147 
C      henke(14,2, 132 ) = 1.87992 
C      henke(14,3, 132 ) = 0.417925 
C      henke(14,1, 133 ) = 83.138 
C      henke(14,2, 133 ) = 1.74284 
C      henke(14,3, 133 ) = 0.413288 
C      henke(14,1, 134 ) = 84.4827 
C      henke(14,2, 134 ) = 1.58757 
C      henke(14,3, 134 ) = 0.409319 
C      henke(14,1, 135 ) = 85.8491 
C      henke(14,2, 135 ) = 1.41949 
C      henke(14,3, 135 ) = 0.41594 
C      henke(14,1, 136 ) = 87.2377 
C      henke(14,2, 136 ) = 1.24204 
C      henke(14,3, 136 ) = 0.422667 
C      henke(14,1, 137 ) = 88.6487 
C      henke(14,2, 137 ) = 1.04516 
C      henke(14,3, 137 ) = 0.429504 
C      henke(14,1, 138 ) = 90.0825 
C      henke(14,2, 138 ) = 0.823388 
C      henke(14,3, 138 ) = 0.436451 
C      henke(14,1, 139 ) = 91.5395 
C      henke(14,2, 139 ) = 0.567875 
C      henke(14,3, 139 ) = 0.444919 
C      henke(14,1, 140 ) = 93.0201 
C      henke(14,2, 140 ) = 0.269396 
C      henke(14,3, 140 ) = 0.456522 
C      henke(14,1, 141 ) = 94.5246 
C      henke(14,2, 141 ) = -0.0903649 
C      henke(14,3, 141 ) = 0.468427 
C      henke(14,1, 142 ) = 96.0535 
C      henke(14,2, 142 ) = -0.553028 
C      henke(14,3, 142 ) = 0.480642 
C      henke(14,1, 143 ) = 97.6071 
C      henke(14,2, 143 ) = -1.22076 
C      henke(14,3, 143 ) = 0.493176 
C      henke(14,1, 144 ) = 99.1858 
C      henke(14,2, 144 ) = -2.61173 
C      henke(14,3, 144 ) = 0.506036 
C      henke(14,1, 145 ) = 99.7 
C      henke(14,2, 145 ) = -4.36195 
C      henke(14,3, 145 ) = 0.510252 
C      henke(14,1, 146 ) = 99.9 
C      henke(14,2, 146 ) = -4.42226 
C      henke(14,3, 146 ) = 3.36544 
C      henke(14,1, 147 ) = 100.79 
C      henke(14,2, 147 ) = -2.52757 
C      henke(14,3, 147 ) = 3.48839 
C      henke(14,1, 148 ) = 102.42 
C      henke(14,2, 148 ) = -1.89095 
C      henke(14,3, 148 ) = 3.72231 
C      henke(14,1, 149 ) = 104.077 
C      henke(14,2, 149 ) = -1.65223 
C      henke(14,3, 149 ) = 3.97192 
C      henke(14,1, 150 ) = 105.76 
C      henke(14,2, 150 ) = -1.53188 
C      henke(14,3, 150 ) = 4.23827 
C      henke(14,1, 151 ) = 107.471 
C      henke(14,2, 151 ) = -1.46339 
C      henke(14,3, 151 ) = 4.52248 
C      henke(14,1, 152 ) = 109.209 
C      henke(14,2, 152 ) = -1.42872 
C      henke(14,3, 152 ) = 4.82575 
C      henke(14,1, 153 ) = 110.975 
C      henke(14,2, 153 ) = -1.40389 
C      henke(14,3, 153 ) = 5.16049 
C      henke(14,1, 154 ) = 112.77 
C      henke(14,2, 154 ) = -1.37428 
C      henke(14,3, 154 ) = 5.52407 
C      henke(14,1, 155 ) = 114.594 
C      henke(14,2, 155 ) = -1.33243 
C      henke(14,3, 155 ) = 5.91327 
C      henke(14,1, 156 ) = 116.448 
C      henke(14,2, 156 ) = -1.27205 
C      henke(14,3, 156 ) = 6.32988 
C      henke(14,1, 157 ) = 118.331 
C      henke(14,2, 157 ) = -1.20547 
C      henke(14,3, 157 ) = 6.78138 
C      henke(14,1, 158 ) = 120.245 
C      henke(14,2, 158 ) = -1.08948 
C      henke(14,3, 158 ) = 7.30531 
C      henke(14,1, 159 ) = 122.19 
C      henke(14,2, 159 ) = -0.832441 
C      henke(14,3, 159 ) = 7.86971 
C      henke(14,1, 160 ) = 124.166 
C      henke(14,2, 160 ) = -0.41994 
C      henke(14,3, 160 ) = 8.38835 
C      henke(14,1, 161 ) = 126.175 
C      henke(14,2, 161 ) = -0.0149922 
C      henke(14,3, 161 ) = 8.75826 
C      henke(14,1, 162 ) = 128.215 
C      henke(14,2, 162 ) = 0.463892 
C      henke(14,3, 162 ) = 9.14448 
C      henke(14,1, 163 ) = 130.289 
C      henke(14,2, 163 ) = 0.98047 
C      henke(14,3, 163 ) = 9.40977 
C      henke(14,1, 164 ) = 132.397 
C      henke(14,2, 164 ) = 1.46277 
C      henke(14,3, 164 ) = 9.52408 
C      henke(14,1, 165 ) = 134.538 
C      henke(14,2, 165 ) = 1.8754 
C      henke(14,3, 165 ) = 9.63977 
C      henke(14,1, 166 ) = 136.714 
C      henke(14,2, 166 ) = 2.28508 
C      henke(14,3, 166 ) = 9.75686 
C      henke(14,1, 167 ) = 138.925 
C      henke(14,2, 167 ) = 2.73049 
C      henke(14,3, 167 ) = 9.81468 
C      henke(14,1, 168 ) = 141.172 
C      henke(14,2, 168 ) = 3.13306 
C      henke(14,3, 168 ) = 9.78032 
C      henke(14,1, 169 ) = 143.456 
C      henke(14,2, 169 ) = 3.44155 
C      henke(14,3, 169 ) = 9.74609 
C      henke(14,1, 170 ) = 145.776 
C      henke(14,2, 170 ) = 3.723 
C      henke(14,3, 170 ) = 9.71197 
C      henke(14,1, 171 ) = 148.134 
C      henke(14,2, 171 ) = 3.97029 
C      henke(14,3, 171 ) = 9.65439 
C      henke(14,1, 172 ) = 150.53 
C      henke(14,2, 172 ) = 4.12976 
C      henke(14,3, 172 ) = 9.58865 
C      henke(14,1, 173 ) = 152.964 
C      henke(14,2, 173 ) = 4.2187 
C      henke(14,3, 173 ) = 9.57811 
C      henke(14,1, 174 ) = 155.439 
C      henke(14,2, 174 ) = 4.30732 
C      henke(14,3, 174 ) = 9.75261 
C      henke(14,1, 175 ) = 157.953 
C      henke(14,2, 175 ) = 4.49148 
C      henke(14,3, 175 ) = 9.93028 
C      henke(14,1, 176 ) = 160.507 
C      henke(14,2, 176 ) = 4.7164 
C      henke(14,3, 176 ) = 10.1112 
C      henke(14,1, 177 ) = 163.103 
C      henke(14,2, 177 ) = 4.9735 
C      henke(14,3, 177 ) = 10.3054 
C      henke(14,1, 178 ) = 165.742 
C      henke(14,2, 178 ) = 5.28403 
C      henke(14,3, 178 ) = 10.5171 
C      henke(14,1, 179 ) = 168.422 
C      henke(14,2, 179 ) = 5.71179 
C      henke(14,3, 179 ) = 10.7332 
C      henke(14,1, 180 ) = 171.146 
C      henke(14,2, 180 ) = 6.19378 
C      henke(14,3, 180 ) = 10.7766 
C      henke(14,1, 181 ) = 173.915 
C      henke(14,2, 181 ) = 6.6414 
C      henke(14,3, 181 ) = 10.8012 
C      henke(14,1, 182 ) = 176.727 
C      henke(14,2, 182 ) = 7.05872 
C      henke(14,3, 182 ) = 10.7479 
C      henke(14,1, 183 ) = 179.586 
C      henke(14,2, 183 ) = 7.47284 
C      henke(14,3, 183 ) = 10.6948 
C      henke(14,1, 184 ) = 182.491 
C      henke(14,2, 184 ) = 7.89655 
C      henke(14,3, 184 ) = 10.5963 
C      henke(14,1, 185 ) = 185.442 
C      henke(14,2, 185 ) = 8.28845 
C      henke(14,3, 185 ) = 10.3962 
C      henke(14,1, 186 ) = 188.442 
C      henke(14,2, 186 ) = 8.59635 
C      henke(14,3, 186 ) = 10.1999 
C      henke(14,1, 187 ) = 191.489 
C      henke(14,2, 187 ) = 8.86152 
C      henke(14,3, 187 ) = 10.0113 
C      henke(14,1, 188 ) = 194.587 
C      henke(14,2, 188 ) = 9.10569 
C      henke(14,3, 188 ) = 9.83461 
C      henke(14,1, 189 ) = 197.734 
C      henke(14,2, 189 ) = 9.33495 
C      henke(14,3, 189 ) = 9.661 
C      henke(14,1, 190 ) = 200.932 
C      henke(14,2, 190 ) = 9.54801 
C      henke(14,3, 190 ) = 9.49045 
C      henke(14,1, 191 ) = 204.182 
C      henke(14,2, 191 ) = 9.74711 
C      henke(14,3, 191 ) = 9.32291 
C      henke(14,1, 192 ) = 207.485 
C      henke(14,2, 192 ) = 9.93385 
C      henke(14,3, 192 ) = 9.15833 
C      henke(14,1, 193 ) = 210.84 
C      henke(14,2, 193 ) = 10.1095 
C      henke(14,3, 193 ) = 8.99666 
C      henke(14,1, 194 ) = 214.251 
C      henke(14,2, 194 ) = 10.2752 
C      henke(14,3, 194 ) = 8.83784 
C      henke(14,1, 195 ) = 217.716 
C      henke(14,2, 195 ) = 10.4318 
C      henke(14,3, 195 ) = 8.68182 
C      henke(14,1, 196 ) = 221.237 
C      henke(14,2, 196 ) = 10.5801 
C      henke(14,3, 196 ) = 8.52856 
C      henke(14,1, 197 ) = 224.816 
C      henke(14,2, 197 ) = 10.7209 
C      henke(14,3, 197 ) = 8.378 
C      henke(14,1, 198 ) = 228.452 
C      henke(14,2, 198 ) = 10.8546 
C      henke(14,3, 198 ) = 8.2301 
C      henke(14,1, 199 ) = 232.147 
C      henke(14,2, 199 ) = 10.9818 
C      henke(14,3, 199 ) = 8.08481 
C      henke(14,1, 200 ) = 235.902 
C      henke(14,2, 200 ) = 11.1031 
C      henke(14,3, 200 ) = 7.94208 
C      henke(14,1, 201 ) = 239.717 
C      henke(14,2, 201 ) = 11.2188 
C      henke(14,3, 201 ) = 7.80188 
C      henke(14,1, 202 ) = 243.595 
C      henke(14,2, 202 ) = 11.3294 
C      henke(14,3, 202 ) = 7.66415 
C      henke(14,1, 203 ) = 247.535 
C      henke(14,2, 203 ) = 11.4352 
C      henke(14,3, 203 ) = 7.52885 
C      henke(14,1, 204 ) = 251.538 
C      henke(14,2, 204 ) = 11.5366 
C      henke(14,3, 204 ) = 7.39594 
C      henke(14,1, 205 ) = 255.607 
C      henke(14,2, 205 ) = 11.634 
C      henke(14,3, 205 ) = 7.26538 
C      henke(14,1, 206 ) = 259.741 
C      henke(14,2, 206 ) = 11.7276 
C      henke(14,3, 206 ) = 7.13712 
C      henke(14,1, 207 ) = 263.942 
C      henke(14,2, 207 ) = 11.8178 
C      henke(14,3, 207 ) = 7.01113 
C      henke(14,1, 208 ) = 268.211 
C      henke(14,2, 208 ) = 11.9051 
C      henke(14,3, 208 ) = 6.88736 
C      henke(14,1, 209 ) = 272.549 
C      henke(14,2, 209 ) = 11.9896 
C      henke(14,3, 209 ) = 6.76577 
C      henke(14,1, 210 ) = 276.957 
C      henke(14,2, 210 ) = 12.0721 
C      henke(14,3, 210 ) = 6.64634 
C      henke(14,1, 211 ) = 281.437 
C      henke(14,2, 211 ) = 12.153 
C      henke(14,3, 211 ) = 6.529 
C      henke(14,1, 212 ) = 285.989 
C      henke(14,2, 212 ) = 12.2334 
C      henke(14,3, 212 ) = 6.41375 
C      henke(14,1, 213 ) = 290.615 
C      henke(14,2, 213 ) = 12.3167 
C      henke(14,3, 213 ) = 6.30052 
C      henke(14,1, 214 ) = 295.315 
C      henke(14,2, 214 ) = 12.4047 
C      henke(14,3, 214 ) = 6.17775 
C      henke(14,1, 215 ) = 300.092 
C      henke(14,2, 215 ) = 12.4852 
C      henke(14,3, 215 ) = 6.04345 
C      henke(14,1, 216 ) = 304.945 
C      henke(14,2, 216 ) = 12.5494 
C      henke(14,3, 216 ) = 5.91207 
C      henke(14,1, 217 ) = 309.878 
C      henke(14,2, 217 ) = 12.6085 
C      henke(14,3, 217 ) = 5.78356 
C      henke(14,1, 218 ) = 314.89 
C      henke(14,2, 218 ) = 12.6624 
C      henke(14,3, 218 ) = 5.65783 
C      henke(14,1, 219 ) = 319.983 
C      henke(14,2, 219 ) = 12.7119 
C      henke(14,3, 219 ) = 5.53483 
C      henke(14,1, 220 ) = 325.158 
C      henke(14,2, 220 ) = 12.7575 
C      henke(14,3, 220 ) = 5.41451 
C      henke(14,1, 221 ) = 330.418 
C      henke(14,2, 221 ) = 12.7995 
C      henke(14,3, 221 ) = 5.29681 
C      henke(14,1, 222 ) = 335.762 
C      henke(14,2, 222 ) = 12.8383 
C      henke(14,3, 222 ) = 5.18166 
C      henke(14,1, 223 ) = 341.192 
C      henke(14,2, 223 ) = 12.8742 
C      henke(14,3, 223 ) = 5.06902 
C      henke(14,1, 224 ) = 346.711 
C      henke(14,2, 224 ) = 12.9073 
C      henke(14,3, 224 ) = 4.95882 
C      henke(14,1, 225 ) = 352.319 
C      henke(14,2, 225 ) = 12.9378 
C      henke(14,3, 225 ) = 4.85102 
C      henke(14,1, 226 ) = 358.017 
C      henke(14,2, 226 ) = 12.9658 
C      henke(14,3, 226 ) = 4.74557 
C      henke(14,1, 227 ) = 363.808 
C      henke(14,2, 227 ) = 12.9915 
C      henke(14,3, 227 ) = 4.6424 
C      henke(14,1, 228 ) = 369.692 
C      henke(14,2, 228 ) = 13.0149 
C      henke(14,3, 228 ) = 4.54148 
C      henke(14,1, 229 ) = 375.672 
C      henke(14,2, 229 ) = 13.0357 
C      henke(14,3, 229 ) = 4.44276 
C      henke(14,1, 230 ) = 381.748 
C      henke(14,2, 230 ) = 13.0537 
C      henke(14,3, 230 ) = 4.34688 
C      henke(14,1, 231 ) = 387.922 
C      henke(14,2, 231 ) = 13.0707 
C      henke(14,3, 231 ) = 4.25572 
C      henke(14,1, 232 ) = 394.197 
C      henke(14,2, 232 ) = 13.0875 
C      henke(14,3, 232 ) = 4.16648 
C      henke(14,1, 233 ) = 400.573 
C      henke(14,2, 233 ) = 13.1036 
C      henke(14,3, 233 ) = 4.07911 
C      henke(14,1, 234 ) = 407.052 
C      henke(14,2, 234 ) = 13.1187 
C      henke(14,3, 234 ) = 3.99357 
C      henke(14,1, 235 ) = 413.635 
C      henke(14,2, 235 ) = 13.1328 
C      henke(14,3, 235 ) = 3.90983 
C      henke(14,1, 236 ) = 420.326 
C      henke(14,2, 236 ) = 13.1461 
C      henke(14,3, 236 ) = 3.82784 
C      henke(14,1, 237 ) = 427.124 
C      henke(14,2, 237 ) = 13.1584 
C      henke(14,3, 237 ) = 3.74757 
C      henke(14,1, 238 ) = 434.032 
C      henke(14,2, 238 ) = 13.1699 
C      henke(14,3, 238 ) = 3.66899 
C      henke(14,1, 239 ) = 441.052 
C      henke(14,2, 239 ) = 13.1806 
C      henke(14,3, 239 ) = 3.59205 
C      henke(14,1, 240 ) = 448.186 
C      henke(14,2, 240 ) = 13.1906 
C      henke(14,3, 240 ) = 3.51673 
C      henke(14,1, 241 ) = 455.435 
C      henke(14,2, 241 ) = 13.1999 
C      henke(14,3, 241 ) = 3.44298 
C      henke(14,1, 242 ) = 462.802 
C      henke(14,2, 242 ) = 13.2086 
C      henke(14,3, 242 ) = 3.37078 
C      henke(14,1, 243 ) = 470.287 
C      henke(14,2, 243 ) = 13.2168 
C      henke(14,3, 243 ) = 3.3001 
C      henke(14,1, 244 ) = 477.894 
C      henke(14,2, 244 ) = 13.2245 
C      henke(14,3, 244 ) = 3.2309 
C      henke(14,1, 245 ) = 485.623 
C      henke(14,2, 245 ) = 13.2319 
C      henke(14,3, 245 ) = 3.16315 
C      henke(14,1, 246 ) = 493.478 
C      henke(14,2, 246 ) = 13.2392 
C      henke(14,3, 246 ) = 3.09681 
C      henke(14,1, 247 ) = 501.459 
C      henke(14,2, 247 ) = 13.2464 
C      henke(14,3, 247 ) = 3.03188 
C      henke(14,1, 248 ) = 509.57 
C      henke(14,2, 248 ) = 13.2548 
C      henke(14,3, 248 ) = 2.9683 
C      henke(14,1, 249 ) = 517.812 
C      henke(14,2, 249 ) = 13.2653 
C      henke(14,3, 249 ) = 2.90606 
C      henke(14,1, 250 ) = 526.187 
C      henke(14,2, 250 ) = 13.2757 
C      henke(14,3, 250 ) = 2.83752 
C      henke(14,1, 251 ) = 534.698 
C      henke(14,2, 251 ) = 13.2816 
C      henke(14,3, 251 ) = 2.76872 
C      henke(14,1, 252 ) = 543.346 
C      henke(14,2, 252 ) = 13.2847 
C      henke(14,3, 252 ) = 2.70158 
C      henke(14,1, 253 ) = 552.134 
C      henke(14,2, 253 ) = 13.286 
C      henke(14,3, 253 ) = 2.63607 
C      henke(14,1, 254 ) = 561.065 
C      henke(14,2, 254 ) = 13.2858 
C      henke(14,3, 254 ) = 2.57215 
C      henke(14,1, 255 ) = 570.139 
C      henke(14,2, 255 ) = 13.2844 
C      henke(14,3, 255 ) = 2.50978 
C      henke(14,1, 256 ) = 579.361 
C      henke(14,2, 256 ) = 13.282 
C      henke(14,3, 256 ) = 2.44892 
C      henke(14,1, 257 ) = 588.732 
C      henke(14,2, 257 ) = 13.2787 
C      henke(14,3, 257 ) = 2.38954 
C      henke(14,1, 258 ) = 598.254 
C      henke(14,2, 258 ) = 13.2746 
C      henke(14,3, 258 ) = 2.3316 
C      henke(14,1, 259 ) = 607.93 
C      henke(14,2, 259 ) = 13.2698 
C      henke(14,3, 259 ) = 2.27507 
C      henke(14,1, 260 ) = 617.763 
C      henke(14,2, 260 ) = 13.2644 
C      henke(14,3, 260 ) = 2.2199 
C      henke(14,1, 261 ) = 627.755 
C      henke(14,2, 261 ) = 13.2585 
C      henke(14,3, 261 ) = 2.16607 
C      henke(14,1, 262 ) = 637.908 
C      henke(14,2, 262 ) = 13.2523 
C      henke(14,3, 262 ) = 2.11355 
C      henke(14,1, 263 ) = 648.226 
C      henke(14,2, 263 ) = 13.2457 
C      henke(14,3, 263 ) = 2.0623 
C      henke(14,1, 264 ) = 658.711 
C      henke(14,2, 264 ) = 13.2392 
C      henke(14,3, 264 ) = 2.01229 
C      henke(14,1, 265 ) = 669.365 
C      henke(14,2, 265 ) = 13.2335 
C      henke(14,3, 265 ) = 1.9635 
C      henke(14,1, 266 ) = 680.191 
C      henke(14,2, 266 ) = 13.2269 
C      henke(14,3, 266 ) = 1.91232 
C      henke(14,1, 267 ) = 691.193 
C      henke(14,2, 267 ) = 13.2188 
C      henke(14,3, 267 ) = 1.86218 
C      henke(14,1, 268 ) = 702.372 
C      henke(14,2, 268 ) = 13.2089 
C      henke(14,3, 268 ) = 1.81336 
C      henke(14,1, 269 ) = 713.733 
C      henke(14,2, 269 ) = 13.1982 
C      henke(14,3, 269 ) = 1.76582 
C      henke(14,1, 270 ) = 725.277 
C      henke(14,2, 270 ) = 13.1866 
C      henke(14,3, 270 ) = 1.71952 
C      henke(14,1, 271 ) = 737.008 
C      henke(14,2, 271 ) = 13.1743 
C      henke(14,3, 271 ) = 1.67444 
C      henke(14,1, 272 ) = 748.928 
C      henke(14,2, 272 ) = 13.1614 
C      henke(14,3, 272 ) = 1.63053 
C      henke(14,1, 273 ) = 761.042 
C      henke(14,2, 273 ) = 13.1479 
C      henke(14,3, 273 ) = 1.58779 
C      henke(14,1, 274 ) = 773.351 
C      henke(14,2, 274 ) = 13.1338 
C      henke(14,3, 274 ) = 1.54615 
C      henke(14,1, 275 ) = 785.859 
C      henke(14,2, 275 ) = 13.119 
C      henke(14,3, 275 ) = 1.50562 
C      henke(14,1, 276 ) = 798.57 
C      henke(14,2, 276 ) = 13.1032 
C      henke(14,3, 276 ) = 1.46614 
C      henke(14,1, 277 ) = 811.486 
C      henke(14,2, 277 ) = 13.087 
C      henke(14,3, 277 ) = 1.42894 
C      henke(14,1, 278 ) = 824.611 
C      henke(14,2, 278 ) = 13.0711 
C      henke(14,3, 278 ) = 1.39288 
C      henke(14,1, 279 ) = 837.949 
C      henke(14,2, 279 ) = 13.0551 
C      henke(14,3, 279 ) = 1.35772 
C      henke(14,1, 280 ) = 851.502 
C      henke(14,2, 280 ) = 13.039 
C      henke(14,3, 280 ) = 1.32346 
C      henke(14,1, 281 ) = 865.274 
C      henke(14,2, 281 ) = 13.0226 
C      henke(14,3, 281 ) = 1.29006 
C      henke(14,1, 282 ) = 879.269 
C      henke(14,2, 282 ) = 13.006 
C      henke(14,3, 282 ) = 1.2575 
C      henke(14,1, 283 ) = 893.491 
C      henke(14,2, 283 ) = 12.9893 
C      henke(14,3, 283 ) = 1.22577 
C      henke(14,1, 284 ) = 907.943 
C      henke(14,2, 284 ) = 12.9723 
C      henke(14,3, 284 ) = 1.19483 
C      henke(14,1, 285 ) = 922.628 
C      henke(14,2, 285 ) = 12.9557 
C      henke(14,3, 285 ) = 1.16468 
C      henke(14,1, 286 ) = 937.551 
C      henke(14,2, 286 ) = 12.9384 
C      henke(14,3, 286 ) = 1.13279 
C      henke(14,1, 287 ) = 952.715 
C      henke(14,2, 287 ) = 12.9191 
C      henke(14,3, 287 ) = 1.10153 
C      henke(14,1, 288 ) = 968.124 
C      henke(14,2, 288 ) = 12.8974 
C      henke(14,3, 288 ) = 1.07112 
C      henke(14,1, 289 ) = 983.783 
C      henke(14,2, 289 ) = 12.8721 
C      henke(14,3, 289 ) = 1.04156 
C      henke(14,1, 290 ) = 999.695 
C      henke(14,2, 290 ) = 12.8413 
C      henke(14,3, 290 ) = 1.02154 
C      henke(14,1, 291 ) = 1015.86 
C      henke(14,2, 291 ) = 12.8267 
C      henke(14,3, 291 ) = 1.01556 
C      henke(14,1, 292 ) = 1032.29 
C      henke(14,2, 292 ) = 12.8151 
C      henke(14,3, 292 ) = 0.989441 
C      henke(14,1, 293 ) = 1048.99 
C      henke(14,2, 293 ) = 12.799 
C      henke(14,3, 293 ) = 0.963824 
C      henke(14,1, 294 ) = 1065.96 
C      henke(14,2, 294 ) = 12.7807 
C      henke(14,3, 294 ) = 0.938869 
C      henke(14,1, 295 ) = 1083.2 
C      henke(14,2, 295 ) = 12.761 
C      henke(14,3, 295 ) = 0.914561 
C      henke(14,1, 296 ) = 1100.72 
C      henke(14,2, 296 ) = 12.7404 
C      henke(14,3, 296 ) = 0.890814 
C      henke(14,1, 297 ) = 1118.52 
C      henke(14,2, 297 ) = 12.7187 
C      henke(14,3, 297 ) = 0.867595 
C      henke(14,1, 298 ) = 1136.61 
C      henke(14,2, 298 ) = 12.696 
C      henke(14,3, 298 ) = 0.844924 
C      henke(14,1, 299 ) = 1155 
C      henke(14,2, 299 ) = 12.6723 
C      henke(14,3, 299 ) = 0.822849 
C      henke(14,1, 300 ) = 1173.68 
C      henke(14,2, 300 ) = 12.6476 
C      henke(14,3, 300 ) = 0.801358 
C      henke(14,1, 301 ) = 1192.66 
C      henke(14,2, 301 ) = 12.6219 
C      henke(14,3, 301 ) = 0.780403 
C      henke(14,1, 302 ) = 1211.95 
C      henke(14,2, 302 ) = 12.5951 
C      henke(14,3, 302 ) = 0.75995 
C      henke(14,1, 303 ) = 1231.55 
C      henke(14,2, 303 ) = 12.5671 
C      henke(14,3, 303 ) = 0.739972 
C      henke(14,1, 304 ) = 1251.47 
C      henke(14,2, 304 ) = 12.5377 
C      henke(14,3, 304 ) = 0.72052 
C      henke(14,1, 305 ) = 1271.72 
C      henke(14,2, 305 ) = 12.5069 
C      henke(14,3, 305 ) = 0.701583 
C      henke(14,1, 306 ) = 1292.29 
C      henke(14,2, 306 ) = 12.4746 
C      henke(14,3, 306 ) = 0.683145 
C      henke(14,1, 307 ) = 1313.19 
C      henke(14,2, 307 ) = 12.4406 
C      henke(14,3, 307 ) = 0.665035 
C      henke(14,1, 308 ) = 1334.43 
C      henke(14,2, 308 ) = 12.4046 
C      henke(14,3, 308 ) = 0.647377 
C      henke(14,1, 309 ) = 1356.01 
C      henke(14,2, 309 ) = 12.3663 
C      henke(14,3, 309 ) = 0.630164 
C      henke(14,1, 310 ) = 1377.94 
C      henke(14,2, 310 ) = 12.3257 
C      henke(14,3, 310 ) = 0.613411 
C      henke(14,1, 311 ) = 1400.23 
C      henke(14,2, 311 ) = 12.2824 
C      henke(14,3, 311 ) = 0.597063 
C      henke(14,1, 312 ) = 1422.88 
C      henke(14,2, 312 ) = 12.2359 
C      henke(14,3, 312 ) = 0.581081 
C      henke(14,1, 313 ) = 1445.89 
C      henke(14,2, 313 ) = 12.1858 
C      henke(14,3, 313 ) = 0.565493 
C      henke(14,1, 314 ) = 1469.28 
C      henke(14,2, 314 ) = 12.1317 
C      henke(14,3, 314 ) = 0.550319 
C      henke(14,1, 315 ) = 1493.04 
C      henke(14,2, 315 ) = 12.0729 
C      henke(14,3, 315 ) = 0.535553 
C      henke(14,1, 316 ) = 1517.19 
C      henke(14,2, 316 ) = 12.0084 
C      henke(14,3, 316 ) = 0.520574 
C      henke(14,1, 317 ) = 1541.73 
C      henke(14,2, 317 ) = 11.9368 
C      henke(14,3, 317 ) = 0.5059 
C      henke(14,1, 318 ) = 1566.67 
C      henke(14,2, 318 ) = 11.8567 
C      henke(14,3, 318 ) = 0.491586 
C      henke(14,1, 319 ) = 1592.01 
C      henke(14,2, 319 ) = 11.7663 
C      henke(14,3, 319 ) = 0.477683 
C      henke(14,1, 320 ) = 1617.76 
C      henke(14,2, 320 ) = 11.6631 
C      henke(14,3, 320 ) = 0.464172 
C      henke(14,1, 321 ) = 1643.92 
C      henke(14,2, 321 ) = 11.5433 
C      henke(14,3, 321 ) = 0.451037 
C      henke(14,1, 322 ) = 1670.51 
C      henke(14,2, 322 ) = 11.4015 
C      henke(14,3, 322 ) = 0.438275 
C      henke(14,1, 323 ) = 1697.53 
C      henke(14,2, 323 ) = 11.2291 
C      henke(14,3, 323 ) = 0.425876 
C      henke(14,1, 324 ) = 1724.99 
C      henke(14,2, 324 ) = 11.0117 
C      henke(14,3, 324 ) = 0.41383 
C      henke(14,1, 325 ) = 1752.89 
C      henke(14,2, 325 ) = 10.7215 
C      henke(14,3, 325 ) = 0.401672 
C      henke(14,1, 326 ) = 1781.24 
C      henke(14,2, 326 ) = 10.2954 
C      henke(14,3, 326 ) = 0.389718 
C      henke(14,1, 327 ) = 1810.05 
C      henke(14,2, 327 ) = 9.52841 
C      henke(14,3, 327 ) = 0.378002 
C      henke(14,1, 328 ) = 1838.8 
C      henke(14,2, 328 ) = 2.79347 
C      henke(14,3, 328 ) = 0.366838 
C      henke(14,1, 329 ) = 1839 
C      henke(14,2, 329 ) = 2.79516 
C      henke(14,3, 329 ) = 4.15734 
C      henke(14,1, 330 ) = 1839.32 
C      henke(14,2, 330 ) = 4.53985 
C      henke(14,3, 330 ) = 4.15632 
C      henke(14,1, 331 ) = 1869.07 
C      henke(14,2, 331 ) = 9.78497 
C      henke(14,3, 331 ) = 4.06452 
C      henke(14,1, 332 ) = 1899.3 
C      henke(14,2, 332 ) = 10.6846 
C      henke(14,3, 332 ) = 3.97475 
C      henke(14,1, 333 ) = 1930.02 
C      henke(14,2, 333 ) = 11.2284 
C      henke(14,3, 333 ) = 3.88688 
C      henke(14,1, 334 ) = 1961.24 
C      henke(14,2, 334 ) = 11.6218 
C      henke(14,3, 334 ) = 3.80093 
C      henke(14,1, 335 ) = 1992.96 
C      henke(14,2, 335 ) = 11.9302 
C      henke(14,3, 335 ) = 3.71688 
C      henke(14,1, 336 ) = 2025.2 
C      henke(14,2, 336 ) = 12.1875 
C      henke(14,3, 336 ) = 3.63698 
C      henke(14,1, 337 ) = 2057.95 
C      henke(14,2, 337 ) = 12.4066 
C      henke(14,3, 337 ) = 3.55385 
C      henke(14,1, 338 ) = 2091.24 
C      henke(14,2, 338 ) = 12.5951 
C      henke(14,3, 338 ) = 3.47181 
C      henke(14,1, 339 ) = 2125.06 
C      henke(14,2, 339 ) = 12.7607 
C      henke(14,3, 339 ) = 3.39095 
C      henke(14,1, 340 ) = 2159.43 
C      henke(14,2, 340 ) = 12.9076 
C      henke(14,3, 340 ) = 3.31123 
C      henke(14,1, 341 ) = 2194.36 
C      henke(14,2, 341 ) = 13.0391 
C      henke(14,3, 341 ) = 3.23274 
C      henke(14,1, 342 ) = 2229.85 
C      henke(14,2, 342 ) = 13.1577 
C      henke(14,3, 342 ) = 3.15553 
C      henke(14,1, 343 ) = 2265.92 
C      henke(14,2, 343 ) = 13.2651 
C      henke(14,3, 343 ) = 3.07956 
C      henke(14,1, 344 ) = 2302.57 
C      henke(14,2, 344 ) = 13.363 
C      henke(14,3, 344 ) = 3.00498 
C      henke(14,1, 345 ) = 2339.81 
C      henke(14,2, 345 ) = 13.4523 
C      henke(14,3, 345 ) = 2.93157 
C      henke(14,1, 346 ) = 2377.66 
C      henke(14,2, 346 ) = 13.5341 
C      henke(14,3, 346 ) = 2.85938 
C      henke(14,1, 347 ) = 2416.11 
C      henke(14,2, 347 ) = 13.6092 
C      henke(14,3, 347 ) = 2.78864 
C      henke(14,1, 348 ) = 2455.19 
C      henke(14,2, 348 ) = 13.6782 
C      henke(14,3, 348 ) = 2.71913 
C      henke(14,1, 349 ) = 2494.9 
C      henke(14,2, 349 ) = 13.7417 
C      henke(14,3, 349 ) = 2.65099 
C      henke(14,1, 350 ) = 2535.26 
C      henke(14,2, 350 ) = 13.8002 
C      henke(14,3, 350 ) = 2.58417 
C      henke(14,1, 351 ) = 2576.26 
C      henke(14,2, 351 ) = 13.8543 
C      henke(14,3, 351 ) = 2.51869 
C      henke(14,1, 352 ) = 2617.93 
C      henke(14,2, 352 ) = 13.9042 
C      henke(14,3, 352 ) = 2.45445 
C      henke(14,1, 353 ) = 2660.27 
C      henke(14,2, 353 ) = 13.9503 
C      henke(14,3, 353 ) = 2.39148 
C      henke(14,1, 354 ) = 2703.3 
C      henke(14,2, 354 ) = 13.9928 
C      henke(14,3, 354 ) = 2.32994 
C      henke(14,1, 355 ) = 2747.03 
C      henke(14,2, 355 ) = 14.0321 
C      henke(14,3, 355 ) = 2.26955 
C      henke(14,1, 356 ) = 2791.46 
C      henke(14,2, 356 ) = 14.0682 
C      henke(14,3, 356 ) = 2.21044 
C      henke(14,1, 357 ) = 2836.61 
C      henke(14,2, 357 ) = 14.1017 
C      henke(14,3, 357 ) = 2.15277 
C      henke(14,1, 358 ) = 2882.49 
C      henke(14,2, 358 ) = 14.1326 
C      henke(14,3, 358 ) = 2.0962 
C      henke(14,1, 359 ) = 2929.11 
C      henke(14,2, 359 ) = 14.161 
C      henke(14,3, 359 ) = 2.04085 
C      henke(14,1, 360 ) = 2976.48 
C      henke(14,2, 360 ) = 14.1871 
C      henke(14,3, 360 ) = 1.98681 
C      henke(14,1, 361 ) = 3024.63 
C      henke(14,2, 361 ) = 14.2112 
C      henke(14,3, 361 ) = 1.93399 
C      henke(14,1, 362 ) = 3073.55 
C      henke(14,2, 362 ) = 14.2332 
C      henke(14,3, 362 ) = 1.88234 
C      henke(14,1, 363 ) = 3123.26 
C      henke(14,2, 363 ) = 14.2535 
C      henke(14,3, 363 ) = 1.83187 
C      henke(14,1, 364 ) = 3173.78 
C      henke(14,2, 364 ) = 14.272 
C      henke(14,3, 364 ) = 1.78256 
C      henke(14,1, 365 ) = 3225.11 
C      henke(14,2, 365 ) = 14.2889 
C      henke(14,3, 365 ) = 1.73442 
C      henke(14,1, 366 ) = 3277.27 
C      henke(14,2, 366 ) = 14.3043 
C      henke(14,3, 366 ) = 1.68741 
C      henke(14,1, 367 ) = 3330.28 
C      henke(14,2, 367 ) = 14.3182 
C      henke(14,3, 367 ) = 1.6415 
C      henke(14,1, 368 ) = 3384.15 
C      henke(14,2, 368 ) = 14.3309 
C      henke(14,3, 368 ) = 1.59669 
C      henke(14,1, 369 ) = 3438.88 
C      henke(14,2, 369 ) = 14.3423 
C      henke(14,3, 369 ) = 1.55296 
C      henke(14,1, 370 ) = 3494.5 
C      henke(14,2, 370 ) = 14.3525 
C      henke(14,3, 370 ) = 1.51031 
C      henke(14,1, 371 ) = 3551.02 
C      henke(14,2, 371 ) = 14.3616 
C      henke(14,3, 371 ) = 1.46867 
C      henke(14,1, 372 ) = 3608.46 
C      henke(14,2, 372 ) = 14.3698 
C      henke(14,3, 372 ) = 1.42807 
C      henke(14,1, 373 ) = 3666.82 
C      henke(14,2, 373 ) = 14.3769 
C      henke(14,3, 373 ) = 1.38848 
C      henke(14,1, 374 ) = 3726.13 
C      henke(14,2, 374 ) = 14.3831 
C      henke(14,3, 374 ) = 1.34989 
C      henke(14,1, 375 ) = 3786.4 
C      henke(14,2, 375 ) = 14.3886 
C      henke(14,3, 375 ) = 1.31225 
C      henke(14,1, 376 ) = 3847.64 
C      henke(14,2, 376 ) = 14.3932 
C      henke(14,3, 376 ) = 1.27555 
C      henke(14,1, 377 ) = 3909.87 
C      henke(14,2, 377 ) = 14.397 
C      henke(14,3, 377 ) = 1.23979 
C      henke(14,1, 378 ) = 3973.11 
C      henke(14,2, 378 ) = 14.4002 
C      henke(14,3, 378 ) = 1.20495 
C      henke(14,1, 379 ) = 4037.38 
C      henke(14,2, 379 ) = 14.4027 
C      henke(14,3, 379 ) = 1.171 
C      henke(14,1, 380 ) = 4102.68 
C      henke(14,2, 380 ) = 14.4046 
C      henke(14,3, 380 ) = 1.13791 
C      henke(14,1, 381 ) = 4169.03 
C      henke(14,2, 381 ) = 14.406 
C      henke(14,3, 381 ) = 1.10569 
C      henke(14,1, 382 ) = 4236.46 
C      henke(14,2, 382 ) = 14.4068 
C      henke(14,3, 382 ) = 1.07432 
C      henke(14,1, 383 ) = 4304.98 
C      henke(14,2, 383 ) = 14.4071 
C      henke(14,3, 383 ) = 1.04375 
C      henke(14,1, 384 ) = 4374.62 
C      henke(14,2, 384 ) = 14.4069 
C      henke(14,3, 384 ) = 1.01398 
C      henke(14,1, 385 ) = 4445.37 
C      henke(14,2, 385 ) = 14.4064 
C      henke(14,3, 385 ) = 0.985008 
C      henke(14,1, 386 ) = 4517.27 
C      henke(14,2, 386 ) = 14.4054 
C      henke(14,3, 386 ) = 0.956808 
C      henke(14,1, 387 ) = 4590.33 
C      henke(14,2, 387 ) = 14.404 
C      henke(14,3, 387 ) = 0.929335 
C      henke(14,1, 388 ) = 4664.58 
C      henke(14,2, 388 ) = 14.4023 
C      henke(14,3, 388 ) = 0.902611 
C      henke(14,1, 389 ) = 4740.03 
C      henke(14,2, 389 ) = 14.4002 
C      henke(14,3, 389 ) = 0.876592 
C      henke(14,1, 390 ) = 4816.69 
C      henke(14,2, 390 ) = 14.3979 
C      henke(14,3, 390 ) = 0.851289 
C      henke(14,1, 391 ) = 4894.6 
C      henke(14,2, 391 ) = 14.3953 
C      henke(14,3, 391 ) = 0.826671 
C      henke(14,1, 392 ) = 4973.77 
C      henke(14,2, 392 ) = 14.3924 
C      henke(14,3, 392 ) = 0.8027 
C      henke(14,1, 393 ) = 5054.21 
C      henke(14,2, 393 ) = 14.3893 
C      henke(14,3, 393 ) = 0.779406 
C      henke(14,1, 394 ) = 5135.96 
C      henke(14,2, 394 ) = 14.386 
C      henke(14,3, 394 ) = 0.756713 
C      henke(14,1, 395 ) = 5219.03 
C      henke(14,2, 395 ) = 14.3824 
C      henke(14,3, 395 ) = 0.734648 
C      henke(14,1, 396 ) = 5303.44 
C      henke(14,2, 396 ) = 14.3787 
C      henke(14,3, 396 ) = 0.713218 
C      henke(14,1, 397 ) = 5389.22 
C      henke(14,2, 397 ) = 14.3748 
C      henke(14,3, 397 ) = 0.692353 
C      henke(14,1, 398 ) = 5476.39 
C      henke(14,2, 398 ) = 14.3708 
C      henke(14,3, 398 ) = 0.672068 
C      henke(14,1, 399 ) = 5564.97 
C      henke(14,2, 399 ) = 14.3666 
C      henke(14,3, 399 ) = 0.652358 
C      henke(14,1, 400 ) = 5654.98 
C      henke(14,2, 400 ) = 14.3623 
C      henke(14,3, 400 ) = 0.633172 
C      henke(14,1, 401 ) = 5746.44 
C      henke(14,2, 401 ) = 14.3579 
C      henke(14,3, 401 ) = 0.614532 
C      henke(14,1, 402 ) = 5839.39 
C      henke(14,2, 402 ) = 14.3533 
C      henke(14,3, 402 ) = 0.596422 
C      henke(14,1, 403 ) = 5933.83 
C      henke(14,2, 403 ) = 14.3487 
C      henke(14,3, 403 ) = 0.578825 
C      henke(14,1, 404 ) = 6029.81 
C      henke(14,2, 404 ) = 14.3441 
C      henke(14,3, 404 ) = 0.561692 
C      henke(14,1, 405 ) = 6127.33 
C      henke(14,2, 405 ) = 14.3393 
C      henke(14,3, 405 ) = 0.545062 
C      henke(14,1, 406 ) = 6226.44 
C      henke(14,2, 406 ) = 14.3345 
C      henke(14,3, 406 ) = 0.528895 
C      henke(14,1, 407 ) = 6327.15 
C      henke(14,2, 407 ) = 14.3296 
C      henke(14,3, 407 ) = 0.513197 
C      henke(14,1, 408 ) = 6429.48 
C      henke(14,2, 408 ) = 14.3247 
C      henke(14,3, 408 ) = 0.497896 
C      henke(14,1, 409 ) = 6533.48 
C      henke(14,2, 409 ) = 14.3198 
C      henke(14,3, 409 ) = 0.483093 
C      henke(14,1, 410 ) = 6639.15 
C      henke(14,2, 410 ) = 14.3148 
C      henke(14,3, 410 ) = 0.468675 
C      henke(14,1, 411 ) = 6746.54 
C      henke(14,2, 411 ) = 14.3098 
C      henke(14,3, 411 ) = 0.454668 
C      henke(14,1, 412 ) = 6855.65 
C      henke(14,2, 412 ) = 14.3048 
C      henke(14,3, 412 ) = 0.441069 
C      henke(14,1, 413 ) = 6966.54 
C      henke(14,2, 413 ) = 14.2998 
C      henke(14,3, 413 ) = 0.427861 
C      henke(14,1, 414 ) = 7079.22 
C      henke(14,2, 414 ) = 14.2948 
C      henke(14,3, 414 ) = 0.415029 
C      henke(14,1, 415 ) = 7193.72 
C      henke(14,2, 415 ) = 14.2898 
C      henke(14,3, 415 ) = 0.402564 
C      henke(14,1, 416 ) = 7310.07 
C      henke(14,2, 416 ) = 14.2847 
C      henke(14,3, 416 ) = 0.390462 
C      henke(14,1, 417 ) = 7428.31 
C      henke(14,2, 417 ) = 14.2798 
C      henke(14,3, 417 ) = 0.378704 
C      henke(14,1, 418 ) = 7548.45 
C      henke(14,2, 418 ) = 14.2748 
C      henke(14,3, 418 ) = 0.367289 
C      henke(14,1, 419 ) = 7670.54 
C      henke(14,2, 419 ) = 14.2698 
C      henke(14,3, 419 ) = 0.356207 
C      henke(14,1, 420 ) = 7794.61 
C      henke(14,2, 420 ) = 14.2649 
C      henke(14,3, 420 ) = 0.345446 
C      henke(14,1, 421 ) = 7920.68 
C      henke(14,2, 421 ) = 14.26 
C      henke(14,3, 421 ) = 0.334993 
C      henke(14,1, 422 ) = 8048.79 
C      henke(14,2, 422 ) = 14.2551 
C      henke(14,3, 422 ) = 0.324848 
C      henke(14,1, 423 ) = 8178.98 
C      henke(14,2, 423 ) = 14.2503 
C      henke(14,3, 423 ) = 0.314994 
C      henke(14,1, 424 ) = 8311.26 
C      henke(14,2, 424 ) = 14.2455 
C      henke(14,3, 424 ) = 0.305432 
C      henke(14,1, 425 ) = 8445.69 
C      henke(14,2, 425 ) = 14.2407 
C      henke(14,3, 425 ) = 0.296153 
C      henke(14,1, 426 ) = 8582.29 
C      henke(14,2, 426 ) = 14.236 
C      henke(14,3, 426 ) = 0.287138 
C      henke(14,1, 427 ) = 8721.11 
C      henke(14,2, 427 ) = 14.2313 
C      henke(14,3, 427 ) = 0.278388 
C      henke(14,1, 428 ) = 8862.16 
C      henke(14,2, 428 ) = 14.2267 
C      henke(14,3, 428 ) = 0.269899 
C      henke(14,1, 429 ) = 9005.5 
C      henke(14,2, 429 ) = 14.2221 
C      henke(14,3, 429 ) = 0.261658 
C      henke(14,1, 430 ) = 9151.16 
C      henke(14,2, 430 ) = 14.2176 
C      henke(14,3, 430 ) = 0.25366 
C      henke(14,1, 431 ) = 9299.17 
C      henke(14,2, 431 ) = 14.2131 
C      henke(14,3, 431 ) = 0.245895 
C      henke(14,1, 432 ) = 9449.58 
C      henke(14,2, 432 ) = 14.2086 
C      henke(14,3, 432 ) = 0.238363 
C      henke(14,1, 433 ) = 9602.42 
C      henke(14,2, 433 ) = 14.2043 
C      henke(14,3, 433 ) = 0.23105 
C      henke(14,1, 434 ) = 9757.73 
C      henke(14,2, 434 ) = 14.1999 
C      henke(14,3, 434 ) = 0.223956 
C      henke(14,1, 435 ) = 9915.55 
C      henke(14,2, 435 ) = 14.1957 
C      henke(14,3, 435 ) = 0.21707 
C      henke(14,1, 436 ) = 10075.9 
C      henke(14,2, 436 ) = 14.1914 
C      henke(14,3, 436 ) = 0.21039 
C      henke(14,1, 437 ) = 10238.9 
C      henke(14,2, 437 ) = 14.1873 
C      henke(14,3, 437 ) = 0.203909 
C      henke(14,1, 438 ) = 10404.5 
C      henke(14,2, 438 ) = 14.1832 
C      henke(14,3, 438 ) = 0.19762 
C      henke(14,1, 439 ) = 10572.8 
C      henke(14,2, 439 ) = 14.1792 
C      henke(14,3, 439 ) = 0.191518 
C      henke(14,1, 440 ) = 10743.8 
C      henke(14,2, 440 ) = 14.1752 
C      henke(14,3, 440 ) = 0.185598 
C      henke(14,1, 441 ) = 10917.6 
C      henke(14,2, 441 ) = 14.1712 
C      henke(14,3, 441 ) = 0.179855 
C      henke(14,1, 442 ) = 11094.2 
C      henke(14,2, 442 ) = 14.1674 
C      henke(14,3, 442 ) = 0.174283 
C      henke(14,1, 443 ) = 11273.6 
C      henke(14,2, 443 ) = 14.1636 
C      henke(14,3, 443 ) = 0.168878 
C      henke(14,1, 444 ) = 11455.9 
C      henke(14,2, 444 ) = 14.1598 
C      henke(14,3, 444 ) = 0.163634 
C      henke(14,1, 445 ) = 11641.2 
C      henke(14,2, 445 ) = 14.1561 
C      henke(14,3, 445 ) = 0.158548 
C      henke(14,1, 446 ) = 11829.5 
C      henke(14,2, 446 ) = 14.1525 
C      henke(14,3, 446 ) = 0.153614 
C      henke(14,1, 447 ) = 12020.8 
C      henke(14,2, 447 ) = 14.1489 
C      henke(14,3, 447 ) = 0.148828 
C      henke(14,1, 448 ) = 12215.3 
C      henke(14,2, 448 ) = 14.1454 
C      henke(14,3, 448 ) = 0.144186 
C      henke(14,1, 449 ) = 12412.8 
C      henke(14,2, 449 ) = 14.142 
C      henke(14,3, 449 ) = 0.139684 
C      henke(14,1, 450 ) = 12613.6 
C      henke(14,2, 450 ) = 14.1386 
C      henke(14,3, 450 ) = 0.135317 
C      henke(14,1, 451 ) = 12817.6 
C      henke(14,2, 451 ) = 14.1353 
C      henke(14,3, 451 ) = 0.131082 
C      henke(14,1, 452 ) = 13025 
C      henke(14,2, 452 ) = 14.132 
C      henke(14,3, 452 ) = 0.126975 
C      henke(14,1, 453 ) = 13235.6 
C      henke(14,2, 453 ) = 14.1288 
C      henke(14,3, 453 ) = 0.122991 
C      henke(14,1, 454 ) = 13449.7 
C      henke(14,2, 454 ) = 14.1256 
C      henke(14,3, 454 ) = 0.119128 
C      henke(14,1, 455 ) = 13667.2 
C      henke(14,2, 455 ) = 14.1225 
C      henke(14,3, 455 ) = 0.115381 
C      henke(14,1, 456 ) = 13888.3 
C      henke(14,2, 456 ) = 14.1194 
C      henke(14,3, 456 ) = 0.111748 
C      henke(14,1, 457 ) = 14112.9 
C      henke(14,2, 457 ) = 14.1165 
C      henke(14,3, 457 ) = 0.108225 
C      henke(14,1, 458 ) = 14341.2 
C      henke(14,2, 458 ) = 14.1135 
C      henke(14,3, 458 ) = 0.104809 
C      henke(14,1, 459 ) = 14573.1 
C      henke(14,2, 459 ) = 14.1106 
C      henke(14,3, 459 ) = 0.101496 
C      henke(14,1, 460 ) = 14808.9 
C      henke(14,2, 460 ) = 14.1078 
C      henke(14,3, 460 ) = 0.0982836 
C      henke(14,1, 461 ) = 15048.4 
C      henke(14,2, 461 ) = 14.105 
C      henke(14,3, 461 ) = 0.0951689 
C      henke(14,1, 462 ) = 15291.8 
C      henke(14,2, 462 ) = 14.1023 
C      henke(14,3, 462 ) = 0.0921489 
C      henke(14,1, 463 ) = 15539.1 
C      henke(14,2, 463 ) = 14.0996 
C      henke(14,3, 463 ) = 0.0892208 
C      henke(14,1, 464 ) = 15790.4 
C      henke(14,2, 464 ) = 14.097 
C      henke(14,3, 464 ) = 0.0863817 
C      henke(14,1, 465 ) = 16045.8 
C      henke(14,2, 465 ) = 14.0945 
C      henke(14,3, 465 ) = 0.0836291 
C      henke(14,1, 466 ) = 16305.4 
C      henke(14,2, 466 ) = 14.0919 
C      henke(14,3, 466 ) = 0.0809604 
C      henke(14,1, 467 ) = 16569.1 
C      henke(14,2, 467 ) = 14.0895 
C      henke(14,3, 467 ) = 0.0783731 
C      henke(14,1, 468 ) = 16837.1 
C      henke(14,2, 468 ) = 14.087 
C      henke(14,3, 468 ) = 0.0758647 
C      henke(14,1, 469 ) = 17109.4 
C      henke(14,2, 469 ) = 14.0847 
C      henke(14,3, 469 ) = 0.073433 
C      henke(14,1, 470 ) = 17386.1 
C      henke(14,2, 470 ) = 14.0824 
C      henke(14,3, 470 ) = 0.0710755 
C      henke(14,1, 471 ) = 17667.4 
C      henke(14,2, 471 ) = 14.0801 
C      henke(14,3, 471 ) = 0.0687901 
C      henke(14,1, 472 ) = 17953.1 
C      henke(14,2, 472 ) = 14.0779 
C      henke(14,3, 472 ) = 0.0665747 
C      henke(14,1, 473 ) = 18243.5 
C      henke(14,2, 473 ) = 14.0757 
C      henke(14,3, 473 ) = 0.064427 
C      henke(14,1, 474 ) = 18538.6 
C      henke(14,2, 474 ) = 14.0735 
C      henke(14,3, 474 ) = 0.0623451 
C      henke(14,1, 475 ) = 18838.4 
C      henke(14,2, 475 ) = 14.0714 
C      henke(14,3, 475 ) = 0.060327 
C      henke(14,1, 476 ) = 19143.1 
C      henke(14,2, 476 ) = 14.0694 
C      henke(14,3, 476 ) = 0.0583708 
C      henke(14,1, 477 ) = 19452.7 
C      henke(14,2, 477 ) = 14.0674 
C      henke(14,3, 477 ) = 0.0564747 
C      henke(14,1, 478 ) = 19767.4 
C      henke(14,2, 478 ) = 14.0654 
C      henke(14,3, 478 ) = 0.0546367 
C      henke(14,1, 479 ) = 20087.1 
C      henke(14,2, 479 ) = 14.0635 
C      henke(14,3, 479 ) = 0.0528536 
C      henke(14,1, 480 ) = 20412 
C      henke(14,2, 480 ) = 14.0616 
C      henke(14,3, 480 ) = 0.0511283 
C      henke(14,1, 481 ) = 20742.1 
C      henke(14,2, 481 ) = 14.0597 
C      henke(14,3, 481 ) = 0.049458 
C      henke(14,1, 482 ) = 21077.6 
C      henke(14,2, 482 ) = 14.0579 
C      henke(14,3, 482 ) = 0.0478407 
C      henke(14,1, 483 ) = 21418.5 
C      henke(14,2, 483 ) = 14.0561 
C      henke(14,3, 483 ) = 0.0462752 
C      henke(14,1, 484 ) = 21765 
C      henke(14,2, 484 ) = 14.0544 
C      henke(14,3, 484 ) = 0.0447595 
C      henke(14,1, 485 ) = 22117 
C      henke(14,2, 485 ) = 14.0527 
C      henke(14,3, 485 ) = 0.0432922 
C      henke(14,1, 486 ) = 22474.7 
C      henke(14,2, 486 ) = 14.051 
C      henke(14,3, 486 ) = 0.0418718 
C      henke(14,1, 487 ) = 22838.2 
C      henke(14,2, 487 ) = 14.0494 
C      henke(14,3, 487 ) = 0.0404967 
C      henke(14,1, 488 ) = 23207.6 
C      henke(14,2, 488 ) = 14.0478 
C      henke(14,3, 488 ) = 0.0391657 
C      henke(14,1, 489 ) = 23583 
C      henke(14,2, 489 ) = 14.0463 
C      henke(14,3, 489 ) = 0.0378772 
C      henke(14,1, 490 ) = 23964.4 
C      henke(14,2, 490 ) = 14.0448 
C      henke(14,3, 490 ) = 0.0366301 
C      henke(14,1, 491 ) = 24352 
C      henke(14,2, 491 ) = 14.0433 
C      henke(14,3, 491 ) = 0.0354228 
C      henke(14,1, 492 ) = 24745.9 
C      henke(14,2, 492 ) = 14.0418 
C      henke(14,3, 492 ) = 0.0342544 
C      henke(14,1, 493 ) = 25146.2 
C      henke(14,2, 493 ) = 14.0404 
C      henke(14,3, 493 ) = 0.0331234 
C      henke(14,1, 494 ) = 25552.9 
C      henke(14,2, 494 ) = 14.039 
C      henke(14,3, 494 ) = 0.0320287 
C      henke(14,1, 495 ) = 25966.2 
C      henke(14,2, 495 ) = 14.0377 
C      henke(14,3, 495 ) = 0.0309693 
C      henke(14,1, 496 ) = 26386.1 
C      henke(14,2, 496 ) = 14.0363 
C      henke(14,3, 496 ) = 0.0299439 
C      henke(14,1, 497 ) = 26812.9 
C      henke(14,2, 497 ) = 14.0351 
C      henke(14,3, 497 ) = 0.0289515 
C      henke(14,1, 498 ) = 27246.6 
C      henke(14,2, 498 ) = 14.0338 
C      henke(14,3, 498 ) = 0.0279911 
C      henke(14,1, 499 ) = 27687.3 
C      henke(14,2, 499 ) = 14.0326 
C      henke(14,3, 499 ) = 0.0270617 
C      henke(14,1, 500 ) = 28135.1 
C      henke(14,2, 500 ) = 14.0314 
C      henke(14,3, 500 ) = 0.0261622 
C      henke(14,1, 501 ) = 28590.2 
C      henke(14,2, 501 ) = 14.0302 
C      henke(14,3, 501 ) = 0.0252918 
C      henke(14,1, 502 ) = 29052.6 
C      henke(14,2, 502 ) = 14.029 
C      henke(14,3, 502 ) = 0.0244496 
C      henke(14,1, 503 ) = 29522.5 
C      henke(14,2, 503 ) = 14.0282 
C      henke(14,3, 503 ) = 0.0236345 
C      henke(14,1, 504 ) = 30000 
C      henke(14,2, 504 ) = 14.0266 
C      henke(14,3, 504 ) = 0.0228459 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C        Henke data for ir  z=77
C      count(77) = 515
C      henke(77,1, 1 ) = 10 
C      henke(77,2, 1 ) = -9999 
C      henke(77,3, 1 ) = 2.22753 
C      henke(77,1, 2 ) = 10.1617 
C      henke(77,2, 2 ) = -9999 
C      henke(77,3, 2 ) = 2.30683 
C      henke(77,1, 3 ) = 10.3261 
C      henke(77,2, 3 ) = -9999 
C      henke(77,3, 3 ) = 2.38895 
C      henke(77,1, 4 ) = 10.4931 
C      henke(77,2, 4 ) = -9999 
C      henke(77,3, 4 ) = 2.474 
C      henke(77,1, 5 ) = 10.6628 
C      henke(77,2, 5 ) = -9999 
C      henke(77,3, 5 ) = 2.56207 
C      henke(77,1, 6 ) = 10.8353 
C      henke(77,2, 6 ) = -9999 
C      henke(77,3, 6 ) = 2.65417 
C      henke(77,1, 7 ) = 11.0106 
C      henke(77,2, 7 ) = -9999 
C      henke(77,3, 7 ) = 2.75003 
C      henke(77,1, 8 ) = 11.1886 
C      henke(77,2, 8 ) = -9999 
C      henke(77,3, 8 ) = 2.84935 
C      henke(77,1, 9 ) = 11.3696 
C      henke(77,2, 9 ) = -9999 
C      henke(77,3, 9 ) = 2.94781 
C      henke(77,1, 10 ) = 11.5535 
C      henke(77,2, 10 ) = -9999 
C      henke(77,3, 10 ) = 3.0118 
C      henke(77,1, 11 ) = 11.7404 
C      henke(77,2, 11 ) = -9999 
C      henke(77,3, 11 ) = 3.07717 
C      henke(77,1, 12 ) = 11.9303 
C      henke(77,2, 12 ) = -9999 
C      henke(77,3, 12 ) = 3.14397 
C      henke(77,1, 13 ) = 12.1232 
C      henke(77,2, 13 ) = -9999 
C      henke(77,3, 13 ) = 3.21221 
C      henke(77,1, 14 ) = 12.3193 
C      henke(77,2, 14 ) = -9999 
C      henke(77,3, 14 ) = 3.26205 
C      henke(77,1, 15 ) = 12.5186 
C      henke(77,2, 15 ) = -9999 
C      henke(77,3, 15 ) = 3.30439 
C      henke(77,1, 16 ) = 12.721 
C      henke(77,2, 16 ) = -9999 
C      henke(77,3, 16 ) = 3.34729 
C      henke(77,1, 17 ) = 12.9268 
C      henke(77,2, 17 ) = -9999 
C      henke(77,3, 17 ) = 3.39074 
C      henke(77,1, 18 ) = 13.1359 
C      henke(77,2, 18 ) = -9999 
C      henke(77,3, 18 ) = 3.43476 
C      henke(77,1, 19 ) = 13.3483 
C      henke(77,2, 19 ) = -9999 
C      henke(77,3, 19 ) = 3.47696 
C      henke(77,1, 20 ) = 13.5642 
C      henke(77,2, 20 ) = -9999 
C      henke(77,3, 20 ) = 3.51962 
C      henke(77,1, 21 ) = 13.7836 
C      henke(77,2, 21 ) = -9999 
C      henke(77,3, 21 ) = 3.56281 
C      henke(77,1, 22 ) = 14.0066 
C      henke(77,2, 22 ) = -9999 
C      henke(77,3, 22 ) = 3.61496 
C      henke(77,1, 23 ) = 14.2331 
C      henke(77,2, 23 ) = -9999 
C      henke(77,3, 23 ) = 3.70069 
C      henke(77,1, 24 ) = 14.4633 
C      henke(77,2, 24 ) = -9999 
C      henke(77,3, 24 ) = 3.78846 
C      henke(77,1, 25 ) = 14.6973 
C      henke(77,2, 25 ) = -9999 
C      henke(77,3, 25 ) = 3.87831 
C      henke(77,1, 26 ) = 14.935 
C      henke(77,2, 26 ) = -9999 
C      henke(77,3, 26 ) = 3.97029 
C      henke(77,1, 27 ) = 15.1765 
C      henke(77,2, 27 ) = -9999 
C      henke(77,3, 27 ) = 4.07172 
C      henke(77,1, 28 ) = 15.422 
C      henke(77,2, 28 ) = -9999 
C      henke(77,3, 28 ) = 4.1956 
C      henke(77,1, 29 ) = 15.6714 
C      henke(77,2, 29 ) = -9999 
C      henke(77,3, 29 ) = 4.32325 
C      henke(77,1, 30 ) = 15.9249 
C      henke(77,2, 30 ) = -9999 
C      henke(77,3, 30 ) = 4.45478 
C      henke(77,1, 31 ) = 16.1825 
C      henke(77,2, 31 ) = -9999 
C      henke(77,3, 31 ) = 4.60711 
C      henke(77,1, 32 ) = 16.4442 
C      henke(77,2, 32 ) = -9999 
C      henke(77,3, 32 ) = 4.77331 
C      henke(77,1, 33 ) = 16.7102 
C      henke(77,2, 33 ) = -9999 
C      henke(77,3, 33 ) = 4.9455 
C      henke(77,1, 34 ) = 16.9805 
C      henke(77,2, 34 ) = -9999 
C      henke(77,3, 34 ) = 5.12391 
C      henke(77,1, 35 ) = 17.2551 
C      henke(77,2, 35 ) = -9999 
C      henke(77,3, 35 ) = 5.30875 
C      henke(77,1, 36 ) = 17.5342 
C      henke(77,2, 36 ) = -9999 
C      henke(77,3, 36 ) = 5.50602 
C      henke(77,1, 37 ) = 17.8178 
C      henke(77,2, 37 ) = -9999 
C      henke(77,3, 37 ) = 5.74269 
C      henke(77,1, 38 ) = 18.106 
C      henke(77,2, 38 ) = -9999 
C      henke(77,3, 38 ) = 5.98954 
C      henke(77,1, 39 ) = 18.3989 
C      henke(77,2, 39 ) = -9999 
C      henke(77,3, 39 ) = 6.24699 
C      henke(77,1, 40 ) = 18.6964 
C      henke(77,2, 40 ) = -9999 
C      henke(77,3, 40 ) = 6.51552 
C      henke(77,1, 41 ) = 18.9988 
C      henke(77,2, 41 ) = -9999 
C      henke(77,3, 41 ) = 6.748 
C      henke(77,1, 42 ) = 19.3061 
C      henke(77,2, 42 ) = -9999 
C      henke(77,3, 42 ) = 6.97561 
C      henke(77,1, 43 ) = 19.6184 
C      henke(77,2, 43 ) = -9999 
C      henke(77,3, 43 ) = 7.21091 
C      henke(77,1, 44 ) = 19.9357 
C      henke(77,2, 44 ) = -9999 
C      henke(77,3, 44 ) = 7.45414 
C      henke(77,1, 45 ) = 20.2582 
C      henke(77,2, 45 ) = -9999 
C      henke(77,3, 45 ) = 7.68496 
C      henke(77,1, 46 ) = 20.5858 
C      henke(77,2, 46 ) = -9999 
C      henke(77,3, 46 ) = 7.89057 
C      henke(77,1, 47 ) = 20.9188 
C      henke(77,2, 47 ) = -9999 
C      henke(77,3, 47 ) = 8.10168 
C      henke(77,1, 48 ) = 21.2571 
C      henke(77,2, 48 ) = -9999 
C      henke(77,3, 48 ) = 8.31844 
C      henke(77,1, 49 ) = 21.6009 
C      henke(77,2, 49 ) = -9999 
C      henke(77,3, 49 ) = 8.52534 
C      henke(77,1, 50 ) = 21.9503 
C      henke(77,2, 50 ) = -9999 
C      henke(77,3, 50 ) = 8.68506 
C      henke(77,1, 51 ) = 22.3053 
C      henke(77,2, 51 ) = -9999 
C      henke(77,3, 51 ) = 8.84777 
C      henke(77,1, 52 ) = 22.6661 
C      henke(77,2, 52 ) = -9999 
C      henke(77,3, 52 ) = 9.01353 
C      henke(77,1, 53 ) = 23.0327 
C      henke(77,2, 53 ) = -9999 
C      henke(77,3, 53 ) = 9.1824 
C      henke(77,1, 54 ) = 23.4053 
C      henke(77,2, 54 ) = -9999 
C      henke(77,3, 54 ) = 9.26201 
C      henke(77,1, 55 ) = 23.7838 
C      henke(77,2, 55 ) = -9999 
C      henke(77,3, 55 ) = 9.32872 
C      henke(77,1, 56 ) = 24.1685 
C      henke(77,2, 56 ) = -9999 
C      henke(77,3, 56 ) = 9.39591 
C      henke(77,1, 57 ) = 24.5594 
C      henke(77,2, 57 ) = -9999 
C      henke(77,3, 57 ) = 9.4636 
C      henke(77,1, 58 ) = 24.9566 
C      henke(77,2, 58 ) = -9999 
C      henke(77,3, 58 ) = 9.52948 
C      henke(77,1, 59 ) = 25.3603 
C      henke(77,2, 59 ) = -9999 
C      henke(77,3, 59 ) = 9.59091 
C      henke(77,1, 60 ) = 25.7705 
C      henke(77,2, 60 ) = -9999 
C      henke(77,3, 60 ) = 9.65272 
C      henke(77,1, 61 ) = 26.1873 
C      henke(77,2, 61 ) = -9999 
C      henke(77,3, 61 ) = 9.71494 
C      henke(77,1, 62 ) = 26.6109 
C      henke(77,2, 62 ) = -9999 
C      henke(77,3, 62 ) = 9.77755 
C      henke(77,1, 63 ) = 27.0413 
C      henke(77,2, 63 ) = -9999 
C      henke(77,3, 63 ) = 9.79801 
C      henke(77,1, 64 ) = 27.4786 
C      henke(77,2, 64 ) = -9999 
C      henke(77,3, 64 ) = 9.75976 
C      henke(77,1, 65 ) = 27.9231 
C      henke(77,2, 65 ) = -9999 
C      henke(77,3, 65 ) = 9.72165 
C      henke(77,1, 66 ) = 28.3747 
C      henke(77,2, 66 ) = -9999 
C      henke(77,3, 66 ) = 9.68369 
C      henke(77,1, 67 ) = 28.8337 
C      henke(77,2, 67 ) = -9999 
C      henke(77,3, 67 ) = 9.64587 
C      henke(77,1, 68 ) = 29.3 
C      henke(77,2, 68 ) = 6.72334 
C      henke(77,3, 68 ) = 9.60821 
C      henke(77,1, 69 ) = 29.7739 
C      henke(77,2, 69 ) = 6.99072 
C      henke(77,3, 69 ) = 9.55265 
C      henke(77,1, 70 ) = 30.2555 
C      henke(77,2, 70 ) = 7.24352 
C      henke(77,3, 70 ) = 9.41385 
C      henke(77,1, 71 ) = 30.7449 
C      henke(77,2, 71 ) = 7.4518 
C      henke(77,3, 71 ) = 9.27707 
C      henke(77,1, 72 ) = 31.2421 
C      henke(77,2, 72 ) = 7.64444 
C      henke(77,3, 72 ) = 9.14228 
C      henke(77,1, 73 ) = 31.7475 
C      henke(77,2, 73 ) = 7.84077 
C      henke(77,3, 73 ) = 9.00945 
C      henke(77,1, 74 ) = 32.2609 
C      henke(77,2, 74 ) = 8.06846 
C      henke(77,3, 74 ) = 8.83057 
C      henke(77,1, 75 ) = 32.7827 
C      henke(77,2, 75 ) = 8.23692 
C      henke(77,3, 75 ) = 8.54247 
C      henke(77,1, 76 ) = 33.313 
C      henke(77,2, 76 ) = 8.30087 
C      henke(77,3, 76 ) = 8.26376 
C      henke(77,1, 77 ) = 33.8518 
C      henke(77,2, 77 ) = 8.29295 
C      henke(77,3, 77 ) = 7.99415 
C      henke(77,1, 78 ) = 34.3993 
C      henke(77,2, 78 ) = 8.20921 
C      henke(77,3, 78 ) = 7.81682 
C      henke(77,1, 79 ) = 34.9557 
C      henke(77,2, 79 ) = 8.1614 
C      henke(77,3, 79 ) = 7.67421 
C      henke(77,1, 80 ) = 35.5211 
C      henke(77,2, 80 ) = 8.10373 
C      henke(77,3, 80 ) = 7.53419 
C      henke(77,1, 81 ) = 36.0956 
C      henke(77,2, 81 ) = 8.01446 
C      henke(77,3, 81 ) = 7.39673 
C      henke(77,1, 82 ) = 36.6794 
C      henke(77,2, 82 ) = 7.87488 
C      henke(77,3, 82 ) = 7.32637 
C      henke(77,1, 83 ) = 37.2727 
C      henke(77,2, 83 ) = 7.77655 
C      henke(77,3, 83 ) = 7.30348 
C      henke(77,1, 84 ) = 37.8755 
C      henke(77,2, 84 ) = 7.69669 
C      henke(77,3, 84 ) = 7.28067 
C      henke(77,1, 85 ) = 38.4882 
C      henke(77,2, 85 ) = 7.61697 
C      henke(77,3, 85 ) = 7.25791 
C      henke(77,1, 86 ) = 39.1107 
C      henke(77,2, 86 ) = 7.52223 
C      henke(77,3, 86 ) = 7.23524 
C      henke(77,1, 87 ) = 39.7432 
C      henke(77,2, 87 ) = 7.40242 
C      henke(77,3, 87 ) = 7.22018 
C      henke(77,1, 88 ) = 40.3861 
C      henke(77,2, 88 ) = 7.28098 
C      henke(77,3, 88 ) = 7.27384 
C      henke(77,1, 89 ) = 41.0393 
C      henke(77,2, 89 ) = 7.18442 
C      henke(77,3, 89 ) = 7.32791 
C      henke(77,1, 90 ) = 41.7031 
C      henke(77,2, 90 ) = 7.09193 
C      henke(77,3, 90 ) = 7.38238 
C      henke(77,1, 91 ) = 42.3776 
C      henke(77,2, 91 ) = 6.9955 
C      henke(77,3, 91 ) = 7.43725 
C      henke(77,1, 92 ) = 43.063 
C      henke(77,2, 92 ) = 6.88132 
C      henke(77,3, 92 ) = 7.49253 
C      henke(77,1, 93 ) = 43.7595 
C      henke(77,2, 93 ) = 6.74127 
C      henke(77,3, 93 ) = 7.57126 
C      henke(77,1, 94 ) = 44.4673 
C      henke(77,2, 94 ) = 6.60653 
C      henke(77,3, 94 ) = 7.66543 
C      henke(77,1, 95 ) = 45.1865 
C      henke(77,2, 95 ) = 6.45295 
C      henke(77,3, 95 ) = 7.76077 
C      henke(77,1, 96 ) = 45.9174 
C      henke(77,2, 96 ) = 6.25263 
C      henke(77,3, 96 ) = 7.85729 
C      henke(77,1, 97 ) = 46.66 
C      henke(77,2, 97 ) = 5.97893 
C      henke(77,3, 97 ) = 7.98694 
C      henke(77,1, 98 ) = 47.4147 
C      henke(77,2, 98 ) = 5.48975 
C      henke(77,3, 98 ) = 8.13775 
C      henke(77,1, 99 ) = 48.1816 
C      henke(77,2, 99 ) = 4.66401 
C      henke(77,3, 99 ) = 8.82385 
C      henke(77,1, 100 ) = 48.9609 
C      henke(77,2, 100 ) = 4.55534 
C      henke(77,3, 100 ) = 10.0722 
C      henke(77,1, 101 ) = 49.7528 
C      henke(77,2, 101 ) = 5.15089 
C      henke(77,3, 101 ) = 11.5471 
C      henke(77,1, 102 ) = 50.5576 
C      henke(77,2, 102 ) = 6.13179 
C      henke(77,3, 102 ) = 11.6384 
C      henke(77,1, 103 ) = 51.3753 
C      henke(77,2, 103 ) = 6.66397 
C      henke(77,3, 103 ) = 11.7304 
C      henke(77,1, 104 ) = 52.2062 
C      henke(77,2, 104 ) = 7.05904 
C      henke(77,3, 104 ) = 11.8232 
C      henke(77,1, 105 ) = 53.0506 
C      henke(77,2, 105 ) = 7.38759 
C      henke(77,3, 105 ) = 11.9167 
C      henke(77,1, 106 ) = 53.9087 
C      henke(77,2, 106 ) = 7.67541 
C      henke(77,3, 106 ) = 12.0109 
C      henke(77,1, 107 ) = 54.7806 
C      henke(77,2, 107 ) = 7.93458 
C      henke(77,3, 107 ) = 12.1059 
C      henke(77,1, 108 ) = 55.6667 
C      henke(77,2, 108 ) = 8.17061 
C      henke(77,3, 108 ) = 12.2016 
C      henke(77,1, 109 ) = 56.567 
C      henke(77,2, 109 ) = 8.38449 
C      henke(77,3, 109 ) = 12.298 
C      henke(77,1, 110 ) = 57.482 
C      henke(77,2, 110 ) = 8.5716 
C      henke(77,3, 110 ) = 12.3953 
C      henke(77,1, 111 ) = 58.4117 
C      henke(77,2, 111 ) = 8.71295 
C      henke(77,3, 111 ) = 12.4933 
C      henke(77,1, 112 ) = 59.3564 
C      henke(77,2, 112 ) = 8.75019 
C      henke(77,3, 112 ) = 12.6564 
C      henke(77,1, 113 ) = 60.3165 
C      henke(77,2, 113 ) = 8.84789 
C      henke(77,3, 113 ) = 13.0205 
C      henke(77,1, 114 ) = 61.2921 
C      henke(77,2, 114 ) = 9.03126 
C      henke(77,3, 114 ) = 13.395 
C      henke(77,1, 115 ) = 62.2834 
C      henke(77,2, 115 ) = 9.23405 
C      henke(77,3, 115 ) = 13.8208 
C      henke(77,1, 116 ) = 63.2908 
C      henke(77,2, 116 ) = 9.58538 
C      henke(77,3, 116 ) = 14.4146 
C      henke(77,1, 117 ) = 64.3145 
C      henke(77,2, 117 ) = 10.1685 
C      henke(77,3, 117 ) = 15.034 
C      henke(77,1, 118 ) = 65.3547 
C      henke(77,2, 118 ) = 11.086 
C      henke(77,3, 118 ) = 15.4537 
C      henke(77,1, 119 ) = 66.4118 
C      henke(77,2, 119 ) = 11.9541 
C      henke(77,3, 119 ) = 15.6977 
C      henke(77,1, 120 ) = 67.4859 
C      henke(77,2, 120 ) = 13.0309 
C      henke(77,3, 120 ) = 15.8904 
C      henke(77,1, 121 ) = 68.5775 
C      henke(77,2, 121 ) = 14.0673 
C      henke(77,3, 121 ) = 15.5224 
C      henke(77,1, 122 ) = 69.6867 
C      henke(77,2, 122 ) = 14.9278 
C      henke(77,3, 122 ) = 15.1628 
C      henke(77,1, 123 ) = 70.8138 
C      henke(77,2, 123 ) = 15.8426 
C      henke(77,3, 123 ) = 14.6264 
C      henke(77,1, 124 ) = 71.9591 
C      henke(77,2, 124 ) = 16.436 
C      henke(77,3, 124 ) = 13.8968 
C      henke(77,1, 125 ) = 73.123 
C      henke(77,2, 125 ) = 16.8343 
C      henke(77,3, 125 ) = 13.2036 
C      henke(77,1, 126 ) = 74.3057 
C      henke(77,2, 126 ) = 17.1096 
C      henke(77,3, 126 ) = 12.545 
C      henke(77,1, 127 ) = 75.5076 
C      henke(77,2, 127 ) = 17.2948 
C      henke(77,3, 127 ) = 11.9467 
C      henke(77,1, 128 ) = 76.7289 
C      henke(77,2, 128 ) = 17.422 
C      henke(77,3, 128 ) = 11.38 
C      henke(77,1, 129 ) = 77.9699 
C      henke(77,2, 129 ) = 17.4918 
C      henke(77,3, 129 ) = 10.8402 
C      henke(77,1, 130 ) = 79.231 
C      henke(77,2, 130 ) = 17.5039 
C      henke(77,3, 130 ) = 10.3259 
C      henke(77,1, 131 ) = 80.5125 
C      henke(77,2, 131 ) = 17.4509 
C      henke(77,3, 131 ) = 9.83611 
C      henke(77,1, 132 ) = 81.8147 
C      henke(77,2, 132 ) = 17.2939 
C      henke(77,3, 132 ) = 9.38831 
C      henke(77,1, 133 ) = 83.138 
C      henke(77,2, 133 ) = 17.1432 
C      henke(77,3, 133 ) = 9.13335 
C      henke(77,1, 134 ) = 84.4827 
C      henke(77,2, 134 ) = 17.0462 
C      henke(77,3, 134 ) = 8.88532 
C      henke(77,1, 135 ) = 85.8491 
C      henke(77,2, 135 ) = 16.9673 
C      henke(77,3, 135 ) = 8.64404 
C      henke(77,1, 136 ) = 87.2377 
C      henke(77,2, 136 ) = 16.8886 
C      henke(77,3, 136 ) = 8.40929 
C      henke(77,1, 137 ) = 88.6487 
C      henke(77,2, 137 ) = 16.8042 
C      henke(77,3, 137 ) = 8.18092 
C      henke(77,1, 138 ) = 90.0825 
C      henke(77,2, 138 ) = 16.706 
C      henke(77,3, 138 ) = 7.95875 
C      henke(77,1, 139 ) = 91.5395 
C      henke(77,2, 139 ) = 16.5772 
C      henke(77,3, 139 ) = 7.74263 
C      henke(77,1, 140 ) = 93.0201 
C      henke(77,2, 140 ) = 16.4456 
C      henke(77,3, 140 ) = 7.59762 
C      henke(77,1, 141 ) = 94.5246 
C      henke(77,2, 141 ) = 16.3386 
C      henke(77,3, 141 ) = 7.45957 
C      henke(77,1, 142 ) = 96.0535 
C      henke(77,2, 142 ) = 16.2389 
C      henke(77,3, 142 ) = 7.32402 
C      henke(77,1, 143 ) = 97.6071 
C      henke(77,2, 143 ) = 16.1407 
C      henke(77,3, 143 ) = 7.19093 
C      henke(77,1, 144 ) = 99.1858 
C      henke(77,2, 144 ) = 16.041 
C      henke(77,3, 144 ) = 7.06026 
C      henke(77,1, 145 ) = 100.79 
C      henke(77,2, 145 ) = 15.9382 
C      henke(77,3, 145 ) = 6.93197 
C      henke(77,1, 146 ) = 102.42 
C      henke(77,2, 146 ) = 15.8332 
C      henke(77,3, 146 ) = 6.80446 
C      henke(77,1, 147 ) = 104.077 
C      henke(77,2, 147 ) = 15.7165 
C      henke(77,3, 147 ) = 6.66951 
C      henke(77,1, 148 ) = 105.76 
C      henke(77,2, 148 ) = 15.5842 
C      henke(77,3, 148 ) = 6.53724 
C      henke(77,1, 149 ) = 107.471 
C      henke(77,2, 149 ) = 15.4346 
C      henke(77,3, 149 ) = 6.40758 
C      henke(77,1, 150 ) = 109.209 
C      henke(77,2, 150 ) = 15.2603 
C      henke(77,3, 150 ) = 6.28051 
C      henke(77,1, 151 ) = 110.975 
C      henke(77,2, 151 ) = 15.0366 
C      henke(77,3, 151 ) = 6.18486 
C      henke(77,1, 152 ) = 112.77 
C      henke(77,2, 152 ) = 14.8316 
C      henke(77,3, 152 ) = 6.12755 
C      henke(77,1, 153 ) = 114.594 
C      henke(77,2, 153 ) = 14.6295 
C      henke(77,3, 153 ) = 6.07076 
C      henke(77,1, 154 ) = 116.448 
C      henke(77,2, 154 ) = 14.4061 
C      henke(77,3, 154 ) = 6.01451 
C      henke(77,1, 155 ) = 118.331 
C      henke(77,2, 155 ) = 14.1093 
C      henke(77,3, 155 ) = 5.9974 
C      henke(77,1, 156 ) = 120.245 
C      henke(77,2, 156 ) = 13.8573 
C      henke(77,3, 156 ) = 6.05809 
C      henke(77,1, 157 ) = 122.19 
C      henke(77,2, 157 ) = 13.6358 
C      henke(77,3, 157 ) = 6.11939 
C      henke(77,1, 158 ) = 124.166 
C      henke(77,2, 158 ) = 13.4142 
C      henke(77,3, 158 ) = 6.1813 
C      henke(77,1, 159 ) = 126.175 
C      henke(77,2, 159 ) = 13.1651 
C      henke(77,3, 159 ) = 6.24385 
C      henke(77,1, 160 ) = 128.215 
C      henke(77,2, 160 ) = 12.9041 
C      henke(77,3, 160 ) = 6.37948 
C      henke(77,1, 161 ) = 130.289 
C      henke(77,2, 161 ) = 12.6851 
C      henke(77,3, 161 ) = 6.54412 
C      henke(77,1, 162 ) = 132.397 
C      henke(77,2, 162 ) = 12.4878 
C      henke(77,3, 162 ) = 6.71301 
C      henke(77,1, 163 ) = 134.538 
C      henke(77,2, 163 ) = 12.3018 
C      henke(77,3, 163 ) = 6.88626 
C      henke(77,1, 164 ) = 136.714 
C      henke(77,2, 164 ) = 12.1216 
C      henke(77,3, 164 ) = 7.06398 
C      henke(77,1, 165 ) = 138.925 
C      henke(77,2, 165 ) = 11.9399 
C      henke(77,3, 165 ) = 7.24629 
C      henke(77,1, 166 ) = 141.172 
C      henke(77,2, 166 ) = 11.7345 
C      henke(77,3, 166 ) = 7.45043 
C      henke(77,1, 167 ) = 143.456 
C      henke(77,2, 167 ) = 11.5582 
C      henke(77,3, 167 ) = 7.7021 
C      henke(77,1, 168 ) = 145.776 
C      henke(77,2, 168 ) = 11.405 
C      henke(77,3, 168 ) = 7.96227 
C      henke(77,1, 169 ) = 148.134 
C      henke(77,2, 169 ) = 11.2679 
C      henke(77,3, 169 ) = 8.23123 
C      henke(77,1, 170 ) = 150.53 
C      henke(77,2, 170 ) = 11.1449 
C      henke(77,3, 170 ) = 8.50927 
C      henke(77,1, 171 ) = 152.964 
C      henke(77,2, 171 ) = 11.0376 
C      henke(77,3, 171 ) = 8.79571 
C      henke(77,1, 172 ) = 155.439 
C      henke(77,2, 172 ) = 10.9412 
C      henke(77,3, 172 ) = 9.08733 
C      henke(77,1, 173 ) = 157.953 
C      henke(77,2, 173 ) = 10.8554 
C      henke(77,3, 173 ) = 9.38862 
C      henke(77,1, 174 ) = 160.507 
C      henke(77,2, 174 ) = 10.7827 
C      henke(77,3, 174 ) = 9.6999 
C      henke(77,1, 175 ) = 163.103 
C      henke(77,2, 175 ) = 10.7248 
C      henke(77,3, 175 ) = 10.0215 
C      henke(77,1, 176 ) = 165.742 
C      henke(77,2, 176 ) = 10.6856 
C      henke(77,3, 176 ) = 10.3538 
C      henke(77,1, 177 ) = 168.422 
C      henke(77,2, 177 ) = 10.6978 
C      henke(77,3, 177 ) = 10.6887 
C      henke(77,1, 178 ) = 171.146 
C      henke(77,2, 178 ) = 10.7035 
C      henke(77,3, 178 ) = 10.9707 
C      henke(77,1, 179 ) = 173.915 
C      henke(77,2, 179 ) = 10.69 
C      henke(77,3, 179 ) = 11.2602 
C      henke(77,1, 180 ) = 176.727 
C      henke(77,2, 180 ) = 10.6726 
C      henke(77,3, 180 ) = 11.5573 
C      henke(77,1, 181 ) = 179.586 
C      henke(77,2, 181 ) = 10.652 
C      henke(77,3, 181 ) = 11.8622 
C      henke(77,1, 182 ) = 182.491 
C      henke(77,2, 182 ) = 10.6221 
C      henke(77,3, 182 ) = 12.1752 
C      henke(77,1, 183 ) = 185.442 
C      henke(77,2, 183 ) = 10.5812 
C      henke(77,3, 183 ) = 12.53 
C      henke(77,1, 184 ) = 188.442 
C      henke(77,2, 184 ) = 10.5699 
C      henke(77,3, 184 ) = 12.9193 
C      henke(77,1, 185 ) = 191.489 
C      henke(77,2, 185 ) = 10.5947 
C      henke(77,3, 185 ) = 13.3208 
C      henke(77,1, 186 ) = 194.587 
C      henke(77,2, 186 ) = 10.6559 
C      henke(77,3, 186 ) = 13.7199 
C      henke(77,1, 187 ) = 197.734 
C      henke(77,2, 187 ) = 10.7189 
C      henke(77,3, 187 ) = 14.1025 
C      henke(77,1, 188 ) = 200.932 
C      henke(77,2, 188 ) = 10.7874 
C      henke(77,3, 188 ) = 14.4957 
C      henke(77,1, 189 ) = 204.182 
C      henke(77,2, 189 ) = 10.8674 
C      henke(77,3, 189 ) = 14.8999 
C      henke(77,1, 190 ) = 207.485 
C      henke(77,2, 190 ) = 10.9628 
C      henke(77,3, 190 ) = 15.3154 
C      henke(77,1, 191 ) = 210.84 
C      henke(77,2, 191 ) = 11.0766 
C      henke(77,3, 191 ) = 15.7425 
C      henke(77,1, 192 ) = 214.251 
C      henke(77,2, 192 ) = 11.2129 
C      henke(77,3, 192 ) = 16.1815 
C      henke(77,1, 193 ) = 217.716 
C      henke(77,2, 193 ) = 11.3904 
C      henke(77,3, 193 ) = 16.6328 
C      henke(77,1, 194 ) = 221.237 
C      henke(77,2, 194 ) = 11.6075 
C      henke(77,3, 194 ) = 17.0582 
C      henke(77,1, 195 ) = 224.816 
C      henke(77,2, 195 ) = 11.8192 
C      henke(77,3, 195 ) = 17.4581 
C      henke(77,1, 196 ) = 228.452 
C      henke(77,2, 196 ) = 12.0354 
C      henke(77,3, 196 ) = 17.8674 
C      henke(77,1, 197 ) = 232.147 
C      henke(77,2, 197 ) = 12.2671 
C      henke(77,3, 197 ) = 18.2863 
C      henke(77,1, 198 ) = 235.902 
C      henke(77,2, 198 ) = 12.5226 
C      henke(77,3, 198 ) = 18.715 
C      henke(77,1, 199 ) = 239.717 
C      henke(77,2, 199 ) = 12.8111 
C      henke(77,3, 199 ) = 19.1538 
C      henke(77,1, 200 ) = 243.595 
C      henke(77,2, 200 ) = 13.1472 
C      henke(77,3, 200 ) = 19.6029 
C      henke(77,1, 201 ) = 247.535 
C      henke(77,2, 201 ) = 13.6293 
C      henke(77,3, 201 ) = 19.9962 
C      henke(77,1, 202 ) = 251.538 
C      henke(77,2, 202 ) = 14.0632 
C      henke(77,3, 202 ) = 20.2299 
C      henke(77,1, 203 ) = 255.607 
C      henke(77,2, 203 ) = 14.4124 
C      henke(77,3, 203 ) = 20.4664 
C      henke(77,1, 204 ) = 259.741 
C      henke(77,2, 204 ) = 14.7453 
C      henke(77,3, 204 ) = 20.7057 
C      henke(77,1, 205 ) = 263.942 
C      henke(77,2, 205 ) = 15.0683 
C      henke(77,3, 205 ) = 20.9477 
C      henke(77,1, 206 ) = 268.211 
C      henke(77,2, 206 ) = 15.3871 
C      henke(77,3, 206 ) = 21.1925 
C      henke(77,1, 207 ) = 272.549 
C      henke(77,2, 207 ) = 15.712 
C      henke(77,3, 207 ) = 21.4371 
C      henke(77,1, 208 ) = 276.957 
C      henke(77,2, 208 ) = 16.0338 
C      henke(77,3, 208 ) = 21.6732 
C      henke(77,1, 209 ) = 281.437 
C      henke(77,2, 209 ) = 16.3522 
C      henke(77,3, 209 ) = 21.9118 
C      henke(77,1, 210 ) = 285.989 
C      henke(77,2, 210 ) = 16.678 
C      henke(77,3, 210 ) = 22.153 
C      henke(77,1, 211 ) = 290.615 
C      henke(77,2, 211 ) = 17.0212 
C      henke(77,3, 211 ) = 22.3776 
C      henke(77,1, 212 ) = 295.315 
C      henke(77,2, 212 ) = 17.3511 
C      henke(77,3, 212 ) = 22.5766 
C      henke(77,1, 213 ) = 300.092 
C      henke(77,2, 213 ) = 17.6603 
C      henke(77,3, 213 ) = 22.7774 
C      henke(77,1, 214 ) = 304.945 
C      henke(77,2, 214 ) = 17.9606 
C      henke(77,3, 214 ) = 22.98 
C      henke(77,1, 215 ) = 309.878 
C      henke(77,2, 215 ) = 18.2496 
C      henke(77,3, 215 ) = 23.1844 
C      henke(77,1, 216 ) = 314.89 
C      henke(77,2, 216 ) = 18.5087 
C      henke(77,3, 216 ) = 23.3906 
C      henke(77,1, 217 ) = 319.983 
C      henke(77,2, 217 ) = 18.7731 
C      henke(77,3, 217 ) = 23.6654 
C      henke(77,1, 218 ) = 325.158 
C      henke(77,2, 218 ) = 19.0664 
C      henke(77,3, 218 ) = 23.9509 
C      henke(77,1, 219 ) = 330.418 
C      henke(77,2, 219 ) = 19.3837 
C      henke(77,3, 219 ) = 24.24 
C      henke(77,1, 220 ) = 335.762 
C      henke(77,2, 220 ) = 19.7185 
C      henke(77,3, 220 ) = 24.5325 
C      henke(77,1, 221 ) = 341.192 
C      henke(77,2, 221 ) = 20.0713 
C      henke(77,3, 221 ) = 24.8285 
C      henke(77,1, 222 ) = 346.711 
C      henke(77,2, 222 ) = 20.4447 
C      henke(77,3, 222 ) = 25.1281 
C      henke(77,1, 223 ) = 352.319 
C      henke(77,2, 223 ) = 20.8441 
C      henke(77,3, 223 ) = 25.4313 
C      henke(77,1, 224 ) = 358.017 
C      henke(77,2, 224 ) = 21.2946 
C      henke(77,3, 224 ) = 25.7382 
C      henke(77,1, 225 ) = 363.808 
C      henke(77,2, 225 ) = 21.7691 
C      henke(77,3, 225 ) = 25.9671 
C      henke(77,1, 226 ) = 369.692 
C      henke(77,2, 226 ) = 22.223 
C      henke(77,3, 226 ) = 26.1695 
C      henke(77,1, 227 ) = 375.672 
C      henke(77,2, 227 ) = 22.6578 
C      henke(77,3, 227 ) = 26.3735 
C      henke(77,1, 228 ) = 381.748 
C      henke(77,2, 228 ) = 23.0929 
C      henke(77,3, 228 ) = 26.579 
C      henke(77,1, 229 ) = 387.922 
C      henke(77,2, 229 ) = 23.5321 
C      henke(77,3, 229 ) = 26.7862 
C      henke(77,1, 230 ) = 394.197 
C      henke(77,2, 230 ) = 23.9789 
C      henke(77,3, 230 ) = 26.995 
C      henke(77,1, 231 ) = 400.573 
C      henke(77,2, 231 ) = 24.4367 
C      henke(77,3, 231 ) = 27.2053 
C      henke(77,1, 232 ) = 407.052 
C      henke(77,2, 232 ) = 24.9102 
C      henke(77,3, 232 ) = 27.4174 
C      henke(77,1, 233 ) = 413.635 
C      henke(77,2, 233 ) = 25.4067 
C      henke(77,3, 233 ) = 27.6311 
C      henke(77,1, 234 ) = 420.326 
C      henke(77,2, 234 ) = 25.949 
C      henke(77,3, 234 ) = 27.8464 
C      henke(77,1, 235 ) = 427.124 
C      henke(77,2, 235 ) = 26.5448 
C      henke(77,3, 235 ) = 27.9861 
C      henke(77,1, 236 ) = 434.032 
C      henke(77,2, 236 ) = 27.1105 
C      henke(77,3, 236 ) = 28.0449 
C      henke(77,1, 237 ) = 441.052 
C      henke(77,2, 237 ) = 27.6193 
C      henke(77,3, 237 ) = 28.1038 
C      henke(77,1, 238 ) = 448.186 
C      henke(77,2, 238 ) = 28.1155 
C      henke(77,3, 238 ) = 28.1628 
C      henke(77,1, 239 ) = 455.435 
C      henke(77,2, 239 ) = 28.6025 
C      henke(77,3, 239 ) = 28.2219 
C      henke(77,1, 240 ) = 462.802 
C      henke(77,2, 240 ) = 29.0838 
C      henke(77,3, 240 ) = 28.2811 
C      henke(77,1, 241 ) = 470.287 
C      henke(77,2, 241 ) = 29.5622 
C      henke(77,3, 241 ) = 28.3405 
C      henke(77,1, 242 ) = 477.894 
C      henke(77,2, 242 ) = 30.0397 
C      henke(77,3, 242 ) = 28.4 
C      henke(77,1, 243 ) = 485.623 
C      henke(77,2, 243 ) = 30.5183 
C      henke(77,3, 243 ) = 28.4596 
C      henke(77,1, 244 ) = 493.478 
C      henke(77,2, 244 ) = 30.9996 
C      henke(77,3, 244 ) = 28.5193 
C      henke(77,1, 245 ) = 501.459 
C      henke(77,2, 245 ) = 31.4855 
C      henke(77,3, 245 ) = 28.5792 
C      henke(77,1, 246 ) = 509.57 
C      henke(77,2, 246 ) = 31.9782 
C      henke(77,3, 246 ) = 28.6392 
C      henke(77,1, 247 ) = 517.812 
C      henke(77,2, 247 ) = 32.4801 
C      henke(77,3, 247 ) = 28.6994 
C      henke(77,1, 248 ) = 526.187 
C      henke(77,2, 248 ) = 32.9947 
C      henke(77,3, 248 ) = 28.7596 
C      henke(77,1, 249 ) = 534.698 
C      henke(77,2, 249 ) = 33.5267 
C      henke(77,3, 249 ) = 28.82 
C      henke(77,1, 250 ) = 543.346 
C      henke(77,2, 250 ) = 34.0827 
C      henke(77,3, 250 ) = 28.8805 
C      henke(77,1, 251 ) = 552.134 
C      henke(77,2, 251 ) = 34.7042 
C      henke(77,3, 251 ) = 28.9411 
C      henke(77,1, 252 ) = 561.065 
C      henke(77,2, 252 ) = 35.3983 
C      henke(77,3, 252 ) = 28.9457 
C      henke(77,1, 253 ) = 570.139 
C      henke(77,2, 253 ) = 36.0692 
C      henke(77,3, 253 ) = 28.7507 
C      henke(77,1, 254 ) = 579.361 
C      henke(77,2, 254 ) = 36.6365 
C      henke(77,3, 254 ) = 28.557 
C      henke(77,1, 255 ) = 588.732 
C      henke(77,2, 255 ) = 37.1613 
C      henke(77,3, 255 ) = 28.3645 
C      henke(77,1, 256 ) = 598.254 
C      henke(77,2, 256 ) = 37.6574 
C      henke(77,3, 256 ) = 28.1734 
C      henke(77,1, 257 ) = 607.93 
C      henke(77,2, 257 ) = 38.1314 
C      henke(77,3, 257 ) = 27.9835 
C      henke(77,1, 258 ) = 617.763 
C      henke(77,2, 258 ) = 38.5876 
C      henke(77,3, 258 ) = 27.795 
C      henke(77,1, 259 ) = 627.755 
C      henke(77,2, 259 ) = 39.0286 
C      henke(77,3, 259 ) = 27.6077 
C      henke(77,1, 260 ) = 637.908 
C      henke(77,2, 260 ) = 39.4568 
C      henke(77,3, 260 ) = 27.4217 
C      henke(77,1, 261 ) = 648.226 
C      henke(77,2, 261 ) = 39.8737 
C      henke(77,3, 261 ) = 27.2369 
C      henke(77,1, 262 ) = 658.711 
C      henke(77,2, 262 ) = 40.2807 
C      henke(77,3, 262 ) = 27.0534 
C      henke(77,1, 263 ) = 669.365 
C      henke(77,2, 263 ) = 40.6791 
C      henke(77,3, 263 ) = 26.8711 
C      henke(77,1, 264 ) = 680.191 
C      henke(77,2, 264 ) = 41.0696 
C      henke(77,3, 264 ) = 26.69 
C      henke(77,1, 265 ) = 691.193 
C      henke(77,2, 265 ) = 41.4534 
C      henke(77,3, 265 ) = 26.5101 
C      henke(77,1, 266 ) = 702.372 
C      henke(77,2, 266 ) = 41.8313 
C      henke(77,3, 266 ) = 26.3315 
C      henke(77,1, 267 ) = 713.733 
C      henke(77,2, 267 ) = 42.2041 
C      henke(77,3, 267 ) = 26.1541 
C      henke(77,1, 268 ) = 725.277 
C      henke(77,2, 268 ) = 42.5727 
C      henke(77,3, 268 ) = 25.9778 
C      henke(77,1, 269 ) = 737.008 
C      henke(77,2, 269 ) = 42.938 
C      henke(77,3, 269 ) = 25.8028 
C      henke(77,1, 270 ) = 748.928 
C      henke(77,2, 270 ) = 43.301 
C      henke(77,3, 270 ) = 25.6289 
C      henke(77,1, 271 ) = 761.042 
C      henke(77,2, 271 ) = 43.6627 
C      henke(77,3, 271 ) = 25.4562 
C      henke(77,1, 272 ) = 773.351 
C      henke(77,2, 272 ) = 44.0245 
C      henke(77,3, 272 ) = 25.2847 
C      henke(77,1, 273 ) = 785.859 
C      henke(77,2, 273 ) = 44.3881 
C      henke(77,3, 273 ) = 25.1143 
C      henke(77,1, 274 ) = 798.57 
C      henke(77,2, 274 ) = 44.7555 
C      henke(77,3, 274 ) = 24.9451 
C      henke(77,1, 275 ) = 811.486 
C      henke(77,2, 275 ) = 45.13 
C      henke(77,3, 275 ) = 24.777 
C      henke(77,1, 276 ) = 824.611 
C      henke(77,2, 276 ) = 45.5162 
C      henke(77,3, 276 ) = 24.61 
C      henke(77,1, 277 ) = 837.949 
C      henke(77,2, 277 ) = 45.9217 
C      henke(77,3, 277 ) = 24.4442 
C      henke(77,1, 278 ) = 851.502 
C      henke(77,2, 278 ) = 46.3525 
C      henke(77,3, 278 ) = 24.2795 
C      henke(77,1, 279 ) = 865.274 
C      henke(77,2, 279 ) = 47.0374 
C      henke(77,3, 279 ) = 24.1159 
C      henke(77,1, 280 ) = 879.269 
C      henke(77,2, 280 ) = 47.7299 
C      henke(77,3, 280 ) = 23.176 
C      henke(77,1, 281 ) = 893.491 
C      henke(77,2, 281 ) = 47.6502 
C      henke(77,3, 281 ) = 22.8917 
C      henke(77,1, 282 ) = 907.943 
C      henke(77,2, 282 ) = 47.8377 
C      henke(77,3, 282 ) = 22.6104 
C      henke(77,1, 283 ) = 922.628 
C      henke(77,2, 283 ) = 48.0699 
C      henke(77,3, 283 ) = 22.3323 
C      henke(77,1, 284 ) = 937.551 
C      henke(77,2, 284 ) = 48.3145 
C      henke(77,3, 284 ) = 22.0307 
C      henke(77,1, 285 ) = 952.715 
C      henke(77,2, 285 ) = 48.5452 
C      henke(77,3, 285 ) = 21.7261 
C      henke(77,1, 286 ) = 968.124 
C      henke(77,2, 286 ) = 48.7641 
C      henke(77,3, 286 ) = 21.4195 
C      henke(77,1, 287 ) = 983.783 
C      henke(77,2, 287 ) = 48.9726 
C      henke(77,3, 287 ) = 21.1168 
C      henke(77,1, 288 ) = 999.695 
C      henke(77,2, 288 ) = 49.1744 
C      henke(77,3, 288 ) = 20.8156 
C      henke(77,1, 289 ) = 1015.86 
C      henke(77,2, 289 ) = 49.3725 
C      henke(77,3, 289 ) = 20.5158 
C      henke(77,1, 290 ) = 1032.29 
C      henke(77,2, 290 ) = 49.5617 
C      henke(77,3, 290 ) = 20.1959 
C      henke(77,1, 291 ) = 1048.99 
C      henke(77,2, 291 ) = 49.7269 
C      henke(77,3, 291 ) = 19.8775 
C      henke(77,1, 292 ) = 1065.96 
C      henke(77,2, 292 ) = 49.875 
C      henke(77,3, 292 ) = 19.5605 
C      henke(77,1, 293 ) = 1083.2 
C      henke(77,2, 293 ) = 50.0074 
C      henke(77,3, 293 ) = 19.2482 
C      henke(77,1, 294 ) = 1100.72 
C      henke(77,2, 294 ) = 50.1261 
C      henke(77,3, 294 ) = 18.9404 
C      henke(77,1, 295 ) = 1118.52 
C      henke(77,2, 295 ) = 50.2318 
C      henke(77,3, 295 ) = 18.6372 
C      henke(77,1, 296 ) = 1136.61 
C      henke(77,2, 296 ) = 50.3254 
C      henke(77,3, 296 ) = 18.3388 
C      henke(77,1, 297 ) = 1155 
C      henke(77,2, 297 ) = 50.4077 
C      henke(77,3, 297 ) = 18.0448 
C      henke(77,1, 298 ) = 1173.68 
C      henke(77,2, 298 ) = 50.4785 
C      henke(77,3, 298 ) = 17.755 
C      henke(77,1, 299 ) = 1192.66 
C      henke(77,2, 299 ) = 50.5384 
C      henke(77,3, 299 ) = 17.4697 
C      henke(77,1, 300 ) = 1211.95 
C      henke(77,2, 300 ) = 50.588 
C      henke(77,3, 300 ) = 17.1886 
C      henke(77,1, 301 ) = 1231.55 
C      henke(77,2, 301 ) = 50.6283 
C      henke(77,3, 301 ) = 16.9115 
C      henke(77,1, 302 ) = 1251.47 
C      henke(77,2, 302 ) = 50.6593 
C      henke(77,3, 302 ) = 16.6345 
C      henke(77,1, 303 ) = 1271.72 
C      henke(77,2, 303 ) = 50.6793 
C      henke(77,3, 303 ) = 16.3572 
C      henke(77,1, 304 ) = 1292.29 
C      henke(77,2, 304 ) = 50.6826 
C      henke(77,3, 304 ) = 16.0786 
C      henke(77,1, 305 ) = 1313.19 
C      henke(77,2, 305 ) = 50.6692 
C      henke(77,3, 305 ) = 15.8041 
C      henke(77,1, 306 ) = 1334.43 
C      henke(77,2, 306 ) = 50.6405 
C      henke(77,3, 306 ) = 15.5341 
C      henke(77,1, 307 ) = 1356.01 
C      henke(77,2, 307 ) = 50.5968 
C      henke(77,3, 307 ) = 15.2685 
C      henke(77,1, 308 ) = 1377.94 
C      henke(77,2, 308 ) = 50.5379 
C      henke(77,3, 308 ) = 15.007 
C      henke(77,1, 309 ) = 1400.23 
C      henke(77,2, 309 ) = 50.4632 
C      henke(77,3, 309 ) = 14.7497 
C      henke(77,1, 310 ) = 1422.88 
C      henke(77,2, 310 ) = 50.3721 
C      henke(77,3, 310 ) = 14.4967 
C      henke(77,1, 311 ) = 1445.89 
C      henke(77,2, 311 ) = 50.2644 
C      henke(77,3, 311 ) = 14.2476 
C      henke(77,1, 312 ) = 1469.28 
C      henke(77,2, 312 ) = 50.1392 
C      henke(77,3, 312 ) = 14.0016 
C      henke(77,1, 313 ) = 1493.04 
C      henke(77,2, 313 ) = 49.9948 
C      henke(77,3, 313 ) = 13.7584 
C      henke(77,1, 314 ) = 1517.19 
C      henke(77,2, 314 ) = 49.8288 
C      henke(77,3, 314 ) = 13.5142 
C      henke(77,1, 315 ) = 1541.73 
C      henke(77,2, 315 ) = 49.6354 
C      henke(77,3, 315 ) = 13.2737 
C      henke(77,1, 316 ) = 1566.67 
C      henke(77,2, 316 ) = 49.4148 
C      henke(77,3, 316 ) = 13.0375 
C      henke(77,1, 317 ) = 1592.01 
C      henke(77,2, 317 ) = 49.1647 
C      henke(77,3, 317 ) = 12.8046 
C      henke(77,1, 318 ) = 1617.76 
C      henke(77,2, 318 ) = 48.8815 
C      henke(77,3, 318 ) = 12.5757 
C      henke(77,1, 319 ) = 1643.92 
C      henke(77,2, 319 ) = 48.5614 
C      henke(77,3, 319 ) = 12.3508 
C      henke(77,1, 320 ) = 1670.51 
C      henke(77,2, 320 ) = 48.1997 
C      henke(77,3, 320 ) = 12.13 
C      henke(77,1, 321 ) = 1697.53 
C      henke(77,2, 321 ) = 47.791 
C      henke(77,3, 321 ) = 11.9127 
C      henke(77,1, 322 ) = 1724.99 
C      henke(77,2, 322 ) = 47.3275 
C      henke(77,3, 322 ) = 11.6986 
C      henke(77,1, 323 ) = 1752.89 
C      henke(77,2, 323 ) = 46.7982 
C      henke(77,3, 323 ) = 11.4807 
C      henke(77,1, 324 ) = 1781.24 
C      henke(77,2, 324 ) = 46.1826 
C      henke(77,3, 324 ) = 11.2642 
C      henke(77,1, 325 ) = 1810.05 
C      henke(77,2, 325 ) = 45.4617 
C      henke(77,3, 325 ) = 11.0495 
C      henke(77,1, 326 ) = 1839.32 
C      henke(77,2, 326 ) = 44.6082 
C      henke(77,3, 326 ) = 10.8384 
C      henke(77,1, 327 ) = 1869.07 
C      henke(77,2, 327 ) = 43.5809 
C      henke(77,3, 327 ) = 10.6314 
C      henke(77,1, 328 ) = 1899.3 
C      henke(77,2, 328 ) = 42.3152 
C      henke(77,3, 328 ) = 10.4286 
C      henke(77,1, 329 ) = 1930.02 
C      henke(77,2, 329 ) = 40.6977 
C      henke(77,3, 329 ) = 10.2293 
C      henke(77,1, 330 ) = 1961.24 
C      henke(77,2, 330 ) = 38.5034 
C      henke(77,3, 330 ) = 10.0336 
C      henke(77,1, 331 ) = 1992.96 
C      henke(77,2, 331 ) = 35.1665 
C      henke(77,3, 331 ) = 9.84134 
C      henke(77,1, 332 ) = 2025.2 
C      henke(77,2, 332 ) = 28.0964 
C      henke(77,3, 332 ) = 9.65784 
C      henke(77,1, 333 ) = 2040.3 
C      henke(77,2, 333 ) = -0.661999 
C      henke(77,3, 333 ) = 9.57403 
C      henke(77,1, 334 ) = 2040.5 
C      henke(77,2, 334 ) = -0.662121 
C      henke(77,3, 334 ) = 27.3304 
C      henke(77,1, 335 ) = 2057.95 
C      henke(77,2, 335 ) = 27.9204 
C      henke(77,3, 335 ) = 27.0332 
C      henke(77,1, 336 ) = 2091.24 
C      henke(77,2, 336 ) = 31.1926 
C      henke(77,3, 336 ) = 26.4821 
C      henke(77,1, 337 ) = 2116 
C      henke(77,2, 337 ) = 12.3218 
C      henke(77,3, 337 ) = 26.0849 
C      henke(77,1, 338 ) = 2116.2 
C      henke(77,2, 338 ) = 12.3531 
C      henke(77,3, 338 ) = 38.4468 
C      henke(77,1, 339 ) = 2125.06 
C      henke(77,2, 339 ) = 30.7428 
C      henke(77,3, 339 ) = 38.2183 
C      henke(77,1, 340 ) = 2159.43 
C      henke(77,2, 340 ) = 39.3349 
C      henke(77,3, 340 ) = 37.3539 
C      henke(77,1, 341 ) = 2194.36 
C      henke(77,2, 341 ) = 43.4216 
C      henke(77,3, 341 ) = 36.5093 
C      henke(77,1, 342 ) = 2229.85 
C      henke(77,2, 342 ) = 46.2669 
C      henke(77,3, 342 ) = 35.6836 
C      henke(77,1, 343 ) = 2265.92 
C      henke(77,2, 343 ) = 48.4512 
C      henke(77,3, 343 ) = 34.8774 
C      henke(77,1, 344 ) = 2302.57 
C      henke(77,2, 344 ) = 50.1998 
C      henke(77,3, 344 ) = 34.0887 
C      henke(77,1, 345 ) = 2339.81 
C      henke(77,2, 345 ) = 51.6236 
C      henke(77,3, 345 ) = 33.3195 
C      henke(77,1, 346 ) = 2377.66 
C      henke(77,2, 346 ) = 52.7806 
C      henke(77,3, 346 ) = 32.5676 
C      henke(77,1, 347 ) = 2416.11 
C      henke(77,2, 347 ) = 53.6903 
C      henke(77,3, 347 ) = 31.8326 
C      henke(77,1, 348 ) = 2455.19 
C      henke(77,2, 348 ) = 54.3294 
C      henke(77,3, 348 ) = 31.1154 
C      henke(77,1, 349 ) = 2494.9 
C      henke(77,2, 349 ) = 54.5727 
C      henke(77,3, 349 ) = 30.4148 
C      henke(77,1, 350 ) = 2535.26 
C      henke(77,2, 350 ) = 53.6177 
C      henke(77,3, 350 ) = 29.7302 
C      henke(77,1, 351 ) = 2550.6 
C      henke(77,2, 351 ) = 46.3715 
C      henke(77,3, 351 ) = 29.4768 
C      henke(77,1, 352 ) = 2550.8 
C      henke(77,2, 352 ) = 46.3776 
C      henke(77,3, 352 ) = 34.2272 
C      henke(77,1, 353 ) = 2576.26 
C      henke(77,2, 353 ) = 55.3436 
C      henke(77,3, 353 ) = 33.7198 
C      henke(77,1, 354 ) = 2617.93 
C      henke(77,2, 354 ) = 57.5958 
C      henke(77,3, 354 ) = 32.9158 
C      henke(77,1, 355 ) = 2660.27 
C      henke(77,2, 355 ) = 59.0087 
C      henke(77,3, 355 ) = 32.1309 
C      henke(77,1, 356 ) = 2703.3 
C      henke(77,2, 356 ) = 60.0854 
C      henke(77,3, 356 ) = 31.3671 
C      henke(77,1, 357 ) = 2747.03 
C      henke(77,2, 357 ) = 60.9473 
C      henke(77,3, 357 ) = 30.6217 
C      henke(77,1, 358 ) = 2791.46 
C      henke(77,2, 358 ) = 61.6302 
C      henke(77,3, 358 ) = 29.8949 
C      henke(77,1, 359 ) = 2836.61 
C      henke(77,2, 359 ) = 62.1188 
C      henke(77,3, 359 ) = 29.1861 
C      henke(77,1, 360 ) = 2882.49 
C      henke(77,2, 360 ) = 62.228 
C      henke(77,3, 360 ) = 28.495 
C      henke(77,1, 361 ) = 2908.6 
C      henke(77,2, 361 ) = 59.4369 
C      henke(77,3, 361 ) = 28.1138 
C      henke(77,1, 362 ) = 2908.8 
C      henke(77,2, 362 ) = 59.4396 
C      henke(77,3, 362 ) = 29.886 
C      henke(77,1, 363 ) = 2929.11 
C      henke(77,2, 363 ) = 62.6994 
C      henke(77,3, 363 ) = 29.5896 
C      henke(77,1, 364 ) = 2976.48 
C      henke(77,2, 364 ) = 63.9144 
C      henke(77,3, 364 ) = 28.9171 
C      henke(77,1, 365 ) = 3024.63 
C      henke(77,2, 365 ) = 64.6814 
C      henke(77,3, 365 ) = 28.2609 
C      henke(77,1, 366 ) = 3073.55 
C      henke(77,2, 366 ) = 65.2621 
C      henke(77,3, 366 ) = 27.621 
C      henke(77,1, 367 ) = 3123.26 
C      henke(77,2, 367 ) = 65.6628 
C      henke(77,3, 367 ) = 26.9958 
C      henke(77,1, 368 ) = 3173.6 
C      henke(77,2, 368 ) = 64.2909 
C      henke(77,3, 368 ) = 26.3869 
C      henke(77,1, 369 ) = 3173.8 
C      henke(77,2, 369 ) = 64.2928 
C      henke(77,3, 369 ) = 27.3502 
C      henke(77,1, 370 ) = 3225.11 
C      henke(77,2, 370 ) = 66.704 
C      henke(77,3, 370 ) = 26.7731 
C      henke(77,1, 371 ) = 3277.27 
C      henke(77,2, 371 ) = 67.3825 
C      henke(77,3, 371 ) = 26.2048 
C      henke(77,1, 372 ) = 3330.28 
C      henke(77,2, 372 ) = 67.9414 
C      henke(77,3, 372 ) = 25.6446 
C      henke(77,1, 373 ) = 3384.15 
C      henke(77,2, 373 ) = 68.4346 
C      henke(77,3, 373 ) = 25.0927 
C      henke(77,1, 374 ) = 3438.88 
C      henke(77,2, 374 ) = 68.8797 
C      henke(77,3, 374 ) = 24.5489 
C      henke(77,1, 375 ) = 3494.5 
C      henke(77,2, 375 ) = 69.2867 
C      henke(77,3, 375 ) = 24.0139 
C      henke(77,1, 376 ) = 3551.02 
C      henke(77,2, 376 ) = 69.6604 
C      henke(77,3, 376 ) = 23.486 
C      henke(77,1, 377 ) = 3608.46 
C      henke(77,2, 377 ) = 70.0058 
C      henke(77,3, 377 ) = 22.9681 
C      henke(77,1, 378 ) = 3666.82 
C      henke(77,2, 378 ) = 70.326 
C      henke(77,3, 378 ) = 22.4579 
C      henke(77,1, 379 ) = 3726.13 
C      henke(77,2, 379 ) = 70.6223 
C      henke(77,3, 379 ) = 21.9572 
C      henke(77,1, 380 ) = 3786.4 
C      henke(77,2, 380 ) = 70.8967 
C      henke(77,3, 380 ) = 21.4634 
C      henke(77,1, 381 ) = 3847.64 
C      henke(77,2, 381 ) = 71.151 
C      henke(77,3, 381 ) = 20.9795 
C      henke(77,1, 382 ) = 3909.87 
C      henke(77,2, 382 ) = 71.3872 
C      henke(77,3, 382 ) = 20.5046 
C      henke(77,1, 383 ) = 3973.11 
C      henke(77,2, 383 ) = 71.6066 
C      henke(77,3, 383 ) = 20.0382 
C      henke(77,1, 384 ) = 4037.38 
C      henke(77,2, 384 ) = 71.8088 
C      henke(77,3, 384 ) = 19.5793 
C      henke(77,1, 385 ) = 4102.68 
C      henke(77,2, 385 ) = 71.9969 
C      henke(77,3, 385 ) = 19.1308 
C      henke(77,1, 386 ) = 4169.03 
C      henke(77,2, 386 ) = 72.1711 
C      henke(77,3, 386 ) = 18.6892 
C      henke(77,1, 387 ) = 4236.46 
C      henke(77,2, 387 ) = 72.331 
C      henke(77,3, 387 ) = 18.2562 
C      henke(77,1, 388 ) = 4304.98 
C      henke(77,2, 388 ) = 72.4781 
C      henke(77,3, 388 ) = 17.8316 
C      henke(77,1, 389 ) = 4374.62 
C      henke(77,2, 389 ) = 72.6135 
C      henke(77,3, 389 ) = 17.4155 
C      henke(77,1, 390 ) = 4445.37 
C      henke(77,2, 390 ) = 72.7374 
C      henke(77,3, 390 ) = 17.0075 
C      henke(77,1, 391 ) = 4517.27 
C      henke(77,2, 391 ) = 72.8504 
C      henke(77,3, 391 ) = 16.6077 
C      henke(77,1, 392 ) = 4590.33 
C      henke(77,2, 392 ) = 72.9533 
C      henke(77,3, 392 ) = 16.2161 
C      henke(77,1, 393 ) = 4664.58 
C      henke(77,2, 393 ) = 73.0465 
C      henke(77,3, 393 ) = 15.8322 
C      henke(77,1, 394 ) = 4740.03 
C      henke(77,2, 394 ) = 73.1304 
C      henke(77,3, 394 ) = 15.4564 
C      henke(77,1, 395 ) = 4816.69 
C      henke(77,2, 395 ) = 73.2056 
C      henke(77,3, 395 ) = 15.0885 
C      henke(77,1, 396 ) = 4894.6 
C      henke(77,2, 396 ) = 73.2725 
C      henke(77,3, 396 ) = 14.7282 
C      henke(77,1, 397 ) = 4973.77 
C      henke(77,2, 397 ) = 73.3314 
C      henke(77,3, 397 ) = 14.3754 
C      henke(77,1, 398 ) = 5054.21 
C      henke(77,2, 398 ) = 73.3829 
C      henke(77,3, 398 ) = 14.0303 
C      henke(77,1, 399 ) = 5135.96 
C      henke(77,2, 399 ) = 73.427 
C      henke(77,3, 399 ) = 13.6926 
C      henke(77,1, 400 ) = 5219.03 
C      henke(77,2, 400 ) = 73.4644 
C      henke(77,3, 400 ) = 13.3622 
C      henke(77,1, 401 ) = 5303.44 
C      henke(77,2, 401 ) = 73.4951 
C      henke(77,3, 401 ) = 13.0389 
C      henke(77,1, 402 ) = 5389.22 
C      henke(77,2, 402 ) = 73.5196 
C      henke(77,3, 402 ) = 12.7228 
C      henke(77,1, 403 ) = 5476.39 
C      henke(77,2, 403 ) = 73.538 
C      henke(77,3, 403 ) = 12.4137 
C      henke(77,1, 404 ) = 5564.97 
C      henke(77,2, 404 ) = 73.5507 
C      henke(77,3, 404 ) = 12.1116 
C      henke(77,1, 405 ) = 5654.98 
C      henke(77,2, 405 ) = 73.558 
C      henke(77,3, 405 ) = 11.8162 
C      henke(77,1, 406 ) = 5746.44 
C      henke(77,2, 406 ) = 73.5601 
C      henke(77,3, 406 ) = 11.5274 
C      henke(77,1, 407 ) = 5839.39 
C      henke(77,2, 407 ) = 73.557 
C      henke(77,3, 407 ) = 11.2452 
C      henke(77,1, 408 ) = 5933.83 
C      henke(77,2, 408 ) = 73.5491 
C      henke(77,3, 408 ) = 10.9694 
C      henke(77,1, 409 ) = 6029.81 
C      henke(77,2, 409 ) = 73.5363 
C      henke(77,3, 409 ) = 10.6999 
C      henke(77,1, 410 ) = 6127.33 
C      henke(77,2, 410 ) = 73.5191 
C      henke(77,3, 410 ) = 10.4367 
C      henke(77,1, 411 ) = 6226.44 
C      henke(77,2, 411 ) = 73.4974 
C      henke(77,3, 411 ) = 10.1796 
C      henke(77,1, 412 ) = 6327.15 
C      henke(77,2, 412 ) = 73.4714 
C      henke(77,3, 412 ) = 9.92852 
C      henke(77,1, 413 ) = 6429.48 
C      henke(77,2, 413 ) = 73.4413 
C      henke(77,3, 413 ) = 9.68345 
C      henke(77,1, 414 ) = 6533.48 
C      henke(77,2, 414 ) = 73.4071 
C      henke(77,3, 414 ) = 9.44395 
C      henke(77,1, 415 ) = 6639.15 
C      henke(77,2, 415 ) = 73.369 
C      henke(77,3, 415 ) = 9.21018 
C      henke(77,1, 416 ) = 6746.54 
C      henke(77,2, 416 ) = 73.3269 
C      henke(77,3, 416 ) = 8.98196 
C      henke(77,1, 417 ) = 6855.65 
C      henke(77,2, 417 ) = 73.281 
C      henke(77,3, 417 ) = 8.75918 
C      henke(77,1, 418 ) = 6966.54 
C      henke(77,2, 418 ) = 73.231 
C      henke(77,3, 418 ) = 8.54146 
C      henke(77,1, 419 ) = 7079.22 
C      henke(77,2, 419 ) = 73.1772 
C      henke(77,3, 419 ) = 8.32915 
C      henke(77,1, 420 ) = 7193.72 
C      henke(77,2, 420 ) = 73.1194 
C      henke(77,3, 420 ) = 8.12195 
C      henke(77,1, 421 ) = 7310.07 
C      henke(77,2, 421 ) = 73.0577 
C      henke(77,3, 421 ) = 7.91989 
C      henke(77,1, 422 ) = 7428.31 
C      henke(77,2, 422 ) = 72.992 
C      henke(77,3, 422 ) = 7.72256 
C      henke(77,1, 423 ) = 7548.45 
C      henke(77,2, 423 ) = 72.9222 
C      henke(77,3, 423 ) = 7.53009 
C      henke(77,1, 424 ) = 7670.54 
C      henke(77,2, 424 ) = 72.8481 
C      henke(77,3, 424 ) = 7.34241 
C      henke(77,1, 425 ) = 7794.61 
C      henke(77,2, 425 ) = 72.7697 
C      henke(77,3, 425 ) = 7.15912 
C      henke(77,1, 426 ) = 7920.68 
C      henke(77,2, 426 ) = 72.6866 
C      henke(77,3, 426 ) = 6.98032 
C      henke(77,1, 427 ) = 8048.79 
C      henke(77,2, 427 ) = 72.5986 
C      henke(77,3, 427 ) = 6.80599 
C      henke(77,1, 428 ) = 8178.98 
C      henke(77,2, 428 ) = 72.5052 
C      henke(77,3, 428 ) = 6.63582 
C      henke(77,1, 429 ) = 8311.26 
C      henke(77,2, 429 ) = 72.4063 
C      henke(77,3, 429 ) = 6.46999 
C      henke(77,1, 430 ) = 8445.69 
C      henke(77,2, 430 ) = 72.3011 
C      henke(77,3, 430 ) = 6.30817 
C      henke(77,1, 431 ) = 8582.29 
C      henke(77,2, 431 ) = 72.1896 
C      henke(77,3, 431 ) = 6.15055 
C      henke(77,1, 432 ) = 8721.11 
C      henke(77,2, 432 ) = 72.0705 
C      henke(77,3, 432 ) = 5.99655 
C      henke(77,1, 433 ) = 8862.16 
C      henke(77,2, 433 ) = 71.9433 
C      henke(77,3, 433 ) = 5.84659 
C      henke(77,1, 434 ) = 9005.5 
C      henke(77,2, 434 ) = 71.8067 
C      henke(77,3, 434 ) = 5.70018 
C      henke(77,1, 435 ) = 9151.16 
C      henke(77,2, 435 ) = 71.6597 
C      henke(77,3, 435 ) = 5.55755 
C      henke(77,1, 436 ) = 9299.17 
C      henke(77,2, 436 ) = 71.5003 
C      henke(77,3, 436 ) = 5.41839 
C      henke(77,1, 437 ) = 9449.58 
C      henke(77,2, 437 ) = 71.3267 
C      henke(77,3, 437 ) = 5.2828 
C      henke(77,1, 438 ) = 9602.42 
C      henke(77,2, 438 ) = 71.1361 
C      henke(77,3, 438 ) = 5.1505 
C      henke(77,1, 439 ) = 9757.73 
C      henke(77,2, 439 ) = 70.9248 
C      henke(77,3, 439 ) = 5.02171 
C      henke(77,1, 440 ) = 9915.55 
C      henke(77,2, 440 ) = 70.6895 
C      henke(77,3, 440 ) = 4.89611 
C      henke(77,1, 441 ) = 10075.9 
C      henke(77,2, 441 ) = 70.4205 
C      henke(77,3, 441 ) = 4.77048 
C      henke(77,1, 442 ) = 10238.9 
C      henke(77,2, 442 ) = 70.1059 
C      henke(77,3, 442 ) = 4.64835 
C      henke(77,1, 443 ) = 10404.5 
C      henke(77,2, 443 ) = 69.7302 
C      henke(77,3, 443 ) = 4.52961 
C      henke(77,1, 444 ) = 10572.8 
C      henke(77,2, 444 ) = 69.2641 
C      henke(77,3, 444 ) = 4.41418 
C      henke(77,1, 445 ) = 10743.8 
C      henke(77,2, 445 ) = 68.6503 
C      henke(77,3, 445 ) = 4.302 
C      henke(77,1, 446 ) = 10917.6 
C      henke(77,2, 446 ) = 67.7469 
C      henke(77,3, 446 ) = 4.19296 
C      henke(77,1, 447 ) = 11094.2 
C      henke(77,2, 447 ) = 65.98 
C      henke(77,3, 447 ) = 4.087 
C      henke(77,1, 448 ) = 11215.1 
C      henke(77,2, 448 ) = 51.9627 
C      henke(77,3, 448 ) = 4.01691 
C      henke(77,1, 449 ) = 11215.3 
C      henke(77,2, 449 ) = 51.9638 
C      henke(77,3, 449 ) = 10.303 
C      henke(77,1, 450 ) = 11273.6 
C      henke(77,2, 450 ) = 64.665 
C      henke(77,3, 450 ) = 10.2052 
C      henke(77,1, 451 ) = 11455.9 
C      henke(77,2, 451 ) = 67.5139 
C      henke(77,3, 451 ) = 9.9083 
C      henke(77,1, 452 ) = 11641.2 
C      henke(77,2, 452 ) = 68.5918 
C      henke(77,3, 452 ) = 9.62008 
C      henke(77,1, 453 ) = 11829.5 
C      henke(77,2, 453 ) = 69.1967 
C      henke(77,3, 453 ) = 9.34025 
C      henke(77,1, 454 ) = 12020.8 
C      henke(77,2, 454 ) = 69.5442 
C      henke(77,3, 454 ) = 9.06856 
C      henke(77,1, 455 ) = 12215.3 
C      henke(77,2, 455 ) = 69.6942 
C      henke(77,3, 455 ) = 8.80476 
C      henke(77,1, 456 ) = 12412.8 
C      henke(77,2, 456 ) = 69.6329 
C      henke(77,3, 456 ) = 8.54866 
C      henke(77,1, 457 ) = 12613.6 
C      henke(77,2, 457 ) = 69.2139 
C      henke(77,3, 457 ) = 8.29999 
C      henke(77,1, 458 ) = 12817.6 
C      henke(77,2, 458 ) = 65.8472 
C      henke(77,3, 458 ) = 8.05857 
C      henke(77,1, 459 ) = 12824 
C      henke(77,2, 459 ) = 61.566 
C      henke(77,3, 459 ) = 8.0512 
C      henke(77,1, 460 ) = 12824.2 
C      henke(77,2, 460 ) = 61.5663 
C      henke(77,3, 460 ) = 11.2792 
C      henke(77,1, 461 ) = 13025 
C      henke(77,2, 461 ) = 69.5017 
C      henke(77,3, 461 ) = 11.0047 
C      henke(77,1, 462 ) = 13235.6 
C      henke(77,2, 462 ) = 70.2243 
C      henke(77,3, 462 ) = 10.7282 
C      henke(77,1, 463 ) = 13418.4 
C      henke(77,2, 463 ) = 67.7144 
C      henke(77,3, 463 ) = 10.4973 
C      henke(77,1, 464 ) = 13418.6 
C      henke(77,2, 464 ) = 67.7161 
C      henke(77,3, 464 ) = 11.9016 
C      henke(77,1, 465 ) = 13449.7 
C      henke(77,2, 465 ) = 70.0605 
C      henke(77,3, 465 ) = 11.8614 
C      henke(77,1, 466 ) = 13667.2 
C      henke(77,2, 466 ) = 71.4638 
C      henke(77,3, 466 ) = 11.5862 
C      henke(77,1, 467 ) = 13888.3 
C      henke(77,2, 467 ) = 72.1629 
C      henke(77,3, 467 ) = 11.3157 
C      henke(77,1, 468 ) = 14112.9 
C      henke(77,2, 468 ) = 72.6906 
C      henke(77,3, 468 ) = 11.0499 
C      henke(77,1, 469 ) = 14341.2 
C      henke(77,2, 469 ) = 73.1237 
C      henke(77,3, 469 ) = 10.7889 
C      henke(77,1, 470 ) = 14573.1 
C      henke(77,2, 470 ) = 73.4929 
C      henke(77,3, 470 ) = 10.5326 
C      henke(77,1, 471 ) = 14808.9 
C      henke(77,2, 471 ) = 73.8143 
C      henke(77,3, 471 ) = 10.281 
C      henke(77,1, 472 ) = 15048.4 
C      henke(77,2, 472 ) = 74.0982 
C      henke(77,3, 472 ) = 10.0342 
C      henke(77,1, 473 ) = 15291.8 
C      henke(77,2, 473 ) = 74.3512 
C      henke(77,3, 473 ) = 9.79217 
C      henke(77,1, 474 ) = 15539.1 
C      henke(77,2, 474 ) = 74.5783 
C      henke(77,3, 474 ) = 9.55482 
C      henke(77,1, 475 ) = 15790.4 
C      henke(77,2, 475 ) = 74.7832 
C      henke(77,3, 475 ) = 9.32215 
C      henke(77,1, 476 ) = 16045.8 
C      henke(77,2, 476 ) = 74.9687 
C      henke(77,3, 476 ) = 9.09416 
C      henke(77,1, 477 ) = 16305.4 
C      henke(77,2, 477 ) = 75.1372 
C      henke(77,3, 477 ) = 8.8708 
C      henke(77,1, 478 ) = 16569.1 
C      henke(77,2, 478 ) = 75.2905 
C      henke(77,3, 478 ) = 8.65203 
C      henke(77,1, 479 ) = 16837.1 
C      henke(77,2, 479 ) = 75.4303 
C      henke(77,3, 479 ) = 8.43782 
C      henke(77,1, 480 ) = 17109.4 
C      henke(77,2, 480 ) = 75.5577 
C      henke(77,3, 480 ) = 8.22812 
C      henke(77,1, 481 ) = 17386.1 
C      henke(77,2, 481 ) = 75.674 
C      henke(77,3, 481 ) = 8.02289 
C      henke(77,1, 482 ) = 17667.4 
C      henke(77,2, 482 ) = 75.7802 
C      henke(77,3, 482 ) = 7.82207 
C      henke(77,1, 483 ) = 17953.1 
C      henke(77,2, 483 ) = 75.8771 
C      henke(77,3, 483 ) = 7.62561 
C      henke(77,1, 484 ) = 18243.5 
C      henke(77,2, 484 ) = 75.9654 
C      henke(77,3, 484 ) = 7.43346 
C      henke(77,1, 485 ) = 18538.6 
C      henke(77,2, 485 ) = 76.0459 
C      henke(77,3, 485 ) = 7.24557 
C      henke(77,1, 486 ) = 18838.4 
C      henke(77,2, 486 ) = 76.1192 
C      henke(77,3, 486 ) = 7.06186 
C      henke(77,1, 487 ) = 19143.1 
C      henke(77,2, 487 ) = 76.1858 
C      henke(77,3, 487 ) = 6.88229 
C      henke(77,1, 488 ) = 19452.7 
C      henke(77,2, 488 ) = 76.2462 
C      henke(77,3, 488 ) = 6.70679 
C      henke(77,1, 489 ) = 19767.4 
C      henke(77,2, 489 ) = 76.3008 
C      henke(77,3, 489 ) = 6.5353 
C      henke(77,1, 490 ) = 20087.1 
C      henke(77,2, 490 ) = 76.35 
C      henke(77,3, 490 ) = 6.36775 
C      henke(77,1, 491 ) = 20412 
C      henke(77,2, 491 ) = 76.3943 
C      henke(77,3, 491 ) = 6.20408 
C      henke(77,1, 492 ) = 20742.1 
C      henke(77,2, 492 ) = 76.4339 
C      henke(77,3, 492 ) = 6.04423 
C      henke(77,1, 493 ) = 21077.6 
C      henke(77,2, 493 ) = 76.4692 
C      henke(77,3, 493 ) = 5.88813 
C      henke(77,1, 494 ) = 21418.5 
C      henke(77,2, 494 ) = 76.5005 
C      henke(77,3, 494 ) = 5.73571 
C      henke(77,1, 495 ) = 21765 
C      henke(77,2, 495 ) = 76.528 
C      henke(77,3, 495 ) = 5.58691 
C      henke(77,1, 496 ) = 22117 
C      henke(77,2, 496 ) = 76.5519 
C      henke(77,3, 496 ) = 5.44167 
C      henke(77,1, 497 ) = 22474.7 
C      henke(77,2, 497 ) = 76.5726 
C      henke(77,3, 497 ) = 5.29991 
C      henke(77,1, 498 ) = 22838.2 
C      henke(77,2, 498 ) = 76.5902 
C      henke(77,3, 498 ) = 5.16156 
C      henke(77,1, 499 ) = 23207.6 
C      henke(77,2, 499 ) = 76.6049 
C      henke(77,3, 499 ) = 5.02658 
C      henke(77,1, 500 ) = 23583 
C      henke(77,2, 500 ) = 76.617 
C      henke(77,3, 500 ) = 4.89487 
C      henke(77,1, 501 ) = 23964.4 
C      henke(77,2, 501 ) = 76.6265 
C      henke(77,3, 501 ) = 4.76639 
C      henke(77,1, 502 ) = 24352 
C      henke(77,2, 502 ) = 76.6337 
C      henke(77,3, 502 ) = 4.64107 
C      henke(77,1, 503 ) = 24745.9 
C      henke(77,2, 503 ) = 76.6386 
C      henke(77,3, 503 ) = 4.51884 
C      henke(77,1, 504 ) = 25146.2 
C      henke(77,2, 504 ) = 76.6415 
C      henke(77,3, 504 ) = 4.39963 
C      henke(77,1, 505 ) = 25552.9 
C      henke(77,2, 505 ) = 76.6425 
C      henke(77,3, 505 ) = 4.2834 
C      henke(77,1, 506 ) = 25966.2 
C      henke(77,2, 506 ) = 76.6417 
C      henke(77,3, 506 ) = 4.17006 
C      henke(77,1, 507 ) = 26386.1 
C      henke(77,2, 507 ) = 76.6391 
C      henke(77,3, 507 ) = 4.05956 
C      henke(77,1, 508 ) = 26812.9 
C      henke(77,2, 508 ) = 76.635 
C      henke(77,3, 508 ) = 3.95184 
C      henke(77,1, 509 ) = 27246.6 
C      henke(77,2, 509 ) = 76.6295 
C      henke(77,3, 509 ) = 3.84683 
C      henke(77,1, 510 ) = 27687.3 
C      henke(77,2, 510 ) = 76.6226 
C      henke(77,3, 510 ) = 3.74448 
C      henke(77,1, 511 ) = 28135.1 
C      henke(77,2, 511 ) = 76.6144 
C      henke(77,3, 511 ) = 3.64473 
C      henke(77,1, 512 ) = 28590.2 
C      henke(77,2, 512 ) = 76.6051 
C      henke(77,3, 512 ) = 3.54751 
C      henke(77,1, 513 ) = 29052.6 
C      henke(77,2, 513 ) = 76.5953 
C      henke(77,3, 513 ) = 3.45278 
C      henke(77,1, 514 ) = 29522.5 
C      henke(77,2, 514 ) = 76.5935 
C      henke(77,3, 514 ) = 3.36047 
C      henke(77,1, 515 ) = 30000 
C      henke(77,2, 515 ) = 76.5426 
C      henke(77,3, 515 ) = 3.27053 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C        Henke data for be  z=4
C      count(4) = 502
C      henke(4,1, 1 ) = 10 
C      henke(4,2, 1 ) = -9999 
C      henke(4,3, 1 ) = 0.398134 
C      henke(4,1, 2 ) = 10.1617 
C      henke(4,2, 2 ) = -9999 
C      henke(4,3, 2 ) = 0.407934 
C      henke(4,1, 3 ) = 10.3261 
C      henke(4,2, 3 ) = -9999 
C      henke(4,3, 3 ) = 0.417975 
C      henke(4,1, 4 ) = 10.4931 
C      henke(4,2, 4 ) = -9999 
C      henke(4,3, 4 ) = 0.428263 
C      henke(4,1, 5 ) = 10.6628 
C      henke(4,2, 5 ) = -9999 
C      henke(4,3, 5 ) = 0.438804 
C      henke(4,1, 6 ) = 10.8353 
C      henke(4,2, 6 ) = -9999 
C      henke(4,3, 6 ) = 0.449604 
C      henke(4,1, 7 ) = 11.0106 
C      henke(4,2, 7 ) = -9999 
C      henke(4,3, 7 ) = 0.460217 
C      henke(4,1, 8 ) = 11.1886 
C      henke(4,2, 8 ) = -9999 
C      henke(4,3, 8 ) = 0.467574 
C      henke(4,1, 9 ) = 11.3696 
C      henke(4,2, 9 ) = -9999 
C      henke(4,3, 9 ) = 0.475049 
C      henke(4,1, 10 ) = 11.5535 
C      henke(4,2, 10 ) = -9999 
C      henke(4,3, 10 ) = 0.482651 
C      henke(4,1, 11 ) = 11.7404 
C      henke(4,2, 11 ) = -9999 
C      henke(4,3, 11 ) = 0.490468 
C      henke(4,1, 12 ) = 11.9303 
C      henke(4,2, 12 ) = -9999 
C      henke(4,3, 12 ) = 0.498411 
C      henke(4,1, 13 ) = 12.1232 
C      henke(4,2, 13 ) = -9999 
C      henke(4,3, 13 ) = 0.506506 
C      henke(4,1, 14 ) = 12.3193 
C      henke(4,2, 14 ) = -9999 
C      henke(4,3, 14 ) = 0.514745 
C      henke(4,1, 15 ) = 12.5186 
C      henke(4,2, 15 ) = -9999 
C      henke(4,3, 15 ) = 0.51971 
C      henke(4,1, 16 ) = 12.721 
C      henke(4,2, 16 ) = -9999 
C      henke(4,3, 16 ) = 0.524527 
C      henke(4,1, 17 ) = 12.9268 
C      henke(4,2, 17 ) = -9999 
C      henke(4,3, 17 ) = 0.529388 
C      henke(4,1, 18 ) = 13.1359 
C      henke(4,2, 18 ) = -9999 
C      henke(4,3, 18 ) = 0.533988 
C      henke(4,1, 19 ) = 13.3483 
C      henke(4,2, 19 ) = -9999 
C      henke(4,3, 19 ) = 0.53642 
C      henke(4,1, 20 ) = 13.5642 
C      henke(4,2, 20 ) = -9999 
C      henke(4,3, 20 ) = 0.538862 
C      henke(4,1, 21 ) = 13.7836 
C      henke(4,2, 21 ) = -9999 
C      henke(4,3, 21 ) = 0.541382 
C      henke(4,1, 22 ) = 14.0066 
C      henke(4,2, 22 ) = -9999 
C      henke(4,3, 22 ) = 0.544467 
C      henke(4,1, 23 ) = 14.2331 
C      henke(4,2, 23 ) = -9999 
C      henke(4,3, 23 ) = 0.547569 
C      henke(4,1, 24 ) = 14.4633 
C      henke(4,2, 24 ) = -9999 
C      henke(4,3, 24 ) = 0.55003 
C      henke(4,1, 25 ) = 14.6973 
C      henke(4,2, 25 ) = -9999 
C      henke(4,3, 25 ) = 0.5521 
C      henke(4,1, 26 ) = 14.935 
C      henke(4,2, 26 ) = -9999 
C      henke(4,3, 26 ) = 0.554176 
C      henke(4,1, 27 ) = 15.1765 
C      henke(4,2, 27 ) = -9999 
C      henke(4,3, 27 ) = 0.556607 
C      henke(4,1, 28 ) = 15.422 
C      henke(4,2, 28 ) = -9999 
C      henke(4,3, 28 ) = 0.559129 
C      henke(4,1, 29 ) = 15.6714 
C      henke(4,2, 29 ) = -9999 
C      henke(4,3, 29 ) = 0.561662 
C      henke(4,1, 30 ) = 15.9249 
C      henke(4,2, 30 ) = -9999 
C      henke(4,3, 30 ) = 0.563425 
C      henke(4,1, 31 ) = 16.1825 
C      henke(4,2, 31 ) = -9999 
C      henke(4,3, 31 ) = 0.564956 
C      henke(4,1, 32 ) = 16.4442 
C      henke(4,2, 32 ) = -9999 
C      henke(4,3, 32 ) = 0.566492 
C      henke(4,1, 33 ) = 16.7102 
C      henke(4,2, 33 ) = -9999 
C      henke(4,3, 33 ) = 0.565608 
C      henke(4,1, 34 ) = 16.9805 
C      henke(4,2, 34 ) = -9999 
C      henke(4,3, 34 ) = 0.562546 
C      henke(4,1, 35 ) = 17.2551 
C      henke(4,2, 35 ) = -9999 
C      henke(4,3, 35 ) = 0.559501 
C      henke(4,1, 36 ) = 17.5342 
C      henke(4,2, 36 ) = -9999 
C      henke(4,3, 36 ) = 0.556472 
C      henke(4,1, 37 ) = 17.8178 
C      henke(4,2, 37 ) = -9999 
C      henke(4,3, 37 ) = 0.553415 
C      henke(4,1, 38 ) = 18.106 
C      henke(4,2, 38 ) = -9999 
C      henke(4,3, 38 ) = 0.550372 
C      henke(4,1, 39 ) = 18.3989 
C      henke(4,2, 39 ) = -9999 
C      henke(4,3, 39 ) = 0.547346 
C      henke(4,1, 40 ) = 18.6964 
C      henke(4,2, 40 ) = -9999 
C      henke(4,3, 40 ) = 0.544766 
C      henke(4,1, 41 ) = 18.9988 
C      henke(4,2, 41 ) = -9999 
C      henke(4,3, 41 ) = 0.542359 
C      henke(4,1, 42 ) = 19.3061 
C      henke(4,2, 42 ) = -9999 
C      henke(4,3, 42 ) = 0.539963 
C      henke(4,1, 43 ) = 19.6184 
C      henke(4,2, 43 ) = -9999 
C      henke(4,3, 43 ) = 0.537577 
C      henke(4,1, 44 ) = 19.9357 
C      henke(4,2, 44 ) = -9999 
C      henke(4,3, 44 ) = 0.532883 
C      henke(4,1, 45 ) = 20.2582 
C      henke(4,2, 45 ) = -9999 
C      henke(4,3, 45 ) = 0.52806 
C      henke(4,1, 46 ) = 20.5858 
C      henke(4,2, 46 ) = -9999 
C      henke(4,3, 46 ) = 0.523282 
C      henke(4,1, 47 ) = 20.9188 
C      henke(4,2, 47 ) = -9999 
C      henke(4,3, 47 ) = 0.51879 
C      henke(4,1, 48 ) = 21.2571 
C      henke(4,2, 48 ) = -9999 
C      henke(4,3, 48 ) = 0.514914 
C      henke(4,1, 49 ) = 21.6009 
C      henke(4,2, 49 ) = -9999 
C      henke(4,3, 49 ) = 0.511068 
C      henke(4,1, 50 ) = 21.9503 
C      henke(4,2, 50 ) = -9999 
C      henke(4,3, 50 ) = 0.50725 
C      henke(4,1, 51 ) = 22.3053 
C      henke(4,2, 51 ) = -9999 
C      henke(4,3, 51 ) = 0.503461 
C      henke(4,1, 52 ) = 22.6661 
C      henke(4,2, 52 ) = -9999 
C      henke(4,3, 52 ) = 0.499701 
C      henke(4,1, 53 ) = 23.0327 
C      henke(4,2, 53 ) = -9999 
C      henke(4,3, 53 ) = 0.495968 
C      henke(4,1, 54 ) = 23.4053 
C      henke(4,2, 54 ) = -9999 
C      henke(4,3, 54 ) = 0.492263 
C      henke(4,1, 55 ) = 23.7838 
C      henke(4,2, 55 ) = -9999 
C      henke(4,3, 55 ) = 0.488586 
C      henke(4,1, 56 ) = 24.1685 
C      henke(4,2, 56 ) = -9999 
C      henke(4,3, 56 ) = 0.484936 
C      henke(4,1, 57 ) = 24.5594 
C      henke(4,2, 57 ) = -9999 
C      henke(4,3, 57 ) = 0.481314 
C      henke(4,1, 58 ) = 24.9566 
C      henke(4,2, 58 ) = -9999 
C      henke(4,3, 58 ) = 0.477718 
C      henke(4,1, 59 ) = 25.3603 
C      henke(4,2, 59 ) = -9999 
C      henke(4,3, 59 ) = 0.47415 
C      henke(4,1, 60 ) = 25.7705 
C      henke(4,2, 60 ) = -9999 
C      henke(4,3, 60 ) = 0.470608 
C      henke(4,1, 61 ) = 26.1873 
C      henke(4,2, 61 ) = -9999 
C      henke(4,3, 61 ) = 0.467093 
C      henke(4,1, 62 ) = 26.6109 
C      henke(4,2, 62 ) = -9999 
C      henke(4,3, 62 ) = 0.463603 
C      henke(4,1, 63 ) = 27.0413 
C      henke(4,2, 63 ) = -9999 
C      henke(4,3, 63 ) = 0.460141 
C      henke(4,1, 64 ) = 27.4786 
C      henke(4,2, 64 ) = -9999 
C      henke(4,3, 64 ) = 0.456703 
C      henke(4,1, 65 ) = 27.9231 
C      henke(4,2, 65 ) = -9999 
C      henke(4,3, 65 ) = 0.453292 
C      henke(4,1, 66 ) = 28.3747 
C      henke(4,2, 66 ) = -9999 
C      henke(4,3, 66 ) = 0.449905 
C      henke(4,1, 67 ) = 28.8337 
C      henke(4,2, 67 ) = -9999 
C      henke(4,3, 67 ) = 0.446545 
C      henke(4,1, 68 ) = 29.3 
C      henke(4,2, 68 ) = 1.78392 
C      henke(4,3, 68 ) = 0.443209 
C      henke(4,1, 69 ) = 29.7739 
C      henke(4,2, 69 ) = 1.78619 
C      henke(4,3, 69 ) = 0.440577 
C      henke(4,1, 70 ) = 30.2555 
C      henke(4,2, 70 ) = 1.78894 
C      henke(4,3, 70 ) = 0.438415 
C      henke(4,1, 71 ) = 30.7449 
C      henke(4,2, 71 ) = 1.79184 
C      henke(4,3, 71 ) = 0.436264 
C      henke(4,1, 72 ) = 31.2421 
C      henke(4,2, 72 ) = 1.79477 
C      henke(4,3, 72 ) = 0.434123 
C      henke(4,1, 73 ) = 31.7475 
C      henke(4,2, 73 ) = 1.79771 
C      henke(4,3, 73 ) = 0.431993 
C      henke(4,1, 74 ) = 32.2609 
C      henke(4,2, 74 ) = 1.80063 
C      henke(4,3, 74 ) = 0.429873 
C      henke(4,1, 75 ) = 32.7827 
C      henke(4,2, 75 ) = 1.80351 
C      henke(4,3, 75 ) = 0.427764 
C      henke(4,1, 76 ) = 33.313 
C      henke(4,2, 76 ) = 1.80636 
C      henke(4,3, 76 ) = 0.425665 
C      henke(4,1, 77 ) = 33.8518 
C      henke(4,2, 77 ) = 1.80917 
C      henke(4,3, 77 ) = 0.423576 
C      henke(4,1, 78 ) = 34.3993 
C      henke(4,2, 78 ) = 1.81195 
C      henke(4,3, 78 ) = 0.421498 
C      henke(4,1, 79 ) = 34.9557 
C      henke(4,2, 79 ) = 1.81469 
C      henke(4,3, 79 ) = 0.41943 
C      henke(4,1, 80 ) = 35.5211 
C      henke(4,2, 80 ) = 1.81741 
C      henke(4,3, 80 ) = 0.417372 
C      henke(4,1, 81 ) = 36.0956 
C      henke(4,2, 81 ) = 1.82013 
C      henke(4,3, 81 ) = 0.415324 
C      henke(4,1, 82 ) = 36.6794 
C      henke(4,2, 82 ) = 1.82288 
C      henke(4,3, 82 ) = 0.413286 
C      henke(4,1, 83 ) = 37.2727 
C      henke(4,2, 83 ) = 1.82573 
C      henke(4,3, 83 ) = 0.411258 
C      henke(4,1, 84 ) = 37.8755 
C      henke(4,2, 84 ) = 1.82883 
C      henke(4,3, 84 ) = 0.409241 
C      henke(4,1, 85 ) = 38.4882 
C      henke(4,2, 85 ) = 1.83271 
C      henke(4,3, 85 ) = 0.406912 
C      henke(4,1, 86 ) = 39.1107 
C      henke(4,2, 86 ) = 1.83607 
C      henke(4,3, 86 ) = 0.402694 
C      henke(4,1, 87 ) = 39.7432 
C      henke(4,2, 87 ) = 1.83846 
C      henke(4,3, 87 ) = 0.39852 
C      henke(4,1, 88 ) = 40.3861 
C      henke(4,2, 88 ) = 1.84026 
C      henke(4,3, 88 ) = 0.394389 
C      henke(4,1, 89 ) = 41.0393 
C      henke(4,2, 89 ) = 1.84164 
C      henke(4,3, 89 ) = 0.390301 
C      henke(4,1, 90 ) = 41.7031 
C      henke(4,2, 90 ) = 1.84265 
C      henke(4,3, 90 ) = 0.386255 
C      henke(4,1, 91 ) = 42.3776 
C      henke(4,2, 91 ) = 1.84333 
C      henke(4,3, 91 ) = 0.382251 
C      henke(4,1, 92 ) = 43.063 
C      henke(4,2, 92 ) = 1.84369 
C      henke(4,3, 92 ) = 0.378288 
C      henke(4,1, 93 ) = 43.7595 
C      henke(4,2, 93 ) = 1.84375 
C      henke(4,3, 93 ) = 0.374367 
C      henke(4,1, 94 ) = 44.4673 
C      henke(4,2, 94 ) = 1.84352 
C      henke(4,3, 94 ) = 0.370486 
C      henke(4,1, 95 ) = 45.1865 
C      henke(4,2, 95 ) = 1.843 
C      henke(4,3, 95 ) = 0.366646 
C      henke(4,1, 96 ) = 45.9174 
C      henke(4,2, 96 ) = 1.8422 
C      henke(4,3, 96 ) = 0.362845 
C      henke(4,1, 97 ) = 46.66 
C      henke(4,2, 97 ) = 1.84111 
C      henke(4,3, 97 ) = 0.359084 
C      henke(4,1, 98 ) = 47.4147 
C      henke(4,2, 98 ) = 1.83975 
C      henke(4,3, 98 ) = 0.355362 
C      henke(4,1, 99 ) = 48.1816 
C      henke(4,2, 99 ) = 1.83811 
C      henke(4,3, 99 ) = 0.351678 
C      henke(4,1, 100 ) = 48.9609 
C      henke(4,2, 100 ) = 1.83621 
C      henke(4,3, 100 ) = 0.348033 
C      henke(4,1, 101 ) = 49.7528 
C      henke(4,2, 101 ) = 1.83405 
C      henke(4,3, 101 ) = 0.344425 
C      henke(4,1, 102 ) = 50.5576 
C      henke(4,2, 102 ) = 1.83168 
C      henke(4,3, 102 ) = 0.340855 
C      henke(4,1, 103 ) = 51.3753 
C      henke(4,2, 103 ) = 1.82924 
C      henke(4,3, 103 ) = 0.337244 
C      henke(4,1, 104 ) = 52.2062 
C      henke(4,2, 104 ) = 1.82637 
C      henke(4,3, 104 ) = 0.333149 
C      henke(4,1, 105 ) = 53.0506 
C      henke(4,2, 105 ) = 1.82296 
C      henke(4,3, 105 ) = 0.329103 
C      henke(4,1, 106 ) = 53.9087 
C      henke(4,2, 106 ) = 1.81912 
C      henke(4,3, 106 ) = 0.325107 
C      henke(4,1, 107 ) = 54.7806 
C      henke(4,2, 107 ) = 1.81491 
C      henke(4,3, 107 ) = 0.32116 
C      henke(4,1, 108 ) = 55.6667 
C      henke(4,2, 108 ) = 1.81043 
C      henke(4,3, 108 ) = 0.31726 
C      henke(4,1, 109 ) = 56.567 
C      henke(4,2, 109 ) = 1.80599 
C      henke(4,3, 109 ) = 0.313408 
C      henke(4,1, 110 ) = 57.482 
C      henke(4,2, 110 ) = 1.80107 
C      henke(4,3, 110 ) = 0.308206 
C      henke(4,1, 111 ) = 58.4117 
C      henke(4,2, 111 ) = 1.79497 
C      henke(4,3, 111 ) = 0.30297 
C      henke(4,1, 112 ) = 59.3564 
C      henke(4,2, 112 ) = 1.78794 
C      henke(4,3, 112 ) = 0.297823 
C      henke(4,1, 113 ) = 60.3165 
C      henke(4,2, 113 ) = 1.78014 
C      henke(4,3, 113 ) = 0.292764 
C      henke(4,1, 114 ) = 61.2921 
C      henke(4,2, 114 ) = 1.77158 
C      henke(4,3, 114 ) = 0.28779 
C      henke(4,1, 115 ) = 62.2834 
C      henke(4,2, 115 ) = 1.76226 
C      henke(4,3, 115 ) = 0.282901 
C      henke(4,1, 116 ) = 63.2908 
C      henke(4,2, 116 ) = 1.75216 
C      henke(4,3, 116 ) = 0.278095 
C      henke(4,1, 117 ) = 64.3145 
C      henke(4,2, 117 ) = 1.74127 
C      henke(4,3, 117 ) = 0.273371 
C      henke(4,1, 118 ) = 65.3547 
C      henke(4,2, 118 ) = 1.72955 
C      henke(4,3, 118 ) = 0.268727 
C      henke(4,1, 119 ) = 66.4118 
C      henke(4,2, 119 ) = 1.71697 
C      henke(4,3, 119 ) = 0.264162 
C      henke(4,1, 120 ) = 67.4859 
C      henke(4,2, 120 ) = 1.70347 
C      henke(4,3, 120 ) = 0.259674 
C      henke(4,1, 121 ) = 68.5775 
C      henke(4,2, 121 ) = 1.68902 
C      henke(4,3, 121 ) = 0.255263 
C      henke(4,1, 122 ) = 69.6867 
C      henke(4,2, 122 ) = 1.67354 
C      henke(4,3, 122 ) = 0.250926 
C      henke(4,1, 123 ) = 70.8138 
C      henke(4,2, 123 ) = 1.65698 
C      henke(4,3, 123 ) = 0.246664 
C      henke(4,1, 124 ) = 71.9591 
C      henke(4,2, 124 ) = 1.63926 
C      henke(4,3, 124 ) = 0.242473 
C      henke(4,1, 125 ) = 73.123 
C      henke(4,2, 125 ) = 1.62029 
C      henke(4,3, 125 ) = 0.238354 
C      henke(4,1, 126 ) = 74.3057 
C      henke(4,2, 126 ) = 1.59998 
C      henke(4,3, 126 ) = 0.234305 
C      henke(4,1, 127 ) = 75.5076 
C      henke(4,2, 127 ) = 1.57822 
C      henke(4,3, 127 ) = 0.230325 
C      henke(4,1, 128 ) = 76.7289 
C      henke(4,2, 128 ) = 1.55489 
C      henke(4,3, 128 ) = 0.226412 
C      henke(4,1, 129 ) = 77.9699 
C      henke(4,2, 129 ) = 1.52984 
C      henke(4,3, 129 ) = 0.222566 
C      henke(4,1, 130 ) = 79.231 
C      henke(4,2, 130 ) = 1.50292 
C      henke(4,3, 130 ) = 0.218785 
C      henke(4,1, 131 ) = 80.5125 
C      henke(4,2, 131 ) = 1.47394 
C      henke(4,3, 131 ) = 0.215068 
C      henke(4,1, 132 ) = 81.8147 
C      henke(4,2, 132 ) = 1.4427 
C      henke(4,3, 132 ) = 0.211414 
C      henke(4,1, 133 ) = 83.138 
C      henke(4,2, 133 ) = 1.40894 
C      henke(4,3, 133 ) = 0.207823 
C      henke(4,1, 134 ) = 84.4827 
C      henke(4,2, 134 ) = 1.37241 
C      henke(4,3, 134 ) = 0.204292 
C      henke(4,1, 135 ) = 85.8491 
C      henke(4,2, 135 ) = 1.33277 
C      henke(4,3, 135 ) = 0.200822 
C      henke(4,1, 136 ) = 87.2377 
C      henke(4,2, 136 ) = 1.28973 
C      henke(4,3, 136 ) = 0.19741 
C      henke(4,1, 137 ) = 88.6487 
C      henke(4,2, 137 ) = 1.2432 
C      henke(4,3, 137 ) = 0.194008 
C      henke(4,1, 138 ) = 90.0825 
C      henke(4,2, 138 ) = 1.19163 
C      henke(4,3, 138 ) = 0.188958 
C      henke(4,1, 139 ) = 91.5395 
C      henke(4,2, 139 ) = 1.1338 
C      henke(4,3, 139 ) = 0.184039 
C      henke(4,1, 140 ) = 93.0201 
C      henke(4,2, 140 ) = 1.06903 
C      henke(4,3, 140 ) = 0.179248 
C      henke(4,1, 141 ) = 94.5246 
C      henke(4,2, 141 ) = 0.99628 
C      henke(4,3, 141 ) = 0.174582 
C      henke(4,1, 142 ) = 96.0535 
C      henke(4,2, 142 ) = 0.914013 
C      henke(4,3, 142 ) = 0.170037 
C      henke(4,1, 143 ) = 97.6071 
C      henke(4,2, 143 ) = 0.82015 
C      henke(4,3, 143 ) = 0.165611 
C      henke(4,1, 144 ) = 99.1858 
C      henke(4,2, 144 ) = 0.711812 
C      henke(4,3, 144 ) = 0.1613 
C      henke(4,1, 145 ) = 100.79 
C      henke(4,2, 145 ) = 0.58488 
C      henke(4,3, 145 ) = 0.157101 
C      henke(4,1, 146 ) = 102.42 
C      henke(4,2, 146 ) = 0.433182 
C      henke(4,3, 146 ) = 0.153011 
C      henke(4,1, 147 ) = 104.077 
C      henke(4,2, 147 ) = 0.246849 
C      henke(4,3, 147 ) = 0.149028 
C      henke(4,1, 148 ) = 105.76 
C      henke(4,2, 148 ) = 0.00859302 
C      henke(4,3, 148 ) = 0.145149 
C      henke(4,1, 149 ) = 107.471 
C      henke(4,2, 149 ) = -0.316509 
C      henke(4,3, 149 ) = 0.14137 
C      henke(4,1, 150 ) = 109.209 
C      henke(4,2, 150 ) = -0.819304 
C      henke(4,3, 150 ) = 0.13769 
C      henke(4,1, 151 ) = 110.975 
C      henke(4,2, 151 ) = -1.95607 
C      henke(4,3, 151 ) = 0.134106 
C      henke(4,1, 152 ) = 111.6 
C      henke(4,2, 152 ) = -3.68317 
C      henke(4,3, 152 ) = 0.132874 
C      henke(4,1, 153 ) = 111.8 
C      henke(4,2, 153 ) = -3.71547 
C      henke(4,3, 153 ) = 2.79011 
C      henke(4,1, 154 ) = 112.77 
C      henke(4,2, 154 ) = -1.8005 
C      henke(4,3, 154 ) = 2.88199 
C      henke(4,1, 155 ) = 114.594 
C      henke(4,2, 155 ) = -1.03772 
C      henke(4,3, 155 ) = 3.06065 
C      henke(4,1, 156 ) = 116.448 
C      henke(4,2, 156 ) = -0.647346 
C      henke(4,3, 156 ) = 3.25039 
C      henke(4,1, 157 ) = 118.331 
C      henke(4,2, 157 ) = -0.352768 
C      henke(4,3, 157 ) = 3.45189 
C      henke(4,1, 158 ) = 120.245 
C      henke(4,2, 158 ) = -0.0852938 
C      henke(4,3, 158 ) = 3.66589 
C      henke(4,1, 159 ) = 122.19 
C      henke(4,2, 159 ) = 0.191651 
C      henke(4,3, 159 ) = 3.89315 
C      henke(4,1, 160 ) = 124.166 
C      henke(4,2, 160 ) = 0.526998 
C      henke(4,3, 160 ) = 4.13449 
C      henke(4,1, 161 ) = 126.175 
C      henke(4,2, 161 ) = 0.901788 
C      henke(4,3, 161 ) = 4.30069 
C      henke(4,1, 162 ) = 128.215 
C      henke(4,2, 162 ) = 1.33218 
C      henke(4,3, 162 ) = 4.4669 
C      henke(4,1, 163 ) = 130.289 
C      henke(4,2, 163 ) = 1.84515 
C      henke(4,3, 163 ) = 4.50954 
C      henke(4,1, 164 ) = 132.397 
C      henke(4,2, 164 ) = 2.45528 
C      henke(4,3, 164 ) = 4.48878 
C      henke(4,1, 165 ) = 134.538 
C      henke(4,2, 165 ) = 2.99166 
C      henke(4,3, 165 ) = 3.97828 
C      henke(4,1, 166 ) = 136.714 
C      henke(4,2, 166 ) = 3.00577 
C      henke(4,3, 166 ) = 3.49585 
C      henke(4,1, 167 ) = 138.925 
C      henke(4,2, 167 ) = 2.95608 
C      henke(4,3, 167 ) = 3.22871 
C      henke(4,1, 168 ) = 141.172 
C      henke(4,2, 168 ) = 2.90972 
C      henke(4,3, 168 ) = 3.12887 
C      henke(4,1, 169 ) = 143.456 
C      henke(4,2, 169 ) = 2.91905 
C      henke(4,3, 169 ) = 3.07172 
C      henke(4,1, 170 ) = 145.776 
C      henke(4,2, 170 ) = 2.9615 
C      henke(4,3, 170 ) = 3.01561 
C      henke(4,1, 171 ) = 148.134 
C      henke(4,2, 171 ) = 3.00741 
C      henke(4,3, 171 ) = 2.96053 
C      henke(4,1, 172 ) = 150.53 
C      henke(4,2, 172 ) = 3.04782 
C      henke(4,3, 172 ) = 2.91521 
C      henke(4,1, 173 ) = 152.964 
C      henke(4,2, 173 ) = 3.0983 
C      henke(4,3, 173 ) = 2.88034 
C      henke(4,1, 174 ) = 155.439 
C      henke(4,2, 174 ) = 3.15603 
C      henke(4,3, 174 ) = 2.84589 
C      henke(4,1, 175 ) = 157.953 
C      henke(4,2, 175 ) = 3.21732 
C      henke(4,3, 175 ) = 2.81186 
C      henke(4,1, 176 ) = 160.507 
C      henke(4,2, 176 ) = 3.28594 
C      henke(4,3, 176 ) = 2.77823 
C      henke(4,1, 177 ) = 163.103 
C      henke(4,2, 177 ) = 3.35586 
C      henke(4,3, 177 ) = 2.7305 
C      henke(4,1, 178 ) = 165.742 
C      henke(4,2, 178 ) = 3.41679 
C      henke(4,3, 178 ) = 2.67935 
C      henke(4,1, 179 ) = 168.422 
C      henke(4,2, 179 ) = 3.4726 
C      henke(4,3, 179 ) = 2.62916 
C      henke(4,1, 180 ) = 171.146 
C      henke(4,2, 180 ) = 3.52493 
C      henke(4,3, 180 ) = 2.57991 
C      henke(4,1, 181 ) = 173.915 
C      henke(4,2, 181 ) = 3.57449 
C      henke(4,3, 181 ) = 2.53158 
C      henke(4,1, 182 ) = 176.727 
C      henke(4,2, 182 ) = 3.62175 
C      henke(4,3, 182 ) = 2.48416 
C      henke(4,1, 183 ) = 179.586 
C      henke(4,2, 183 ) = 3.66716 
C      henke(4,3, 183 ) = 2.43763 
C      henke(4,1, 184 ) = 182.491 
C      henke(4,2, 184 ) = 3.71131 
C      henke(4,3, 184 ) = 2.39196 
C      henke(4,1, 185 ) = 185.442 
C      henke(4,2, 185 ) = 3.75618 
C      henke(4,3, 185 ) = 2.34578 
C      henke(4,1, 186 ) = 188.442 
C      henke(4,2, 186 ) = 3.79694 
C      henke(4,3, 186 ) = 2.29644 
C      henke(4,1, 187 ) = 191.489 
C      henke(4,2, 187 ) = 3.83426 
C      henke(4,3, 187 ) = 2.24813 
C      henke(4,1, 188 ) = 194.587 
C      henke(4,2, 188 ) = 3.86897 
C      henke(4,3, 188 ) = 2.20084 
C      henke(4,1, 189 ) = 197.734 
C      henke(4,2, 189 ) = 3.90157 
C      henke(4,3, 189 ) = 2.15455 
C      henke(4,1, 190 ) = 200.932 
C      henke(4,2, 190 ) = 3.93229 
C      henke(4,3, 190 ) = 2.10922 
C      henke(4,1, 191 ) = 204.182 
C      henke(4,2, 191 ) = 3.96133 
C      henke(4,3, 191 ) = 2.06486 
C      henke(4,1, 192 ) = 207.485 
C      henke(4,2, 192 ) = 3.98887 
C      henke(4,3, 192 ) = 2.02142 
C      henke(4,1, 193 ) = 210.84 
C      henke(4,2, 193 ) = 4.01504 
C      henke(4,3, 193 ) = 1.9789 
C      henke(4,1, 194 ) = 214.251 
C      henke(4,2, 194 ) = 4.03999 
C      henke(4,3, 194 ) = 1.93727 
C      henke(4,1, 195 ) = 217.716 
C      henke(4,2, 195 ) = 4.06385 
C      henke(4,3, 195 ) = 1.89652 
C      henke(4,1, 196 ) = 221.237 
C      henke(4,2, 196 ) = 4.08676 
C      henke(4,3, 196 ) = 1.85663 
C      henke(4,1, 197 ) = 224.816 
C      henke(4,2, 197 ) = 4.10888 
C      henke(4,3, 197 ) = 1.81757 
C      henke(4,1, 198 ) = 228.452 
C      henke(4,2, 198 ) = 4.13041 
C      henke(4,3, 198 ) = 1.77934 
C      henke(4,1, 199 ) = 232.147 
C      henke(4,2, 199 ) = 4.15165 
C      henke(4,3, 199 ) = 1.74191 
C      henke(4,1, 200 ) = 235.902 
C      henke(4,2, 200 ) = 4.17319 
C      henke(4,3, 200 ) = 1.70527 
C      henke(4,1, 201 ) = 239.717 
C      henke(4,2, 201 ) = 4.19759 
C      henke(4,3, 201 ) = 1.6689 
C      henke(4,1, 202 ) = 243.595 
C      henke(4,2, 202 ) = 4.21916 
C      henke(4,3, 202 ) = 1.62506 
C      henke(4,1, 203 ) = 247.535 
C      henke(4,2, 203 ) = 4.23679 
C      henke(4,3, 203 ) = 1.58238 
C      henke(4,1, 204 ) = 251.538 
C      henke(4,2, 204 ) = 4.25163 
C      henke(4,3, 204 ) = 1.54083 
C      henke(4,1, 205 ) = 255.607 
C      henke(4,2, 205 ) = 4.26461 
C      henke(4,3, 205 ) = 1.50036 
C      henke(4,1, 206 ) = 259.741 
C      henke(4,2, 206 ) = 4.27605 
C      henke(4,3, 206 ) = 1.46095 
C      henke(4,1, 207 ) = 263.942 
C      henke(4,2, 207 ) = 4.28617 
C      henke(4,3, 207 ) = 1.42258 
C      henke(4,1, 208 ) = 268.211 
C      henke(4,2, 208 ) = 4.29512 
C      henke(4,3, 208 ) = 1.38522 
C      henke(4,1, 209 ) = 272.549 
C      henke(4,2, 209 ) = 4.30302 
C      henke(4,3, 209 ) = 1.34884 
C      henke(4,1, 210 ) = 276.957 
C      henke(4,2, 210 ) = 4.30997 
C      henke(4,3, 210 ) = 1.31342 
C      henke(4,1, 211 ) = 281.437 
C      henke(4,2, 211 ) = 4.31606 
C      henke(4,3, 211 ) = 1.27892 
C      henke(4,1, 212 ) = 285.989 
C      henke(4,2, 212 ) = 4.32135 
C      henke(4,3, 212 ) = 1.24533 
C      henke(4,1, 213 ) = 290.615 
C      henke(4,2, 213 ) = 4.32591 
C      henke(4,3, 213 ) = 1.21263 
C      henke(4,1, 214 ) = 295.315 
C      henke(4,2, 214 ) = 4.32978 
C      henke(4,3, 214 ) = 1.18078 
C      henke(4,1, 215 ) = 300.092 
C      henke(4,2, 215 ) = 4.33301 
C      henke(4,3, 215 ) = 1.14977 
C      henke(4,1, 216 ) = 304.945 
C      henke(4,2, 216 ) = 4.3356 
C      henke(4,3, 216 ) = 1.11957 
C      henke(4,1, 217 ) = 309.878 
C      henke(4,2, 217 ) = 4.33752 
C      henke(4,3, 217 ) = 1.09017 
C      henke(4,1, 218 ) = 314.89 
C      henke(4,2, 218 ) = 4.33862 
C      henke(4,3, 218 ) = 1.06196 
C      henke(4,1, 219 ) = 319.983 
C      henke(4,2, 219 ) = 4.33968 
C      henke(4,3, 219 ) = 1.03493 
C      henke(4,1, 220 ) = 325.158 
C      henke(4,2, 220 ) = 4.34068 
C      henke(4,3, 220 ) = 1.00857 
C      henke(4,1, 221 ) = 330.418 
C      henke(4,2, 221 ) = 4.34144 
C      henke(4,3, 221 ) = 0.982895 
C      henke(4,1, 222 ) = 335.762 
C      henke(4,2, 222 ) = 4.34199 
C      henke(4,3, 222 ) = 0.957879 
C      henke(4,1, 223 ) = 341.192 
C      henke(4,2, 223 ) = 4.34231 
C      henke(4,3, 223 ) = 0.933502 
C      henke(4,1, 224 ) = 346.711 
C      henke(4,2, 224 ) = 4.34244 
C      henke(4,3, 224 ) = 0.909753 
C      henke(4,1, 225 ) = 352.319 
C      henke(4,2, 225 ) = 4.34241 
C      henke(4,3, 225 ) = 0.886606 
C      henke(4,1, 226 ) = 358.017 
C      henke(4,2, 226 ) = 4.3422 
C      henke(4,3, 226 ) = 0.864038 
C      henke(4,1, 227 ) = 363.808 
C      henke(4,2, 227 ) = 4.34187 
C      henke(4,3, 227 ) = 0.842061 
C      henke(4,1, 228 ) = 369.692 
C      henke(4,2, 228 ) = 4.34147 
C      henke(4,3, 228 ) = 0.82064 
C      henke(4,1, 229 ) = 375.672 
C      henke(4,2, 229 ) = 4.34104 
C      henke(4,3, 229 ) = 0.799753 
C      henke(4,1, 230 ) = 381.748 
C      henke(4,2, 230 ) = 4.34069 
C      henke(4,3, 230 ) = 0.7794 
C      henke(4,1, 231 ) = 387.922 
C      henke(4,2, 231 ) = 4.34072 
C      henke(4,3, 231 ) = 0.759289 
C      henke(4,1, 232 ) = 394.197 
C      henke(4,2, 232 ) = 4.34074 
C      henke(4,3, 232 ) = 0.7391 
C      henke(4,1, 233 ) = 400.573 
C      henke(4,2, 233 ) = 4.34043 
C      henke(4,3, 233 ) = 0.718469 
C      henke(4,1, 234 ) = 407.052 
C      henke(4,2, 234 ) = 4.33923 
C      henke(4,3, 234 ) = 0.698036 
C      henke(4,1, 235 ) = 413.635 
C      henke(4,2, 235 ) = 4.33747 
C      henke(4,3, 235 ) = 0.678186 
C      henke(4,1, 236 ) = 420.326 
C      henke(4,2, 236 ) = 4.33533 
C      henke(4,3, 236 ) = 0.658904 
C      henke(4,1, 237 ) = 427.124 
C      henke(4,2, 237 ) = 4.33291 
C      henke(4,3, 237 ) = 0.64017 
C      henke(4,1, 238 ) = 434.032 
C      henke(4,2, 238 ) = 4.33024 
C      henke(4,3, 238 ) = 0.621962 
C      henke(4,1, 239 ) = 441.052 
C      henke(4,2, 239 ) = 4.32738 
C      henke(4,3, 239 ) = 0.604274 
C      henke(4,1, 240 ) = 448.186 
C      henke(4,2, 240 ) = 4.3244 
C      henke(4,3, 240 ) = 0.587076 
C      henke(4,1, 241 ) = 455.435 
C      henke(4,2, 241 ) = 4.32126 
C      henke(4,3, 241 ) = 0.570302 
C      henke(4,1, 242 ) = 462.802 
C      henke(4,2, 242 ) = 4.31797 
C      henke(4,3, 242 ) = 0.553961 
C      henke(4,1, 243 ) = 470.287 
C      henke(4,2, 243 ) = 4.31452 
C      henke(4,3, 243 ) = 0.538064 
C      henke(4,1, 244 ) = 477.894 
C      henke(4,2, 244 ) = 4.31094 
C      henke(4,3, 244 ) = 0.522621 
C      henke(4,1, 245 ) = 485.623 
C      henke(4,2, 245 ) = 4.30727 
C      henke(4,3, 245 ) = 0.507623 
C      henke(4,1, 246 ) = 493.478 
C      henke(4,2, 246 ) = 4.30351 
C      henke(4,3, 246 ) = 0.493056 
C      henke(4,1, 247 ) = 501.459 
C      henke(4,2, 247 ) = 4.29969 
C      henke(4,3, 247 ) = 0.478909 
C      henke(4,1, 248 ) = 509.57 
C      henke(4,2, 248 ) = 4.29581 
C      henke(4,3, 248 ) = 0.465162 
C      henke(4,1, 249 ) = 517.812 
C      henke(4,2, 249 ) = 4.29185 
C      henke(4,3, 249 ) = 0.451825 
C      henke(4,1, 250 ) = 526.187 
C      henke(4,2, 250 ) = 4.28787 
C      henke(4,3, 250 ) = 0.438924 
C      henke(4,1, 251 ) = 534.698 
C      henke(4,2, 251 ) = 4.28391 
C      henke(4,3, 251 ) = 0.426483 
C      henke(4,1, 252 ) = 543.346 
C      henke(4,2, 252 ) = 4.28007 
C      henke(4,3, 252 ) = 0.414437 
C      henke(4,1, 253 ) = 552.134 
C      henke(4,2, 253 ) = 4.27645 
C      henke(4,3, 253 ) = 0.402734 
C      henke(4,1, 254 ) = 561.065 
C      henke(4,2, 254 ) = 4.27294 
C      henke(4,3, 254 ) = 0.390883 
C      henke(4,1, 255 ) = 570.139 
C      henke(4,2, 255 ) = 4.26911 
C      henke(4,3, 255 ) = 0.379178 
C      henke(4,1, 256 ) = 579.361 
C      henke(4,2, 256 ) = 4.2651 
C      henke(4,3, 256 ) = 0.367948 
C      henke(4,1, 257 ) = 588.732 
C      henke(4,2, 257 ) = 4.26106 
C      henke(4,3, 257 ) = 0.357094 
C      henke(4,1, 258 ) = 598.254 
C      henke(4,2, 258 ) = 4.25705 
C      henke(4,3, 258 ) = 0.346587 
C      henke(4,1, 259 ) = 607.93 
C      henke(4,2, 259 ) = 4.25308 
C      henke(4,3, 259 ) = 0.3364 
C      henke(4,1, 260 ) = 617.763 
C      henke(4,2, 260 ) = 4.24919 
C      henke(4,3, 260 ) = 0.326505 
C      henke(4,1, 261 ) = 627.755 
C      henke(4,2, 261 ) = 4.24546 
C      henke(4,3, 261 ) = 0.316873 
C      henke(4,1, 262 ) = 637.908 
C      henke(4,2, 262 ) = 4.24185 
C      henke(4,3, 262 ) = 0.307247 
C      henke(4,1, 263 ) = 648.226 
C      henke(4,2, 263 ) = 4.23817 
C      henke(4,3, 263 ) = 0.297505 
C      henke(4,1, 264 ) = 658.711 
C      henke(4,2, 264 ) = 4.23403 
C      henke(4,3, 264 ) = 0.28781 
C      henke(4,1, 265 ) = 669.365 
C      henke(4,2, 265 ) = 4.22936 
C      henke(4,3, 265 ) = 0.278431 
C      henke(4,1, 266 ) = 680.191 
C      henke(4,2, 266 ) = 4.22431 
C      henke(4,3, 266 ) = 0.270158 
C      henke(4,1, 267 ) = 691.193 
C      henke(4,2, 267 ) = 4.21971 
C      henke(4,3, 267 ) = 0.262736 
C      henke(4,1, 268 ) = 702.372 
C      henke(4,2, 268 ) = 4.216 
C      henke(4,3, 268 ) = 0.255658 
C      henke(4,1, 269 ) = 713.733 
C      henke(4,2, 269 ) = 4.21267 
C      henke(4,3, 269 ) = 0.248183 
C      henke(4,1, 270 ) = 725.277 
C      henke(4,2, 270 ) = 4.20908 
C      henke(4,3, 270 ) = 0.240533 
C      henke(4,1, 271 ) = 737.008 
C      henke(4,2, 271 ) = 4.20536 
C      henke(4,3, 271 ) = 0.23313 
C      henke(4,1, 272 ) = 748.928 
C      henke(4,2, 272 ) = 4.20161 
C      henke(4,3, 272 ) = 0.225953 
C      henke(4,1, 273 ) = 761.042 
C      henke(4,2, 273 ) = 4.19786 
C      henke(4,3, 273 ) = 0.218997 
C      henke(4,1, 274 ) = 773.351 
C      henke(4,2, 274 ) = 4.19415 
C      henke(4,3, 274 ) = 0.212248 
C      henke(4,1, 275 ) = 785.859 
C      henke(4,2, 275 ) = 4.19046 
C      henke(4,3, 275 ) = 0.205674 
C      henke(4,1, 276 ) = 798.57 
C      henke(4,2, 276 ) = 4.18676 
C      henke(4,3, 276 ) = 0.199278 
C      henke(4,1, 277 ) = 811.486 
C      henke(4,2, 277 ) = 4.18308 
C      henke(4,3, 277 ) = 0.193085 
C      henke(4,1, 278 ) = 824.611 
C      henke(4,2, 278 ) = 4.17942 
C      henke(4,3, 278 ) = 0.187081 
C      henke(4,1, 279 ) = 837.949 
C      henke(4,2, 279 ) = 4.17578 
C      henke(4,3, 279 ) = 0.181261 
C      henke(4,1, 280 ) = 851.502 
C      henke(4,2, 280 ) = 4.17215 
C      henke(4,3, 280 ) = 0.175669 
C      henke(4,1, 281 ) = 865.274 
C      henke(4,2, 281 ) = 4.16858 
C      henke(4,3, 281 ) = 0.17029 
C      henke(4,1, 282 ) = 879.269 
C      henke(4,2, 282 ) = 4.16509 
C      henke(4,3, 282 ) = 0.165111 
C      henke(4,1, 283 ) = 893.491 
C      henke(4,2, 283 ) = 4.1617 
C      henke(4,3, 283 ) = 0.16009 
C      henke(4,1, 284 ) = 907.943 
C      henke(4,2, 284 ) = 4.15838 
C      henke(4,3, 284 ) = 0.155222 
C      henke(4,1, 285 ) = 922.628 
C      henke(4,2, 285 ) = 4.15518 
C      henke(4,3, 285 ) = 0.150502 
C      henke(4,1, 286 ) = 937.551 
C      henke(4,2, 286 ) = 4.15202 
C      henke(4,3, 286 ) = 0.145811 
C      henke(4,1, 287 ) = 952.715 
C      henke(4,2, 287 ) = 4.14889 
C      henke(4,3, 287 ) = 0.141239 
C      henke(4,1, 288 ) = 968.124 
C      henke(4,2, 288 ) = 4.14576 
C      henke(4,3, 288 ) = 0.136786 
C      henke(4,1, 289 ) = 983.783 
C      henke(4,2, 289 ) = 4.14265 
C      henke(4,3, 289 ) = 0.132473 
C      henke(4,1, 290 ) = 999.695 
C      henke(4,2, 290 ) = 4.13956 
C      henke(4,3, 290 ) = 0.128287 
C      henke(4,1, 291 ) = 1015.86 
C      henke(4,2, 291 ) = 4.1365 
C      henke(4,3, 291 ) = 0.124282 
C      henke(4,1, 292 ) = 1032.29 
C      henke(4,2, 292 ) = 4.13352 
C      henke(4,3, 292 ) = 0.120403 
C      henke(4,1, 293 ) = 1048.99 
C      henke(4,2, 293 ) = 4.13058 
C      henke(4,3, 293 ) = 0.116645 
C      henke(4,1, 294 ) = 1065.96 
C      henke(4,2, 294 ) = 4.1277 
C      henke(4,3, 294 ) = 0.113004 
C      henke(4,1, 295 ) = 1083.2 
C      henke(4,2, 295 ) = 4.12487 
C      henke(4,3, 295 ) = 0.109477 
C      henke(4,1, 296 ) = 1100.72 
C      henke(4,2, 296 ) = 4.12209 
C      henke(4,3, 296 ) = 0.10606 
C      henke(4,1, 297 ) = 1118.52 
C      henke(4,2, 297 ) = 4.11936 
C      henke(4,3, 297 ) = 0.10275 
C      henke(4,1, 298 ) = 1136.61 
C      henke(4,2, 298 ) = 4.11668 
C      henke(4,3, 298 ) = 0.0995429 
C      henke(4,1, 299 ) = 1155 
C      henke(4,2, 299 ) = 4.11405 
C      henke(4,3, 299 ) = 0.0964359 
C      henke(4,1, 300 ) = 1173.68 
C      henke(4,2, 300 ) = 4.11147 
C      henke(4,3, 300 ) = 0.0934261 
C      henke(4,1, 301 ) = 1192.66 
C      henke(4,2, 301 ) = 4.10894 
C      henke(4,3, 301 ) = 0.0905101 
C      henke(4,1, 302 ) = 1211.95 
C      henke(4,2, 302 ) = 4.10646 
C      henke(4,3, 302 ) = 0.0876851 
C      henke(4,1, 303 ) = 1231.55 
C      henke(4,2, 303 ) = 4.10403 
C      henke(4,3, 303 ) = 0.0849484 
C      henke(4,1, 304 ) = 1251.47 
C      henke(4,2, 304 ) = 4.10164 
C      henke(4,3, 304 ) = 0.0822969 
C      henke(4,1, 305 ) = 1271.72 
C      henke(4,2, 305 ) = 4.09931 
C      henke(4,3, 305 ) = 0.0797283 
C      henke(4,1, 306 ) = 1292.29 
C      henke(4,2, 306 ) = 4.09702 
C      henke(4,3, 306 ) = 0.0772398 
C      henke(4,1, 307 ) = 1313.19 
C      henke(4,2, 307 ) = 4.09477 
C      henke(4,3, 307 ) = 0.0748291 
C      henke(4,1, 308 ) = 1334.43 
C      henke(4,2, 308 ) = 4.09258 
C      henke(4,3, 308 ) = 0.0724936 
C      henke(4,1, 309 ) = 1356.01 
C      henke(4,2, 309 ) = 4.09043 
C      henke(4,3, 309 ) = 0.0702309 
C      henke(4,1, 310 ) = 1377.94 
C      henke(4,2, 310 ) = 4.08833 
C      henke(4,3, 310 ) = 0.0680389 
C      henke(4,1, 311 ) = 1400.23 
C      henke(4,2, 311 ) = 4.08627 
C      henke(4,3, 311 ) = 0.0659153 
C      henke(4,1, 312 ) = 1422.88 
C      henke(4,2, 312 ) = 4.08426 
C      henke(4,3, 312 ) = 0.063858 
C      henke(4,1, 313 ) = 1445.89 
C      henke(4,2, 313 ) = 4.08229 
C      henke(4,3, 313 ) = 0.0618648 
C      henke(4,1, 314 ) = 1469.28 
C      henke(4,2, 314 ) = 4.08038 
C      henke(4,3, 314 ) = 0.059934 
C      henke(4,1, 315 ) = 1493.04 
C      henke(4,2, 315 ) = 4.07853 
C      henke(4,3, 315 ) = 0.0580634 
C      henke(4,1, 316 ) = 1517.19 
C      henke(4,2, 316 ) = 4.07672 
C      henke(4,3, 316 ) = 0.0562083 
C      henke(4,1, 317 ) = 1541.73 
C      henke(4,2, 317 ) = 4.07493 
C      henke(4,3, 317 ) = 0.0543956 
C      henke(4,1, 318 ) = 1566.67 
C      henke(4,2, 318 ) = 4.07315 
C      henke(4,3, 318 ) = 0.0526414 
C      henke(4,1, 319 ) = 1592.01 
C      henke(4,2, 319 ) = 4.07141 
C      henke(4,3, 319 ) = 0.0509438 
C      henke(4,1, 320 ) = 1617.76 
C      henke(4,2, 320 ) = 4.06971 
C      henke(4,3, 320 ) = 0.0493008 
C      henke(4,1, 321 ) = 1643.92 
C      henke(4,2, 321 ) = 4.06803 
C      henke(4,3, 321 ) = 0.0477109 
C      henke(4,1, 322 ) = 1670.51 
C      henke(4,2, 322 ) = 4.06639 
C      henke(4,3, 322 ) = 0.0461723 
C      henke(4,1, 323 ) = 1697.53 
C      henke(4,2, 323 ) = 4.06478 
C      henke(4,3, 323 ) = 0.0446833 
C      henke(4,1, 324 ) = 1724.99 
C      henke(4,2, 324 ) = 4.06321 
C      henke(4,3, 324 ) = 0.0432423 
C      henke(4,1, 325 ) = 1752.89 
C      henke(4,2, 325 ) = 4.06167 
C      henke(4,3, 325 ) = 0.0418477 
C      henke(4,1, 326 ) = 1781.24 
C      henke(4,2, 326 ) = 4.06016 
C      henke(4,3, 326 ) = 0.0404982 
C      henke(4,1, 327 ) = 1810.05 
C      henke(4,2, 327 ) = 4.05868 
C      henke(4,3, 327 ) = 0.0391921 
C      henke(4,1, 328 ) = 1839.32 
C      henke(4,2, 328 ) = 4.05724 
C      henke(4,3, 328 ) = 0.0379282 
C      henke(4,1, 329 ) = 1869.07 
C      henke(4,2, 329 ) = 4.05583 
C      henke(4,3, 329 ) = 0.036705 
C      henke(4,1, 330 ) = 1899.3 
C      henke(4,2, 330 ) = 4.05446 
C      henke(4,3, 330 ) = 0.0355213 
C      henke(4,1, 331 ) = 1930.02 
C      henke(4,2, 331 ) = 4.05312 
C      henke(4,3, 331 ) = 0.0343758 
C      henke(4,1, 332 ) = 1961.24 
C      henke(4,2, 332 ) = 4.05181 
C      henke(4,3, 332 ) = 0.0332672 
C      henke(4,1, 333 ) = 1992.96 
C      henke(4,2, 333 ) = 4.05054 
C      henke(4,3, 333 ) = 0.0321944 
C      henke(4,1, 334 ) = 2025.2 
C      henke(4,2, 334 ) = 4.0493 
C      henke(4,3, 334 ) = 0.0311312 
C      henke(4,1, 335 ) = 2057.95 
C      henke(4,2, 335 ) = 4.04808 
C      henke(4,3, 335 ) = 0.0300964 
C      henke(4,1, 336 ) = 2091.24 
C      henke(4,2, 336 ) = 4.04688 
C      henke(4,3, 336 ) = 0.029096 
C      henke(4,1, 337 ) = 2125.06 
C      henke(4,2, 337 ) = 4.0457 
C      henke(4,3, 337 ) = 0.0281288 
C      henke(4,1, 338 ) = 2159.43 
C      henke(4,2, 338 ) = 4.04454 
C      henke(4,3, 338 ) = 0.0271938 
C      henke(4,1, 339 ) = 2194.36 
C      henke(4,2, 339 ) = 4.04341 
C      henke(4,3, 339 ) = 0.0262898 
C      henke(4,1, 340 ) = 2229.85 
C      henke(4,2, 340 ) = 4.0423 
C      henke(4,3, 340 ) = 0.0254159 
C      henke(4,1, 341 ) = 2265.92 
C      henke(4,2, 341 ) = 4.04122 
C      henke(4,3, 341 ) = 0.0245711 
C      henke(4,1, 342 ) = 2302.57 
C      henke(4,2, 342 ) = 4.04016 
C      henke(4,3, 342 ) = 0.0237543 
C      henke(4,1, 343 ) = 2339.81 
C      henke(4,2, 343 ) = 4.03913 
C      henke(4,3, 343 ) = 0.0229647 
C      henke(4,1, 344 ) = 2377.66 
C      henke(4,2, 344 ) = 4.03812 
C      henke(4,3, 344 ) = 0.0222014 
C      henke(4,1, 345 ) = 2416.11 
C      henke(4,2, 345 ) = 4.03713 
C      henke(4,3, 345 ) = 0.0214634 
C      henke(4,1, 346 ) = 2455.19 
C      henke(4,2, 346 ) = 4.03616 
C      henke(4,3, 346 ) = 0.0207499 
C      henke(4,1, 347 ) = 2494.9 
C      henke(4,2, 347 ) = 4.03522 
C      henke(4,3, 347 ) = 0.0200602 
C      henke(4,1, 348 ) = 2535.26 
C      henke(4,2, 348 ) = 4.0343 
C      henke(4,3, 348 ) = 0.0193933 
C      henke(4,1, 349 ) = 2576.26 
C      henke(4,2, 349 ) = 4.03341 
C      henke(4,3, 349 ) = 0.0187487 
C      henke(4,1, 350 ) = 2617.93 
C      henke(4,2, 350 ) = 4.03253 
C      henke(4,3, 350 ) = 0.0181255 
C      henke(4,1, 351 ) = 2660.27 
C      henke(4,2, 351 ) = 4.03167 
C      henke(4,3, 351 ) = 0.017523 
C      henke(4,1, 352 ) = 2703.3 
C      henke(4,2, 352 ) = 4.03084 
C      henke(4,3, 352 ) = 0.0169405 
C      henke(4,1, 353 ) = 2747.03 
C      henke(4,2, 353 ) = 4.03003 
C      henke(4,3, 353 ) = 0.0163774 
C      henke(4,1, 354 ) = 2791.46 
C      henke(4,2, 354 ) = 4.02923 
C      henke(4,3, 354 ) = 0.015833 
C      henke(4,1, 355 ) = 2836.61 
C      henke(4,2, 355 ) = 4.02846 
C      henke(4,3, 355 ) = 0.0153067 
C      henke(4,1, 356 ) = 2882.49 
C      henke(4,2, 356 ) = 4.0277 
C      henke(4,3, 356 ) = 0.0147979 
C      henke(4,1, 357 ) = 2929.11 
C      henke(4,2, 357 ) = 4.02697 
C      henke(4,3, 357 ) = 0.014306 
C      henke(4,1, 358 ) = 2976.48 
C      henke(4,2, 358 ) = 4.02625 
C      henke(4,3, 358 ) = 0.0138305 
C      henke(4,1, 359 ) = 3024.63 
C      henke(4,2, 359 ) = 4.02556 
C      henke(4,3, 359 ) = 0.0133645 
C      henke(4,1, 360 ) = 3073.55 
C      henke(4,2, 360 ) = 4.02488 
C      henke(4,3, 360 ) = 0.0129085 
C      henke(4,1, 361 ) = 3123.26 
C      henke(4,2, 361 ) = 4.02421 
C      henke(4,3, 361 ) = 0.0124679 
C      henke(4,1, 362 ) = 3173.78 
C      henke(4,2, 362 ) = 4.02356 
C      henke(4,3, 362 ) = 0.0120425 
C      henke(4,1, 363 ) = 3225.11 
C      henke(4,2, 363 ) = 4.02293 
C      henke(4,3, 363 ) = 0.0116316 
C      henke(4,1, 364 ) = 3277.27 
C      henke(4,2, 364 ) = 4.0223 
C      henke(4,3, 364 ) = 0.0112347 
C      henke(4,1, 365 ) = 3330.28 
C      henke(4,2, 365 ) = 4.0217 
C      henke(4,3, 365 ) = 0.0108513 
C      henke(4,1, 366 ) = 3384.15 
C      henke(4,2, 366 ) = 4.0211 
C      henke(4,3, 366 ) = 0.010481 
C      henke(4,1, 367 ) = 3438.88 
C      henke(4,2, 367 ) = 4.02052 
C      henke(4,3, 367 ) = 0.0101233 
C      henke(4,1, 368 ) = 3494.5 
C      henke(4,2, 368 ) = 4.01996 
C      henke(4,3, 368 ) = 0.00977786 
C      henke(4,1, 369 ) = 3551.02 
C      henke(4,2, 369 ) = 4.01941 
C      henke(4,3, 369 ) = 0.00944423 
C      henke(4,1, 370 ) = 3608.46 
C      henke(4,2, 370 ) = 4.01887 
C      henke(4,3, 370 ) = 0.00912194 
C      henke(4,1, 371 ) = 3666.82 
C      henke(4,2, 371 ) = 4.01835 
C      henke(4,3, 371 ) = 0.00881066 
C      henke(4,1, 372 ) = 3726.13 
C      henke(4,2, 372 ) = 4.01784 
C      henke(4,3, 372 ) = 0.00851001 
C      henke(4,1, 373 ) = 3786.4 
C      henke(4,2, 373 ) = 4.01735 
C      henke(4,3, 373 ) = 0.0082196 
C      henke(4,1, 374 ) = 3847.64 
C      henke(4,2, 374 ) = 4.01686 
C      henke(4,3, 374 ) = 0.00793914 
C      henke(4,1, 375 ) = 3909.87 
C      henke(4,2, 375 ) = 4.01639 
C      henke(4,3, 375 ) = 0.00766821 
C      henke(4,1, 376 ) = 3973.11 
C      henke(4,2, 376 ) = 4.01593 
C      henke(4,3, 376 ) = 0.00740654 
C      henke(4,1, 377 ) = 4037.38 
C      henke(4,2, 377 ) = 4.01549 
C      henke(4,3, 377 ) = 0.00715149 
C      henke(4,1, 378 ) = 4102.68 
C      henke(4,2, 378 ) = 4.01505 
C      henke(4,3, 378 ) = 0.00690366 
C      henke(4,1, 379 ) = 4169.03 
C      henke(4,2, 379 ) = 4.01463 
C      henke(4,3, 379 ) = 0.00666438 
C      henke(4,1, 380 ) = 4236.46 
C      henke(4,2, 380 ) = 4.01421 
C      henke(4,3, 380 ) = 0.00643341 
C      henke(4,1, 381 ) = 4304.98 
C      henke(4,2, 381 ) = 4.01381 
C      henke(4,3, 381 ) = 0.00621045 
C      henke(4,1, 382 ) = 4374.62 
C      henke(4,2, 382 ) = 4.01341 
C      henke(4,3, 382 ) = 0.00599521 
C      henke(4,1, 383 ) = 4445.37 
C      henke(4,2, 383 ) = 4.01303 
C      henke(4,3, 383 ) = 0.00578744 
C      henke(4,1, 384 ) = 4517.27 
C      henke(4,2, 384 ) = 4.01265 
C      henke(4,3, 384 ) = 0.00558684 
C      henke(4,1, 385 ) = 4590.33 
C      henke(4,2, 385 ) = 4.01229 
C      henke(4,3, 385 ) = 0.00539322 
C      henke(4,1, 386 ) = 4664.58 
C      henke(4,2, 386 ) = 4.01193 
C      henke(4,3, 386 ) = 0.00520631 
C      henke(4,1, 387 ) = 4740.03 
C      henke(4,2, 387 ) = 4.01159 
C      henke(4,3, 387 ) = 0.00502587 
C      henke(4,1, 388 ) = 4816.69 
C      henke(4,2, 388 ) = 4.01125 
C      henke(4,3, 388 ) = 0.00485169 
C      henke(4,1, 389 ) = 4894.6 
C      henke(4,2, 389 ) = 4.01092 
C      henke(4,3, 389 ) = 0.00468353 
C      henke(4,1, 390 ) = 4973.77 
C      henke(4,2, 390 ) = 4.0106 
C      henke(4,3, 390 ) = 0.00452121 
C      henke(4,1, 391 ) = 5054.21 
C      henke(4,2, 391 ) = 4.01029 
C      henke(4,3, 391 ) = 0.0043633 
C      henke(4,1, 392 ) = 5135.96 
C      henke(4,2, 392 ) = 4.00999 
C      henke(4,3, 392 ) = 0.00421033 
C      henke(4,1, 393 ) = 5219.03 
C      henke(4,2, 393 ) = 4.00969 
C      henke(4,3, 393 ) = 0.00406272 
C      henke(4,1, 394 ) = 5303.44 
C      henke(4,2, 394 ) = 4.00941 
C      henke(4,3, 394 ) = 0.00392028 
C      henke(4,1, 395 ) = 5389.22 
C      henke(4,2, 395 ) = 4.00913 
C      henke(4,3, 395 ) = 0.00378285 
C      henke(4,1, 396 ) = 5476.39 
C      henke(4,2, 396 ) = 4.00885 
C      henke(4,3, 396 ) = 0.00365022 
C      henke(4,1, 397 ) = 5564.97 
C      henke(4,2, 397 ) = 4.00859 
C      henke(4,3, 397 ) = 0.00352225 
C      henke(4,1, 398 ) = 5654.98 
C      henke(4,2, 398 ) = 4.00833 
C      henke(4,3, 398 ) = 0.00339876 
C      henke(4,1, 399 ) = 5746.44 
C      henke(4,2, 399 ) = 4.00808 
C      henke(4,3, 399 ) = 0.00327961 
C      henke(4,1, 400 ) = 5839.39 
C      henke(4,2, 400 ) = 4.00783 
C      henke(4,3, 400 ) = 0.00316463 
C      henke(4,1, 401 ) = 5933.83 
C      henke(4,2, 401 ) = 4.00759 
C      henke(4,3, 401 ) = 0.00305368 
C      henke(4,1, 402 ) = 6029.81 
C      henke(4,2, 402 ) = 4.00736 
C      henke(4,3, 402 ) = 0.00294623 
C      henke(4,1, 403 ) = 6127.33 
C      henke(4,2, 403 ) = 4.00714 
C      henke(4,3, 403 ) = 0.00284174 
C      henke(4,1, 404 ) = 6226.44 
C      henke(4,2, 404 ) = 4.00692 
C      henke(4,3, 404 ) = 0.00274094 
C      henke(4,1, 405 ) = 6327.15 
C      henke(4,2, 405 ) = 4.0067 
C      henke(4,3, 405 ) = 0.00264373 
C      henke(4,1, 406 ) = 6429.48 
C      henke(4,2, 406 ) = 4.00649 
C      henke(4,3, 406 ) = 0.00254996 
C      henke(4,1, 407 ) = 6533.48 
C      henke(4,2, 407 ) = 4.00629 
C      henke(4,3, 407 ) = 0.00245951 
C      henke(4,1, 408 ) = 6639.15 
C      henke(4,2, 408 ) = 4.00609 
C      henke(4,3, 408 ) = 0.00237228 
C      henke(4,1, 409 ) = 6746.54 
C      henke(4,2, 409 ) = 4.0059 
C      henke(4,3, 409 ) = 0.00228814 
C      henke(4,1, 410 ) = 6855.65 
C      henke(4,2, 410 ) = 4.00571 
C      henke(4,3, 410 ) = 0.00220698 
C      henke(4,1, 411 ) = 6966.54 
C      henke(4,2, 411 ) = 4.00553 
C      henke(4,3, 411 ) = 0.0021287 
C      henke(4,1, 412 ) = 7079.22 
C      henke(4,2, 412 ) = 4.00535 
C      henke(4,3, 412 ) = 0.0020532 
C      henke(4,1, 413 ) = 7193.72 
C      henke(4,2, 413 ) = 4.00518 
C      henke(4,3, 413 ) = 0.00198037 
C      henke(4,1, 414 ) = 7310.07 
C      henke(4,2, 414 ) = 4.00501 
C      henke(4,3, 414 ) = 0.00191013 
C      henke(4,1, 415 ) = 7428.31 
C      henke(4,2, 415 ) = 4.00485 
C      henke(4,3, 415 ) = 0.00184238 
C      henke(4,1, 416 ) = 7548.45 
C      henke(4,2, 416 ) = 4.00469 
C      henke(4,3, 416 ) = 0.00177703 
C      henke(4,1, 417 ) = 7670.54 
C      henke(4,2, 417 ) = 4.00454 
C      henke(4,3, 417 ) = 0.001714 
C      henke(4,1, 418 ) = 7794.61 
C      henke(4,2, 418 ) = 4.00439 
C      henke(4,3, 418 ) = 0.00165321 
C      henke(4,1, 419 ) = 7920.68 
C      henke(4,2, 419 ) = 4.00424 
C      henke(4,3, 419 ) = 0.00159457 
C      henke(4,1, 420 ) = 8048.79 
C      henke(4,2, 420 ) = 4.0041 
C      henke(4,3, 420 ) = 0.00153779 
C      henke(4,1, 421 ) = 8178.98 
C      henke(4,2, 421 ) = 4.00396 
C      henke(4,3, 421 ) = 0.00148265 
C      henke(4,1, 422 ) = 8311.26 
C      henke(4,2, 422 ) = 4.00383 
C      henke(4,3, 422 ) = 0.00142949 
C      henke(4,1, 423 ) = 8445.69 
C      henke(4,2, 423 ) = 4.0037 
C      henke(4,3, 423 ) = 0.00137824 
C      henke(4,1, 424 ) = 8582.29 
C      henke(4,2, 424 ) = 4.00357 
C      henke(4,3, 424 ) = 0.00132882 
C      henke(4,1, 425 ) = 8721.11 
C      henke(4,2, 425 ) = 4.00345 
C      henke(4,3, 425 ) = 0.00128118 
C      henke(4,1, 426 ) = 8862.16 
C      henke(4,2, 426 ) = 4.00333 
C      henke(4,3, 426 ) = 0.00123525 
C      henke(4,1, 427 ) = 9005.5 
C      henke(4,2, 427 ) = 4.00321 
C      henke(4,3, 427 ) = 0.00119096 
C      henke(4,1, 428 ) = 9151.16 
C      henke(4,2, 428 ) = 4.00309 
C      henke(4,3, 428 ) = 0.00114826 
C      henke(4,1, 429 ) = 9299.17 
C      henke(4,2, 429 ) = 4.00298 
C      henke(4,3, 429 ) = 0.00110709 
C      henke(4,1, 430 ) = 9449.58 
C      henke(4,2, 430 ) = 4.00288 
C      henke(4,3, 430 ) = 0.0010674 
C      henke(4,1, 431 ) = 9602.42 
C      henke(4,2, 431 ) = 4.00277 
C      henke(4,3, 431 ) = 0.00102913 
C      henke(4,1, 432 ) = 9757.73 
C      henke(4,2, 432 ) = 4.00267 
C      henke(4,3, 432 ) = 0.000992234 
C      henke(4,1, 433 ) = 9915.55 
C      henke(4,2, 433 ) = 4.00257 
C      henke(4,3, 433 ) = 0.000956657 
C      henke(4,1, 434 ) = 10075.9 
C      henke(4,2, 434 ) = 4.00248 
C      henke(4,3, 434 ) = 0.000922385 
C      henke(4,1, 435 ) = 10238.9 
C      henke(4,2, 435 ) = 4.00238 
C      henke(4,3, 435 ) = 0.000889326 
C      henke(4,1, 436 ) = 10404.5 
C      henke(4,2, 436 ) = 4.00229 
C      henke(4,3, 436 ) = 0.000857435 
C      henke(4,1, 437 ) = 10572.8 
C      henke(4,2, 437 ) = 4.0022 
C      henke(4,3, 437 ) = 0.00082667 
C      henke(4,1, 438 ) = 10743.8 
C      henke(4,2, 438 ) = 4.00212 
C      henke(4,3, 438 ) = 0.000796994 
C      henke(4,1, 439 ) = 10917.6 
C      henke(4,2, 439 ) = 4.00203 
C      henke(4,3, 439 ) = 0.000768367 
C      henke(4,1, 440 ) = 11094.2 
C      henke(4,2, 440 ) = 4.00195 
C      henke(4,3, 440 ) = 0.000740753 
C      henke(4,1, 441 ) = 11273.6 
C      henke(4,2, 441 ) = 4.00187 
C      henke(4,3, 441 ) = 0.000714114 
C      henke(4,1, 442 ) = 11455.9 
C      henke(4,2, 442 ) = 4.0018 
C      henke(4,3, 442 ) = 0.00068842 
C      henke(4,1, 443 ) = 11641.2 
C      henke(4,2, 443 ) = 4.00172 
C      henke(4,3, 443 ) = 0.000663634 
C      henke(4,1, 444 ) = 11829.5 
C      henke(4,2, 444 ) = 4.00165 
C      henke(4,3, 444 ) = 0.000639724 
C      henke(4,1, 445 ) = 12020.8 
C      henke(4,2, 445 ) = 4.00158 
C      henke(4,3, 445 ) = 0.000616663 
C      henke(4,1, 446 ) = 12215.3 
C      henke(4,2, 446 ) = 4.00151 
C      henke(4,3, 446 ) = 0.000594417 
C      henke(4,1, 447 ) = 12412.8 
C      henke(4,2, 447 ) = 4.00145 
C      henke(4,3, 447 ) = 0.00057296 
C      henke(4,1, 448 ) = 12613.6 
C      henke(4,2, 448 ) = 4.00138 
C      henke(4,3, 448 ) = 0.000552263 
C      henke(4,1, 449 ) = 12817.6 
C      henke(4,2, 449 ) = 4.00132 
C      henke(4,3, 449 ) = 0.000532301 
C      henke(4,1, 450 ) = 13025 
C      henke(4,2, 450 ) = 4.00126 
C      henke(4,3, 450 ) = 0.000513046 
C      henke(4,1, 451 ) = 13235.6 
C      henke(4,2, 451 ) = 4.0012 
C      henke(4,3, 451 ) = 0.000494476 
C      henke(4,1, 452 ) = 13449.7 
C      henke(4,2, 452 ) = 4.00114 
C      henke(4,3, 452 ) = 0.000476565 
C      henke(4,1, 453 ) = 13667.2 
C      henke(4,2, 453 ) = 4.00109 
C      henke(4,3, 453 ) = 0.000459289 
C      henke(4,1, 454 ) = 13888.3 
C      henke(4,2, 454 ) = 4.00103 
C      henke(4,3, 454 ) = 0.000442629 
C      henke(4,1, 455 ) = 14112.9 
C      henke(4,2, 455 ) = 4.00098 
C      henke(4,3, 455 ) = 0.000426561 
C      henke(4,1, 456 ) = 14341.2 
C      henke(4,2, 456 ) = 4.00093 
C      henke(4,3, 456 ) = 0.000411065 
C      henke(4,1, 457 ) = 14573.1 
C      henke(4,2, 457 ) = 4.00088 
C      henke(4,3, 457 ) = 0.000396121 
C      henke(4,1, 458 ) = 14808.9 
C      henke(4,2, 458 ) = 4.00083 
C      henke(4,3, 458 ) = 0.00038171 
C      henke(4,1, 459 ) = 15048.4 
C      henke(4,2, 459 ) = 4.00079 
C      henke(4,3, 459 ) = 0.000367813 
C      henke(4,1, 460 ) = 15291.8 
C      henke(4,2, 460 ) = 4.00074 
C      henke(4,3, 460 ) = 0.000354413 
C      henke(4,1, 461 ) = 15539.1 
C      henke(4,2, 461 ) = 4.0007 
C      henke(4,3, 461 ) = 0.000341491 
C      henke(4,1, 462 ) = 15790.4 
C      henke(4,2, 462 ) = 4.00065 
C      henke(4,3, 462 ) = 0.000329031 
C      henke(4,1, 463 ) = 16045.8 
C      henke(4,2, 463 ) = 4.00061 
C      henke(4,3, 463 ) = 0.000317018 
C      henke(4,1, 464 ) = 16305.4 
C      henke(4,2, 464 ) = 4.00057 
C      henke(4,3, 464 ) = 0.000305435 
C      henke(4,1, 465 ) = 16569.1 
C      henke(4,2, 465 ) = 4.00053 
C      henke(4,3, 465 ) = 0.000294267 
C      henke(4,1, 466 ) = 16837.1 
C      henke(4,2, 466 ) = 4.00049 
C      henke(4,3, 466 ) = 0.0002835 
C      henke(4,1, 467 ) = 17109.4 
C      henke(4,2, 467 ) = 4.00046 
C      henke(4,3, 467 ) = 0.000273121 
C      henke(4,1, 468 ) = 17386.1 
C      henke(4,2, 468 ) = 4.00042 
C      henke(4,3, 468 ) = 0.000263115 
C      henke(4,1, 469 ) = 17667.4 
C      henke(4,2, 469 ) = 4.00039 
C      henke(4,3, 469 ) = 0.00025347 
C      henke(4,1, 470 ) = 17953.1 
C      henke(4,2, 470 ) = 4.00035 
C      henke(4,3, 470 ) = 0.000244172 
C      henke(4,1, 471 ) = 18243.5 
C      henke(4,2, 471 ) = 4.00032 
C      henke(4,3, 471 ) = 0.00023521 
C      henke(4,1, 472 ) = 18538.6 
C      henke(4,2, 472 ) = 4.00029 
C      henke(4,3, 472 ) = 0.000226573 
C      henke(4,1, 473 ) = 18838.4 
C      henke(4,2, 473 ) = 4.00026 
C      henke(4,3, 473 ) = 0.000218248 
C      henke(4,1, 474 ) = 19143.1 
C      henke(4,2, 474 ) = 4.00023 
C      henke(4,3, 474 ) = 0.000210225 
C      henke(4,1, 475 ) = 19452.7 
C      henke(4,2, 475 ) = 4.0002 
C      henke(4,3, 475 ) = 0.000202493 
C      henke(4,1, 476 ) = 19767.4 
C      henke(4,2, 476 ) = 4.00017 
C      henke(4,3, 476 ) = 0.000195043 
C      henke(4,1, 477 ) = 20087.1 
C      henke(4,2, 477 ) = 4.00014 
C      henke(4,3, 477 ) = 0.000187868 
C      henke(4,1, 478 ) = 20412 
C      henke(4,2, 478 ) = 4.00011 
C      henke(4,3, 478 ) = 0.000180955 
C      henke(4,1, 479 ) = 20742.1 
C      henke(4,2, 479 ) = 4.00009 
C      henke(4,3, 479 ) = 0.000174299 
C      henke(4,1, 480 ) = 21077.6 
C      henke(4,2, 480 ) = 4.00006 
C      henke(4,3, 480 ) = 0.00016789 
C      henke(4,1, 481 ) = 21418.5 
C      henke(4,2, 481 ) = 4.00004 
C      henke(4,3, 481 ) = 0.00016172 
C      henke(4,1, 482 ) = 21765 
C      henke(4,2, 482 ) = 4.00001 
C      henke(4,3, 482 ) = 0.000155777 
C      henke(4,1, 483 ) = 22117 
C      henke(4,2, 483 ) = 3.99999 
C      henke(4,3, 483 ) = 0.000150055 
C      henke(4,1, 484 ) = 22474.7 
C      henke(4,2, 484 ) = 3.99997 
C      henke(4,3, 484 ) = 0.000144545 
C      henke(4,1, 485 ) = 22838.2 
C      henke(4,2, 485 ) = 3.99995 
C      henke(4,3, 485 ) = 0.000139239 
C      henke(4,1, 486 ) = 23207.6 
C      henke(4,2, 486 ) = 3.99992 
C      henke(4,3, 486 ) = 0.000134129 
C      henke(4,1, 487 ) = 23583 
C      henke(4,2, 487 ) = 3.9999 
C      henke(4,3, 487 ) = 0.000129207 
C      henke(4,1, 488 ) = 23964.4 
C      henke(4,2, 488 ) = 3.99988 
C      henke(4,3, 488 ) = 0.000124467 
C      henke(4,1, 489 ) = 24352 
C      henke(4,2, 489 ) = 3.99986 
C      henke(4,3, 489 ) = 0.000119902 
C      henke(4,1, 490 ) = 24745.9 
C      henke(4,2, 490 ) = 3.99985 
C      henke(4,3, 490 ) = 0.000115505 
C      henke(4,1, 491 ) = 25146.2 
C      henke(4,2, 491 ) = 3.99983 
C      henke(4,3, 491 ) = 0.00011127 
C      henke(4,1, 492 ) = 25552.9 
C      henke(4,2, 492 ) = 3.99981 
C      henke(4,3, 492 ) = 0.000107191 
C      henke(4,1, 493 ) = 25966.2 
C      henke(4,2, 493 ) = 3.99979 
C      henke(4,3, 493 ) = 0.000103261 
C      henke(4,1, 494 ) = 26386.1 
C      henke(4,2, 494 ) = 3.99978 
C      henke(4,3, 494 ) = 9.94763e-05 
C      henke(4,1, 495 ) = 26812.9 
C      henke(4,2, 495 ) = 3.99976 
C      henke(4,3, 495 ) = 9.58302e-05 
C      henke(4,1, 496 ) = 27246.6 
C      henke(4,2, 496 ) = 3.99974 
C      henke(4,3, 496 ) = 9.23179e-05 
C      henke(4,1, 497 ) = 27687.3 
C      henke(4,2, 497 ) = 3.99973 
C      henke(4,3, 497 ) = 8.89344e-05 
C      henke(4,1, 498 ) = 28135.1 
C      henke(4,2, 498 ) = 3.99971 
C      henke(4,3, 498 ) = 8.56748e-05 
C      henke(4,1, 499 ) = 28590.2 
C      henke(4,2, 499 ) = 3.9997 
C      henke(4,3, 499 ) = 8.25347e-05 
C      henke(4,1, 500 ) = 29052.6 
C      henke(4,2, 500 ) = 3.99969 
C      henke(4,3, 500 ) = 7.95095e-05 
C      henke(4,1, 501 ) = 29522.5 
C      henke(4,2, 501 ) = 3.99967 
C      henke(4,3, 501 ) = 7.65949e-05 
C      henke(4,1, 502 ) = 30000 
C      henke(4,2, 502 ) = 3.99966 
C      henke(4,3, 502 ) = 7.3787e-05 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C        Henke data for ti  z=22
C      count(22) = 504
C      henke(22,1, 1 ) = 10 
C      henke(22,2, 1 ) = -9999 
C      henke(22,3, 1 ) = 2.38456 
C      henke(22,1, 2 ) = 10.1617 
C      henke(22,2, 2 ) = -9999 
C      henke(22,3, 2 ) = 2.37555 
C      henke(22,1, 3 ) = 10.3261 
C      henke(22,2, 3 ) = -9999 
C      henke(22,3, 3 ) = 2.36658 
C      henke(22,1, 4 ) = 10.4931 
C      henke(22,2, 4 ) = -9999 
C      henke(22,3, 4 ) = 2.35765 
C      henke(22,1, 5 ) = 10.6628 
C      henke(22,2, 5 ) = -9999 
C      henke(22,3, 5 ) = 2.34874 
C      henke(22,1, 6 ) = 10.8353 
C      henke(22,2, 6 ) = -9999 
C      henke(22,3, 6 ) = 2.33987 
C      henke(22,1, 7 ) = 11.0106 
C      henke(22,2, 7 ) = -9999 
C      henke(22,3, 7 ) = 2.33104 
C      henke(22,1, 8 ) = 11.1886 
C      henke(22,2, 8 ) = -9999 
C      henke(22,3, 8 ) = 2.32572 
C      henke(22,1, 9 ) = 11.3696 
C      henke(22,2, 9 ) = -9999 
C      henke(22,3, 9 ) = 2.32484 
C      henke(22,1, 10 ) = 11.5535 
C      henke(22,2, 10 ) = -9999 
C      henke(22,3, 10 ) = 2.32396 
C      henke(22,1, 11 ) = 11.7404 
C      henke(22,2, 11 ) = -9999 
C      henke(22,3, 11 ) = 2.32308 
C      henke(22,1, 12 ) = 11.9303 
C      henke(22,2, 12 ) = -9999 
C      henke(22,3, 12 ) = 2.32221 
C      henke(22,1, 13 ) = 12.1232 
C      henke(22,2, 13 ) = -9999 
C      henke(22,3, 13 ) = 2.32133 
C      henke(22,1, 14 ) = 12.3193 
C      henke(22,2, 14 ) = -9999 
C      henke(22,3, 14 ) = 2.32045 
C      henke(22,1, 15 ) = 12.5186 
C      henke(22,2, 15 ) = -9999 
C      henke(22,3, 15 ) = 2.31958 
C      henke(22,1, 16 ) = 12.721 
C      henke(22,2, 16 ) = -9999 
C      henke(22,3, 16 ) = 2.3187 
C      henke(22,1, 17 ) = 12.9268 
C      henke(22,2, 17 ) = -9999 
C      henke(22,3, 17 ) = 2.31783 
C      henke(22,1, 18 ) = 13.1359 
C      henke(22,2, 18 ) = -9999 
C      henke(22,3, 18 ) = 2.31695 
C      henke(22,1, 19 ) = 13.3483 
C      henke(22,2, 19 ) = -9999 
C      henke(22,3, 19 ) = 2.31608 
C      henke(22,1, 20 ) = 13.5642 
C      henke(22,2, 20 ) = -9999 
C      henke(22,3, 20 ) = 2.31824 
C      henke(22,1, 21 ) = 13.7836 
C      henke(22,2, 21 ) = -9999 
C      henke(22,3, 21 ) = 2.32115 
C      henke(22,1, 22 ) = 14.0066 
C      henke(22,2, 22 ) = -9999 
C      henke(22,3, 22 ) = 2.32406 
C      henke(22,1, 23 ) = 14.2331 
C      henke(22,2, 23 ) = -9999 
C      henke(22,3, 23 ) = 2.32697 
C      henke(22,1, 24 ) = 14.4633 
C      henke(22,2, 24 ) = -9999 
C      henke(22,3, 24 ) = 2.32989 
C      henke(22,1, 25 ) = 14.6973 
C      henke(22,2, 25 ) = -9999 
C      henke(22,3, 25 ) = 2.33281 
C      henke(22,1, 26 ) = 14.935 
C      henke(22,2, 26 ) = -9999 
C      henke(22,3, 26 ) = 2.33573 
C      henke(22,1, 27 ) = 15.1765 
C      henke(22,2, 27 ) = -9999 
C      henke(22,3, 27 ) = 2.34122 
C      henke(22,1, 28 ) = 15.422 
C      henke(22,2, 28 ) = -9999 
C      henke(22,3, 28 ) = 2.34677 
C      henke(22,1, 29 ) = 15.6714 
C      henke(22,2, 29 ) = -9999 
C      henke(22,3, 29 ) = 2.35234 
C      henke(22,1, 30 ) = 15.9249 
C      henke(22,2, 30 ) = -9999 
C      henke(22,3, 30 ) = 2.35791 
C      henke(22,1, 31 ) = 16.1825 
C      henke(22,2, 31 ) = -9999 
C      henke(22,3, 31 ) = 2.36351 
C      henke(22,1, 32 ) = 16.4442 
C      henke(22,2, 32 ) = -9999 
C      henke(22,3, 32 ) = 2.37618 
C      henke(22,1, 33 ) = 16.7102 
C      henke(22,2, 33 ) = -9999 
C      henke(22,3, 33 ) = 2.39319 
C      henke(22,1, 34 ) = 16.9805 
C      henke(22,2, 34 ) = -9999 
C      henke(22,3, 34 ) = 2.41032 
C      henke(22,1, 35 ) = 17.2551 
C      henke(22,2, 35 ) = -9999 
C      henke(22,3, 35 ) = 2.42885 
C      henke(22,1, 36 ) = 17.5342 
C      henke(22,2, 36 ) = -9999 
C      henke(22,3, 36 ) = 2.46979 
C      henke(22,1, 37 ) = 17.8178 
C      henke(22,2, 37 ) = -9999 
C      henke(22,3, 37 ) = 2.51143 
C      henke(22,1, 38 ) = 18.106 
C      henke(22,2, 38 ) = -9999 
C      henke(22,3, 38 ) = 2.55377 
C      henke(22,1, 39 ) = 18.3989 
C      henke(22,2, 39 ) = -9999 
C      henke(22,3, 39 ) = 2.59682 
C      henke(22,1, 40 ) = 18.6964 
C      henke(22,2, 40 ) = -9999 
C      henke(22,3, 40 ) = 2.64495 
C      henke(22,1, 41 ) = 18.9988 
C      henke(22,2, 41 ) = -9999 
C      henke(22,3, 41 ) = 2.70692 
C      henke(22,1, 42 ) = 19.3061 
C      henke(22,2, 42 ) = -9999 
C      henke(22,3, 42 ) = 2.77035 
C      henke(22,1, 43 ) = 19.6184 
C      henke(22,2, 43 ) = -9999 
C      henke(22,3, 43 ) = 2.83526 
C      henke(22,1, 44 ) = 19.9357 
C      henke(22,2, 44 ) = -9999 
C      henke(22,3, 44 ) = 2.93286 
C      henke(22,1, 45 ) = 20.2582 
C      henke(22,2, 45 ) = -9999 
C      henke(22,3, 45 ) = 3.04925 
C      henke(22,1, 46 ) = 20.5858 
C      henke(22,2, 46 ) = -9999 
C      henke(22,3, 46 ) = 3.17025 
C      henke(22,1, 47 ) = 20.9188 
C      henke(22,2, 47 ) = -9999 
C      henke(22,3, 47 ) = 3.30828 
C      henke(22,1, 48 ) = 21.2571 
C      henke(22,2, 48 ) = -9999 
C      henke(22,3, 48 ) = 3.46104 
C      henke(22,1, 49 ) = 21.6009 
C      henke(22,2, 49 ) = -9999 
C      henke(22,3, 49 ) = 3.62084 
C      henke(22,1, 50 ) = 21.9503 
C      henke(22,2, 50 ) = -9999 
C      henke(22,3, 50 ) = 3.78803 
C      henke(22,1, 51 ) = 22.3053 
C      henke(22,2, 51 ) = -9999 
C      henke(22,3, 51 ) = 3.96294 
C      henke(22,1, 52 ) = 22.6661 
C      henke(22,2, 52 ) = -9999 
C      henke(22,3, 52 ) = 4.14592 
C      henke(22,1, 53 ) = 23.0327 
C      henke(22,2, 53 ) = -9999 
C      henke(22,3, 53 ) = 4.26843 
C      henke(22,1, 54 ) = 23.4053 
C      henke(22,2, 54 ) = -9999 
C      henke(22,3, 54 ) = 4.37668 
C      henke(22,1, 55 ) = 23.7838 
C      henke(22,2, 55 ) = -9999 
C      henke(22,3, 55 ) = 4.48768 
C      henke(22,1, 56 ) = 24.1685 
C      henke(22,2, 56 ) = -9999 
C      henke(22,3, 56 ) = 4.6015 
C      henke(22,1, 57 ) = 24.5594 
C      henke(22,2, 57 ) = -9999 
C      henke(22,3, 57 ) = 4.71819 
C      henke(22,1, 58 ) = 24.9566 
C      henke(22,2, 58 ) = -9999 
C      henke(22,3, 58 ) = 4.83786 
C      henke(22,1, 59 ) = 25.3603 
C      henke(22,2, 59 ) = -9999 
C      henke(22,3, 59 ) = 4.91587 
C      henke(22,1, 60 ) = 25.7705 
C      henke(22,2, 60 ) = -9999 
C      henke(22,3, 60 ) = 4.95342 
C      henke(22,1, 61 ) = 26.1873 
C      henke(22,2, 61 ) = -9999 
C      henke(22,3, 61 ) = 4.99126 
C      henke(22,1, 62 ) = 26.6109 
C      henke(22,2, 62 ) = -9999 
C      henke(22,3, 62 ) = 5.02939 
C      henke(22,1, 63 ) = 27.0413 
C      henke(22,2, 63 ) = -9999 
C      henke(22,3, 63 ) = 5.06781 
C      henke(22,1, 64 ) = 27.4786 
C      henke(22,2, 64 ) = -9999 
C      henke(22,3, 64 ) = 5.05289 
C      henke(22,1, 65 ) = 27.9231 
C      henke(22,2, 65 ) = -9999 
C      henke(22,3, 65 ) = 4.99747 
C      henke(22,1, 66 ) = 28.3747 
C      henke(22,2, 66 ) = -9999 
C      henke(22,3, 66 ) = 4.94266 
C      henke(22,1, 67 ) = 28.8337 
C      henke(22,2, 67 ) = -9999 
C      henke(22,3, 67 ) = 4.88845 
C      henke(22,1, 68 ) = 29.3 
C      henke(22,2, 68 ) = 2.27863 
C      henke(22,3, 68 ) = 4.83484 
C      henke(22,1, 69 ) = 29.7739 
C      henke(22,2, 69 ) = 2.26302 
C      henke(22,3, 69 ) = 4.77767 
C      henke(22,1, 70 ) = 30.2555 
C      henke(22,2, 70 ) = 2.2156 
C      henke(22,3, 70 ) = 4.72068 
C      henke(22,1, 71 ) = 30.7449 
C      henke(22,2, 71 ) = 2.12534 
C      henke(22,3, 71 ) = 4.66438 
C      henke(22,1, 72 ) = 31.2421 
C      henke(22,2, 72 ) = 1.9694 
C      henke(22,3, 72 ) = 4.65287 
C      henke(22,1, 73 ) = 31.7475 
C      henke(22,2, 73 ) = 1.81449 
C      henke(22,3, 73 ) = 4.72636 
C      henke(22,1, 74 ) = 32.2609 
C      henke(22,2, 74 ) = 1.69655 
C      henke(22,3, 74 ) = 4.80102 
C      henke(22,1, 75 ) = 32.7827 
C      henke(22,2, 75 ) = 1.55941 
C      henke(22,3, 75 ) = 4.87685 
C      henke(22,1, 76 ) = 33.313 
C      henke(22,2, 76 ) = 1.36802 
C      henke(22,3, 76 ) = 4.98488 
C      henke(22,1, 77 ) = 33.8518 
C      henke(22,2, 77 ) = 1.1844 
C      henke(22,3, 77 ) = 5.19195 
C      henke(22,1, 78 ) = 34.3993 
C      henke(22,2, 78 ) = 1.05557 
C      henke(22,3, 78 ) = 5.40762 
C      henke(22,1, 79 ) = 34.9557 
C      henke(22,2, 79 ) = 0.923268 
C      henke(22,3, 79 ) = 5.63225 
C      henke(22,1, 80 ) = 35.5211 
C      henke(22,2, 80 ) = 0.776736 
C      henke(22,3, 80 ) = 5.90198 
C      henke(22,1, 81 ) = 36.0956 
C      henke(22,2, 81 ) = 0.656309 
C      henke(22,3, 81 ) = 6.22897 
C      henke(22,1, 82 ) = 36.6794 
C      henke(22,2, 82 ) = 0.575787 
C      henke(22,3, 82 ) = 6.57407 
C      henke(22,1, 83 ) = 37.2727 
C      henke(22,2, 83 ) = 0.508507 
C      henke(22,3, 83 ) = 6.9383 
C      henke(22,1, 84 ) = 37.8755 
C      henke(22,2, 84 ) = 0.448347 
C      henke(22,3, 84 ) = 7.34882 
C      henke(22,1, 85 ) = 38.4882 
C      henke(22,2, 85 ) = 0.429323 
C      henke(22,3, 85 ) = 7.81476 
C      henke(22,1, 86 ) = 39.1107 
C      henke(22,2, 86 ) = 0.465914 
C      henke(22,3, 86 ) = 8.31024 
C      henke(22,1, 87 ) = 39.7432 
C      henke(22,2, 87 ) = 0.551386 
C      henke(22,3, 87 ) = 8.83714 
C      henke(22,1, 88 ) = 40.3861 
C      henke(22,2, 88 ) = 0.705481 
C      henke(22,3, 88 ) = 9.39744 
C      henke(22,1, 89 ) = 41.0393 
C      henke(22,2, 89 ) = 0.926428 
C      henke(22,3, 89 ) = 9.96367 
C      henke(22,1, 90 ) = 41.7031 
C      henke(22,2, 90 ) = 1.20569 
C      henke(22,3, 90 ) = 10.5594 
C      henke(22,1, 91 ) = 42.3776 
C      henke(22,2, 91 ) = 1.57864 
C      henke(22,3, 91 ) = 11.1907 
C      henke(22,1, 92 ) = 43.063 
C      henke(22,2, 92 ) = 2.17717 
C      henke(22,3, 92 ) = 11.841 
C      henke(22,1, 93 ) = 43.7595 
C      henke(22,2, 93 ) = 2.86386 
C      henke(22,3, 93 ) = 12.2348 
C      henke(22,1, 94 ) = 44.4673 
C      henke(22,2, 94 ) = 3.5303 
C      henke(22,3, 94 ) = 12.6416 
C      henke(22,1, 95 ) = 45.1865 
C      henke(22,2, 95 ) = 4.27191 
C      henke(22,3, 95 ) = 12.9275 
C      henke(22,1, 96 ) = 45.9174 
C      henke(22,2, 96 ) = 4.99547 
C      henke(22,3, 96 ) = 13.1541 
C      henke(22,1, 97 ) = 46.66 
C      henke(22,2, 97 ) = 5.81039 
C      henke(22,3, 97 ) = 13.3846 
C      henke(22,1, 98 ) = 47.4147 
C      henke(22,2, 98 ) = 6.66221 
C      henke(22,3, 98 ) = 13.3404 
C      henke(22,1, 99 ) = 48.1816 
C      henke(22,2, 99 ) = 7.41583 
C      henke(22,3, 99 ) = 13.2926 
C      henke(22,1, 100 ) = 48.9609 
C      henke(22,2, 100 ) = 8.21005 
C      henke(22,3, 100 ) = 13.2134 
C      henke(22,1, 101 ) = 49.7528 
C      henke(22,2, 101 ) = 8.99189 
C      henke(22,3, 101 ) = 13.0142 
C      henke(22,1, 102 ) = 50.5576 
C      henke(22,2, 102 ) = 9.87913 
C      henke(22,3, 102 ) = 12.818 
C      henke(22,1, 103 ) = 51.3753 
C      henke(22,2, 103 ) = 10.7654 
C      henke(22,3, 103 ) = 12.25 
C      henke(22,1, 104 ) = 52.2062 
C      henke(22,2, 104 ) = 11.3311 
C      henke(22,3, 104 ) = 11.583 
C      henke(22,1, 105 ) = 53.0506 
C      henke(22,2, 105 ) = 11.7574 
C      henke(22,3, 105 ) = 10.9523 
C      henke(22,1, 106 ) = 53.9087 
C      henke(22,2, 106 ) = 12.0921 
C      henke(22,3, 106 ) = 10.356 
C      henke(22,1, 107 ) = 54.7806 
C      henke(22,2, 107 ) = 12.3673 
C      henke(22,3, 107 ) = 9.79211 
C      henke(22,1, 108 ) = 55.6667 
C      henke(22,2, 108 ) = 12.5843 
C      henke(22,3, 108 ) = 9.21805 
C      henke(22,1, 109 ) = 56.567 
C      henke(22,2, 109 ) = 12.733 
C      henke(22,3, 109 ) = 8.67767 
C      henke(22,1, 110 ) = 57.482 
C      henke(22,2, 110 ) = 12.8383 
C      henke(22,3, 110 ) = 8.16894 
C      henke(22,1, 111 ) = 58.4117 
C      henke(22,2, 111 ) = 12.9183 
C      henke(22,3, 111 ) = 7.69006 
C      henke(22,1, 112 ) = 59.3564 
C      henke(22,2, 112 ) = 12.9794 
C      henke(22,3, 112 ) = 7.20058 
C      henke(22,1, 113 ) = 60.3165 
C      henke(22,2, 113 ) = 12.9818 
C      henke(22,3, 113 ) = 6.7034 
C      henke(22,1, 114 ) = 61.2921 
C      henke(22,2, 114 ) = 12.9157 
C      henke(22,3, 114 ) = 6.24055 
C      henke(22,1, 115 ) = 62.2834 
C      henke(22,2, 115 ) = 12.7967 
C      henke(22,3, 115 ) = 5.80968 
C      henke(22,1, 116 ) = 63.2908 
C      henke(22,2, 116 ) = 12.6495 
C      henke(22,3, 116 ) = 5.46644 
C      henke(22,1, 117 ) = 64.3145 
C      henke(22,2, 117 ) = 12.5124 
C      henke(22,3, 117 ) = 5.14676 
C      henke(22,1, 118 ) = 65.3547 
C      henke(22,2, 118 ) = 12.3638 
C      henke(22,3, 118 ) = 4.84578 
C      henke(22,1, 119 ) = 66.4118 
C      henke(22,2, 119 ) = 12.1983 
C      henke(22,3, 119 ) = 4.5624 
C      henke(22,1, 120 ) = 67.4859 
C      henke(22,2, 120 ) = 11.9609 
C      henke(22,3, 120 ) = 4.29559 
C      henke(22,1, 121 ) = 68.5775 
C      henke(22,2, 121 ) = 11.7093 
C      henke(22,3, 121 ) = 4.16251 
C      henke(22,1, 122 ) = 69.6867 
C      henke(22,2, 122 ) = 11.5432 
C      henke(22,3, 122 ) = 4.05894 
C      henke(22,1, 123 ) = 70.8138 
C      henke(22,2, 123 ) = 11.3955 
C      henke(22,3, 123 ) = 3.95795 
C      henke(22,1, 124 ) = 71.9591 
C      henke(22,2, 124 ) = 11.2499 
C      henke(22,3, 124 ) = 3.85948 
C      henke(22,1, 125 ) = 73.123 
C      henke(22,2, 125 ) = 11.1054 
C      henke(22,3, 125 ) = 3.78039 
C      henke(22,1, 126 ) = 74.3057 
C      henke(22,2, 126 ) = 10.9646 
C      henke(22,3, 126 ) = 3.71807 
C      henke(22,1, 127 ) = 75.5076 
C      henke(22,2, 127 ) = 10.8366 
C      henke(22,3, 127 ) = 3.68632 
C      henke(22,1, 128 ) = 76.7289 
C      henke(22,2, 128 ) = 10.7337 
C      henke(22,3, 128 ) = 3.65484 
C      henke(22,1, 129 ) = 77.9699 
C      henke(22,2, 129 ) = 10.6313 
C      henke(22,3, 129 ) = 3.62362 
C      henke(22,1, 130 ) = 79.231 
C      henke(22,2, 130 ) = 10.532 
C      henke(22,3, 130 ) = 3.61766 
C      henke(22,1, 131 ) = 80.5125 
C      henke(22,2, 131 ) = 10.4529 
C      henke(22,3, 131 ) = 3.6186 
C      henke(22,1, 132 ) = 81.8147 
C      henke(22,2, 132 ) = 10.387 
C      henke(22,3, 132 ) = 3.61953 
C      henke(22,1, 133 ) = 83.138 
C      henke(22,2, 133 ) = 10.3284 
C      henke(22,3, 133 ) = 3.62046 
C      henke(22,1, 134 ) = 84.4827 
C      henke(22,2, 134 ) = 10.2655 
C      henke(22,3, 134 ) = 3.62139 
C      henke(22,1, 135 ) = 85.8491 
C      henke(22,2, 135 ) = 10.2071 
C      henke(22,3, 135 ) = 3.64392 
C      henke(22,1, 136 ) = 87.2377 
C      henke(22,2, 136 ) = 10.1702 
C      henke(22,3, 136 ) = 3.67029 
C      henke(22,1, 137 ) = 88.6487 
C      henke(22,2, 137 ) = 10.1433 
C      henke(22,3, 137 ) = 3.69685 
C      henke(22,1, 138 ) = 90.0825 
C      henke(22,2, 138 ) = 10.1254 
C      henke(22,3, 138 ) = 3.7236 
C      henke(22,1, 139 ) = 91.5395 
C      henke(22,2, 139 ) = 10.1157 
C      henke(22,3, 139 ) = 3.75055 
C      henke(22,1, 140 ) = 93.0201 
C      henke(22,2, 140 ) = 10.1143 
C      henke(22,3, 140 ) = 3.77769 
C      henke(22,1, 141 ) = 94.5246 
C      henke(22,2, 141 ) = 10.1212 
C      henke(22,3, 141 ) = 3.80503 
C      henke(22,1, 142 ) = 96.0535 
C      henke(22,2, 142 ) = 10.1464 
C      henke(22,3, 142 ) = 3.83256 
C      henke(22,1, 143 ) = 97.6071 
C      henke(22,2, 143 ) = 10.1807 
C      henke(22,3, 143 ) = 3.83855 
C      henke(22,1, 144 ) = 99.1858 
C      henke(22,2, 144 ) = 10.2045 
C      henke(22,3, 144 ) = 3.83573 
C      henke(22,1, 145 ) = 100.79 
C      henke(22,2, 145 ) = 10.2259 
C      henke(22,3, 145 ) = 3.83291 
C      henke(22,1, 146 ) = 102.42 
C      henke(22,2, 146 ) = 10.2471 
C      henke(22,3, 146 ) = 3.8301 
C      henke(22,1, 147 ) = 104.077 
C      henke(22,2, 147 ) = 10.269 
C      henke(22,3, 147 ) = 3.82728 
C      henke(22,1, 148 ) = 105.76 
C      henke(22,2, 148 ) = 10.2924 
C      henke(22,3, 148 ) = 3.82447 
C      henke(22,1, 149 ) = 107.471 
C      henke(22,2, 149 ) = 10.3179 
C      henke(22,3, 149 ) = 3.82166 
C      henke(22,1, 150 ) = 109.209 
C      henke(22,2, 150 ) = 10.3491 
C      henke(22,3, 150 ) = 3.81886 
C      henke(22,1, 151 ) = 110.975 
C      henke(22,2, 151 ) = 10.3868 
C      henke(22,3, 151 ) = 3.81121 
C      henke(22,1, 152 ) = 112.77 
C      henke(22,2, 152 ) = 10.4222 
C      henke(22,3, 152 ) = 3.78556 
C      henke(22,1, 153 ) = 114.594 
C      henke(22,2, 153 ) = 10.4479 
C      henke(22,3, 153 ) = 3.76009 
C      henke(22,1, 154 ) = 116.448 
C      henke(22,2, 154 ) = 10.469 
C      henke(22,3, 154 ) = 3.73479 
C      henke(22,1, 155 ) = 118.331 
C      henke(22,2, 155 ) = 10.4863 
C      henke(22,3, 155 ) = 3.70966 
C      henke(22,1, 156 ) = 120.245 
C      henke(22,2, 156 ) = 10.4999 
C      henke(22,3, 156 ) = 3.68471 
C      henke(22,1, 157 ) = 122.19 
C      henke(22,2, 157 ) = 10.5095 
C      henke(22,3, 157 ) = 3.65991 
C      henke(22,1, 158 ) = 124.166 
C      henke(22,2, 158 ) = 10.5041 
C      henke(22,3, 158 ) = 3.63529 
C      henke(22,1, 159 ) = 126.175 
C      henke(22,2, 159 ) = 10.4947 
C      henke(22,3, 159 ) = 3.63501 
C      henke(22,1, 160 ) = 128.215 
C      henke(22,2, 160 ) = 10.5022 
C      henke(22,3, 160 ) = 3.63961 
C      henke(22,1, 161 ) = 130.289 
C      henke(22,2, 161 ) = 10.5141 
C      henke(22,3, 161 ) = 3.64421 
C      henke(22,1, 162 ) = 132.397 
C      henke(22,2, 162 ) = 10.5296 
C      henke(22,3, 162 ) = 3.64882 
C      henke(22,1, 163 ) = 134.538 
C      henke(22,2, 163 ) = 10.548 
C      henke(22,3, 163 ) = 3.65343 
C      henke(22,1, 164 ) = 136.714 
C      henke(22,2, 164 ) = 10.5692 
C      henke(22,3, 164 ) = 3.65805 
C      henke(22,1, 165 ) = 138.925 
C      henke(22,2, 165 ) = 10.5937 
C      henke(22,3, 165 ) = 3.66267 
C      henke(22,1, 166 ) = 141.172 
C      henke(22,2, 166 ) = 10.6209 
C      henke(22,3, 166 ) = 3.66357 
C      henke(22,1, 167 ) = 143.456 
C      henke(22,2, 167 ) = 10.6477 
C      henke(22,3, 167 ) = 3.66345 
C      henke(22,1, 168 ) = 145.776 
C      henke(22,2, 168 ) = 10.6748 
C      henke(22,3, 168 ) = 3.66334 
C      henke(22,1, 169 ) = 148.134 
C      henke(22,2, 169 ) = 10.7029 
C      henke(22,3, 169 ) = 3.66322 
C      henke(22,1, 170 ) = 150.53 
C      henke(22,2, 170 ) = 10.7323 
C      henke(22,3, 170 ) = 3.6631 
C      henke(22,1, 171 ) = 152.964 
C      henke(22,2, 171 ) = 10.7632 
C      henke(22,3, 171 ) = 3.66299 
C      henke(22,1, 172 ) = 155.439 
C      henke(22,2, 172 ) = 10.7961 
C      henke(22,3, 172 ) = 3.66288 
C      henke(22,1, 173 ) = 157.953 
C      henke(22,2, 173 ) = 10.8314 
C      henke(22,3, 173 ) = 3.66276 
C      henke(22,1, 174 ) = 160.507 
C      henke(22,2, 174 ) = 10.8775 
C      henke(22,3, 174 ) = 3.66264 
C      henke(22,1, 175 ) = 163.103 
C      henke(22,2, 175 ) = 10.9258 
C      henke(22,3, 175 ) = 3.64366 
C      henke(22,1, 176 ) = 165.742 
C      henke(22,2, 176 ) = 10.9604 
C      henke(22,3, 176 ) = 3.62325 
C      henke(22,1, 177 ) = 168.422 
C      henke(22,2, 177 ) = 10.9926 
C      henke(22,3, 177 ) = 3.60297 
C      henke(22,1, 178 ) = 171.146 
C      henke(22,2, 178 ) = 11.0223 
C      henke(22,3, 178 ) = 3.58279 
C      henke(22,1, 179 ) = 173.915 
C      henke(22,2, 179 ) = 11.0499 
C      henke(22,3, 179 ) = 3.56273 
C      henke(22,1, 180 ) = 176.727 
C      henke(22,2, 180 ) = 11.0755 
C      henke(22,3, 180 ) = 3.54278 
C      henke(22,1, 181 ) = 179.586 
C      henke(22,2, 181 ) = 11.0988 
C      henke(22,3, 181 ) = 3.52294 
C      henke(22,1, 182 ) = 182.491 
C      henke(22,2, 182 ) = 11.1173 
C      henke(22,3, 182 ) = 3.50489 
C      henke(22,1, 183 ) = 185.442 
C      henke(22,2, 183 ) = 11.1363 
C      henke(22,3, 183 ) = 3.49521 
C      henke(22,1, 184 ) = 188.442 
C      henke(22,2, 184 ) = 11.1613 
C      henke(22,3, 184 ) = 3.48556 
C      henke(22,1, 185 ) = 191.489 
C      henke(22,2, 185 ) = 11.1884 
C      henke(22,3, 185 ) = 3.47593 
C      henke(22,1, 186 ) = 194.587 
C      henke(22,2, 186 ) = 11.2187 
C      henke(22,3, 186 ) = 3.46633 
C      henke(22,1, 187 ) = 197.734 
C      henke(22,2, 187 ) = 11.2562 
C      henke(22,3, 187 ) = 3.45676 
C      henke(22,1, 188 ) = 200.932 
C      henke(22,2, 188 ) = 11.2995 
C      henke(22,3, 188 ) = 3.43062 
C      henke(22,1, 189 ) = 204.182 
C      henke(22,2, 189 ) = 11.3335 
C      henke(22,3, 189 ) = 3.39642 
C      henke(22,1, 190 ) = 207.485 
C      henke(22,2, 190 ) = 11.3593 
C      henke(22,3, 190 ) = 3.36256 
C      henke(22,1, 191 ) = 210.84 
C      henke(22,2, 191 ) = 11.3821 
C      henke(22,3, 191 ) = 3.32903 
C      henke(22,1, 192 ) = 214.251 
C      henke(22,2, 192 ) = 11.4033 
C      henke(22,3, 192 ) = 3.29584 
C      henke(22,1, 193 ) = 217.716 
C      henke(22,2, 193 ) = 11.4256 
C      henke(22,3, 193 ) = 3.26298 
C      henke(22,1, 194 ) = 221.237 
C      henke(22,2, 194 ) = 11.4459 
C      henke(22,3, 194 ) = 3.21703 
C      henke(22,1, 195 ) = 224.816 
C      henke(22,2, 195 ) = 11.4556 
C      henke(22,3, 195 ) = 3.1714 
C      henke(22,1, 196 ) = 228.452 
C      henke(22,2, 196 ) = 11.4592 
C      henke(22,3, 196 ) = 3.12641 
C      henke(22,1, 197 ) = 232.147 
C      henke(22,2, 197 ) = 11.4573 
C      henke(22,3, 197 ) = 3.08207 
C      henke(22,1, 198 ) = 235.902 
C      henke(22,2, 198 ) = 11.445 
C      henke(22,3, 198 ) = 3.03835 
C      henke(22,1, 199 ) = 239.717 
C      henke(22,2, 199 ) = 11.4278 
C      henke(22,3, 199 ) = 3.00748 
C      henke(22,1, 200 ) = 243.595 
C      henke(22,2, 200 ) = 11.417 
C      henke(22,3, 200 ) = 2.97875 
C      henke(22,1, 201 ) = 247.535 
C      henke(22,2, 201 ) = 11.4055 
C      henke(22,3, 201 ) = 2.9503 
C      henke(22,1, 202 ) = 251.538 
C      henke(22,2, 202 ) = 11.3936 
C      henke(22,3, 202 ) = 2.92212 
C      henke(22,1, 203 ) = 255.607 
C      henke(22,2, 203 ) = 11.3819 
C      henke(22,3, 203 ) = 2.89421 
C      henke(22,1, 204 ) = 259.741 
C      henke(22,2, 204 ) = 11.3704 
C      henke(22,3, 204 ) = 2.86151 
C      henke(22,1, 205 ) = 263.942 
C      henke(22,2, 205 ) = 11.3535 
C      henke(22,3, 205 ) = 2.82532 
C      henke(22,1, 206 ) = 268.211 
C      henke(22,2, 206 ) = 11.3305 
C      henke(22,3, 206 ) = 2.78959 
C      henke(22,1, 207 ) = 272.549 
C      henke(22,2, 207 ) = 11.3035 
C      henke(22,3, 207 ) = 2.75431 
C      henke(22,1, 208 ) = 276.957 
C      henke(22,2, 208 ) = 11.2727 
C      henke(22,3, 208 ) = 2.71947 
C      henke(22,1, 209 ) = 281.437 
C      henke(22,2, 209 ) = 11.2378 
C      henke(22,3, 209 ) = 2.68422 
C      henke(22,1, 210 ) = 285.989 
C      henke(22,2, 210 ) = 11.1979 
C      henke(22,3, 210 ) = 2.64929 
C      henke(22,1, 211 ) = 290.615 
C      henke(22,2, 211 ) = 11.1532 
C      henke(22,3, 211 ) = 2.61481 
C      henke(22,1, 212 ) = 295.315 
C      henke(22,2, 212 ) = 11.1037 
C      henke(22,3, 212 ) = 2.58078 
C      henke(22,1, 213 ) = 300.092 
C      henke(22,2, 213 ) = 11.049 
C      henke(22,3, 213 ) = 2.54719 
C      henke(22,1, 214 ) = 304.945 
C      henke(22,2, 214 ) = 10.9891 
C      henke(22,3, 214 ) = 2.51404 
C      henke(22,1, 215 ) = 309.878 
C      henke(22,2, 215 ) = 10.9234 
C      henke(22,3, 215 ) = 2.4811 
C      henke(22,1, 216 ) = 314.89 
C      henke(22,2, 216 ) = 10.8513 
C      henke(22,3, 216 ) = 2.44781 
C      henke(22,1, 217 ) = 319.983 
C      henke(22,2, 217 ) = 10.7718 
C      henke(22,3, 217 ) = 2.41497 
C      henke(22,1, 218 ) = 325.158 
C      henke(22,2, 218 ) = 10.6848 
C      henke(22,3, 218 ) = 2.38257 
C      henke(22,1, 219 ) = 330.418 
C      henke(22,2, 219 ) = 10.5895 
C      henke(22,3, 219 ) = 2.35061 
C      henke(22,1, 220 ) = 335.762 
C      henke(22,2, 220 ) = 10.4852 
C      henke(22,3, 220 ) = 2.31907 
C      henke(22,1, 221 ) = 341.192 
C      henke(22,2, 221 ) = 10.3714 
C      henke(22,3, 221 ) = 2.28796 
C      henke(22,1, 222 ) = 346.711 
C      henke(22,2, 222 ) = 10.2475 
C      henke(22,3, 222 ) = 2.25726 
C      henke(22,1, 223 ) = 352.319 
C      henke(22,2, 223 ) = 10.1146 
C      henke(22,3, 223 ) = 2.22698 
C      henke(22,1, 224 ) = 358.017 
C      henke(22,2, 224 ) = 9.96989 
C      henke(22,3, 224 ) = 2.1847 
C      henke(22,1, 225 ) = 363.808 
C      henke(22,2, 225 ) = 9.79951 
C      henke(22,3, 225 ) = 2.13812 
C      henke(22,1, 226 ) = 369.692 
C      henke(22,2, 226 ) = 9.60261 
C      henke(22,3, 226 ) = 2.09252 
C      henke(22,1, 227 ) = 375.672 
C      henke(22,2, 227 ) = 9.37848 
C      henke(22,3, 227 ) = 2.0479 
C      henke(22,1, 228 ) = 381.748 
C      henke(22,2, 228 ) = 9.1207 
C      henke(22,3, 228 ) = 2.00423 
C      henke(22,1, 229 ) = 387.922 
C      henke(22,2, 229 ) = 8.8237 
C      henke(22,3, 229 ) = 1.96503 
C      henke(22,1, 230 ) = 394.197 
C      henke(22,2, 230 ) = 8.48753 
C      henke(22,3, 230 ) = 1.93947 
C      henke(22,1, 231 ) = 400.573 
C      henke(22,2, 231 ) = 8.10598 
C      henke(22,3, 231 ) = 1.91164 
C      henke(22,1, 232 ) = 407.052 
C      henke(22,2, 232 ) = 7.65755 
C      henke(22,3, 232 ) = 1.88318 
C      henke(22,1, 233 ) = 413.635 
C      henke(22,2, 233 ) = 7.12029 
C      henke(22,3, 233 ) = 1.85515 
C      henke(22,1, 234 ) = 420.326 
C      henke(22,2, 234 ) = 6.45861 
C      henke(22,3, 234 ) = 1.82754 
C      henke(22,1, 235 ) = 427.124 
C      henke(22,2, 235 ) = 5.61123 
C      henke(22,3, 235 ) = 1.80033 
C      henke(22,1, 236 ) = 434.032 
C      henke(22,2, 236 ) = 4.45863 
C      henke(22,3, 236 ) = 1.77351 
C      henke(22,1, 237 ) = 441.052 
C      henke(22,2, 237 ) = 2.71435 
C      henke(22,3, 237 ) = 1.74711 
C      henke(22,1, 238 ) = 448.186 
C      henke(22,2, 238 ) = -0.679332 
C      henke(22,3, 238 ) = 1.72112 
C      henke(22,1, 239 ) = 453.7 
C      henke(22,2, 239 ) = -18.2884 
C      henke(22,3, 239 ) = 1.70156 
C      henke(22,1, 240 ) = 453.9 
C      henke(22,2, 240 ) = -18.2691 
C      henke(22,3, 240 ) = 15.6456 
C      henke(22,1, 241 ) = 455.435 
C      henke(22,2, 241 ) = -5.76893 
C      henke(22,3, 241 ) = 15.5845 
C      henke(22,1, 242 ) = 462.802 
C      henke(22,2, 242 ) = 2.0858 
C      henke(22,3, 242 ) = 15.2973 
C      henke(22,1, 243 ) = 470.287 
C      henke(22,2, 243 ) = 4.96679 
C      henke(22,3, 243 ) = 15.0155 
C      henke(22,1, 244 ) = 477.894 
C      henke(22,2, 244 ) = 6.7984 
C      henke(22,3, 244 ) = 14.7389 
C      henke(22,1, 245 ) = 485.623 
C      henke(22,2, 245 ) = 8.14683 
C      henke(22,3, 245 ) = 14.4673 
C      henke(22,1, 246 ) = 493.478 
C      henke(22,2, 246 ) = 9.211 
C      henke(22,3, 246 ) = 14.2007 
C      henke(22,1, 247 ) = 501.459 
C      henke(22,2, 247 ) = 10.0843 
C      henke(22,3, 247 ) = 13.9392 
C      henke(22,1, 248 ) = 509.57 
C      henke(22,2, 248 ) = 10.8175 
C      henke(22,3, 248 ) = 13.6824 
C      henke(22,1, 249 ) = 517.812 
C      henke(22,2, 249 ) = 11.4398 
C      henke(22,3, 249 ) = 13.4303 
C      henke(22,1, 250 ) = 526.187 
C      henke(22,2, 250 ) = 11.9676 
C      henke(22,3, 250 ) = 13.1825 
C      henke(22,1, 251 ) = 534.698 
C      henke(22,2, 251 ) = 12.4079 
C      henke(22,3, 251 ) = 12.9397 
C      henke(22,1, 252 ) = 543.346 
C      henke(22,2, 252 ) = 12.7632 
C      henke(22,3, 252 ) = 12.7014 
C      henke(22,1, 253 ) = 552.134 
C      henke(22,2, 253 ) = 12.8659 
C      henke(22,3, 253 ) = 12.4676 
C      henke(22,1, 254 ) = 561.065 
C      henke(22,2, 254 ) = 12.8684 
C      henke(22,3, 254 ) = 12.6328 
C      henke(22,1, 255 ) = 570.139 
C      henke(22,2, 255 ) = 13.2025 
C      henke(22,3, 255 ) = 12.9952 
C      henke(22,1, 256 ) = 579.361 
C      henke(22,2, 256 ) = 13.8081 
C      henke(22,3, 256 ) = 13.3681 
C      henke(22,1, 257 ) = 588.732 
C      henke(22,2, 257 ) = 14.6565 
C      henke(22,3, 257 ) = 13.358 
C      henke(22,1, 258 ) = 598.254 
C      henke(22,2, 258 ) = 15.3266 
C      henke(22,3, 258 ) = 13.102 
C      henke(22,1, 259 ) = 607.93 
C      henke(22,2, 259 ) = 15.814 
C      henke(22,3, 259 ) = 12.851 
C      henke(22,1, 260 ) = 617.763 
C      henke(22,2, 260 ) = 16.2476 
C      henke(22,3, 260 ) = 12.6048 
C      henke(22,1, 261 ) = 627.755 
C      henke(22,2, 261 ) = 16.6407 
C      henke(22,3, 261 ) = 12.3626 
C      henke(22,1, 262 ) = 637.908 
C      henke(22,2, 262 ) = 17.0021 
C      henke(22,3, 262 ) = 12.1171 
C      henke(22,1, 263 ) = 648.226 
C      henke(22,2, 263 ) = 17.3325 
C      henke(22,3, 263 ) = 11.8653 
C      henke(22,1, 264 ) = 658.711 
C      henke(22,2, 264 ) = 17.6283 
C      henke(22,3, 264 ) = 11.6115 
C      henke(22,1, 265 ) = 669.365 
C      henke(22,2, 265 ) = 17.8818 
C      henke(22,3, 265 ) = 11.3625 
C      henke(22,1, 266 ) = 680.191 
C      henke(22,2, 266 ) = 18.1077 
C      henke(22,3, 266 ) = 11.1436 
C      henke(22,1, 267 ) = 691.193 
C      henke(22,2, 267 ) = 18.3374 
C      henke(22,3, 267 ) = 10.9478 
C      henke(22,1, 268 ) = 702.372 
C      henke(22,2, 268 ) = 18.5732 
C      henke(22,3, 268 ) = 10.7585 
C      henke(22,1, 269 ) = 713.733 
C      henke(22,2, 269 ) = 18.8142 
C      henke(22,3, 269 ) = 10.5467 
C      henke(22,1, 270 ) = 725.277 
C      henke(22,2, 270 ) = 19.0312 
C      henke(22,3, 270 ) = 10.3216 
C      henke(22,1, 271 ) = 737.008 
C      henke(22,2, 271 ) = 19.2245 
C      henke(22,3, 271 ) = 10.1014 
C      henke(22,1, 272 ) = 748.928 
C      henke(22,2, 272 ) = 19.4045 
C      henke(22,3, 272 ) = 9.88576 
C      henke(22,1, 273 ) = 761.042 
C      henke(22,2, 273 ) = 19.5731 
C      henke(22,3, 273 ) = 9.67465 
C      henke(22,1, 274 ) = 773.351 
C      henke(22,2, 274 ) = 19.7319 
C      henke(22,3, 274 ) = 9.46726 
C      henke(22,1, 275 ) = 785.859 
C      henke(22,2, 275 ) = 19.8817 
C      henke(22,3, 275 ) = 9.26165 
C      henke(22,1, 276 ) = 798.57 
C      henke(22,2, 276 ) = 20.0208 
C      henke(22,3, 276 ) = 9.05835 
C      henke(22,1, 277 ) = 811.486 
C      henke(22,2, 277 ) = 20.15 
C      henke(22,3, 277 ) = 8.8595 
C      henke(22,1, 278 ) = 824.611 
C      henke(22,2, 278 ) = 20.271 
C      henke(22,3, 278 ) = 8.66501 
C      henke(22,1, 279 ) = 837.949 
C      henke(22,2, 279 ) = 20.3849 
C      henke(22,3, 279 ) = 8.47477 
C      henke(22,1, 280 ) = 851.502 
C      henke(22,2, 280 ) = 20.4923 
C      henke(22,3, 280 ) = 8.288 
C      henke(22,1, 281 ) = 865.274 
C      henke(22,2, 281 ) = 20.5933 
C      henke(22,3, 281 ) = 8.10458 
C      henke(22,1, 282 ) = 879.269 
C      henke(22,2, 282 ) = 20.6881 
C      henke(22,3, 282 ) = 7.92455 
C      henke(22,1, 283 ) = 893.491 
C      henke(22,2, 283 ) = 20.777 
C      henke(22,3, 283 ) = 7.74846 
C      henke(22,1, 284 ) = 907.943 
C      henke(22,2, 284 ) = 20.861 
C      henke(22,3, 284 ) = 7.57631 
C      henke(22,1, 285 ) = 922.628 
C      henke(22,2, 285 ) = 20.9425 
C      henke(22,3, 285 ) = 7.40802 
C      henke(22,1, 286 ) = 937.551 
C      henke(22,2, 286 ) = 21.02 
C      henke(22,3, 286 ) = 7.23839 
C      henke(22,1, 287 ) = 952.715 
C      henke(22,2, 287 ) = 21.09 
C      henke(22,3, 287 ) = 7.07142 
C      henke(22,1, 288 ) = 968.124 
C      henke(22,2, 288 ) = 21.1545 
C      henke(22,3, 288 ) = 6.90723 
C      henke(22,1, 289 ) = 983.783 
C      henke(22,2, 289 ) = 21.2135 
C      henke(22,3, 289 ) = 6.74687 
C      henke(22,1, 290 ) = 999.695 
C      henke(22,2, 290 ) = 21.2681 
C      henke(22,3, 290 ) = 6.59037 
C      henke(22,1, 291 ) = 1015.86 
C      henke(22,2, 291 ) = 21.3185 
C      henke(22,3, 291 ) = 6.43766 
C      henke(22,1, 292 ) = 1032.29 
C      henke(22,2, 292 ) = 21.3663 
C      henke(22,3, 292 ) = 6.28968 
C      henke(22,1, 293 ) = 1048.99 
C      henke(22,2, 293 ) = 21.4127 
C      henke(22,3, 293 ) = 6.14293 
C      henke(22,1, 294 ) = 1065.96 
C      henke(22,2, 294 ) = 21.4546 
C      henke(22,3, 294 ) = 5.99728 
C      henke(22,1, 295 ) = 1083.2 
C      henke(22,2, 295 ) = 21.4919 
C      henke(22,3, 295 ) = 5.85509 
C      henke(22,1, 296 ) = 1100.72 
C      henke(22,2, 296 ) = 21.5258 
C      henke(22,3, 296 ) = 5.7163 
C      henke(22,1, 297 ) = 1118.52 
C      henke(22,2, 297 ) = 21.5567 
C      henke(22,3, 297 ) = 5.58081 
C      henke(22,1, 298 ) = 1136.61 
C      henke(22,2, 298 ) = 21.5849 
C      henke(22,3, 298 ) = 5.44849 
C      henke(22,1, 299 ) = 1155 
C      henke(22,2, 299 ) = 21.6106 
C      henke(22,3, 299 ) = 5.31932 
C      henke(22,1, 300 ) = 1173.68 
C      henke(22,2, 300 ) = 21.6341 
C      henke(22,3, 300 ) = 5.19325 
C      henke(22,1, 301 ) = 1192.66 
C      henke(22,2, 301 ) = 21.6555 
C      henke(22,3, 301 ) = 5.07013 
C      henke(22,1, 302 ) = 1211.95 
C      henke(22,2, 302 ) = 21.6751 
C      henke(22,3, 302 ) = 4.94992 
C      henke(22,1, 303 ) = 1231.55 
C      henke(22,2, 303 ) = 21.6935 
C      henke(22,3, 303 ) = 4.83257 
C      henke(22,1, 304 ) = 1251.47 
C      henke(22,2, 304 ) = 21.7108 
C      henke(22,3, 304 ) = 4.71682 
C      henke(22,1, 305 ) = 1271.72 
C      henke(22,2, 305 ) = 21.7263 
C      henke(22,3, 305 ) = 4.60264 
C      henke(22,1, 306 ) = 1292.29 
C      henke(22,2, 306 ) = 21.7394 
C      henke(22,3, 306 ) = 4.48977 
C      henke(22,1, 307 ) = 1313.19 
C      henke(22,2, 307 ) = 21.7496 
C      henke(22,3, 307 ) = 4.37967 
C      henke(22,1, 308 ) = 1334.43 
C      henke(22,2, 308 ) = 21.7581 
C      henke(22,3, 308 ) = 4.27224 
C      henke(22,1, 309 ) = 1356.01 
C      henke(22,2, 309 ) = 21.7648 
C      henke(22,3, 309 ) = 4.16739 
C      henke(22,1, 310 ) = 1377.94 
C      henke(22,2, 310 ) = 21.77 
C      henke(22,3, 310 ) = 4.06517 
C      henke(22,1, 311 ) = 1400.23 
C      henke(22,2, 311 ) = 21.774 
C      henke(22,3, 311 ) = 3.96544 
C      henke(22,1, 312 ) = 1422.88 
C      henke(22,2, 312 ) = 21.7769 
C      henke(22,3, 312 ) = 3.86813 
C      henke(22,1, 313 ) = 1445.89 
C      henke(22,2, 313 ) = 21.7791 
C      henke(22,3, 313 ) = 3.77327 
C      henke(22,1, 314 ) = 1469.28 
C      henke(22,2, 314 ) = 21.7807 
C      henke(22,3, 314 ) = 3.6803 
C      henke(22,1, 315 ) = 1493.04 
C      henke(22,2, 315 ) = 21.7824 
C      henke(22,3, 315 ) = 3.58895 
C      henke(22,1, 316 ) = 1517.19 
C      henke(22,2, 316 ) = 21.7832 
C      henke(22,3, 316 ) = 3.49695 
C      henke(22,1, 317 ) = 1541.73 
C      henke(22,2, 317 ) = 21.7803 
C      henke(22,3, 317 ) = 3.40693 
C      henke(22,1, 318 ) = 1566.67 
C      henke(22,2, 318 ) = 21.776 
C      henke(22,3, 318 ) = 3.31928 
C      henke(22,1, 319 ) = 1592.01 
C      henke(22,2, 319 ) = 21.7705 
C      henke(22,3, 319 ) = 3.23386 
C      henke(22,1, 320 ) = 1617.76 
C      henke(22,2, 320 ) = 21.7638 
C      henke(22,3, 320 ) = 3.15062 
C      henke(22,1, 321 ) = 1643.92 
C      henke(22,2, 321 ) = 21.756 
C      henke(22,3, 321 ) = 3.06952 
C      henke(22,1, 322 ) = 1670.51 
C      henke(22,2, 322 ) = 21.7474 
C      henke(22,3, 322 ) = 2.9906 
C      henke(22,1, 323 ) = 1697.53 
C      henke(22,2, 323 ) = 21.7383 
C      henke(22,3, 323 ) = 2.91366 
C      henke(22,1, 324 ) = 1724.99 
C      henke(22,2, 324 ) = 21.7286 
C      henke(22,3, 324 ) = 2.83861 
C      henke(22,1, 325 ) = 1752.89 
C      henke(22,2, 325 ) = 21.7184 
C      henke(22,3, 325 ) = 2.76463 
C      henke(22,1, 326 ) = 1781.24 
C      henke(22,2, 326 ) = 21.7071 
C      henke(22,3, 326 ) = 2.6923 
C      henke(22,1, 327 ) = 1810.05 
C      henke(22,2, 327 ) = 21.6947 
C      henke(22,3, 327 ) = 2.6217 
C      henke(22,1, 328 ) = 1839.32 
C      henke(22,2, 328 ) = 21.6816 
C      henke(22,3, 328 ) = 2.55294 
C      henke(22,1, 329 ) = 1869.07 
C      henke(22,2, 329 ) = 21.6678 
C      henke(22,3, 329 ) = 2.48596 
C      henke(22,1, 330 ) = 1899.3 
C      henke(22,2, 330 ) = 21.6534 
C      henke(22,3, 330 ) = 2.4207 
C      henke(22,1, 331 ) = 1930.02 
C      henke(22,2, 331 ) = 21.6384 
C      henke(22,3, 331 ) = 2.35715 
C      henke(22,1, 332 ) = 1961.24 
C      henke(22,2, 332 ) = 21.6229 
C      henke(22,3, 332 ) = 2.29528 
C      henke(22,1, 333 ) = 1992.96 
C      henke(22,2, 333 ) = 21.6068 
C      henke(22,3, 333 ) = 2.23505 
C      henke(22,1, 334 ) = 2025.2 
C      henke(22,2, 334 ) = 21.5904 
C      henke(22,3, 334 ) = 2.1771 
C      henke(22,1, 335 ) = 2057.95 
C      henke(22,2, 335 ) = 21.5744 
C      henke(22,3, 335 ) = 2.1196 
C      henke(22,1, 336 ) = 2091.24 
C      henke(22,2, 336 ) = 21.5575 
C      henke(22,3, 336 ) = 2.06352 
C      henke(22,1, 337 ) = 2125.06 
C      henke(22,2, 337 ) = 21.5401 
C      henke(22,3, 337 ) = 2.00886 
C      henke(22,1, 338 ) = 2159.43 
C      henke(22,2, 338 ) = 21.5223 
C      henke(22,3, 338 ) = 1.95557 
C      henke(22,1, 339 ) = 2194.36 
C      henke(22,2, 339 ) = 21.504 
C      henke(22,3, 339 ) = 1.90367 
C      henke(22,1, 340 ) = 2229.85 
C      henke(22,2, 340 ) = 21.4853 
C      henke(22,3, 340 ) = 1.85306 
C      henke(22,1, 341 ) = 2265.92 
C      henke(22,2, 341 ) = 21.4663 
C      henke(22,3, 341 ) = 1.80376 
C      henke(22,1, 342 ) = 2302.57 
C      henke(22,2, 342 ) = 21.4469 
C      henke(22,3, 342 ) = 1.75573 
C      henke(22,1, 343 ) = 2339.81 
C      henke(22,2, 343 ) = 21.4272 
C      henke(22,3, 343 ) = 1.70892 
C      henke(22,1, 344 ) = 2377.66 
C      henke(22,2, 344 ) = 21.4071 
C      henke(22,3, 344 ) = 1.66332 
C      henke(22,1, 345 ) = 2416.11 
C      henke(22,2, 345 ) = 21.3866 
C      henke(22,3, 345 ) = 1.61889 
C      henke(22,1, 346 ) = 2455.19 
C      henke(22,2, 346 ) = 21.3658 
C      henke(22,3, 346 ) = 1.57563 
C      henke(22,1, 347 ) = 2494.9 
C      henke(22,2, 347 ) = 21.3447 
C      henke(22,3, 347 ) = 1.53346 
C      henke(22,1, 348 ) = 2535.26 
C      henke(22,2, 348 ) = 21.3232 
C      henke(22,3, 348 ) = 1.49241 
C      henke(22,1, 349 ) = 2576.26 
C      henke(22,2, 349 ) = 21.3013 
C      henke(22,3, 349 ) = 1.45241 
C      henke(22,1, 350 ) = 2617.93 
C      henke(22,2, 350 ) = 21.2791 
C      henke(22,3, 350 ) = 1.41345 
C      henke(22,1, 351 ) = 2660.27 
C      henke(22,2, 351 ) = 21.2565 
C      henke(22,3, 351 ) = 1.37554 
C      henke(22,1, 352 ) = 2703.3 
C      henke(22,2, 352 ) = 21.2335 
C      henke(22,3, 352 ) = 1.33858 
C      henke(22,1, 353 ) = 2747.03 
C      henke(22,2, 353 ) = 21.21 
C      henke(22,3, 353 ) = 1.30261 
C      henke(22,1, 354 ) = 2791.46 
C      henke(22,2, 354 ) = 21.1862 
C      henke(22,3, 354 ) = 1.26756 
C      henke(22,1, 355 ) = 2836.61 
C      henke(22,2, 355 ) = 21.1619 
C      henke(22,3, 355 ) = 1.23344 
C      henke(22,1, 356 ) = 2882.49 
C      henke(22,2, 356 ) = 21.137 
C      henke(22,3, 356 ) = 1.20024 
C      henke(22,1, 357 ) = 2929.11 
C      henke(22,2, 357 ) = 21.1117 
C      henke(22,3, 357 ) = 1.16787 
C      henke(22,1, 358 ) = 2976.48 
C      henke(22,2, 358 ) = 21.0858 
C      henke(22,3, 358 ) = 1.13638 
C      henke(22,1, 359 ) = 3024.63 
C      henke(22,2, 359 ) = 21.0593 
C      henke(22,3, 359 ) = 1.10572 
C      henke(22,1, 360 ) = 3073.55 
C      henke(22,2, 360 ) = 21.0322 
C      henke(22,3, 360 ) = 1.07587 
C      henke(22,1, 361 ) = 3123.26 
C      henke(22,2, 361 ) = 21.0043 
C      henke(22,3, 361 ) = 1.04678 
C      henke(22,1, 362 ) = 3173.78 
C      henke(22,2, 362 ) = 20.9757 
C      henke(22,3, 362 ) = 1.01846 
C      henke(22,1, 363 ) = 3225.11 
C      henke(22,2, 363 ) = 20.9462 
C      henke(22,3, 363 ) = 0.990907 
C      henke(22,1, 364 ) = 3277.27 
C      henke(22,2, 364 ) = 20.9158 
C      henke(22,3, 364 ) = 0.964074 
C      henke(22,1, 365 ) = 3330.28 
C      henke(22,2, 365 ) = 20.8844 
C      henke(22,3, 365 ) = 0.937973 
C      henke(22,1, 366 ) = 3384.15 
C      henke(22,2, 366 ) = 20.8519 
C      henke(22,3, 366 ) = 0.91254 
C      henke(22,1, 367 ) = 3438.88 
C      henke(22,2, 367 ) = 20.8181 
C      henke(22,3, 367 ) = 0.887797 
C      henke(22,1, 368 ) = 3494.5 
C      henke(22,2, 368 ) = 20.7829 
C      henke(22,3, 368 ) = 0.863676 
C      henke(22,1, 369 ) = 3551.02 
C      henke(22,2, 369 ) = 20.7462 
C      henke(22,3, 369 ) = 0.840234 
C      henke(22,1, 370 ) = 3608.46 
C      henke(22,2, 370 ) = 20.7078 
C      henke(22,3, 370 ) = 0.817394 
C      henke(22,1, 371 ) = 3666.82 
C      henke(22,2, 371 ) = 20.6674 
C      henke(22,3, 371 ) = 0.795143 
C      henke(22,1, 372 ) = 3726.13 
C      henke(22,2, 372 ) = 20.6248 
C      henke(22,3, 372 ) = 0.77349 
C      henke(22,1, 373 ) = 3786.4 
C      henke(22,2, 373 ) = 20.5797 
C      henke(22,3, 373 ) = 0.752444 
C      henke(22,1, 374 ) = 3847.64 
C      henke(22,2, 374 ) = 20.5317 
C      henke(22,3, 374 ) = 0.731915 
C      henke(22,1, 375 ) = 3909.87 
C      henke(22,2, 375 ) = 20.4804 
C      henke(22,3, 375 ) = 0.711976 
C      henke(22,1, 376 ) = 3973.11 
C      henke(22,2, 376 ) = 20.4253 
C      henke(22,3, 376 ) = 0.692548 
C      henke(22,1, 377 ) = 4037.38 
C      henke(22,2, 377 ) = 20.3657 
C      henke(22,3, 377 ) = 0.673609 
C      henke(22,1, 378 ) = 4102.68 
C      henke(22,2, 378 ) = 20.3007 
C      henke(22,3, 378 ) = 0.655204 
C      henke(22,1, 379 ) = 4169.03 
C      henke(22,2, 379 ) = 20.2293 
C      henke(22,3, 379 ) = 0.637274 
C      henke(22,1, 380 ) = 4236.46 
C      henke(22,2, 380 ) = 20.1502 
C      henke(22,3, 380 ) = 0.619807 
C      henke(22,1, 381 ) = 4304.98 
C      henke(22,2, 381 ) = 20.0614 
C      henke(22,3, 381 ) = 0.602855 
C      henke(22,1, 382 ) = 4374.62 
C      henke(22,2, 382 ) = 19.9606 
C      henke(22,3, 382 ) = 0.586299 
C      henke(22,1, 383 ) = 4445.37 
C      henke(22,2, 383 ) = 19.844 
C      henke(22,3, 383 ) = 0.570202 
C      henke(22,1, 384 ) = 4517.27 
C      henke(22,2, 384 ) = 19.7064 
C      henke(22,3, 384 ) = 0.554551 
C      henke(22,1, 385 ) = 4590.33 
C      henke(22,2, 385 ) = 19.5394 
C      henke(22,3, 385 ) = 0.539289 
C      henke(22,1, 386 ) = 4664.58 
C      henke(22,2, 386 ) = 19.3287 
C      henke(22,3, 386 ) = 0.524429 
C      henke(22,1, 387 ) = 4740.03 
C      henke(22,2, 387 ) = 19.0468 
C      henke(22,3, 387 ) = 0.509971 
C      henke(22,1, 388 ) = 4816.69 
C      henke(22,2, 388 ) = 18.63 
C      henke(22,3, 388 ) = 0.495901 
C      henke(22,1, 389 ) = 4894.6 
C      henke(22,2, 389 ) = 17.8613 
C      henke(22,3, 389 ) = 0.482202 
C      henke(22,1, 390 ) = 4966.3 
C      henke(22,2, 390 ) = 10.4859 
C      henke(22,3, 390 ) = 0.470113 
C      henke(22,1, 391 ) = 4966.5 
C      henke(22,2, 391 ) = 10.4865 
C      henke(22,3, 391 ) = 4.03728 
C      henke(22,1, 392 ) = 4973.77 
C      henke(22,2, 392 ) = 15.3814 
C      henke(22,3, 392 ) = 4.02875 
C      henke(22,1, 393 ) = 5054.21 
C      henke(22,2, 393 ) = 18.2832 
C      henke(22,3, 393 ) = 3.93636 
C      henke(22,1, 394 ) = 5135.96 
C      henke(22,2, 394 ) = 19.0881 
C      henke(22,3, 394 ) = 3.84571 
C      henke(22,1, 395 ) = 5219.03 
C      henke(22,2, 395 ) = 19.585 
C      henke(22,3, 395 ) = 3.75632 
C      henke(22,1, 396 ) = 5303.44 
C      henke(22,2, 396 ) = 19.9471 
C      henke(22,3, 396 ) = 3.66816 
C      henke(22,1, 397 ) = 5389.22 
C      henke(22,2, 397 ) = 20.2321 
C      henke(22,3, 397 ) = 3.58137 
C      henke(22,1, 398 ) = 5476.39 
C      henke(22,2, 398 ) = 20.4667 
C      henke(22,3, 398 ) = 3.49596 
C      henke(22,1, 399 ) = 5564.97 
C      henke(22,2, 399 ) = 20.6654 
C      henke(22,3, 399 ) = 3.41191 
C      henke(22,1, 400 ) = 5654.98 
C      henke(22,2, 400 ) = 20.8369 
C      henke(22,3, 400 ) = 3.32924 
C      henke(22,1, 401 ) = 5746.44 
C      henke(22,2, 401 ) = 20.9871 
C      henke(22,3, 401 ) = 3.24793 
C      henke(22,1, 402 ) = 5839.39 
C      henke(22,2, 402 ) = 21.1201 
C      henke(22,3, 402 ) = 3.16813 
C      henke(22,1, 403 ) = 5933.83 
C      henke(22,2, 403 ) = 21.2389 
C      henke(22,3, 403 ) = 3.08973 
C      henke(22,1, 404 ) = 6029.81 
C      henke(22,2, 404 ) = 21.3456 
C      henke(22,3, 404 ) = 3.01276 
C      henke(22,1, 405 ) = 6127.33 
C      henke(22,2, 405 ) = 21.442 
C      henke(22,3, 405 ) = 2.93722 
C      henke(22,1, 406 ) = 6226.44 
C      henke(22,2, 406 ) = 21.5294 
C      henke(22,3, 406 ) = 2.86314 
C      henke(22,1, 407 ) = 6327.15 
C      henke(22,2, 407 ) = 21.6089 
C      henke(22,3, 407 ) = 2.79051 
C      henke(22,1, 408 ) = 6429.48 
C      henke(22,2, 408 ) = 21.6815 
C      henke(22,3, 408 ) = 2.71928 
C      henke(22,1, 409 ) = 6533.48 
C      henke(22,2, 409 ) = 21.7478 
C      henke(22,3, 409 ) = 2.64947 
C      henke(22,1, 410 ) = 6639.15 
C      henke(22,2, 410 ) = 21.8084 
C      henke(22,3, 410 ) = 2.58115 
C      henke(22,1, 411 ) = 6746.54 
C      henke(22,2, 411 ) = 21.8641 
C      henke(22,3, 411 ) = 2.51425 
C      henke(22,1, 412 ) = 6855.65 
C      henke(22,2, 412 ) = 21.9152 
C      henke(22,3, 412 ) = 2.4487 
C      henke(22,1, 413 ) = 6966.54 
C      henke(22,2, 413 ) = 21.962 
C      henke(22,3, 413 ) = 2.38459 
C      henke(22,1, 414 ) = 7079.22 
C      henke(22,2, 414 ) = 22.0051 
C      henke(22,3, 414 ) = 2.32187 
C      henke(22,1, 415 ) = 7193.72 
C      henke(22,2, 415 ) = 22.0446 
C      henke(22,3, 415 ) = 2.2605 
C      henke(22,1, 416 ) = 7310.07 
C      henke(22,2, 416 ) = 22.0809 
C      henke(22,3, 416 ) = 2.20051 
C      henke(22,1, 417 ) = 7428.31 
C      henke(22,2, 417 ) = 22.1143 
C      henke(22,3, 417 ) = 2.14182 
C      henke(22,1, 418 ) = 7548.45 
C      henke(22,2, 418 ) = 22.1448 
C      henke(22,3, 418 ) = 2.08447 
C      henke(22,1, 419 ) = 7670.54 
C      henke(22,2, 419 ) = 22.1728 
C      henke(22,3, 419 ) = 2.02842 
C      henke(22,1, 420 ) = 7794.61 
C      henke(22,2, 420 ) = 22.1985 
C      henke(22,3, 420 ) = 1.97371 
C      henke(22,1, 421 ) = 7920.68 
C      henke(22,2, 421 ) = 22.2219 
C      henke(22,3, 421 ) = 1.92025 
C      henke(22,1, 422 ) = 8048.79 
C      henke(22,2, 422 ) = 22.2433 
C      henke(22,3, 422 ) = 1.86808 
C      henke(22,1, 423 ) = 8178.98 
C      henke(22,2, 423 ) = 22.2629 
C      henke(22,3, 423 ) = 1.81708 
C      henke(22,1, 424 ) = 8311.26 
C      henke(22,2, 424 ) = 22.2806 
C      henke(22,3, 424 ) = 1.7673 
C      henke(22,1, 425 ) = 8445.69 
C      henke(22,2, 425 ) = 22.2967 
C      henke(22,3, 425 ) = 1.71874 
C      henke(22,1, 426 ) = 8582.29 
C      henke(22,2, 426 ) = 22.3112 
C      henke(22,3, 426 ) = 1.67137 
C      henke(22,1, 427 ) = 8721.11 
C      henke(22,2, 427 ) = 22.3243 
C      henke(22,3, 427 ) = 1.62515 
C      henke(22,1, 428 ) = 8862.16 
C      henke(22,2, 428 ) = 22.3361 
C      henke(22,3, 428 ) = 1.5801 
C      henke(22,1, 429 ) = 9005.5 
C      henke(22,2, 429 ) = 22.3467 
C      henke(22,3, 429 ) = 1.5361 
C      henke(22,1, 430 ) = 9151.16 
C      henke(22,2, 430 ) = 22.3559 
C      henke(22,3, 430 ) = 1.49323 
C      henke(22,1, 431 ) = 9299.17 
C      henke(22,2, 431 ) = 22.3642 
C      henke(22,3, 431 ) = 1.45146 
C      henke(22,1, 432 ) = 9449.58 
C      henke(22,2, 432 ) = 22.3714 
C      henke(22,3, 432 ) = 1.41072 
C      henke(22,1, 433 ) = 9602.42 
C      henke(22,2, 433 ) = 22.3777 
C      henke(22,3, 433 ) = 1.37098 
C      henke(22,1, 434 ) = 9757.73 
C      henke(22,2, 434 ) = 22.383 
C      henke(22,3, 434 ) = 1.3323 
C      henke(22,1, 435 ) = 9915.55 
C      henke(22,2, 435 ) = 22.3875 
C      henke(22,3, 435 ) = 1.29456 
C      henke(22,1, 436 ) = 10075.9 
C      henke(22,2, 436 ) = 22.3913 
C      henke(22,3, 436 ) = 1.25783 
C      henke(22,1, 437 ) = 10238.9 
C      henke(22,2, 437 ) = 22.3943 
C      henke(22,3, 437 ) = 1.22206 
C      henke(22,1, 438 ) = 10404.5 
C      henke(22,2, 438 ) = 22.3966 
C      henke(22,3, 438 ) = 1.18721 
C      henke(22,1, 439 ) = 10572.8 
C      henke(22,2, 439 ) = 22.3983 
C      henke(22,3, 439 ) = 1.15327 
C      henke(22,1, 440 ) = 10743.8 
C      henke(22,2, 440 ) = 22.3993 
C      henke(22,3, 440 ) = 1.12023 
C      henke(22,1, 441 ) = 10917.6 
C      henke(22,2, 441 ) = 22.3999 
C      henke(22,3, 441 ) = 1.08806 
C      henke(22,1, 442 ) = 11094.2 
C      henke(22,2, 442 ) = 22.3999 
C      henke(22,3, 442 ) = 1.05675 
C      henke(22,1, 443 ) = 11273.6 
C      henke(22,2, 443 ) = 22.3994 
C      henke(22,3, 443 ) = 1.02627 
C      henke(22,1, 444 ) = 11455.9 
C      henke(22,2, 444 ) = 22.3985 
C      henke(22,3, 444 ) = 0.9966 
C      henke(22,1, 445 ) = 11641.2 
C      henke(22,2, 445 ) = 22.3972 
C      henke(22,3, 445 ) = 0.967731 
C      henke(22,1, 446 ) = 11829.5 
C      henke(22,2, 446 ) = 22.3954 
C      henke(22,3, 446 ) = 0.93964 
C      henke(22,1, 447 ) = 12020.8 
C      henke(22,2, 447 ) = 22.3934 
C      henke(22,3, 447 ) = 0.91231 
C      henke(22,1, 448 ) = 12215.3 
C      henke(22,2, 448 ) = 22.391 
C      henke(22,3, 448 ) = 0.885721 
C      henke(22,1, 449 ) = 12412.8 
C      henke(22,2, 449 ) = 22.3882 
C      henke(22,3, 449 ) = 0.859858 
C      henke(22,1, 450 ) = 12613.6 
C      henke(22,2, 450 ) = 22.3852 
C      henke(22,3, 450 ) = 0.834702 
C      henke(22,1, 451 ) = 12817.6 
C      henke(22,2, 451 ) = 22.382 
C      henke(22,3, 451 ) = 0.810237 
C      henke(22,1, 452 ) = 13025 
C      henke(22,2, 452 ) = 22.3785 
C      henke(22,3, 452 ) = 0.786445 
C      henke(22,1, 453 ) = 13235.6 
C      henke(22,2, 453 ) = 22.3748 
C      henke(22,3, 453 ) = 0.76331 
C      henke(22,1, 454 ) = 13449.7 
C      henke(22,2, 454 ) = 22.3709 
C      henke(22,3, 454 ) = 0.740817 
C      henke(22,1, 455 ) = 13667.2 
C      henke(22,2, 455 ) = 22.3668 
C      henke(22,3, 455 ) = 0.718948 
C      henke(22,1, 456 ) = 13888.3 
C      henke(22,2, 456 ) = 22.3625 
C      henke(22,3, 456 ) = 0.69769 
C      henke(22,1, 457 ) = 14112.9 
C      henke(22,2, 457 ) = 22.3581 
C      henke(22,3, 457 ) = 0.677025 
C      henke(22,1, 458 ) = 14341.2 
C      henke(22,2, 458 ) = 22.3535 
C      henke(22,3, 458 ) = 0.65694 
C      henke(22,1, 459 ) = 14573.1 
C      henke(22,2, 459 ) = 22.3488 
C      henke(22,3, 459 ) = 0.63742 
C      henke(22,1, 460 ) = 14808.9 
C      henke(22,2, 460 ) = 22.344 
C      henke(22,3, 460 ) = 0.61845 
C      henke(22,1, 461 ) = 15048.4 
C      henke(22,2, 461 ) = 22.3391 
C      henke(22,3, 461 ) = 0.600015 
C      henke(22,1, 462 ) = 15291.8 
C      henke(22,2, 462 ) = 22.3342 
C      henke(22,3, 462 ) = 0.582103 
C      henke(22,1, 463 ) = 15539.1 
C      henke(22,2, 463 ) = 22.3291 
C      henke(22,3, 463 ) = 0.5647 
C      henke(22,1, 464 ) = 15790.4 
C      henke(22,2, 464 ) = 22.324 
C      henke(22,3, 464 ) = 0.547792 
C      henke(22,1, 465 ) = 16045.8 
C      henke(22,2, 465 ) = 22.3188 
C      henke(22,3, 465 ) = 0.531367 
C      henke(22,1, 466 ) = 16305.4 
C      henke(22,2, 466 ) = 22.3136 
C      henke(22,3, 466 ) = 0.515411 
C      henke(22,1, 467 ) = 16569.1 
C      henke(22,2, 467 ) = 22.3084 
C      henke(22,3, 467 ) = 0.499913 
C      henke(22,1, 468 ) = 16837.1 
C      henke(22,2, 468 ) = 22.3031 
C      henke(22,3, 468 ) = 0.48486 
C      henke(22,1, 469 ) = 17109.4 
C      henke(22,2, 469 ) = 22.2978 
C      henke(22,3, 469 ) = 0.470241 
C      henke(22,1, 470 ) = 17386.1 
C      henke(22,2, 470 ) = 22.2924 
C      henke(22,3, 470 ) = 0.456043 
C      henke(22,1, 471 ) = 17667.4 
C      henke(22,2, 471 ) = 22.2871 
C      henke(22,3, 471 ) = 0.442256 
C      henke(22,1, 472 ) = 17953.1 
C      henke(22,2, 472 ) = 22.2818 
C      henke(22,3, 472 ) = 0.428868 
C      henke(22,1, 473 ) = 18243.5 
C      henke(22,2, 473 ) = 22.2765 
C      henke(22,3, 473 ) = 0.415869 
C      henke(22,1, 474 ) = 18538.6 
C      henke(22,2, 474 ) = 22.2711 
C      henke(22,3, 474 ) = 0.403248 
C      henke(22,1, 475 ) = 18838.4 
C      henke(22,2, 475 ) = 22.2658 
C      henke(22,3, 475 ) = 0.390995 
C      henke(22,1, 476 ) = 19143.1 
C      henke(22,2, 476 ) = 22.2605 
C      henke(22,3, 476 ) = 0.379099 
C      henke(22,1, 477 ) = 19452.7 
C      henke(22,2, 477 ) = 22.2553 
C      henke(22,3, 477 ) = 0.367551 
C      henke(22,1, 478 ) = 19767.4 
C      henke(22,2, 478 ) = 22.25 
C      henke(22,3, 478 ) = 0.356342 
C      henke(22,1, 479 ) = 20087.1 
C      henke(22,2, 479 ) = 22.2448 
C      henke(22,3, 479 ) = 0.345462 
C      henke(22,1, 480 ) = 20412 
C      henke(22,2, 480 ) = 22.2396 
C      henke(22,3, 480 ) = 0.334901 
C      henke(22,1, 481 ) = 20742.1 
C      henke(22,2, 481 ) = 22.2345 
C      henke(22,3, 481 ) = 0.324652 
C      henke(22,1, 482 ) = 21077.6 
C      henke(22,2, 482 ) = 22.2294 
C      henke(22,3, 482 ) = 0.314704 
C      henke(22,1, 483 ) = 21418.5 
C      henke(22,2, 483 ) = 22.2243 
C      henke(22,3, 483 ) = 0.305051 
C      henke(22,1, 484 ) = 21765 
C      henke(22,2, 484 ) = 22.2193 
C      henke(22,3, 484 ) = 0.295684 
C      henke(22,1, 485 ) = 22117 
C      henke(22,2, 485 ) = 22.2144 
C      henke(22,3, 485 ) = 0.286594 
C      henke(22,1, 486 ) = 22474.7 
C      henke(22,2, 486 ) = 22.2094 
C      henke(22,3, 486 ) = 0.277774 
C      henke(22,1, 487 ) = 22838.2 
C      henke(22,2, 487 ) = 22.2046 
C      henke(22,3, 487 ) = 0.269216 
C      henke(22,1, 488 ) = 23207.6 
C      henke(22,2, 488 ) = 22.1998 
C      henke(22,3, 488 ) = 0.260913 
C      henke(22,1, 489 ) = 23583 
C      henke(22,2, 489 ) = 22.195 
C      henke(22,3, 489 ) = 0.252857 
C      henke(22,1, 490 ) = 23964.4 
C      henke(22,2, 490 ) = 22.1903 
C      henke(22,3, 490 ) = 0.245042 
C      henke(22,1, 491 ) = 24352 
C      henke(22,2, 491 ) = 22.1857 
C      henke(22,3, 491 ) = 0.237461 
C      henke(22,1, 492 ) = 24745.9 
C      henke(22,2, 492 ) = 22.1811 
C      henke(22,3, 492 ) = 0.230107 
C      henke(22,1, 493 ) = 25146.2 
C      henke(22,2, 493 ) = 22.1766 
C      henke(22,3, 493 ) = 0.222973 
C      henke(22,1, 494 ) = 25552.9 
C      henke(22,2, 494 ) = 22.1721 
C      henke(22,3, 494 ) = 0.216053 
C      henke(22,1, 495 ) = 25966.2 
C      henke(22,2, 495 ) = 22.1677 
C      henke(22,3, 495 ) = 0.209342 
C      henke(22,1, 496 ) = 26386.1 
C      henke(22,2, 496 ) = 22.1634 
C      henke(22,3, 496 ) = 0.202832 
C      henke(22,1, 497 ) = 26812.9 
C      henke(22,2, 497 ) = 22.1591 
C      henke(22,3, 497 ) = 0.196518 
C      henke(22,1, 498 ) = 27246.6 
C      henke(22,2, 498 ) = 22.1549 
C      henke(22,3, 498 ) = 0.190395 
C      henke(22,1, 499 ) = 27687.3 
C      henke(22,2, 499 ) = 22.1507 
C      henke(22,3, 499 ) = 0.184457 
C      henke(22,1, 500 ) = 28135.1 
C      henke(22,2, 500 ) = 22.1466 
C      henke(22,3, 500 ) = 0.178699 
C      henke(22,1, 501 ) = 28590.2 
C      henke(22,2, 501 ) = 22.1426 
C      henke(22,3, 501 ) = 0.173115 
C      henke(22,1, 502 ) = 29052.6 
C      henke(22,2, 502 ) = 22.1387 
C      henke(22,3, 502 ) = 0.1677 
C      henke(22,1, 503 ) = 29522.5 
C      henke(22,2, 503 ) = 22.1353 
C      henke(22,3, 503 ) = 0.16245 
C      henke(22,1, 504 ) = 30000 
C      henke(22,2, 504 ) = 22.1294 
C      henke(22,3, 504 ) = 0.157359 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C        Henke data for ni  z=28
C      count(28) = 504
C      henke(28,1, 1 ) = 10 
C      henke(28,2, 1 ) = -9999 
C      henke(28,3, 1 ) = 1.37727 
C      henke(28,1, 2 ) = 10.1617 
C      henke(28,2, 2 ) = -9999 
C      henke(28,3, 2 ) = 1.38064 
C      henke(28,1, 3 ) = 10.3261 
C      henke(28,2, 3 ) = -9999 
C      henke(28,3, 3 ) = 1.38401 
C      henke(28,1, 4 ) = 10.4931 
C      henke(28,2, 4 ) = -9999 
C      henke(28,3, 4 ) = 1.3874 
C      henke(28,1, 5 ) = 10.6628 
C      henke(28,2, 5 ) = -9999 
C      henke(28,3, 5 ) = 1.39079 
C      henke(28,1, 6 ) = 10.8353 
C      henke(28,2, 6 ) = -9999 
C      henke(28,3, 6 ) = 1.39419 
C      henke(28,1, 7 ) = 11.0106 
C      henke(28,2, 7 ) = -9999 
C      henke(28,3, 7 ) = 1.39982 
C      henke(28,1, 8 ) = 11.1886 
C      henke(28,2, 8 ) = -9999 
C      henke(28,3, 8 ) = 1.44104 
C      henke(28,1, 9 ) = 11.3696 
C      henke(28,2, 9 ) = -9999 
C      henke(28,3, 9 ) = 1.48347 
C      henke(28,1, 10 ) = 11.5535 
C      henke(28,2, 10 ) = -9999 
C      henke(28,3, 10 ) = 1.52716 
C      henke(28,1, 11 ) = 11.7404 
C      henke(28,2, 11 ) = -9999 
C      henke(28,3, 11 ) = 1.57212 
C      henke(28,1, 12 ) = 11.9303 
C      henke(28,2, 12 ) = -9999 
C      henke(28,3, 12 ) = 1.61841 
C      henke(28,1, 13 ) = 12.1232 
C      henke(28,2, 13 ) = -9999 
C      henke(28,3, 13 ) = 1.66663 
C      henke(28,1, 14 ) = 12.3193 
C      henke(28,2, 14 ) = -9999 
C      henke(28,3, 14 ) = 1.71662 
C      henke(28,1, 15 ) = 12.5186 
C      henke(28,2, 15 ) = -9999 
C      henke(28,3, 15 ) = 1.7681 
C      henke(28,1, 16 ) = 12.721 
C      henke(28,2, 16 ) = -9999 
C      henke(28,3, 16 ) = 1.82113 
C      henke(28,1, 17 ) = 12.9268 
C      henke(28,2, 17 ) = -9999 
C      henke(28,3, 17 ) = 1.87575 
C      henke(28,1, 18 ) = 13.1359 
C      henke(28,2, 18 ) = -9999 
C      henke(28,3, 18 ) = 1.93142 
C      henke(28,1, 19 ) = 13.3483 
C      henke(28,2, 19 ) = -9999 
C      henke(28,3, 19 ) = 1.98842 
C      henke(28,1, 20 ) = 13.5642 
C      henke(28,2, 20 ) = -9999 
C      henke(28,3, 20 ) = 2.0471 
C      henke(28,1, 21 ) = 13.7836 
C      henke(28,2, 21 ) = -9999 
C      henke(28,3, 21 ) = 2.10752 
C      henke(28,1, 22 ) = 14.0066 
C      henke(28,2, 22 ) = -9999 
C      henke(28,3, 22 ) = 2.16971 
C      henke(28,1, 23 ) = 14.2331 
C      henke(28,2, 23 ) = -9999 
C      henke(28,3, 23 ) = 2.23204 
C      henke(28,1, 24 ) = 14.4633 
C      henke(28,2, 24 ) = -9999 
C      henke(28,3, 24 ) = 2.28582 
C      henke(28,1, 25 ) = 14.6973 
C      henke(28,2, 25 ) = -9999 
C      henke(28,3, 25 ) = 2.34091 
C      henke(28,1, 26 ) = 14.935 
C      henke(28,2, 26 ) = -9999 
C      henke(28,3, 26 ) = 2.39732 
C      henke(28,1, 27 ) = 15.1765 
C      henke(28,2, 27 ) = -9999 
C      henke(28,3, 27 ) = 2.45509 
C      henke(28,1, 28 ) = 15.422 
C      henke(28,2, 28 ) = -9999 
C      henke(28,3, 28 ) = 2.51425 
C      henke(28,1, 29 ) = 15.6714 
C      henke(28,2, 29 ) = -9999 
C      henke(28,3, 29 ) = 2.5714 
C      henke(28,1, 30 ) = 15.9249 
C      henke(28,2, 30 ) = -9999 
C      henke(28,3, 30 ) = 2.62103 
C      henke(28,1, 31 ) = 16.1825 
C      henke(28,2, 31 ) = -9999 
C      henke(28,3, 31 ) = 2.67162 
C      henke(28,1, 32 ) = 16.4442 
C      henke(28,2, 32 ) = -9999 
C      henke(28,3, 32 ) = 2.72318 
C      henke(28,1, 33 ) = 16.7102 
C      henke(28,2, 33 ) = -9999 
C      henke(28,3, 33 ) = 2.77574 
C      henke(28,1, 34 ) = 16.9805 
C      henke(28,2, 34 ) = -9999 
C      henke(28,3, 34 ) = 2.82931 
C      henke(28,1, 35 ) = 17.2551 
C      henke(28,2, 35 ) = -9999 
C      henke(28,3, 35 ) = 2.88392 
C      henke(28,1, 36 ) = 17.5342 
C      henke(28,2, 36 ) = -9999 
C      henke(28,3, 36 ) = 2.93007 
C      henke(28,1, 37 ) = 17.8178 
C      henke(28,2, 37 ) = -9999 
C      henke(28,3, 37 ) = 2.9711 
C      henke(28,1, 38 ) = 18.106 
C      henke(28,2, 38 ) = -9999 
C      henke(28,3, 38 ) = 3.01271 
C      henke(28,1, 39 ) = 18.3989 
C      henke(28,2, 39 ) = -9999 
C      henke(28,3, 39 ) = 3.05491 
C      henke(28,1, 40 ) = 18.6964 
C      henke(28,2, 40 ) = -9999 
C      henke(28,3, 40 ) = 3.09769 
C      henke(28,1, 41 ) = 18.9988 
C      henke(28,2, 41 ) = -9999 
C      henke(28,3, 41 ) = 3.14107 
C      henke(28,1, 42 ) = 19.3061 
C      henke(28,2, 42 ) = -9999 
C      henke(28,3, 42 ) = 3.1147 
C      henke(28,1, 43 ) = 19.6184 
C      henke(28,2, 43 ) = -9999 
C      henke(28,3, 43 ) = 3.09192 
C      henke(28,1, 44 ) = 19.9357 
C      henke(28,2, 44 ) = -9999 
C      henke(28,3, 44 ) = 3.0999 
C      henke(28,1, 45 ) = 20.2582 
C      henke(28,2, 45 ) = -9999 
C      henke(28,3, 45 ) = 3.1079 
C      henke(28,1, 46 ) = 20.5858 
C      henke(28,2, 46 ) = -9999 
C      henke(28,3, 46 ) = 3.11592 
C      henke(28,1, 47 ) = 20.9188 
C      henke(28,2, 47 ) = -9999 
C      henke(28,3, 47 ) = 3.12491 
C      henke(28,1, 48 ) = 21.2571 
C      henke(28,2, 48 ) = -9999 
C      henke(28,3, 48 ) = 3.16974 
C      henke(28,1, 49 ) = 21.6009 
C      henke(28,2, 49 ) = -9999 
C      henke(28,3, 49 ) = 3.21521 
C      henke(28,1, 50 ) = 21.9503 
C      henke(28,2, 50 ) = -9999 
C      henke(28,3, 50 ) = 3.26133 
C      henke(28,1, 51 ) = 22.3053 
C      henke(28,2, 51 ) = -9999 
C      henke(28,3, 51 ) = 3.34677 
C      henke(28,1, 52 ) = 22.6661 
C      henke(28,2, 52 ) = -9999 
C      henke(28,3, 52 ) = 3.44429 
C      henke(28,1, 53 ) = 23.0327 
C      henke(28,2, 53 ) = -9999 
C      henke(28,3, 53 ) = 3.54465 
C      henke(28,1, 54 ) = 23.4053 
C      henke(28,2, 54 ) = -9999 
C      henke(28,3, 54 ) = 3.64793 
C      henke(28,1, 55 ) = 23.7838 
C      henke(28,2, 55 ) = -9999 
C      henke(28,3, 55 ) = 3.75422 
C      henke(28,1, 56 ) = 24.1685 
C      henke(28,2, 56 ) = -9999 
C      henke(28,3, 56 ) = 3.80593 
C      henke(28,1, 57 ) = 24.5594 
C      henke(28,2, 57 ) = -9999 
C      henke(28,3, 57 ) = 3.83313 
C      henke(28,1, 58 ) = 24.9566 
C      henke(28,2, 58 ) = -9999 
C      henke(28,3, 58 ) = 3.86051 
C      henke(28,1, 59 ) = 25.3603 
C      henke(28,2, 59 ) = -9999 
C      henke(28,3, 59 ) = 3.88809 
C      henke(28,1, 60 ) = 25.7705 
C      henke(28,2, 60 ) = -9999 
C      henke(28,3, 60 ) = 3.91587 
C      henke(28,1, 61 ) = 26.1873 
C      henke(28,2, 61 ) = -9999 
C      henke(28,3, 61 ) = 3.90685 
C      henke(28,1, 62 ) = 26.6109 
C      henke(28,2, 62 ) = -9999 
C      henke(28,3, 62 ) = 3.88468 
C      henke(28,1, 63 ) = 27.0413 
C      henke(28,2, 63 ) = -9999 
C      henke(28,3, 63 ) = 3.86263 
C      henke(28,1, 64 ) = 27.4786 
C      henke(28,2, 64 ) = -9999 
C      henke(28,3, 64 ) = 3.8407 
C      henke(28,1, 65 ) = 27.9231 
C      henke(28,2, 65 ) = -9999 
C      henke(28,3, 65 ) = 3.81412 
C      henke(28,1, 66 ) = 28.3747 
C      henke(28,2, 66 ) = -9999 
C      henke(28,3, 66 ) = 3.77863 
C      henke(28,1, 67 ) = 28.8337 
C      henke(28,2, 67 ) = -9999 
C      henke(28,3, 67 ) = 3.74347 
C      henke(28,1, 68 ) = 29.3 
C      henke(28,2, 68 ) = 4.07489 
C      henke(28,3, 68 ) = 3.70864 
C      henke(28,1, 69 ) = 29.7739 
C      henke(28,2, 69 ) = 4.11878 
C      henke(28,3, 69 ) = 3.67413 
C      henke(28,1, 70 ) = 30.2555 
C      henke(28,2, 70 ) = 4.15559 
C      henke(28,3, 70 ) = 3.63994 
C      henke(28,1, 71 ) = 30.7449 
C      henke(28,2, 71 ) = 4.18799 
C      henke(28,3, 71 ) = 3.60945 
C      henke(28,1, 72 ) = 31.2421 
C      henke(28,2, 72 ) = 4.21844 
C      henke(28,3, 72 ) = 3.57991 
C      henke(28,1, 73 ) = 31.7475 
C      henke(28,2, 73 ) = 4.24569 
C      henke(28,3, 73 ) = 3.55062 
C      henke(28,1, 74 ) = 32.2609 
C      henke(28,2, 74 ) = 4.26954 
C      henke(28,3, 74 ) = 3.52157 
C      henke(28,1, 75 ) = 32.7827 
C      henke(28,2, 75 ) = 4.28991 
C      henke(28,3, 75 ) = 3.49275 
C      henke(28,1, 76 ) = 33.313 
C      henke(28,2, 76 ) = 4.30665 
C      henke(28,3, 76 ) = 3.46417 
C      henke(28,1, 77 ) = 33.8518 
C      henke(28,2, 77 ) = 4.31936 
C      henke(28,3, 77 ) = 3.43582 
C      henke(28,1, 78 ) = 34.3993 
C      henke(28,2, 78 ) = 4.32706 
C      henke(28,3, 78 ) = 3.40771 
C      henke(28,1, 79 ) = 34.9557 
C      henke(28,2, 79 ) = 4.33038 
C      henke(28,3, 79 ) = 3.38228 
C      henke(28,1, 80 ) = 35.5211 
C      henke(28,2, 80 ) = 4.33103 
C      henke(28,3, 80 ) = 3.36017 
C      henke(28,1, 81 ) = 36.0956 
C      henke(28,2, 81 ) = 4.32965 
C      henke(28,3, 81 ) = 3.33819 
C      henke(28,1, 82 ) = 36.6794 
C      henke(28,2, 82 ) = 4.32479 
C      henke(28,3, 82 ) = 3.31636 
C      henke(28,1, 83 ) = 37.2727 
C      henke(28,2, 83 ) = 4.3155 
C      henke(28,3, 83 ) = 3.29467 
C      henke(28,1, 84 ) = 37.8755 
C      henke(28,2, 84 ) = 4.3002 
C      henke(28,3, 84 ) = 3.27312 
C      henke(28,1, 85 ) = 38.4882 
C      henke(28,2, 85 ) = 4.27468 
C      henke(28,3, 85 ) = 3.25172 
C      henke(28,1, 86 ) = 39.1107 
C      henke(28,2, 86 ) = 4.24425 
C      henke(28,3, 86 ) = 3.25034 
C      henke(28,1, 87 ) = 39.7432 
C      henke(28,2, 87 ) = 4.2183 
C      henke(28,3, 87 ) = 3.25005 
C      henke(28,1, 88 ) = 40.3861 
C      henke(28,2, 88 ) = 4.19406 
C      henke(28,3, 88 ) = 3.24976 
C      henke(28,1, 89 ) = 41.0393 
C      henke(28,2, 89 ) = 4.16743 
C      henke(28,3, 89 ) = 3.24947 
C      henke(28,1, 90 ) = 41.7031 
C      henke(28,2, 90 ) = 4.13541 
C      henke(28,3, 90 ) = 3.24918 
C      henke(28,1, 91 ) = 42.3776 
C      henke(28,2, 91 ) = 4.09414 
C      henke(28,3, 91 ) = 3.24888 
C      henke(28,1, 92 ) = 43.063 
C      henke(28,2, 92 ) = 4.0477 
C      henke(28,3, 92 ) = 3.26499 
C      henke(28,1, 93 ) = 43.7595 
C      henke(28,2, 93 ) = 4.00654 
C      henke(28,3, 93 ) = 3.28972 
C      henke(28,1, 94 ) = 44.4673 
C      henke(28,2, 94 ) = 3.96885 
C      henke(28,3, 94 ) = 3.31464 
C      henke(28,1, 95 ) = 45.1865 
C      henke(28,2, 95 ) = 3.93122 
C      henke(28,3, 95 ) = 3.33976 
C      henke(28,1, 96 ) = 45.9174 
C      henke(28,2, 96 ) = 3.89203 
C      henke(28,3, 96 ) = 3.36506 
C      henke(28,1, 97 ) = 46.66 
C      henke(28,2, 97 ) = 3.85034 
C      henke(28,3, 97 ) = 3.39055 
C      henke(28,1, 98 ) = 47.4147 
C      henke(28,2, 98 ) = 3.79831 
C      henke(28,3, 98 ) = 3.41624 
C      henke(28,1, 99 ) = 48.1816 
C      henke(28,2, 99 ) = 3.73782 
C      henke(28,3, 99 ) = 3.44854 
C      henke(28,1, 100 ) = 48.9609 
C      henke(28,2, 100 ) = 3.68007 
C      henke(28,3, 100 ) = 3.50082 
C      henke(28,1, 101 ) = 49.7528 
C      henke(28,2, 101 ) = 3.62828 
C      henke(28,3, 101 ) = 3.55389 
C      henke(28,1, 102 ) = 50.5576 
C      henke(28,2, 102 ) = 3.57767 
C      henke(28,3, 102 ) = 3.60778 
C      henke(28,1, 103 ) = 51.3753 
C      henke(28,2, 103 ) = 3.52588 
C      henke(28,3, 103 ) = 3.66247 
C      henke(28,1, 104 ) = 52.2062 
C      henke(28,2, 104 ) = 3.47153 
C      henke(28,3, 104 ) = 3.718 
C      henke(28,1, 105 ) = 53.0506 
C      henke(28,2, 105 ) = 3.4142 
C      henke(28,3, 105 ) = 3.77753 
C      henke(28,1, 106 ) = 53.9087 
C      henke(28,2, 106 ) = 3.35497 
C      henke(28,3, 106 ) = 3.8391 
C      henke(28,1, 107 ) = 54.7806 
C      henke(28,2, 107 ) = 3.29249 
C      henke(28,3, 107 ) = 3.90168 
C      henke(28,1, 108 ) = 55.6667 
C      henke(28,2, 108 ) = 3.22528 
C      henke(28,3, 108 ) = 3.96528 
C      henke(28,1, 109 ) = 56.567 
C      henke(28,2, 109 ) = 3.1525 
C      henke(28,3, 109 ) = 4.02991 
C      henke(28,1, 110 ) = 57.482 
C      henke(28,2, 110 ) = 3.0782 
C      henke(28,3, 110 ) = 4.09444 
C      henke(28,1, 111 ) = 58.4117 
C      henke(28,2, 111 ) = 2.98535 
C      henke(28,3, 111 ) = 4.14027 
C      henke(28,1, 112 ) = 59.3564 
C      henke(28,2, 112 ) = 2.86335 
C      henke(28,3, 112 ) = 4.18662 
C      henke(28,1, 113 ) = 60.3165 
C      henke(28,2, 113 ) = 2.70077 
C      henke(28,3, 113 ) = 4.23349 
C      henke(28,1, 114 ) = 61.2921 
C      henke(28,2, 114 ) = 2.45011 
C      henke(28,3, 114 ) = 4.30894 
C      henke(28,1, 115 ) = 62.2834 
C      henke(28,2, 115 ) = 2.18829 
C      henke(28,3, 115 ) = 4.47415 
C      henke(28,1, 116 ) = 63.2908 
C      henke(28,2, 116 ) = 1.90363 
C      henke(28,3, 116 ) = 4.64568 
C      henke(28,1, 117 ) = 64.3145 
C      henke(28,2, 117 ) = 1.52278 
C      henke(28,3, 117 ) = 4.82379 
C      henke(28,1, 118 ) = 65.3547 
C      henke(28,2, 118 ) = 1.0005 
C      henke(28,3, 118 ) = 5.3592 
C      henke(28,1, 119 ) = 66.4118 
C      henke(28,2, 119 ) = 0.7129 
C      henke(28,3, 119 ) = 6.16858 
C      henke(28,1, 120 ) = 67.4859 
C      henke(28,2, 120 ) = 0.694467 
C      henke(28,3, 120 ) = 7.10021 
C      henke(28,1, 121 ) = 68.5775 
C      henke(28,2, 121 ) = 1.10772 
C      henke(28,3, 121 ) = 8.17252 
C      henke(28,1, 122 ) = 69.6867 
C      henke(28,2, 122 ) = 1.75751 
C      henke(28,3, 122 ) = 8.50016 
C      henke(28,1, 123 ) = 70.8138 
C      henke(28,2, 123 ) = 2.26228 
C      henke(28,3, 123 ) = 8.79611 
C      henke(28,1, 124 ) = 71.9591 
C      henke(28,2, 124 ) = 2.71469 
C      henke(28,3, 124 ) = 9.08103 
C      henke(28,1, 125 ) = 73.123 
C      henke(28,2, 125 ) = 3.15797 
C      henke(28,3, 125 ) = 9.20206 
C      henke(28,1, 126 ) = 74.3057 
C      henke(28,2, 126 ) = 3.49643 
C      henke(28,3, 126 ) = 9.32471 
C      henke(28,1, 127 ) = 75.5076 
C      henke(28,2, 127 ) = 3.81415 
C      henke(28,3, 127 ) = 9.44899 
C      henke(28,1, 128 ) = 76.7289 
C      henke(28,2, 128 ) = 4.14091 
C      henke(28,3, 128 ) = 9.57493 
C      henke(28,1, 129 ) = 77.9699 
C      henke(28,2, 129 ) = 4.46124 
C      henke(28,3, 129 ) = 9.64899 
C      henke(28,1, 130 ) = 79.231 
C      henke(28,2, 130 ) = 4.75594 
C      henke(28,3, 130 ) = 9.70549 
C      henke(28,1, 131 ) = 80.5125 
C      henke(28,2, 131 ) = 5.03118 
C      henke(28,3, 131 ) = 9.76232 
C      henke(28,1, 132 ) = 81.8147 
C      henke(28,2, 132 ) = 5.3015 
C      henke(28,3, 132 ) = 9.8195 
C      henke(28,1, 133 ) = 83.138 
C      henke(28,2, 133 ) = 5.58627 
C      henke(28,3, 133 ) = 9.87699 
C      henke(28,1, 134 ) = 84.4827 
C      henke(28,2, 134 ) = 5.88145 
C      henke(28,3, 134 ) = 9.86813 
C      henke(28,1, 135 ) = 85.8491 
C      henke(28,2, 135 ) = 6.12735 
C      henke(28,3, 135 ) = 9.84309 
C      henke(28,1, 136 ) = 87.2377 
C      henke(28,2, 136 ) = 6.34846 
C      henke(28,3, 136 ) = 9.81811 
C      henke(28,1, 137 ) = 88.6487 
C      henke(28,2, 137 ) = 6.55119 
C      henke(28,3, 137 ) = 9.7932 
C      henke(28,1, 138 ) = 90.0825 
C      henke(28,2, 138 ) = 6.73894 
C      henke(28,3, 138 ) = 9.76835 
C      henke(28,1, 139 ) = 91.5395 
C      henke(28,2, 139 ) = 6.90617 
C      henke(28,3, 139 ) = 9.74356 
C      henke(28,1, 140 ) = 93.0201 
C      henke(28,2, 140 ) = 7.04896 
C      henke(28,3, 140 ) = 9.73075 
C      henke(28,1, 141 ) = 94.5246 
C      henke(28,2, 141 ) = 7.19681 
C      henke(28,3, 141 ) = 9.74377 
C      henke(28,1, 142 ) = 96.0535 
C      henke(28,2, 142 ) = 7.35361 
C      henke(28,3, 142 ) = 9.75681 
C      henke(28,1, 143 ) = 97.6071 
C      henke(28,2, 143 ) = 7.51027 
C      henke(28,3, 143 ) = 9.76987 
C      henke(28,1, 144 ) = 99.1858 
C      henke(28,2, 144 ) = 7.66641 
C      henke(28,3, 144 ) = 9.78295 
C      henke(28,1, 145 ) = 100.79 
C      henke(28,2, 145 ) = 7.82189 
C      henke(28,3, 145 ) = 9.79605 
C      henke(28,1, 146 ) = 102.42 
C      henke(28,2, 146 ) = 7.97682 
C      henke(28,3, 146 ) = 9.80915 
C      henke(28,1, 147 ) = 104.077 
C      henke(28,2, 147 ) = 8.1316 
C      henke(28,3, 147 ) = 9.82228 
C      henke(28,1, 148 ) = 105.76 
C      henke(28,2, 148 ) = 8.28712 
C      henke(28,3, 148 ) = 9.83543 
C      henke(28,1, 149 ) = 107.471 
C      henke(28,2, 149 ) = 8.44647 
C      henke(28,3, 149 ) = 9.8486 
C      henke(28,1, 150 ) = 109.209 
C      henke(28,2, 150 ) = 8.60494 
C      henke(28,3, 150 ) = 9.84981 
C      henke(28,1, 151 ) = 110.975 
C      henke(28,2, 151 ) = 8.75933 
C      henke(28,3, 151 ) = 9.8482 
C      henke(28,1, 152 ) = 112.77 
C      henke(28,2, 152 ) = 8.90703 
C      henke(28,3, 152 ) = 9.8466 
C      henke(28,1, 153 ) = 114.594 
C      henke(28,2, 153 ) = 9.0524 
C      henke(28,3, 153 ) = 9.84499 
C      henke(28,1, 154 ) = 116.448 
C      henke(28,2, 154 ) = 9.19571 
C      henke(28,3, 154 ) = 9.84339 
C      henke(28,1, 155 ) = 118.331 
C      henke(28,2, 155 ) = 9.33813 
C      henke(28,3, 155 ) = 9.84179 
C      henke(28,1, 156 ) = 120.245 
C      henke(28,2, 156 ) = 9.48087 
C      henke(28,3, 156 ) = 9.84019 
C      henke(28,1, 157 ) = 122.19 
C      henke(28,2, 157 ) = 9.62523 
C      henke(28,3, 157 ) = 9.82776 
C      henke(28,1, 158 ) = 124.166 
C      henke(28,2, 158 ) = 9.75819 
C      henke(28,3, 158 ) = 9.81204 
C      henke(28,1, 159 ) = 126.175 
C      henke(28,2, 159 ) = 9.88397 
C      henke(28,3, 159 ) = 9.79634 
C      henke(28,1, 160 ) = 128.215 
C      henke(28,2, 160 ) = 10.0028 
C      henke(28,3, 160 ) = 9.78065 
C      henke(28,1, 161 ) = 130.289 
C      henke(28,2, 161 ) = 10.1138 
C      henke(28,3, 161 ) = 9.76501 
C      henke(28,1, 162 ) = 132.397 
C      henke(28,2, 162 ) = 10.2099 
C      henke(28,3, 162 ) = 9.74938 
C      henke(28,1, 163 ) = 134.538 
C      henke(28,2, 163 ) = 10.2682 
C      henke(28,3, 163 ) = 9.73377 
C      henke(28,1, 164 ) = 136.714 
C      henke(28,2, 164 ) = 10.3327 
C      henke(28,3, 164 ) = 9.79365 
C      henke(28,1, 165 ) = 138.925 
C      henke(28,2, 165 ) = 10.4316 
C      henke(28,3, 165 ) = 9.86007 
C      henke(28,1, 166 ) = 141.172 
C      henke(28,2, 166 ) = 10.5474 
C      henke(28,3, 166 ) = 9.92692 
C      henke(28,1, 167 ) = 143.456 
C      henke(28,2, 167 ) = 10.6757 
C      henke(28,3, 167 ) = 9.99425 
C      henke(28,1, 168 ) = 145.776 
C      henke(28,2, 168 ) = 10.8152 
C      henke(28,3, 168 ) = 10.062 
C      henke(28,1, 169 ) = 148.134 
C      henke(28,2, 169 ) = 10.9657 
C      henke(28,3, 169 ) = 10.1303 
C      henke(28,1, 170 ) = 150.53 
C      henke(28,2, 170 ) = 11.1282 
C      henke(28,3, 170 ) = 10.199 
C      henke(28,1, 171 ) = 152.964 
C      henke(28,2, 171 ) = 11.3049 
C      henke(28,3, 171 ) = 10.2681 
C      henke(28,1, 172 ) = 155.439 
C      henke(28,2, 172 ) = 11.4992 
C      henke(28,3, 172 ) = 10.3378 
C      henke(28,1, 173 ) = 157.953 
C      henke(28,2, 173 ) = 11.7511 
C      henke(28,3, 173 ) = 10.3978 
C      henke(28,1, 174 ) = 160.507 
C      henke(28,2, 174 ) = 12.0042 
C      henke(28,3, 174 ) = 10.3668 
C      henke(28,1, 175 ) = 163.103 
C      henke(28,2, 175 ) = 12.2017 
C      henke(28,3, 175 ) = 10.3359 
C      henke(28,1, 176 ) = 165.742 
C      henke(28,2, 176 ) = 12.3889 
C      henke(28,3, 176 ) = 10.3051 
C      henke(28,1, 177 ) = 168.422 
C      henke(28,2, 177 ) = 12.5688 
C      henke(28,3, 177 ) = 10.2744 
C      henke(28,1, 178 ) = 171.146 
C      henke(28,2, 178 ) = 12.7435 
C      henke(28,3, 178 ) = 10.2438 
C      henke(28,1, 179 ) = 173.915 
C      henke(28,2, 179 ) = 12.9142 
C      henke(28,3, 179 ) = 10.2133 
C      henke(28,1, 180 ) = 176.727 
C      henke(28,2, 180 ) = 13.0823 
C      henke(28,3, 180 ) = 10.1829 
C      henke(28,1, 181 ) = 179.586 
C      henke(28,2, 181 ) = 13.2484 
C      henke(28,3, 181 ) = 10.1525 
C      henke(28,1, 182 ) = 182.491 
C      henke(28,2, 182 ) = 13.4134 
C      henke(28,3, 182 ) = 10.1223 
C      henke(28,1, 183 ) = 185.442 
C      henke(28,2, 183 ) = 13.578 
C      henke(28,3, 183 ) = 10.0921 
C      henke(28,1, 184 ) = 188.442 
C      henke(28,2, 184 ) = 13.7429 
C      henke(28,3, 184 ) = 10.0621 
C      henke(28,1, 185 ) = 191.489 
C      henke(28,2, 185 ) = 13.9091 
C      henke(28,3, 185 ) = 10.0321 
C      henke(28,1, 186 ) = 194.587 
C      henke(28,2, 186 ) = 14.0776 
C      henke(28,3, 186 ) = 10.0022 
C      henke(28,1, 187 ) = 197.734 
C      henke(28,2, 187 ) = 14.2497 
C      henke(28,3, 187 ) = 9.97242 
C      henke(28,1, 188 ) = 200.932 
C      henke(28,2, 188 ) = 14.4351 
C      henke(28,3, 188 ) = 9.94271 
C      henke(28,1, 189 ) = 204.182 
C      henke(28,2, 189 ) = 14.6388 
C      henke(28,3, 189 ) = 9.91308 
C      henke(28,1, 190 ) = 207.485 
C      henke(28,2, 190 ) = 14.844 
C      henke(28,3, 190 ) = 9.82709 
C      henke(28,1, 191 ) = 210.84 
C      henke(28,2, 191 ) = 15.0233 
C      henke(28,3, 191 ) = 9.73137 
C      henke(28,1, 192 ) = 214.251 
C      henke(28,2, 192 ) = 15.1866 
C      henke(28,3, 192 ) = 9.63658 
C      henke(28,1, 193 ) = 217.716 
C      henke(28,2, 193 ) = 15.34 
C      henke(28,3, 193 ) = 9.54272 
C      henke(28,1, 194 ) = 221.237 
C      henke(28,2, 194 ) = 15.486 
C      henke(28,3, 194 ) = 9.44977 
C      henke(28,1, 195 ) = 224.816 
C      henke(28,2, 195 ) = 15.6259 
C      henke(28,3, 195 ) = 9.35773 
C      henke(28,1, 196 ) = 228.452 
C      henke(28,2, 196 ) = 15.7608 
C      henke(28,3, 196 ) = 9.26659 
C      henke(28,1, 197 ) = 232.147 
C      henke(28,2, 197 ) = 15.8913 
C      henke(28,3, 197 ) = 9.17632 
C      henke(28,1, 198 ) = 235.902 
C      henke(28,2, 198 ) = 16.0179 
C      henke(28,3, 198 ) = 9.08694 
C      henke(28,1, 199 ) = 239.717 
C      henke(28,2, 199 ) = 16.1412 
C      henke(28,3, 199 ) = 8.99844 
C      henke(28,1, 200 ) = 243.595 
C      henke(28,2, 200 ) = 16.2616 
C      henke(28,3, 200 ) = 8.91079 
C      henke(28,1, 201 ) = 247.535 
C      henke(28,2, 201 ) = 16.3794 
C      henke(28,3, 201 ) = 8.82399 
C      henke(28,1, 202 ) = 251.538 
C      henke(28,2, 202 ) = 16.495 
C      henke(28,3, 202 ) = 8.73804 
C      henke(28,1, 203 ) = 255.607 
C      henke(28,2, 203 ) = 16.6088 
C      henke(28,3, 203 ) = 8.65294 
C      henke(28,1, 204 ) = 259.741 
C      henke(28,2, 204 ) = 16.7212 
C      henke(28,3, 204 ) = 8.56865 
C      henke(28,1, 205 ) = 263.942 
C      henke(28,2, 205 ) = 16.8328 
C      henke(28,3, 205 ) = 8.4852 
C      henke(28,1, 206 ) = 268.211 
C      henke(28,2, 206 ) = 16.944 
C      henke(28,3, 206 ) = 8.40255 
C      henke(28,1, 207 ) = 272.549 
C      henke(28,2, 207 ) = 17.0559 
C      henke(28,3, 207 ) = 8.3207 
C      henke(28,1, 208 ) = 276.957 
C      henke(28,2, 208 ) = 17.1684 
C      henke(28,3, 208 ) = 8.23966 
C      henke(28,1, 209 ) = 281.437 
C      henke(28,2, 209 ) = 17.2961 
C      henke(28,3, 209 ) = 8.1594 
C      henke(28,1, 210 ) = 285.989 
C      henke(28,2, 210 ) = 17.428 
C      henke(28,3, 210 ) = 8.06947 
C      henke(28,1, 211 ) = 290.615 
C      henke(28,2, 211 ) = 17.5535 
C      henke(28,3, 211 ) = 7.94306 
C      henke(28,1, 212 ) = 295.315 
C      henke(28,2, 212 ) = 17.6582 
C      henke(28,3, 212 ) = 7.81865 
C      henke(28,1, 213 ) = 300.092 
C      henke(28,2, 213 ) = 17.7522 
C      henke(28,3, 213 ) = 7.69617 
C      henke(28,1, 214 ) = 304.945 
C      henke(28,2, 214 ) = 17.8383 
C      henke(28,3, 214 ) = 7.57562 
C      henke(28,1, 215 ) = 309.878 
C      henke(28,2, 215 ) = 17.9182 
C      henke(28,3, 215 ) = 7.45695 
C      henke(28,1, 216 ) = 314.89 
C      henke(28,2, 216 ) = 17.9926 
C      henke(28,3, 216 ) = 7.34015 
C      henke(28,1, 217 ) = 319.983 
C      henke(28,2, 217 ) = 18.0622 
C      henke(28,3, 217 ) = 7.22517 
C      henke(28,1, 218 ) = 325.158 
C      henke(28,2, 218 ) = 18.1275 
C      henke(28,3, 218 ) = 7.11199 
C      henke(28,1, 219 ) = 330.418 
C      henke(28,2, 219 ) = 18.189 
C      henke(28,3, 219 ) = 7.00059 
C      henke(28,1, 220 ) = 335.762 
C      henke(28,2, 220 ) = 18.2469 
C      henke(28,3, 220 ) = 6.89094 
C      henke(28,1, 221 ) = 341.192 
C      henke(28,2, 221 ) = 18.3016 
C      henke(28,3, 221 ) = 6.783 
C      henke(28,1, 222 ) = 346.711 
C      henke(28,2, 222 ) = 18.3535 
C      henke(28,3, 222 ) = 6.67675 
C      henke(28,1, 223 ) = 352.319 
C      henke(28,2, 223 ) = 18.4028 
C      henke(28,3, 223 ) = 6.57216 
C      henke(28,1, 224 ) = 358.017 
C      henke(28,2, 224 ) = 18.4502 
C      henke(28,3, 224 ) = 6.46922 
C      henke(28,1, 225 ) = 363.808 
C      henke(28,2, 225 ) = 18.4964 
C      henke(28,3, 225 ) = 6.36788 
C      henke(28,1, 226 ) = 369.692 
C      henke(28,2, 226 ) = 18.5455 
C      henke(28,3, 226 ) = 6.26813 
C      henke(28,1, 227 ) = 375.672 
C      henke(28,2, 227 ) = 18.5909 
C      henke(28,3, 227 ) = 6.15792 
C      henke(28,1, 228 ) = 381.748 
C      henke(28,2, 228 ) = 18.6295 
C      henke(28,3, 228 ) = 6.04599 
C      henke(28,1, 229 ) = 387.922 
C      henke(28,2, 229 ) = 18.6603 
C      henke(28,3, 229 ) = 5.93609 
C      henke(28,1, 230 ) = 394.197 
C      henke(28,2, 230 ) = 18.6861 
C      henke(28,3, 230 ) = 5.82819 
C      henke(28,1, 231 ) = 400.573 
C      henke(28,2, 231 ) = 18.7075 
C      henke(28,3, 231 ) = 5.72225 
C      henke(28,1, 232 ) = 407.052 
C      henke(28,2, 232 ) = 18.725 
C      henke(28,3, 232 ) = 5.61823 
C      henke(28,1, 233 ) = 413.635 
C      henke(28,2, 233 ) = 18.7389 
C      henke(28,3, 233 ) = 5.51611 
C      henke(28,1, 234 ) = 420.326 
C      henke(28,2, 234 ) = 18.7492 
C      henke(28,3, 234 ) = 5.41584 
C      henke(28,1, 235 ) = 427.124 
C      henke(28,2, 235 ) = 18.7562 
C      henke(28,3, 235 ) = 5.3174 
C      henke(28,1, 236 ) = 434.032 
C      henke(28,2, 236 ) = 18.7599 
C      henke(28,3, 236 ) = 5.22074 
C      henke(28,1, 237 ) = 441.052 
C      henke(28,2, 237 ) = 18.7606 
C      henke(28,3, 237 ) = 5.12584 
C      henke(28,1, 238 ) = 448.186 
C      henke(28,2, 238 ) = 18.7582 
C      henke(28,3, 238 ) = 5.03267 
C      henke(28,1, 239 ) = 455.435 
C      henke(28,2, 239 ) = 18.753 
C      henke(28,3, 239 ) = 4.94119 
C      henke(28,1, 240 ) = 462.802 
C      henke(28,2, 240 ) = 18.7451 
C      henke(28,3, 240 ) = 4.85137 
C      henke(28,1, 241 ) = 470.287 
C      henke(28,2, 241 ) = 18.7346 
C      henke(28,3, 241 ) = 4.76319 
C      henke(28,1, 242 ) = 477.894 
C      henke(28,2, 242 ) = 18.7219 
C      henke(28,3, 242 ) = 4.67661 
C      henke(28,1, 243 ) = 485.623 
C      henke(28,2, 243 ) = 18.7078 
C      henke(28,3, 243 ) = 4.5916 
C      henke(28,1, 244 ) = 493.478 
C      henke(28,2, 244 ) = 18.6944 
C      henke(28,3, 244 ) = 4.50813 
C      henke(28,1, 245 ) = 501.459 
C      henke(28,2, 245 ) = 18.6841 
C      henke(28,3, 245 ) = 4.41984 
C      henke(28,1, 246 ) = 509.57 
C      henke(28,2, 246 ) = 18.6676 
C      henke(28,3, 246 ) = 4.3153 
C      henke(28,1, 247 ) = 517.812 
C      henke(28,2, 247 ) = 18.6345 
C      henke(28,3, 247 ) = 4.21322 
C      henke(28,1, 248 ) = 526.187 
C      henke(28,2, 248 ) = 18.5923 
C      henke(28,3, 248 ) = 4.11356 
C      henke(28,1, 249 ) = 534.698 
C      henke(28,2, 249 ) = 18.5425 
C      henke(28,3, 249 ) = 4.01626 
C      henke(28,1, 250 ) = 543.346 
C      henke(28,2, 250 ) = 18.4853 
C      henke(28,3, 250 ) = 3.92125 
C      henke(28,1, 251 ) = 552.134 
C      henke(28,2, 251 ) = 18.4207 
C      henke(28,3, 251 ) = 3.8285 
C      henke(28,1, 252 ) = 561.065 
C      henke(28,2, 252 ) = 18.3488 
C      henke(28,3, 252 ) = 3.73793 
C      henke(28,1, 253 ) = 570.139 
C      henke(28,2, 253 ) = 18.2691 
C      henke(28,3, 253 ) = 3.64952 
C      henke(28,1, 254 ) = 579.361 
C      henke(28,2, 254 ) = 18.1812 
C      henke(28,3, 254 ) = 3.56319 
C      henke(28,1, 255 ) = 588.732 
C      henke(28,2, 255 ) = 18.0845 
C      henke(28,3, 255 ) = 3.4789 
C      henke(28,1, 256 ) = 598.254 
C      henke(28,2, 256 ) = 17.9775 
C      henke(28,3, 256 ) = 3.39661 
C      henke(28,1, 257 ) = 607.93 
C      henke(28,2, 257 ) = 17.8558 
C      henke(28,3, 257 ) = 3.31626 
C      henke(28,1, 258 ) = 617.763 
C      henke(28,2, 258 ) = 17.7261 
C      henke(28,3, 258 ) = 3.25118 
C      henke(28,1, 259 ) = 627.755 
C      henke(28,2, 259 ) = 17.5904 
C      henke(28,3, 259 ) = 3.1909 
C      henke(28,1, 260 ) = 637.908 
C      henke(28,2, 260 ) = 17.4496 
C      henke(28,3, 260 ) = 3.13174 
C      henke(28,1, 261 ) = 648.226 
C      henke(28,2, 261 ) = 17.2992 
C      henke(28,3, 261 ) = 3.07368 
C      henke(28,1, 262 ) = 658.711 
C      henke(28,2, 262 ) = 17.1372 
C      henke(28,3, 262 ) = 3.01669 
C      henke(28,1, 263 ) = 669.365 
C      henke(28,2, 263 ) = 16.9618 
C      henke(28,3, 263 ) = 2.96076 
C      henke(28,1, 264 ) = 680.191 
C      henke(28,2, 264 ) = 16.7709 
C      henke(28,3, 264 ) = 2.90587 
C      henke(28,1, 265 ) = 691.193 
C      henke(28,2, 265 ) = 16.5627 
C      henke(28,3, 265 ) = 2.85199 
C      henke(28,1, 266 ) = 702.372 
C      henke(28,2, 266 ) = 16.3354 
C      henke(28,3, 266 ) = 2.79911 
C      henke(28,1, 267 ) = 713.733 
C      henke(28,2, 267 ) = 16.0924 
C      henke(28,3, 267 ) = 2.74722 
C      henke(28,1, 268 ) = 725.277 
C      henke(28,2, 268 ) = 15.8265 
C      henke(28,3, 268 ) = 2.66726 
C      henke(28,1, 269 ) = 737.008 
C      henke(28,2, 269 ) = 15.4916 
C      henke(28,3, 269 ) = 2.54699 
C      henke(28,1, 270 ) = 748.928 
C      henke(28,2, 270 ) = 15.0476 
C      henke(28,3, 270 ) = 2.43214 
C      henke(28,1, 271 ) = 761.042 
C      henke(28,2, 271 ) = 14.5541 
C      henke(28,3, 271 ) = 2.40333 
C      henke(28,1, 272 ) = 773.351 
C      henke(28,2, 272 ) = 13.9833 
C      henke(28,3, 272 ) = 2.3552 
C      henke(28,1, 273 ) = 785.859 
C      henke(28,2, 273 ) = 13.2954 
C      henke(28,3, 273 ) = 2.31346 
C      henke(28,1, 274 ) = 798.57 
C      henke(28,2, 274 ) = 12.4407 
C      henke(28,3, 274 ) = 2.27693 
C      henke(28,1, 275 ) = 811.486 
C      henke(28,2, 275 ) = 11.3146 
C      henke(28,3, 275 ) = 2.24149 
C      henke(28,1, 276 ) = 824.611 
C      henke(28,2, 276 ) = 9.68933 
C      henke(28,3, 276 ) = 2.20661 
C      henke(28,1, 277 ) = 837.949 
C      henke(28,2, 277 ) = 6.86521 
C      henke(28,3, 277 ) = 2.17229 
C      henke(28,1, 278 ) = 851.502 
C      henke(28,2, 278 ) = -4.7785 
C      henke(28,3, 278 ) = 2.1385 
C      henke(28,1, 279 ) = 852.6 
C      henke(28,2, 279 ) = -16.5847 
C      henke(28,3, 279 ) = 2.13581 
C      henke(28,1, 280 ) = 852.8 
C      henke(28,2, 280 ) = -16.5694 
C      henke(28,3, 280 ) = 17.1612 
C      henke(28,1, 281 ) = 865.274 
C      henke(28,2, 281 ) = 6.89208 
C      henke(28,3, 281 ) = 16.82 
C      henke(28,1, 282 ) = 879.269 
C      henke(28,2, 282 ) = 10.6978 
C      henke(28,3, 282 ) = 16.4508 
C      henke(28,1, 283 ) = 893.491 
C      henke(28,2, 283 ) = 12.9007 
C      henke(28,3, 283 ) = 16.0897 
C      henke(28,1, 284 ) = 907.943 
C      henke(28,2, 284 ) = 14.4482 
C      henke(28,3, 284 ) = 15.7365 
C      henke(28,1, 285 ) = 922.628 
C      henke(28,2, 285 ) = 15.6208 
C      henke(28,3, 285 ) = 15.3911 
C      henke(28,1, 286 ) = 937.551 
C      henke(28,2, 286 ) = 16.5503 
C      henke(28,3, 286 ) = 15.0686 
C      henke(28,1, 287 ) = 952.715 
C      henke(28,2, 287 ) = 17.2837 
C      henke(28,3, 287 ) = 14.7422 
C      henke(28,1, 288 ) = 968.124 
C      henke(28,2, 288 ) = 17.7758 
C      henke(28,3, 288 ) = 14.4139 
C      henke(28,1, 289 ) = 983.783 
C      henke(28,2, 289 ) = 18.0717 
C      henke(28,3, 289 ) = 14.2733 
C      henke(28,1, 290 ) = 999.695 
C      henke(28,2, 290 ) = 18.1198 
C      henke(28,3, 290 ) = 14.5442 
C      henke(28,1, 291 ) = 1015.86 
C      henke(28,2, 291 ) = 19.1887 
C      henke(28,3, 291 ) = 15.2836 
C      henke(28,1, 292 ) = 1032.29 
C      henke(28,2, 292 ) = 20.4147 
C      henke(28,3, 292 ) = 14.9622 
C      henke(28,1, 293 ) = 1048.99 
C      henke(28,2, 293 ) = 21.0748 
C      henke(28,3, 293 ) = 14.6335 
C      henke(28,1, 294 ) = 1065.96 
C      henke(28,2, 294 ) = 21.6619 
C      henke(28,3, 294 ) = 14.3064 
C      henke(28,1, 295 ) = 1083.2 
C      henke(28,2, 295 ) = 22.1779 
C      henke(28,3, 295 ) = 13.9864 
C      henke(28,1, 296 ) = 1100.72 
C      henke(28,2, 296 ) = 22.6378 
C      henke(28,3, 296 ) = 13.6735 
C      henke(28,1, 297 ) = 1118.52 
C      henke(28,2, 297 ) = 23.0529 
C      henke(28,3, 297 ) = 13.3675 
C      henke(28,1, 298 ) = 1136.61 
C      henke(28,2, 298 ) = 23.4306 
C      henke(28,3, 298 ) = 13.0684 
C      henke(28,1, 299 ) = 1155 
C      henke(28,2, 299 ) = 23.7764 
C      henke(28,3, 299 ) = 12.776 
C      henke(28,1, 300 ) = 1173.68 
C      henke(28,2, 300 ) = 24.0946 
C      henke(28,3, 300 ) = 12.4902 
C      henke(28,1, 301 ) = 1192.66 
C      henke(28,2, 301 ) = 24.3887 
C      henke(28,3, 301 ) = 12.2108 
C      henke(28,1, 302 ) = 1211.95 
C      henke(28,2, 302 ) = 24.6617 
C      henke(28,3, 302 ) = 11.9376 
C      henke(28,1, 303 ) = 1231.55 
C      henke(28,2, 303 ) = 24.9164 
C      henke(28,3, 303 ) = 11.6705 
C      henke(28,1, 304 ) = 1251.47 
C      henke(28,2, 304 ) = 25.1548 
C      henke(28,3, 304 ) = 11.4073 
C      henke(28,1, 305 ) = 1271.72 
C      henke(28,2, 305 ) = 25.3771 
C      henke(28,3, 305 ) = 11.1477 
C      henke(28,1, 306 ) = 1292.29 
C      henke(28,2, 306 ) = 25.583 
C      henke(28,3, 306 ) = 10.8913 
C      henke(28,1, 307 ) = 1313.19 
C      henke(28,2, 307 ) = 25.7736 
C      henke(28,3, 307 ) = 10.6408 
C      henke(28,1, 308 ) = 1334.43 
C      henke(28,2, 308 ) = 25.9511 
C      henke(28,3, 308 ) = 10.396 
C      henke(28,1, 309 ) = 1356.01 
C      henke(28,2, 309 ) = 26.1167 
C      henke(28,3, 309 ) = 10.1568 
C      henke(28,1, 310 ) = 1377.94 
C      henke(28,2, 310 ) = 26.2716 
C      henke(28,3, 310 ) = 9.92318 
C      henke(28,1, 311 ) = 1400.23 
C      henke(28,2, 311 ) = 26.4168 
C      henke(28,3, 311 ) = 9.69489 
C      henke(28,1, 312 ) = 1422.88 
C      henke(28,2, 312 ) = 26.5534 
C      henke(28,3, 312 ) = 9.47183 
C      henke(28,1, 313 ) = 1445.89 
C      henke(28,2, 313 ) = 26.6824 
C      henke(28,3, 313 ) = 9.25396 
C      henke(28,1, 314 ) = 1469.28 
C      henke(28,2, 314 ) = 26.8062 
C      henke(28,3, 314 ) = 9.03977 
C      henke(28,1, 315 ) = 1493.04 
C      henke(28,2, 315 ) = 26.9235 
C      henke(28,3, 315 ) = 8.82853 
C      henke(28,1, 316 ) = 1517.19 
C      henke(28,2, 316 ) = 27.0337 
C      henke(28,3, 316 ) = 8.6141 
C      henke(28,1, 317 ) = 1541.73 
C      henke(28,2, 317 ) = 27.1321 
C      henke(28,3, 317 ) = 8.40382 
C      henke(28,1, 318 ) = 1566.67 
C      henke(28,2, 318 ) = 27.2219 
C      henke(28,3, 318 ) = 8.19876 
C      henke(28,1, 319 ) = 1592.01 
C      henke(28,2, 319 ) = 27.3047 
C      henke(28,3, 319 ) = 7.99863 
C      henke(28,1, 320 ) = 1617.76 
C      henke(28,2, 320 ) = 27.3809 
C      henke(28,3, 320 ) = 7.80334 
C      henke(28,1, 321 ) = 1643.92 
C      henke(28,2, 321 ) = 27.4513 
C      henke(28,3, 321 ) = 7.61278 
C      henke(28,1, 322 ) = 1670.51 
C      henke(28,2, 322 ) = 27.5164 
C      henke(28,3, 322 ) = 7.42691 
C      henke(28,1, 323 ) = 1697.53 
C      henke(28,2, 323 ) = 27.5768 
C      henke(28,3, 323 ) = 7.24564 
C      henke(28,1, 324 ) = 1724.99 
C      henke(28,2, 324 ) = 27.634 
C      henke(28,3, 324 ) = 7.06889 
C      henke(28,1, 325 ) = 1752.89 
C      henke(28,2, 325 ) = 27.6875 
C      henke(28,3, 325 ) = 6.89317 
C      henke(28,1, 326 ) = 1781.24 
C      henke(28,2, 326 ) = 27.7356 
C      henke(28,3, 326 ) = 6.72078 
C      henke(28,1, 327 ) = 1810.05 
C      henke(28,2, 327 ) = 27.778 
C      henke(28,3, 327 ) = 6.55195 
C      henke(28,1, 328 ) = 1839.32 
C      henke(28,2, 328 ) = 27.8161 
C      henke(28,3, 328 ) = 6.38739 
C      henke(28,1, 329 ) = 1869.07 
C      henke(28,2, 329 ) = 27.8503 
C      henke(28,3, 329 ) = 6.22694 
C      henke(28,1, 330 ) = 1899.3 
C      henke(28,2, 330 ) = 27.8808 
C      henke(28,3, 330 ) = 6.07048 
C      henke(28,1, 331 ) = 1930.02 
C      henke(28,2, 331 ) = 27.9082 
C      henke(28,3, 331 ) = 5.91807 
C      henke(28,1, 332 ) = 1961.24 
C      henke(28,2, 332 ) = 27.9323 
C      henke(28,3, 332 ) = 5.76947 
C      henke(28,1, 333 ) = 1992.96 
C      henke(28,2, 333 ) = 27.9538 
C      henke(28,3, 333 ) = 5.62449 
C      henke(28,1, 334 ) = 2025.2 
C      henke(28,2, 334 ) = 27.9735 
C      henke(28,3, 334 ) = 5.48525 
C      henke(28,1, 335 ) = 2057.95 
C      henke(28,2, 335 ) = 27.9917 
C      henke(28,3, 335 ) = 5.34614 
C      henke(28,1, 336 ) = 2091.24 
C      henke(28,2, 336 ) = 28.0074 
C      henke(28,3, 336 ) = 5.21021 
C      henke(28,1, 337 ) = 2125.06 
C      henke(28,2, 337 ) = 28.0198 
C      henke(28,3, 337 ) = 5.07749 
C      henke(28,1, 338 ) = 2159.43 
C      henke(28,2, 338 ) = 28.0301 
C      henke(28,3, 338 ) = 4.94801 
C      henke(28,1, 339 ) = 2194.36 
C      henke(28,2, 339 ) = 28.0381 
C      henke(28,3, 339 ) = 4.82139 
C      henke(28,1, 340 ) = 2229.85 
C      henke(28,2, 340 ) = 28.0443 
C      henke(28,3, 340 ) = 4.69811 
C      henke(28,1, 341 ) = 2265.92 
C      henke(28,2, 341 ) = 28.0487 
C      henke(28,3, 341 ) = 4.57759 
C      henke(28,1, 342 ) = 2302.57 
C      henke(28,2, 342 ) = 28.0512 
C      henke(28,3, 342 ) = 4.45991 
C      henke(28,1, 343 ) = 2339.81 
C      henke(28,2, 343 ) = 28.052 
C      henke(28,3, 343 ) = 4.34528 
C      henke(28,1, 344 ) = 2377.66 
C      henke(28,2, 344 ) = 28.0512 
C      henke(28,3, 344 ) = 4.23335 
C      henke(28,1, 345 ) = 2416.11 
C      henke(28,2, 345 ) = 28.0492 
C      henke(28,3, 345 ) = 4.12431 
C      henke(28,1, 346 ) = 2455.19 
C      henke(28,2, 346 ) = 28.0457 
C      henke(28,3, 346 ) = 4.01774 
C      henke(28,1, 347 ) = 2494.9 
C      henke(28,2, 347 ) = 28.0409 
C      henke(28,3, 347 ) = 3.91381 
C      henke(28,1, 348 ) = 2535.26 
C      henke(28,2, 348 ) = 28.0351 
C      henke(28,3, 348 ) = 3.81264 
C      henke(28,1, 349 ) = 2576.26 
C      henke(28,2, 349 ) = 28.028 
C      henke(28,3, 349 ) = 3.71371 
C      henke(28,1, 350 ) = 2617.93 
C      henke(28,2, 350 ) = 28.0198 
C      henke(28,3, 350 ) = 3.61737 
C      henke(28,1, 351 ) = 2660.27 
C      henke(28,2, 351 ) = 28.0107 
C      henke(28,3, 351 ) = 3.52337 
C      henke(28,1, 352 ) = 2703.3 
C      henke(28,2, 352 ) = 28.0006 
C      henke(28,3, 352 ) = 3.43174 
C      henke(28,1, 353 ) = 2747.03 
C      henke(28,2, 353 ) = 27.9897 
C      henke(28,3, 353 ) = 3.34237 
C      henke(28,1, 354 ) = 2791.46 
C      henke(28,2, 354 ) = 27.978 
C      henke(28,3, 354 ) = 3.25525 
C      henke(28,1, 355 ) = 2836.61 
C      henke(28,2, 355 ) = 27.9654 
C      henke(28,3, 355 ) = 3.17028 
C      henke(28,1, 356 ) = 2882.49 
C      henke(28,2, 356 ) = 27.9522 
C      henke(28,3, 356 ) = 3.08748 
C      henke(28,1, 357 ) = 2929.11 
C      henke(28,2, 357 ) = 27.9383 
C      henke(28,3, 357 ) = 3.00673 
C      henke(28,1, 358 ) = 2976.48 
C      henke(28,2, 358 ) = 27.9237 
C      henke(28,3, 358 ) = 2.92803 
C      henke(28,1, 359 ) = 3024.63 
C      henke(28,2, 359 ) = 27.9086 
C      henke(28,3, 359 ) = 2.85132 
C      henke(28,1, 360 ) = 3073.55 
C      henke(28,2, 360 ) = 27.8929 
C      henke(28,3, 360 ) = 2.77654 
C      henke(28,1, 361 ) = 3123.26 
C      henke(28,2, 361 ) = 27.8767 
C      henke(28,3, 361 ) = 2.70362 
C      henke(28,1, 362 ) = 3173.78 
C      henke(28,2, 362 ) = 27.86 
C      henke(28,3, 362 ) = 2.63256 
C      henke(28,1, 363 ) = 3225.11 
C      henke(28,2, 363 ) = 27.8428 
C      henke(28,3, 363 ) = 2.56329 
C      henke(28,1, 364 ) = 3277.27 
C      henke(28,2, 364 ) = 27.8251 
C      henke(28,3, 364 ) = 2.49582 
C      henke(28,1, 365 ) = 3330.28 
C      henke(28,2, 365 ) = 27.8071 
C      henke(28,3, 365 ) = 2.43004 
C      henke(28,1, 366 ) = 3384.15 
C      henke(28,2, 366 ) = 27.7887 
C      henke(28,3, 366 ) = 2.36592 
C      henke(28,1, 367 ) = 3438.88 
C      henke(28,2, 367 ) = 27.7699 
C      henke(28,3, 367 ) = 2.30341 
C      henke(28,1, 368 ) = 3494.5 
C      henke(28,2, 368 ) = 27.7507 
C      henke(28,3, 368 ) = 2.24255 
C      henke(28,1, 369 ) = 3551.02 
C      henke(28,2, 369 ) = 27.7313 
C      henke(28,3, 369 ) = 2.18319 
C      henke(28,1, 370 ) = 3608.46 
C      henke(28,2, 370 ) = 27.7115 
C      henke(28,3, 370 ) = 2.12538 
C      henke(28,1, 371 ) = 3666.82 
C      henke(28,2, 371 ) = 27.6914 
C      henke(28,3, 371 ) = 2.06903 
C      henke(28,1, 372 ) = 3726.13 
C      henke(28,2, 372 ) = 27.671 
C      henke(28,3, 372 ) = 2.0141 
C      henke(28,1, 373 ) = 3786.4 
C      henke(28,2, 373 ) = 27.6503 
C      henke(28,3, 373 ) = 1.9606 
C      henke(28,1, 374 ) = 3847.64 
C      henke(28,2, 374 ) = 27.6293 
C      henke(28,3, 374 ) = 1.90848 
C      henke(28,1, 375 ) = 3909.87 
C      henke(28,2, 375 ) = 27.6081 
C      henke(28,3, 375 ) = 1.85767 
C      henke(28,1, 376 ) = 3973.11 
C      henke(28,2, 376 ) = 27.5866 
C      henke(28,3, 376 ) = 1.80819 
C      henke(28,1, 377 ) = 4037.38 
C      henke(28,2, 377 ) = 27.5648 
C      henke(28,3, 377 ) = 1.75993 
C      henke(28,1, 378 ) = 4102.68 
C      henke(28,2, 378 ) = 27.5427 
C      henke(28,3, 378 ) = 1.71294 
C      henke(28,1, 379 ) = 4169.03 
C      henke(28,2, 379 ) = 27.5203 
C      henke(28,3, 379 ) = 1.66712 
C      henke(28,1, 380 ) = 4236.46 
C      henke(28,2, 380 ) = 27.4977 
C      henke(28,3, 380 ) = 1.62253 
C      henke(28,1, 381 ) = 4304.98 
C      henke(28,2, 381 ) = 27.4748 
C      henke(28,3, 381 ) = 1.57905 
C      henke(28,1, 382 ) = 4374.62 
C      henke(28,2, 382 ) = 27.4516 
C      henke(28,3, 382 ) = 1.53665 
C      henke(28,1, 383 ) = 4445.37 
C      henke(28,2, 383 ) = 27.4281 
C      henke(28,3, 383 ) = 1.4954 
C      henke(28,1, 384 ) = 4517.27 
C      henke(28,2, 384 ) = 27.4043 
C      henke(28,3, 384 ) = 1.45514 
C      henke(28,1, 385 ) = 4590.33 
C      henke(28,2, 385 ) = 27.3801 
C      henke(28,3, 385 ) = 1.41597 
C      henke(28,1, 386 ) = 4664.58 
C      henke(28,2, 386 ) = 27.3555 
C      henke(28,3, 386 ) = 1.37776 
C      henke(28,1, 387 ) = 4740.03 
C      henke(28,2, 387 ) = 27.3305 
C      henke(28,3, 387 ) = 1.34054 
C      henke(28,1, 388 ) = 4816.69 
C      henke(28,2, 388 ) = 27.3052 
C      henke(28,3, 388 ) = 1.30428 
C      henke(28,1, 389 ) = 4894.6 
C      henke(28,2, 389 ) = 27.2794 
C      henke(28,3, 389 ) = 1.26897 
C      henke(28,1, 390 ) = 4973.77 
C      henke(28,2, 390 ) = 27.2531 
C      henke(28,3, 390 ) = 1.23452 
C      henke(28,1, 391 ) = 5054.21 
C      henke(28,2, 391 ) = 27.2262 
C      henke(28,3, 391 ) = 1.20094 
C      henke(28,1, 392 ) = 5135.96 
C      henke(28,2, 392 ) = 27.1988 
C      henke(28,3, 392 ) = 1.16828 
C      henke(28,1, 393 ) = 5219.03 
C      henke(28,2, 393 ) = 27.1708 
C      henke(28,3, 393 ) = 1.13642 
C      henke(28,1, 394 ) = 5303.44 
C      henke(28,2, 394 ) = 27.1421 
C      henke(28,3, 394 ) = 1.10536 
C      henke(28,1, 395 ) = 5389.22 
C      henke(28,2, 395 ) = 27.1127 
C      henke(28,3, 395 ) = 1.07511 
C      henke(28,1, 396 ) = 5476.39 
C      henke(28,2, 396 ) = 27.0824 
C      henke(28,3, 396 ) = 1.0456 
C      henke(28,1, 397 ) = 5564.97 
C      henke(28,2, 397 ) = 27.0512 
C      henke(28,3, 397 ) = 1.01693 
C      henke(28,1, 398 ) = 5654.98 
C      henke(28,2, 398 ) = 27.019 
C      henke(28,3, 398 ) = 0.988877 
C      henke(28,1, 399 ) = 5746.44 
C      henke(28,2, 399 ) = 26.9857 
C      henke(28,3, 399 ) = 0.961612 
C      henke(28,1, 400 ) = 5839.39 
C      henke(28,2, 400 ) = 26.9511 
C      henke(28,3, 400 ) = 0.935044 
C      henke(28,1, 401 ) = 5933.83 
C      henke(28,2, 401 ) = 26.9152 
C      henke(28,3, 401 ) = 0.90913 
C      henke(28,1, 402 ) = 6029.81 
C      henke(28,2, 402 ) = 26.8777 
C      henke(28,3, 402 ) = 0.883844 
C      henke(28,1, 403 ) = 6127.33 
C      henke(28,2, 403 ) = 26.8384 
C      henke(28,3, 403 ) = 0.859254 
C      henke(28,1, 404 ) = 6226.44 
C      henke(28,2, 404 ) = 26.7972 
C      henke(28,3, 404 ) = 0.83524 
C      henke(28,1, 405 ) = 6327.15 
C      henke(28,2, 405 ) = 26.7536 
C      henke(28,3, 405 ) = 0.811858 
C      henke(28,1, 406 ) = 6429.48 
C      henke(28,2, 406 ) = 26.7075 
C      henke(28,3, 406 ) = 0.789069 
C      henke(28,1, 407 ) = 6533.48 
C      henke(28,2, 407 ) = 26.6584 
C      henke(28,3, 407 ) = 0.766841 
C      henke(28,1, 408 ) = 6639.15 
C      henke(28,2, 408 ) = 26.6058 
C      henke(28,3, 408 ) = 0.745185 
C      henke(28,1, 409 ) = 6746.54 
C      henke(28,2, 409 ) = 26.5492 
C      henke(28,3, 409 ) = 0.724075 
C      henke(28,1, 410 ) = 6855.65 
C      henke(28,2, 410 ) = 26.4878 
C      henke(28,3, 410 ) = 0.703492 
C      henke(28,1, 411 ) = 6966.54 
C      henke(28,2, 411 ) = 26.4206 
C      henke(28,3, 411 ) = 0.683436 
C      henke(28,1, 412 ) = 7079.22 
C      henke(28,2, 412 ) = 26.3466 
C      henke(28,3, 412 ) = 0.663872 
C      henke(28,1, 413 ) = 7193.72 
C      henke(28,2, 413 ) = 26.2639 
C      henke(28,3, 413 ) = 0.644803 
C      henke(28,1, 414 ) = 7310.07 
C      henke(28,2, 414 ) = 26.1706 
C      henke(28,3, 414 ) = 0.626209 
C      henke(28,1, 415 ) = 7428.31 
C      henke(28,2, 415 ) = 26.0635 
C      henke(28,3, 415 ) = 0.608093 
C      henke(28,1, 416 ) = 7548.45 
C      henke(28,2, 416 ) = 25.9382 
C      henke(28,3, 416 ) = 0.590415 
C      henke(28,1, 417 ) = 7670.54 
C      henke(28,2, 417 ) = 25.7876 
C      henke(28,3, 417 ) = 0.573185 
C      henke(28,1, 418 ) = 7794.61 
C      henke(28,2, 418 ) = 25.6001 
C      henke(28,3, 418 ) = 0.556386 
C      henke(28,1, 419 ) = 7920.68 
C      henke(28,2, 419 ) = 25.3543 
C      henke(28,3, 419 ) = 0.540007 
C      henke(28,1, 420 ) = 8048.79 
C      henke(28,2, 420 ) = 25.003 
C      henke(28,3, 420 ) = 0.524024 
C      henke(28,1, 421 ) = 8178.98 
C      henke(28,2, 421 ) = 24.4098 
C      henke(28,3, 421 ) = 0.508444 
C      henke(28,1, 422 ) = 8311.26 
C      henke(28,2, 422 ) = 22.3857 
C      henke(28,3, 422 ) = 0.493285 
C      henke(28,1, 423 ) = 8332.7 
C      henke(28,2, 423 ) = 16.7028 
C      henke(28,3, 423 ) = 0.490893 
C      henke(28,1, 424 ) = 8332.9 
C      henke(28,2, 424 ) = 16.7033 
C      henke(28,3, 424 ) = 3.83905 
C      henke(28,1, 425 ) = 8445.69 
C      henke(28,2, 425 ) = 24.2527 
C      henke(28,3, 425 ) = 3.76427 
C      henke(28,1, 426 ) = 8582.29 
C      henke(28,2, 426 ) = 25.1541 
C      henke(28,3, 426 ) = 3.67693 
C      henke(28,1, 427 ) = 8721.11 
C      henke(28,2, 427 ) = 25.6675 
C      henke(28,3, 427 ) = 3.59086 
C      henke(28,1, 428 ) = 8862.16 
C      henke(28,2, 428 ) = 26.0303 
C      henke(28,3, 428 ) = 3.50611 
C      henke(28,1, 429 ) = 9005.5 
C      henke(28,2, 429 ) = 26.3112 
C      henke(28,3, 429 ) = 3.42271 
C      henke(28,1, 430 ) = 9151.16 
C      henke(28,2, 430 ) = 26.5399 
C      henke(28,3, 430 ) = 3.34062 
C      henke(28,1, 431 ) = 9299.17 
C      henke(28,2, 431 ) = 26.7321 
C      henke(28,3, 431 ) = 3.25979 
C      henke(28,1, 432 ) = 9449.58 
C      henke(28,2, 432 ) = 26.8971 
C      henke(28,3, 432 ) = 3.18038 
C      henke(28,1, 433 ) = 9602.42 
C      henke(28,2, 433 ) = 27.041 
C      henke(28,3, 433 ) = 3.10241 
C      henke(28,1, 434 ) = 9757.73 
C      henke(28,2, 434 ) = 27.1679 
C      henke(28,3, 434 ) = 3.02575 
C      henke(28,1, 435 ) = 9915.55 
C      henke(28,2, 435 ) = 27.2808 
C      henke(28,3, 435 ) = 2.95068 
C      henke(28,1, 436 ) = 10075.9 
C      henke(28,2, 436 ) = 27.382 
C      henke(28,3, 436 ) = 2.87686 
C      henke(28,1, 437 ) = 10238.9 
C      henke(28,2, 437 ) = 27.4733 
C      henke(28,3, 437 ) = 2.80444 
C      henke(28,1, 438 ) = 10404.5 
C      henke(28,2, 438 ) = 27.5558 
C      henke(28,3, 438 ) = 2.73343 
C      henke(28,1, 439 ) = 10572.8 
C      henke(28,2, 439 ) = 27.6307 
C      henke(28,3, 439 ) = 2.66382 
C      henke(28,1, 440 ) = 10743.8 
C      henke(28,2, 440 ) = 27.6989 
C      henke(28,3, 440 ) = 2.5956 
C      henke(28,1, 441 ) = 10917.6 
C      henke(28,2, 441 ) = 27.7611 
C      henke(28,3, 441 ) = 2.52878 
C      henke(28,1, 442 ) = 11094.2 
C      henke(28,2, 442 ) = 27.818 
C      henke(28,3, 442 ) = 2.46334 
C      henke(28,1, 443 ) = 11273.6 
C      henke(28,2, 443 ) = 27.87 
C      henke(28,3, 443 ) = 2.39927 
C      henke(28,1, 444 ) = 11455.9 
C      henke(28,2, 444 ) = 27.9176 
C      henke(28,3, 444 ) = 2.33657 
C      henke(28,1, 445 ) = 11641.2 
C      henke(28,2, 445 ) = 27.9613 
C      henke(28,3, 445 ) = 2.27521 
C      henke(28,1, 446 ) = 11829.5 
C      henke(28,2, 446 ) = 28.0013 
C      henke(28,3, 446 ) = 2.21519 
C      henke(28,1, 447 ) = 12020.8 
C      henke(28,2, 447 ) = 28.038 
C      henke(28,3, 447 ) = 2.1565 
C      henke(28,1, 448 ) = 12215.3 
C      henke(28,2, 448 ) = 28.0716 
C      henke(28,3, 448 ) = 2.09912 
C      henke(28,1, 449 ) = 12412.8 
C      henke(28,2, 449 ) = 28.1024 
C      henke(28,3, 449 ) = 2.04303 
C      henke(28,1, 450 ) = 12613.6 
C      henke(28,2, 450 ) = 28.1306 
C      henke(28,3, 450 ) = 1.98822 
C      henke(28,1, 451 ) = 12817.6 
C      henke(28,2, 451 ) = 28.1564 
C      henke(28,3, 451 ) = 1.93467 
C      henke(28,1, 452 ) = 13025 
C      henke(28,2, 452 ) = 28.18 
C      henke(28,3, 452 ) = 1.88237 
C      henke(28,1, 453 ) = 13235.6 
C      henke(28,2, 453 ) = 28.2014 
C      henke(28,3, 453 ) = 1.83129 
C      henke(28,1, 454 ) = 13449.7 
C      henke(28,2, 454 ) = 28.221 
C      henke(28,3, 454 ) = 1.78141 
C      henke(28,1, 455 ) = 13667.2 
C      henke(28,2, 455 ) = 28.2388 
C      henke(28,3, 455 ) = 1.73273 
C      henke(28,1, 456 ) = 13888.3 
C      henke(28,2, 456 ) = 28.2549 
C      henke(28,3, 456 ) = 1.68521 
C      henke(28,1, 457 ) = 14112.9 
C      henke(28,2, 457 ) = 28.2694 
C      henke(28,3, 457 ) = 1.63884 
C      henke(28,1, 458 ) = 14341.2 
C      henke(28,2, 458 ) = 28.2826 
C      henke(28,3, 458 ) = 1.59361 
C      henke(28,1, 459 ) = 14573.1 
C      henke(28,2, 459 ) = 28.2943 
C      henke(28,3, 459 ) = 1.54948 
C      henke(28,1, 460 ) = 14808.9 
C      henke(28,2, 460 ) = 28.3048 
C      henke(28,3, 460 ) = 1.50644 
C      henke(28,1, 461 ) = 15048.4 
C      henke(28,2, 461 ) = 28.3141 
C      henke(28,3, 461 ) = 1.46447 
C      henke(28,1, 462 ) = 15291.8 
C      henke(28,2, 462 ) = 28.3224 
C      henke(28,3, 462 ) = 1.42356 
C      henke(28,1, 463 ) = 15539.1 
C      henke(28,2, 463 ) = 28.3296 
C      henke(28,3, 463 ) = 1.38367 
C      henke(28,1, 464 ) = 15790.4 
C      henke(28,2, 464 ) = 28.3358 
C      henke(28,3, 464 ) = 1.3448 
C      henke(28,1, 465 ) = 16045.8 
C      henke(28,2, 465 ) = 28.3412 
C      henke(28,3, 465 ) = 1.30691 
C      henke(28,1, 466 ) = 16305.4 
C      henke(28,2, 466 ) = 28.3457 
C      henke(28,3, 466 ) = 1.26999 
C      henke(28,1, 467 ) = 16569.1 
C      henke(28,2, 467 ) = 28.3494 
C      henke(28,3, 467 ) = 1.23403 
C      henke(28,1, 468 ) = 16837.1 
C      henke(28,2, 468 ) = 28.3524 
C      henke(28,3, 468 ) = 1.19899 
C      henke(28,1, 469 ) = 17109.4 
C      henke(28,2, 469 ) = 28.3547 
C      henke(28,3, 469 ) = 1.16487 
C      henke(28,1, 470 ) = 17386.1 
C      henke(28,2, 470 ) = 28.3564 
C      henke(28,3, 470 ) = 1.13164 
C      henke(28,1, 471 ) = 17667.4 
C      henke(28,2, 471 ) = 28.3575 
C      henke(28,3, 471 ) = 1.09928 
C      henke(28,1, 472 ) = 17953.1 
C      henke(28,2, 472 ) = 28.3581 
C      henke(28,3, 472 ) = 1.06777 
C      henke(28,1, 473 ) = 18243.5 
C      henke(28,2, 473 ) = 28.3581 
C      henke(28,3, 473 ) = 1.0371 
C      henke(28,1, 474 ) = 18538.6 
C      henke(28,2, 474 ) = 28.3577 
C      henke(28,3, 474 ) = 1.00725 
C      henke(28,1, 475 ) = 18838.4 
C      henke(28,2, 475 ) = 28.3568 
C      henke(28,3, 475 ) = 0.978188 
C      henke(28,1, 476 ) = 19143.1 
C      henke(28,2, 476 ) = 28.3555 
C      henke(28,3, 476 ) = 0.949909 
C      henke(28,1, 477 ) = 19452.7 
C      henke(28,2, 477 ) = 28.3539 
C      henke(28,3, 477 ) = 0.922391 
C      henke(28,1, 478 ) = 19767.4 
C      henke(28,2, 478 ) = 28.3518 
C      henke(28,3, 478 ) = 0.895616 
C      henke(28,1, 479 ) = 20087.1 
C      henke(28,2, 479 ) = 28.3495 
C      henke(28,3, 479 ) = 0.869567 
C      henke(28,1, 480 ) = 20412 
C      henke(28,2, 480 ) = 28.3468 
C      henke(28,3, 480 ) = 0.844228 
C      henke(28,1, 481 ) = 20742.1 
C      henke(28,2, 481 ) = 28.3439 
C      henke(28,3, 481 ) = 0.81958 
C      henke(28,1, 482 ) = 21077.6 
C      henke(28,2, 482 ) = 28.3407 
C      henke(28,3, 482 ) = 0.795607 
C      henke(28,1, 483 ) = 21418.5 
C      henke(28,2, 483 ) = 28.3373 
C      henke(28,3, 483 ) = 0.772295 
C      henke(28,1, 484 ) = 21765 
C      henke(28,2, 484 ) = 28.3336 
C      henke(28,3, 484 ) = 0.749624 
C      henke(28,1, 485 ) = 22117 
C      henke(28,2, 485 ) = 28.3298 
C      henke(28,3, 485 ) = 0.727581 
C      henke(28,1, 486 ) = 22474.7 
C      henke(28,2, 486 ) = 28.3257 
C      henke(28,3, 486 ) = 0.70615 
C      henke(28,1, 487 ) = 22838.2 
C      henke(28,2, 487 ) = 28.3216 
C      henke(28,3, 487 ) = 0.685315 
C      henke(28,1, 488 ) = 23207.6 
C      henke(28,2, 488 ) = 28.3172 
C      henke(28,3, 488 ) = 0.665061 
C      henke(28,1, 489 ) = 23583 
C      henke(28,2, 489 ) = 28.3127 
C      henke(28,3, 489 ) = 0.645374 
C      henke(28,1, 490 ) = 23964.4 
C      henke(28,2, 490 ) = 28.3081 
C      henke(28,3, 490 ) = 0.626241 
C      henke(28,1, 491 ) = 24352 
C      henke(28,2, 491 ) = 28.3034 
C      henke(28,3, 491 ) = 0.607644 
C      henke(28,1, 492 ) = 24745.9 
C      henke(28,2, 492 ) = 28.2986 
C      henke(28,3, 492 ) = 0.589574 
C      henke(28,1, 493 ) = 25146.2 
C      henke(28,2, 493 ) = 28.2937 
C      henke(28,3, 493 ) = 0.572013 
C      henke(28,1, 494 ) = 25552.9 
C      henke(28,2, 494 ) = 28.2888 
C      henke(28,3, 494 ) = 0.554951 
C      henke(28,1, 495 ) = 25966.2 
C      henke(28,2, 495 ) = 28.2838 
C      henke(28,3, 495 ) = 0.538374 
C      henke(28,1, 496 ) = 26386.1 
C      henke(28,2, 496 ) = 28.2787 
C      henke(28,3, 496 ) = 0.522269 
C      henke(28,1, 497 ) = 26812.9 
C      henke(28,2, 497 ) = 28.2736 
C      henke(28,3, 497 ) = 0.506624 
C      henke(28,1, 498 ) = 27246.6 
C      henke(28,2, 498 ) = 28.2684 
C      henke(28,3, 498 ) = 0.491427 
C      henke(28,1, 499 ) = 27687.3 
C      henke(28,2, 499 ) = 28.2632 
C      henke(28,3, 499 ) = 0.476665 
C      henke(28,1, 500 ) = 28135.1 
C      henke(28,2, 500 ) = 28.2581 
C      henke(28,3, 500 ) = 0.462328 
C      henke(28,1, 501 ) = 28590.2 
C      henke(28,2, 501 ) = 28.2529 
C      henke(28,3, 501 ) = 0.448404 
C      henke(28,1, 502 ) = 29052.6 
C      henke(28,2, 502 ) = 28.248 
C      henke(28,3, 502 ) = 0.434882 
C      henke(28,1, 503 ) = 29522.5 
C      henke(28,2, 503 ) = 28.2436 
C      henke(28,3, 503 ) = 0.42175 
C      henke(28,1, 504 ) = 30000 
C      henke(28,2, 504 ) = 28.2337 
C      henke(28,3, 504 ) = 0.408999 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C  Alan Owens data for Gold-
       count(79) = 706
       henke(79,1, 1 ) = 10 
       henke(79,2, 1 ) = -9999 
       henke(79,3, 1 ) = 2.42357 
       henke(79,1, 2 ) = 10.08 
        henke(79,2, 2 ) = -9999 
        henke(79,3, 2 ) = 2.45021 
        henke(79,1, 3 ) = 10.1626 
        henke(79,2, 3 ) = -9999 
        henke(79,3, 3 ) = 2.47279 
        henke(79,1, 4 ) = 10.2466 
        henke(79,2, 4 ) = -9999 
        henke(79,3, 4 ) = 2.49321 
        henke(79,1, 5 ) = 10.332 
        henke(79,2, 5 ) = -9999 
        henke(79,3, 5 ) = 2.52183 
        henke(79,1, 6 ) = 10.4188 
        henke(79,2, 6 ) = -9999 
        henke(79,3, 6 ) = 2.54573 
        henke(79,1, 7 ) = 10.5071 
        henke(79,2, 7 ) = -9999 
        henke(79,3, 7 ) = 2.57551 
        henke(79,1, 8 ) = 10.5969 
        henke(79,2, 8 ) = -9999 
        henke(79,3, 8 ) = 2.59766 
        henke(79,1, 9 ) = 10.6882 
        henke(79,2, 9 ) = -9999 
        henke(79,3, 9 ) = 2.623 
        henke(79,1, 10 ) = 10.7812 
        henke(79,2, 10 ) = -9999 
        henke(79,3, 10 ) = 2.66025 
        henke(79,1, 11 ) = 10.8757 
        henke(79,2, 11 ) = -9999 
        henke(79,3, 11 ) = 2.6926 
        henke(79,1, 12 ) = 10.972 
        henke(79,2, 12 ) = -9999 
        henke(79,3, 12 ) = 2.72569 
        henke(79,1, 13 ) = 11.07 
        henke(79,2, 13 ) = -9999 
        henke(79,3, 13 ) = 2.75051 
        henke(79,1, 14 ) = 11.1697 
        henke(79,2, 14 ) = -9999 
        henke(79,3, 14 ) = 2.77884 
        henke(79,1, 15 ) = 11.2712 
        henke(79,2, 15 ) = -9999 
        henke(79,3, 15 ) = 2.80776 
        henke(79,1, 16 ) = 11.3746 
        henke(79,2, 16 ) = -9999 
        henke(79,3, 16 ) = 2.83727 
        henke(79,1, 17 ) = 11.4799 
        henke(79,2, 17 ) = -9999 
        henke(79,3, 17 ) = 2.86417 
        henke(79,1, 18 ) = 11.5872 
        henke(79,2, 18 ) = -9999 
        henke(79,3, 18 ) = 2.89487 
        henke(79,1, 19 ) = 11.6966 
        henke(79,2, 19 ) = -9999 
        henke(79,3, 19 ) = 2.92288 
        henke(79,1, 20 ) = 11.808 
        henke(79,2, 20 ) = -9999 
        henke(79,3, 20 ) = 2.96169 
        henke(79,1, 21 ) = 11.9215 
        henke(79,2, 21 ) = -9999 
        henke(79,3, 21 ) = 3.00147 
        henke(79,1, 22 ) = 12.0372 
        henke(79,2, 22 ) = -9999 
        henke(79,3, 22 ) = 3.03513 
        henke(79,1, 23 ) = 12.1552 
        henke(79,2, 23 ) = -9999 
        henke(79,3, 23 ) = 3.07679 
        henke(79,1, 24 ) = 12.2756 
        henke(79,2, 24 ) = -9999 
        henke(79,3, 24 ) = 3.11582 
        henke(79,1, 25 ) = 12.3983 
        henke(79,2, 25 ) = -9999 
        henke(79,3, 25 ) = 3.15579 
        henke(79,1, 26 ) = 12.5236 
        henke(79,2, 26 ) = -9999 
        henke(79,3, 26 ) = 3.20062 
        henke(79,1, 27 ) = 12.6514 
        henke(79,2, 27 ) = -9999 
        henke(79,3, 27 ) = 3.24661 
        henke(79,1, 28 ) = 12.7818 
        henke(79,2, 28 ) = -9999 
        henke(79,3, 28 ) = 3.30186 
        henke(79,1, 29 ) = 12.915 
        henke(79,2, 29 ) = -9999 
        henke(79,3, 29 ) = 3.35463 
        henke(79,1, 30 ) = 13.0509 
        henke(79,2, 30 ) = -9999 
        henke(79,3, 30 ) = 3.40889 
        henke(79,1, 31 ) = 13.1897 
        henke(79,2, 31 ) = -9999 
        henke(79,3, 31 ) = 3.46899 
        henke(79,1, 32 ) = 13.3316 
        henke(79,2, 32 ) = -9999 
        henke(79,3, 32 ) = 3.5309 
        henke(79,1, 33 ) = 13.4765 
        henke(79,2, 33 ) = -9999 
        henke(79,3, 33 ) = 3.5947 
        henke(79,1, 34 ) = 13.6246 
        henke(79,2, 34 ) = -9999 
        henke(79,3, 34 ) = 3.65134 
        henke(79,1, 35 ) = 13.7759 
        henke(79,2, 35 ) = -9999 
        henke(79,3, 35 ) = 3.71895 
        henke(79,1, 36 ) = 13.9307 
        henke(79,2, 36 ) = -9999 
        henke(79,3, 36 ) = 3.77917 
        henke(79,1, 37 ) = 14.089 
        henke(79,2, 37 ) = -9999 
        henke(79,3, 37 ) = 3.84604 
        henke(79,1, 38 ) = 14.251 
        henke(79,2, 38 ) = -9999 
        henke(79,3, 38 ) = 3.91003 
        henke(79,1, 39 ) = 14.4167 
        henke(79,2, 39 ) = -9999 
        henke(79,3, 39 ) = 3.98108 
        henke(79,1, 40 ) = 14.5863 
        henke(79,2, 40 ) = -9999 
        henke(79,3, 40 ) = 4.04917 
        henke(79,1, 41 ) = 14.7599 
        henke(79,2, 41 ) = -9999 
        henke(79,3, 41 ) = 4.11941 
        henke(79,1, 42 ) = 14.9378 
        henke(79,2, 42 ) = -9999 
        henke(79,3, 42 ) = 4.19187 
        henke(79,1, 43 ) = 15.1199 
        henke(79,2, 43 ) = -9999 
        henke(79,3, 43 ) = 4.26105 
        henke(79,1, 44 ) = 15.3066 
        henke(79,2, 44 ) = -9999 
        henke(79,3, 44 ) = 4.32663 
        henke(79,1, 45 ) = 15.4979 
        henke(79,2, 45 ) = -9999 
        henke(79,3, 45 ) = 4.39419 
        henke(79,1, 46 ) = 15.6941 
        henke(79,2, 46 ) = -9999 
        henke(79,3, 46 ) = 4.46985 
        henke(79,1, 47 ) = 15.8953 
        henke(79,2, 47 ) = -9999 
        henke(79,3, 47 ) = 4.52936 
        henke(79,1, 48 ) = 16.1017 
        henke(79,2, 48 ) = -9999 
        henke(79,3, 48 ) = 4.5841 
        henke(79,1, 49 ) = 16.3136 
        henke(79,2, 49 ) = -9999 
        henke(79,3, 49 ) = 4.65977 
        henke(79,1, 50 ) = 16.5311 
        henke(79,2, 50 ) = -9999 
        henke(79,3, 50 ) = 4.72447 
        henke(79,1, 51 ) = 16.7545 
        henke(79,2, 51 ) = -9999 
        henke(79,3, 51 ) = 4.80477 
        henke(79,1, 52 ) = 16.984 
        henke(79,2, 52 ) = -9999 
        henke(79,3, 52 ) = 4.88772 
        henke(79,1, 53 ) = 17.2199 
        henke(79,2, 53 ) = -9999 
        henke(79,3, 53 ) = 4.98802 
        henke(79,1, 54 ) = 17.4625 
        henke(79,2, 54 ) = -9999 
        henke(79,3, 54 ) = 5.09208 
        henke(79,1, 55 ) = 17.7119 
        henke(79,2, 55 ) = -9999 
        henke(79,3, 55 ) = 5.2232 
        henke(79,1, 56 ) = 17.9686 
        henke(79,2, 56 ) = -9999 
        henke(79,3, 56 ) = 5.39155 
        henke(79,1, 57 ) = 18.2329 
        henke(79,2, 57 ) = -9999 
        henke(79,3, 57 ) = 5.60843 
        henke(79,1, 58 ) = 18.505 
        henke(79,2, 58 ) = -9999 
        henke(79,3, 58 ) = 5.83596 
        henke(79,1, 59 ) = 18.7854 
        henke(79,2, 59 ) = -9999 
        henke(79,3, 59 ) = 6.06615 
        henke(79,1, 60 ) = 19.0744 
        henke(79,2, 60 ) = -9999 
        henke(79,3, 60 ) = 6.34358 
        henke(79,1, 61 ) = 19.3724 
        henke(79,2, 61 ) = -9999 
        henke(79,3, 61 ) = 6.72768 
        henke(79,1, 62 ) = 19.6799 
        henke(79,2, 62 ) = -9999 
        henke(79,3, 62 ) = 7.13317 
        henke(79,1, 63 ) = 19.9973 
        henke(79,2, 63 ) = -9999 
        henke(79,3, 63 ) = 7.56153 
        henke(79,1, 64 ) = 20.3208 
        henke(79,2, 64 ) = -9999 
        henke(79,3, 64 ) = 7.97873 
        henke(79,1, 65 ) = 20.6495 
        henke(79,2, 65 ) = -9999 
        henke(79,3, 65 ) = 8.41895 
        henke(79,1, 66 ) = 20.9834 
        henke(79,2, 66 ) = -9999 
        henke(79,3, 66 ) = 8.88345 
        henke(79,1, 67 ) = 21.3228 
        henke(79,2, 67 ) = -9999 
        henke(79,3, 67 ) = 9.37359 
        henke(79,1, 68 ) = 21.6677 
        henke(79,2, 68 ) = -9999 
        henke(79,3, 68 ) = 9.6941 
        henke(79,1, 69 ) = 22.0182 
        henke(79,2, 69 ) = -9999 
        henke(79,3, 69 ) = 9.89242 
        henke(79,1, 70 ) = 22.3743 
        henke(79,2, 70 ) = -9999 
        henke(79,3, 70 ) = 10.0948 
        henke(79,1, 71 ) = 22.7362 
        henke(79,2, 71 ) = -9999 
        henke(79,3, 71 ) = 10.1107 
        henke(79,1, 72 ) = 23.1039 
        henke(79,2, 72 ) = -9999 
        henke(79,3, 72 ) = 9.98361 
        henke(79,1, 73 ) = 23.4776 
        henke(79,2, 73 ) = -9999 
        henke(79,3, 73 ) = 9.84802 
        henke(79,1, 74 ) = 23.8573 
        henke(79,2, 74 ) = -9999 
        henke(79,3, 74 ) = 9.62491 
        henke(79,1, 75 ) = 24.2432 
        henke(79,2, 75 ) = -9999 
        henke(79,3, 75 ) = 9.40686 
        henke(79,1, 76 ) = 24.6353 
        henke(79,2, 76 ) = -9999 
        henke(79,3, 76 ) = 9.1434 
        henke(79,1, 77 ) = 25.0338 
        henke(79,2, 77 ) = -9999 
        henke(79,3, 77 ) = 8.85791 
        henke(79,1, 78 ) = 25.4387 
        henke(79,2, 78 ) = -9999 
        henke(79,3, 78 ) = 8.80754 
        henke(79,1, 79 ) = 25.8501 
        henke(79,2, 79 ) = -9999 
        henke(79,3, 79 ) = 8.83951 
        henke(79,1, 80 ) = 26.2682 
        henke(79,2, 80 ) = -9999 
        henke(79,3, 80 ) = 8.87159 
        henke(79,1, 81 ) = 26.6931 
        henke(79,2, 81 ) = -9999 
        henke(79,3, 81 ) = 8.9266 
        henke(79,1, 82 ) = 27.1248 
        henke(79,2, 82 ) = -9999 
        henke(79,3, 82 ) = 9.2167 
        henke(79,1, 83 ) = 27.5636 
        henke(79,2, 83 ) = -9999 
        henke(79,3, 83 ) = 9.51624 
        henke(79,1, 84 ) = 28.0094 
        henke(79,2, 84 ) = -9999 
        henke(79,3, 84 ) = 9.84618 
        henke(79,1, 85 ) = 28.4624 
        henke(79,2, 85 ) = -9999 
        henke(79,3, 85 ) = 10.3686 
        henke(79,1, 86 ) = 28.9228 
        henke(79,2, 86 ) = -9999 
        henke(79,3, 86 ) = 10.9186 
        henke(79,1, 87 ) = 29.3906 
        henke(79,2, 87 ) = 2.80453 
        henke(79,3, 87 ) = 11.4926 
        henke(79,1, 88 ) = 29.8659 
        henke(79,2, 88 ) = 3.17209 
        henke(79,3, 88 ) = 12.0568 
        henke(79,1, 89 ) = 30.349 
        henke(79,2, 89 ) = 3.77287 
        henke(79,3, 89 ) = 12.4227 
        henke(79,1, 90 ) = 30.8399 
        henke(79,2, 90 ) = 4.27837 
        henke(79,3, 90 ) = 12.6656 
        henke(79,1, 91 ) = 31.3387 
        henke(79,2, 91 ) = 4.82841 
        henke(79,3, 91 ) = 12.9132 
        henke(79,1, 92 ) = 31.8456 
        henke(79,2, 92 ) = 5.54243 
        henke(79,3, 92 ) = 12.8346 
        henke(79,1, 93 ) = 32.3606 
        henke(79,2, 93 ) = 5.87121 
        henke(79,3, 93 ) = 12.581 
        henke(79,1, 94 ) = 32.884 
        henke(79,2, 94 ) = 6.08198 
        henke(79,3, 94 ) = 12.5114 
        henke(79,1, 95 ) = 33.4159 
        henke(79,2, 95 ) = 6.32549 
        henke(79,3, 95 ) = 12.4719 
        henke(79,1, 96 ) = 33.9564 
        henke(79,2, 96 ) = 6.56301 
        henke(79,3, 96 ) = 12.4326 
        henke(79,1, 97 ) = 34.5056 
        henke(79,2, 97 ) = 6.78224 
        henke(79,3, 97 ) = 12.3934 
        henke(79,1, 98 ) = 35.0637 
        henke(79,2, 98 ) = 6.98448 
        henke(79,3, 98 ) = 12.3534 
        henke(79,1, 99 ) = 35.6308 
        henke(79,2, 99 ) = 7.1681 
        henke(79,3, 99 ) = 12.3133 
        henke(79,1, 100 ) = 36.2071 
        henke(79,2, 100 ) = 7.32969 
        henke(79,3, 100 ) = 12.2732 
        henke(79,1, 101 ) = 36.7928 
        henke(79,2, 101 ) = 7.44923 
        henke(79,3, 101 ) = 12.2333 
        henke(79,1, 102 ) = 37.3879 
        henke(79,2, 102 ) = 7.56922 
        henke(79,3, 102 ) = 12.2604 
        henke(79,1, 103 ) = 37.9926 
        henke(79,2, 103 ) = 7.69736 
        henke(79,3, 103 ) = 12.3041 
        henke(79,1, 104 ) = 38.6071 
        henke(79,2, 104 ) = 7.83973 
        henke(79,3, 104 ) = 12.3479 
        henke(79,1, 105 ) = 39.2315 
        henke(79,2, 105 ) = 7.98382 
        henke(79,3, 105 ) = 12.392 
        henke(79,1, 106 ) = 39.866 
        henke(79,2, 106 ) = 8.12765 
        henke(79,3, 106 ) = 12.4361 
        henke(79,1, 107 ) = 40.5108 
        henke(79,2, 107 ) = 8.27286 
        henke(79,3, 107 ) = 12.5027 
        henke(79,1, 108 ) = 41.1661 
        henke(79,2, 108 ) = 8.43105 
        henke(79,3, 108 ) = 12.5779 
        henke(79,1, 109 ) = 41.8319 
        henke(79,2, 109 ) = 8.6029 
        henke(79,3, 109 ) = 12.6535 
        henke(79,1, 110 ) = 42.5085 
        henke(79,2, 110 ) = 8.78461 
        henke(79,3, 110 ) = 12.7296 
        henke(79,1, 111 ) = 43.196 
        henke(79,2, 111 ) = 8.99277 
        henke(79,3, 111 ) = 12.8061 
        henke(79,1, 112 ) = 43.8947 
        henke(79,2, 112 ) = 9.22547 
        henke(79,3, 112 ) = 12.8831 
        henke(79,1, 113 ) = 44.6047 
        henke(79,2, 113 ) = 9.4703 
        henke(79,3, 113 ) = 12.9092 
        henke(79,1, 114 ) = 45.3261 
        henke(79,2, 114 ) = 9.70579 
        henke(79,3, 114 ) = 12.8761 
        henke(79,1, 115 ) = 46.0592 
        henke(79,2, 115 ) = 9.90002 
        henke(79,3, 115 ) = 12.8432 
        henke(79,1, 116 ) = 46.8042 
        henke(79,2, 116 ) = 10.0759 
        henke(79,3, 116 ) = 12.8103 
        henke(79,1, 117 ) = 47.5612 
        henke(79,2, 117 ) = 10.2371 
        henke(79,3, 117 ) = 12.7666 
        henke(79,1, 118 ) = 48.3305 
        henke(79,2, 118 ) = 10.3669 
        henke(79,3, 118 ) = 12.7155 
        henke(79,1, 119 ) = 49.1122 
        henke(79,2, 119 ) = 10.4612 
        henke(79,3, 119 ) = 12.6646 
        henke(79,1, 120 ) = 49.9065 
        henke(79,2, 120 ) = 10.4911 
        henke(79,3, 120 ) = 12.6139 
        henke(79,1, 121 ) = 50.7137 
        henke(79,2, 121 ) = 10.4937 
        henke(79,3, 121 ) = 12.6944 
        henke(79,1, 122 ) = 51.534 
        henke(79,2, 122 ) = 10.5152 
        henke(79,3, 122 ) = 12.8304 
        henke(79,1, 123 ) = 52.3675 
        henke(79,2, 123 ) = 10.6083 
        henke(79,3, 123 ) = 12.9678 
        henke(79,1, 124 ) = 53.2145 
        henke(79,2, 124 ) = 10.7081 
        henke(79,3, 124 ) = 13.1067 
        henke(79,1, 125 ) = 54.0752 
        henke(79,2, 125 ) = 10.8079 
        henke(79,3, 125 ) = 13.2471 
        henke(79,1, 126 ) = 54.9498 
        henke(79,2, 126 ) = 10.8783 
        henke(79,3, 126 ) = 13.4719 
        henke(79,1, 127 ) = 55.8386 
        henke(79,2, 127 ) = 11.0389 
        henke(79,3, 127 ) = 13.7491 
        henke(79,1, 128 ) = 56.7418 
        henke(79,2, 128 ) = 11.2608 
        henke(79,3, 128 ) = 14.032 
        henke(79,1, 129 ) = 57.6595 
        henke(79,2, 129 ) = 11.5376 
        henke(79,3, 129 ) = 14.3207 
        henke(79,1, 130 ) = 58.5921 
        henke(79,2, 130 ) = 11.9423 
        henke(79,3, 130 ) = 14.6154 
        henke(79,1, 131 ) = 59.5398 
        henke(79,2, 131 ) = 12.401 
        henke(79,3, 131 ) = 14.8206 
        henke(79,1, 132 ) = 60.5028 
        henke(79,2, 132 ) = 12.8496 
        henke(79,3, 132 ) = 14.954 
        henke(79,1, 133 ) = 61.4814 
        henke(79,2, 133 ) = 13.3645 
        henke(79,3, 133 ) = 15.0886 
        henke(79,1, 134 ) = 62.4758 
        henke(79,2, 134 ) = 13.927 
        henke(79,3, 134 ) = 15.2243 
        henke(79,1, 135 ) = 63.4863 
        henke(79,2, 135 ) = 14.5646 
        henke(79,3, 135 ) = 15.1067 
        henke(79,1, 136 ) = 64.5131 
        henke(79,2, 136 ) = 15.1118 
        henke(79,3, 136 ) = 14.8748 
        henke(79,1, 137 ) = 65.5566 
        henke(79,2, 137 ) = 15.5683 
        henke(79,3, 137 ) = 14.6187 
        henke(79,1, 138 ) = 66.6169 
        henke(79,2, 138 ) = 15.9403 
        henke(79,3, 138 ) = 14.3026 
        henke(79,1, 139 ) = 67.6944 
        henke(79,2, 139 ) = 16.2255 
        henke(79,3, 139 ) = 13.9934 
        henke(79,1, 140 ) = 68.7893 
        henke(79,2, 140 ) = 16.4416 
        henke(79,3, 140 ) = 13.6909 
        henke(79,1, 141 ) = 69.9019 
        henke(79,2, 141 ) = 16.5471 
        henke(79,3, 141 ) = 13.3949 
        henke(79,1, 142 ) = 71.0325 
        henke(79,2, 142 ) = 16.6355 
        henke(79,3, 142 ) = 13.2833 
        henke(79,1, 143 ) = 72.1814 
        henke(79,2, 143 ) = 16.7806 
        henke(79,3, 143 ) = 13.1807 
        henke(79,1, 144 ) = 73.3489 
        henke(79,2, 144 ) = 16.9315 
        henke(79,3, 144 ) = 13.0789 
        henke(79,1, 145 ) = 74.5352 
        henke(79,2, 145 ) = 17.0879 
        henke(79,3, 145 ) = 13.0141 
        henke(79,1, 146 ) = 75.7408 
        henke(79,2, 146 ) = 17.2846 
        henke(79,3, 146 ) = 12.9799 
        henke(79,1, 147 ) = 76.9658 
        henke(79,2, 147 ) = 17.5311 
        henke(79,3, 147 ) = 12.9458 
        henke(79,1, 148 ) = 78.2107 
        henke(79,2, 148 ) = 17.8314 
        henke(79,3, 148 ) = 12.828 
        henke(79,1, 149 ) = 79.4757 
        henke(79,2, 149 ) = 18.0679 
        henke(79,3, 149 ) = 12.6516 
        henke(79,1, 150 ) = 80.7611 
        henke(79,2, 150 ) = 18.2641 
        henke(79,3, 150 ) = 12.4775 
        henke(79,1, 151 ) = 82.0674 
        henke(79,2, 151 ) = 18.3103 
        henke(79,3, 151 ) = 12.3059 
        henke(79,1, 152 ) = 83.3947 
        henke(79,2, 152 ) = 18.3008 
        henke(79,3, 152 ) = 12.5122 
        henke(79,1, 153 ) = 84.4844 
        henke(79,2, 153 ) = 18.9133 
        henke(79,3, 153 ) = 12.953 
        henke(79,1, 154 ) = 85.8509 
        henke(79,2, 154 ) = 19.5637 
        henke(79,3, 154 ) = 12.587 
        henke(79,1, 155 ) = 87.2394 
        henke(79,2, 155 ) = 20.0617 
        henke(79,3, 155 ) = 12.2168 
        henke(79,1, 156 ) = 88.6505 
        henke(79,2, 156 ) = 20.4357 
        henke(79,3, 156 ) = 11.7339 
        henke(79,1, 157 ) = 90.0843 
        henke(79,2, 157 ) = 20.704 
        henke(79,3, 157 ) = 11.2701 
        henke(79,1, 158 ) = 91.5414 
        henke(79,2, 158 ) = 20.9224 
        henke(79,3, 158 ) = 10.8246 
        henke(79,1, 159 ) = 93.022 
        henke(79,2, 159 ) = 21.0704 
        henke(79,3, 159 ) = 10.3137 
        henke(79,1, 160 ) = 94.5265 
        henke(79,2, 160 ) = 21.0991 
        henke(79,3, 160 ) = 9.82436 
        henke(79,1, 161 ) = 96.0554 
        henke(79,2, 161 ) = 21.0349 
        henke(79,3, 161 ) = 9.4296 
        henke(79,1, 162 ) = 97.609 
        henke(79,2, 162 ) = 20.9829 
        henke(79,3, 162 ) = 9.10735 
        henke(79,1, 163 ) = 99.1878 
        henke(79,2, 163 ) = 20.9856 
        henke(79,3, 163 ) = 8.79609 
        henke(79,1, 164 ) = 100.792 
        henke(79,2, 164 ) = 20.9775 
        henke(79,3, 164 ) = 8.49547 
        henke(79,1, 165 ) = 102.422 
        henke(79,2, 165 ) = 20.9534 
        henke(79,3, 165 ) = 8.16666 
        henke(79,1, 166 ) = 104.079 
        henke(79,2, 166 ) = 20.8974 
        henke(79,3, 166 ) = 7.83522 
        henke(79,1, 167 ) = 105.762 
        henke(79,2, 167 ) = 20.8049 
        henke(79,3, 167 ) = 7.51724 
        henke(79,1, 168 ) = 107.473 
        henke(79,2, 168 ) = 20.6731 
        henke(79,3, 168 ) = 7.21216 
        henke(79,1, 169 ) = 109.211 
        henke(79,2, 169 ) = 20.5053 
        henke(79,3, 169 ) = 6.97471 
        henke(79,1, 170 ) = 110.978 
        henke(79,2, 170 ) = 20.3663 
        henke(79,3, 170 ) = 6.76866 
        henke(79,1, 171 ) = 112.773 
        henke(79,2, 171 ) = 20.2312 
        henke(79,3, 171 ) = 6.56871 
        henke(79,1, 172 ) = 114.597 
        henke(79,2, 172 ) = 20.0948 
        henke(79,3, 172 ) = 6.37465 
        henke(79,1, 173 ) = 116.45 
        henke(79,2, 173 ) = 19.9483 
        henke(79,3, 173 ) = 6.18633 
        henke(79,1, 174 ) = 118.334 
        henke(79,2, 174 ) = 19.7979 
        henke(79,3, 174 ) = 6.01686 
        henke(79,1, 175 ) = 120.248 
        henke(79,2, 175 ) = 19.6489 
        henke(79,3, 175 ) = 5.85783 
        henke(79,1, 176 ) = 122.192 
        henke(79,2, 176 ) = 19.4996 
        henke(79,3, 176 ) = 5.703 
        henke(79,1, 177 ) = 124.169 
        henke(79,2, 177 ) = 19.3479 
        henke(79,3, 177 ) = 5.55227 
        henke(79,1, 178 ) = 126.177 
        henke(79,2, 178 ) = 19.1996 
        henke(79,3, 178 ) = 5.40552 
        henke(79,1, 179 ) = 128.218 
        henke(79,2, 179 ) = 19.0606 
        henke(79,3, 179 ) = 5.24076 
        henke(79,1, 180 ) = 130.292 
        henke(79,2, 180 ) = 18.8926 
        henke(79,3, 180 ) = 5.0235 
        henke(79,1, 181 ) = 132.399 
        henke(79,2, 181 ) = 18.6442 
        henke(79,3, 181 ) = 4.81524 
        henke(79,1, 182 ) = 134.541 
        henke(79,2, 182 ) = 18.3342 
        henke(79,3, 182 ) = 4.65523 
        henke(79,1, 183 ) = 136.717 
        henke(79,2, 183 ) = 18.0138 
        henke(79,3, 183 ) = 4.59484 
        henke(79,1, 184 ) = 138.928 
        henke(79,2, 184 ) = 17.7348 
        henke(79,3, 184 ) = 4.53523 
        henke(79,1, 185 ) = 141.175 
        henke(79,2, 185 ) = 17.4516 
        henke(79,3, 185 ) = 4.47639 
        henke(79,1, 186 ) = 143.458 
        henke(79,2, 186 ) = 17.1516 
        henke(79,3, 186 ) = 4.41832 
        henke(79,1, 187 ) = 145.779 
        henke(79,2, 187 ) = 16.8125 
        henke(79,3, 187 ) = 4.41244 
        henke(79,1, 188 ) = 148.137 
        henke(79,2, 188 ) = 16.5025 
        henke(79,3, 188 ) = 4.4549 
        henke(79,1, 189 ) = 150.533 
        henke(79,2, 189 ) = 16.2086 
        henke(79,3, 189 ) = 4.49777 
        henke(79,1, 190 ) = 152.967 
        henke(79,2, 190 ) = 15.9195 
        henke(79,3, 190 ) = 4.54105 
        henke(79,1, 191 ) = 155.441 
        henke(79,2, 191 ) = 15.584 
        henke(79,3, 191 ) = 4.58475 
        henke(79,1, 192 ) = 157.956 
        henke(79,2, 192 ) = 15.2275 
        henke(79,3, 192 ) = 4.64453 
        henke(79,1, 193 ) = 160.51 
        henke(79,2, 193 ) = 14.8771 
        henke(79,3, 193 ) = 4.79755 
        henke(79,1, 194 ) = 163.107 
        henke(79,2, 194 ) = 14.5507 
        henke(79,3, 194 ) = 4.95562 
        henke(79,1, 195 ) = 165.745 
        henke(79,2, 195 ) = 14.2265 
        henke(79,3, 195 ) = 5.11889 
        henke(79,1, 196 ) = 168.425 
        henke(79,2, 196 ) = 13.881 
        henke(79,3, 196 ) = 5.28753 
        henke(79,1, 197 ) = 171.15 
        henke(79,2, 197 ) = 13.5076 
        henke(79,3, 197 ) = 5.50654 
        henke(79,1, 198 ) = 173.918 
        henke(79,2, 198 ) = 13.1561 
        henke(79,3, 198 ) = 5.81347 
        henke(79,1, 199 ) = 176.731 
        henke(79,2, 199 ) = 12.8307 
        henke(79,3, 199 ) = 6.13751 
        henke(79,1, 200 ) = 179.589 
        henke(79,2, 200 ) = 12.5409 
        henke(79,3, 200 ) = 6.47961 
        henke(79,1, 201 ) = 182.494 
        henke(79,2, 201 ) = 12.2643 
        henke(79,3, 201 ) = 6.84079 
        henke(79,1, 202 ) = 185.446 
        henke(79,2, 202 ) = 12.0048 
        henke(79,3, 202 ) = 7.22473 
        henke(79,1, 203 ) = 188.445 
        henke(79,2, 203 ) = 11.7606 
        henke(79,3, 203 ) = 7.63208 
        henke(79,1, 204 ) = 191.493 
        henke(79,2, 204 ) = 11.5355 
        henke(79,3, 204 ) = 8.0624 
        henke(79,1, 205 ) = 194.59 
        henke(79,2, 205 ) = 11.3323 
        henke(79,3, 205 ) = 8.51697 
        henke(79,1, 206 ) = 197.738 
        henke(79,2, 206 ) = 11.1556 
        henke(79,3, 206 ) = 8.99718 
        henke(79,1, 207 ) = 200.936 
        henke(79,2, 207 ) = 11.0174 
        henke(79,3, 207 ) = 9.49691 
        henke(79,1, 208 ) = 204.186 
        henke(79,2, 208 ) = 10.905 
        henke(79,3, 208 ) = 9.99765 
        henke(79,1, 209 ) = 207.488 
        henke(79,2, 209 ) = 10.8104 
        henke(79,3, 209 ) = 10.5248 
        henke(79,1, 210 ) = 210.844 
        henke(79,2, 210 ) = 10.7755 
        henke(79,3, 210 ) = 11.0798 
        henke(79,1, 211 ) = 214.255 
        henke(79,2, 211 ) = 10.7835 
        henke(79,3, 211 ) = 11.6561 
        henke(79,1, 212 ) = 217.72 
        henke(79,2, 212 ) = 10.8392 
        henke(79,3, 212 ) = 12.1158 
        henke(79,1, 213 ) = 221.241 
        henke(79,2, 213 ) = 10.8665 
        henke(79,3, 213 ) = 12.5937 
        henke(79,1, 214 ) = 224.82 
        henke(79,2, 214 ) = 10.897 
        henke(79,3, 214 ) = 13.0903 
        henke(79,1, 215 ) = 228.456 
        henke(79,2, 215 ) = 10.942 
        henke(79,3, 215 ) = 13.6066 
        henke(79,1, 216 ) = 232.151 
        henke(79,2, 216 ) = 11.052 
        henke(79,3, 216 ) = 14.1432 
        henke(79,1, 217 ) = 235.906 
        henke(79,2, 217 ) = 11.1874 
        henke(79,3, 217 ) = 14.6383 
        henke(79,1, 218 ) = 239.722 
        henke(79,2, 218 ) = 11.3103 
        henke(79,3, 218 ) = 15.1205 
        henke(79,1, 219 ) = 243.599 
        henke(79,2, 219 ) = 11.4342 
        henke(79,3, 219 ) = 15.6187 
        henke(79,1, 220 ) = 247.539 
        henke(79,2, 220 ) = 11.5822 
        henke(79,3, 220 ) = 16.1333 
        henke(79,1, 221 ) = 251.543 
        henke(79,2, 221 ) = 11.7833 
        henke(79,3, 221 ) = 16.6648 
        henke(79,1, 222 ) = 255.611 
        henke(79,2, 222 ) = 11.9915 
        henke(79,3, 222 ) = 17.135 
        henke(79,1, 223 ) = 259.745 
        henke(79,2, 223 ) = 12.2034 
        henke(79,3, 223 ) = 17.6104 
        henke(79,1, 224 ) = 263.947 
        henke(79,2, 224 ) = 12.4216 
        henke(79,3, 224 ) = 18.0989 
        henke(79,1, 225 ) = 268.216 
        henke(79,2, 225 ) = 12.6827 
        henke(79,3, 225 ) = 18.601 
        henke(79,1, 226 ) = 272.554 
        henke(79,2, 226 ) = 12.9827 
        henke(79,3, 226 ) = 19.117 
        henke(79,1, 227 ) = 276.962 
        henke(79,2, 227 ) = 13.3236 
        henke(79,3, 227 ) = 19.5633 
        henke(79,1, 228 ) = 281.442 
        henke(79,2, 228 ) = 13.6572 
        henke(79,3, 228 ) = 19.9466 
        henke(79,1, 229 ) = 285.994 
        henke(79,2, 229 ) = 13.9592 
        henke(79,3, 229 ) = 20.3374 
        henke(79,1, 230 ) = 290.62 
        henke(79,2, 230 ) = 14.2574 
        henke(79,3, 230 ) = 20.7358 
        henke(79,1, 231 ) = 295.32 
        henke(79,2, 231 ) = 14.5594 
        henke(79,3, 231 ) = 21.1421 
        henke(79,1, 232 ) = 300.097 
        henke(79,2, 232 ) = 14.8722 
        henke(79,3, 232 ) = 21.5563 
        henke(79,1, 233 ) = 304.951 
        henke(79,2, 233 ) = 15.2033 
        henke(79,3, 233 ) = 21.9786 
        henke(79,1, 234 ) = 309.883 
        henke(79,2, 234 ) = 15.5677 
        henke(79,3, 234 ) = 22.4092 
        henke(79,1, 235 ) = 314.895 
        henke(79,2, 235 ) = 15.9533 
        henke(79,3, 235 ) = 22.7884 
        henke(79,1, 236 ) = 319.988 
        henke(79,2, 236 ) = 16.341 
        henke(79,3, 236 ) = 23.157 
        henke(79,1, 237 ) = 325.164 
        henke(79,2, 237 ) = 16.7109 
        henke(79,3, 237 ) = 23.5316 
        henke(79,1, 238 ) = 330.423 
        henke(79,2, 238 ) = 17.0928 
        henke(79,3, 238 ) = 23.9122 
        henke(79,1, 239 ) = 335.767 
        henke(79,2, 239 ) = 17.4898 
        henke(79,3, 239 ) = 24.2989 
        henke(79,1, 240 ) = 341.198 
        henke(79,2, 240 ) = 17.912 
        henke(79,3, 240 ) = 24.6919 
        henke(79,1, 241 ) = 346.717 
        henke(79,2, 241 ) = 18.3841 
        henke(79,3, 241 ) = 25.0913 
        henke(79,1, 242 ) = 352.325 
        henke(79,2, 242 ) = 18.8883 
        henke(79,3, 242 ) = 25.4934 
        henke(79,1, 243 ) = 358.023 
        henke(79,2, 243 ) = 19.4299 
        henke(79,3, 243 ) = 25.7447 
        henke(79,1, 244 ) = 363.814 
        henke(79,2, 244 ) = 19.9195 
        henke(79,3, 244 ) = 25.9984 
        henke(79,1, 245 ) = 369.698 
        henke(79,2, 245 ) = 20.3928 
        henke(79,3, 245 ) = 26.2547 
        henke(79,1, 246 ) = 375.678 
        henke(79,2, 246 ) = 20.8623 
        henke(79,3, 246 ) = 26.5135 
        henke(79,1, 247 ) = 381.754 
        henke(79,2, 247 ) = 21.3345 
        henke(79,3, 247 ) = 26.7748 
        henke(79,1, 248 ) = 387.929 
        henke(79,2, 248 ) = 21.8146 
        henke(79,3, 248 ) = 27.0387 
        henke(79,1, 249 ) = 394.203 
        henke(79,2, 249 ) = 22.3046 
        henke(79,3, 249 ) = 27.3052 
        henke(79,1, 250 ) = 400.579 
        henke(79,2, 250 ) = 22.8731 
        henke(79,3, 250 ) = 27.5744 
        henke(79,1, 251 ) = 407.058 
        henke(79,2, 251 ) = 23.4568 
        henke(79,3, 251 ) = 27.759 
        henke(79,1, 252 ) = 413.642 
        henke(79,2, 252 ) = 23.9925 
        henke(79,3, 252 ) = 27.9019 
        henke(79,1, 253 ) = 420.332 
        henke(79,2, 253 ) = 24.4957 
        henke(79,3, 253 ) = 28.0454 
        henke(79,1, 254 ) = 427.131 
        henke(79,2, 254 ) = 24.9921 
        henke(79,3, 254 ) = 28.1897 
        henke(79,1, 255 ) = 434.039 
        henke(79,2, 255 ) = 25.4842 
        henke(79,3, 255 ) = 28.3347 
        henke(79,1, 256 ) = 441.06 
        henke(79,2, 256 ) = 25.9866 
        henke(79,3, 256 ) = 28.4805 
        henke(79,1, 257 ) = 448.193 
        henke(79,2, 257 ) = 26.4959 
        henke(79,3, 257 ) = 28.627 
        henke(79,1, 258 ) = 455.443 
        henke(79,2, 258 ) = 27.0173 
        henke(79,3, 258 ) = 28.7422 
        henke(79,1, 259 ) = 462.809 
        henke(79,2, 259 ) = 27.5245 
        henke(79,3, 259 ) = 28.8271 
        henke(79,1, 260 ) = 470.295 
        henke(79,2, 260 ) = 28.0127 
        henke(79,3, 260 ) = 28.9122 
        henke(79,1, 261 ) = 477.901 
        henke(79,2, 261 ) = 28.4927 
        henke(79,3, 261 ) = 28.9975 
        henke(79,1, 262 ) = 485.631 
        henke(79,2, 262 ) = 28.9679 
        henke(79,3, 262 ) = 29.0831 
        henke(79,1, 263 ) = 493.486 
        henke(79,2, 263 ) = 29.4407 
        henke(79,3, 263 ) = 29.1689 
        henke(79,1, 264 ) = 501.467 
        henke(79,2, 264 ) = 29.9135 
        henke(79,3, 264 ) = 29.255 
        henke(79,1, 265 ) = 509.578 
        henke(79,2, 265 ) = 30.3896 
        henke(79,3, 265 ) = 29.3414 
        henke(79,1, 266 ) = 517.82 
        henke(79,2, 266 ) = 30.8679 
        henke(79,3, 266 ) = 29.4179 
        henke(79,1, 267 ) = 526.196 
        henke(79,2, 267 ) = 31.345 
        henke(79,3, 267 ) = 29.4914 
        henke(79,1, 268 ) = 534.706 
        henke(79,2, 268 ) = 31.8181 
        henke(79,3, 268 ) = 29.565 
        henke(79,1, 269 ) = 543.355 
        henke(79,2, 269 ) = 32.2934 
        henke(79,3, 269 ) = 29.6388 
        henke(79,1, 270 ) = 552.143 
        henke(79,2, 270 ) = 32.772 
        henke(79,3, 270 ) = 29.7128 
        henke(79,1, 271 ) = 561.074 
        henke(79,2, 271 ) = 33.258 
        henke(79,3, 271 ) = 29.787 
        henke(79,1, 272 ) = 570.148 
        henke(79,2, 272 ) = 33.7579 
        henke(79,3, 272 ) = 29.8572 
        henke(79,1, 273 ) = 579.37 
        henke(79,2, 273 ) = 34.2603 
        henke(79,3, 273 ) = 29.9098 
        henke(79,1, 274 ) = 588.741 
        henke(79,2, 274 ) = 34.7558 
        henke(79,3, 274 ) = 29.9624 
        henke(79,1, 275 ) = 598.263 
        henke(79,2, 275 ) = 35.2555 
        henke(79,3, 275 ) = 30.0151 
        henke(79,1, 276 ) = 607.94 
        henke(79,2, 276 ) = 35.7621 
        henke(79,3, 276 ) = 30.0679 
        henke(79,1, 277 ) = 617.773 
        henke(79,2, 277 ) = 36.2787 
        henke(79,3, 277 ) = 30.1208 
        henke(79,1, 278 ) = 627.765 
        henke(79,2, 278 ) = 36.8097 
        henke(79,3, 278 ) = 30.1738 
        henke(79,1, 279 ) = 637.918 
        henke(79,2, 279 ) = 37.3636 
        henke(79,3, 279 ) = 30.2269 
        henke(79,1, 280 ) = 648.236 
        henke(79,2, 280 ) = 37.9693 
        henke(79,3, 280 ) = 30.2801 
        henke(79,1, 281 ) = 658.721 
        henke(79,2, 281 ) = 38.5956 
        henke(79,3, 281 ) = 30.2413 
        henke(79,1, 282 ) = 669.375 
        henke(79,2, 282 ) = 39.2069 
        henke(79,3, 282 ) = 30.1231 
        henke(79,1, 283 ) = 680.202 
        henke(79,2, 283 ) = 39.7605 
        henke(79,3, 283 ) = 30.0053 
        henke(79,1, 284 ) = 691.203 
        henke(79,2, 284 ) = 40.2827 
        henke(79,3, 284 ) = 29.888 
        henke(79,1, 285 ) = 702.383 
        henke(79,2, 285 ) = 40.7916 
        henke(79,3, 285 ) = 29.7712 
        henke(79,1, 286 ) = 713.744 
        henke(79,2, 286 ) = 41.2894 
        henke(79,3, 286 ) = 29.6548 
        henke(79,1, 287 ) = 725.288 
        henke(79,2, 287 ) = 41.7755 
        henke(79,3, 287 ) = 29.5388 
        henke(79,1, 288 ) = 737.019 
        henke(79,2, 288 ) = 42.2569 
        henke(79,3, 288 ) = 29.4357 
        henke(79,1, 289 ) = 748.94 
        henke(79,2, 289 ) = 42.7413 
        henke(79,3, 289 ) = 29.3333 
        henke(79,1, 290 ) = 761.053 
        henke(79,2, 290 ) = 43.231 
        henke(79,3, 290 ) = 29.2313 
        henke(79,1, 291 ) = 773.363 
        henke(79,2, 291 ) = 43.7263 
        henke(79,3, 291 ) = 29.1296 
        henke(79,1, 292 ) = 785.871 
        henke(79,2, 292 ) = 44.2345 
        henke(79,3, 292 ) = 29.0283 
        henke(79,1, 293 ) = 798.582 
        henke(79,2, 293 ) = 44.766 
        henke(79,3, 293 ) = 28.927 
        henke(79,1, 294 ) = 811.498 
        henke(79,2, 294 ) = 45.3015 
        henke(79,3, 294 ) = 28.7521 
        henke(79,1, 295 ) = 824.624 
        henke(79,2, 295 ) = 45.8244 
        henke(79,3, 295 ) = 28.5782 
        henke(79,1, 296 ) = 837.961 
        henke(79,2, 296 ) = 46.3241 
        henke(79,3, 296 ) = 28.4055 
        henke(79,1, 297 ) = 851.515 
        henke(79,2, 297 ) = 46.8314 
        henke(79,3, 297 ) = 28.2337 
        henke(79,1, 298 ) = 865.287 
        henke(79,2, 298 ) = 47.3573 
        henke(79,3, 298 ) = 28.063 
        henke(79,1, 299 ) = 879.283 
        henke(79,2, 299 ) = 47.9211 
        henke(79,3, 299 ) = 27.8879 
        henke(79,1, 300 ) = 893.504 
        henke(79,2, 300 ) = 48.4693 
        henke(79,3, 300 ) = 27.5751 
        henke(79,1, 301 ) = 907.956 
        henke(79,2, 301 ) = 48.9892 
        henke(79,3, 301 ) = 27.2658 
        henke(79,1, 302 ) = 922.641 
        henke(79,2, 302 ) = 49.4553 
        henke(79,3, 302 ) = 26.96 
        henke(79,1, 303 ) = 937.564 
        henke(79,2, 303 ) = 49.9126 
        henke(79,3, 303 ) = 26.6576 
        henke(79,1, 304 ) = 952.729 
        henke(79,2, 304 ) = 50.3692 
        henke(79,3, 304 ) = 26.3586 
        henke(79,1, 305 ) = 968.138 
        henke(79,2, 305 ) = 50.8412 
        henke(79,3, 305 ) = 26.0205 
        henke(79,1, 306 ) = 983.797 
        henke(79,2, 306 ) = 51.2684 
        henke(79,3, 306 ) = 25.6646 
        henke(79,1, 307 ) = 999.709 
        henke(79,2, 307 ) = 51.6763 
        henke(79,3, 307 ) = 25.3137 
        henke(79,1, 308 ) = 1015.88 
        henke(79,2, 308 ) = 52.0824 
        henke(79,3, 308 ) = 24.9676 
        henke(79,1, 309 ) = 1032.31 
        henke(79,2, 309 ) = 52.5523 
        henke(79,3, 309 ) = 24.6262 
        henke(79,1, 310 ) = 1049.01 
        henke(79,2, 310 ) = 53.0057 
        henke(79,3, 310 ) = 24.1725 
        henke(79,1, 311 ) = 1065.97 
        henke(79,2, 311 ) = 53.3737 
        henke(79,3, 311 ) = 23.6657 
        henke(79,1, 312 ) = 1083.21 
        henke(79,2, 312 ) = 53.6758 
        henke(79,3, 312 ) = 23.1695 
        henke(79,1, 313 ) = 1100.73 
        henke(79,2, 313 ) = 53.9376 
        henke(79,3, 313 ) = 22.6837 
        henke(79,1, 314 ) = 1118.54 
        henke(79,2, 314 ) = 54.1661 
        henke(79,3, 314 ) = 22.2081 
        henke(79,1, 315 ) = 1136.63 
        henke(79,2, 315 ) = 54.3659 
        henke(79,3, 315 ) = 21.7425 
        henke(79,1, 316 ) = 1155.01 
        henke(79,2, 316 ) = 54.5394 
        henke(79,3, 316 ) = 21.2862 
        henke(79,1, 317 ) = 1173.7 
        henke(79,2, 317 ) = 54.6876 
        henke(79,3, 317 ) = 20.8393 
        henke(79,1, 318 ) = 1192.68 
        henke(79,2, 318 ) = 54.8083 
        henke(79,3, 318 ) = 20.4018 
        henke(79,1, 319 ) = 1211.97 
        henke(79,2, 319 ) = 54.9012 
        henke(79,3, 319 ) = 19.9735 
        henke(79,1, 320 ) = 1231.57 
        henke(79,2, 320 ) = 54.9452 
        henke(79,3, 320 ) = 19.5716 
        henke(79,1, 321 ) = 1251.49 
        henke(79,2, 321 ) = 55.001 
        henke(79,3, 321 ) = 19.2373 
        henke(79,1, 322 ) = 1271.73 
        henke(79,2, 322 ) = 55.0744 
        henke(79,3, 322 ) = 18.9088 
        henke(79,1, 323 ) = 1292.3 
        henke(79,2, 323 ) = 55.1542 
        henke(79,3, 323 ) = 18.5858 
        henke(79,1, 324 ) = 1313.2 
        henke(79,2, 324 ) = 55.2534 
        henke(79,3, 324 ) = 18.2684 
        henke(79,1, 325 ) = 1334.44 
        henke(79,2, 325 ) = 55.3503 
        henke(79,3, 325 ) = 17.8975 
        henke(79,1, 326 ) = 1356.03 
        henke(79,2, 326 ) = 55.4186 
        henke(79,3, 326 ) = 17.5235 
        henke(79,1, 327 ) = 1377.96 
        henke(79,2, 327 ) = 55.4434 
        henke(79,3, 327 ) = 17.1573 
        henke(79,1, 328 ) = 1400.25 
        henke(79,2, 328 ) = 55.4509 
        henke(79,3, 328 ) = 16.7988 
        henke(79,1, 329 ) = 1422.9 
        henke(79,2, 329 ) = 55.4304 
        henke(79,3, 329 ) = 16.4477 
        henke(79,1, 330 ) = 1445.91 
        henke(79,2, 330 ) = 55.3923 
        henke(79,3, 330 ) = 16.1606 
        henke(79,1, 331 ) = 1460 
        henke(79,2, 331 ) = 55.3927 
        henke(79,3, 331 ) = 15.9948 
        henke(79,1, 332 ) = 1483.61 
        henke(79,2, 332 ) = 55.4252 
        henke(79,3, 332 ) = 15.7206 
        henke(79,1, 333 ) = 1507.61 
        henke(79,2, 333 ) = 55.5477 
        henke(79,3, 333 ) = 15.3391 
        henke(79,1, 334 ) = 1531.99 
        henke(79,2, 334 ) = 55.4832 
        henke(79,3, 334 ) = 14.8501 
        henke(79,1, 335 ) = 1556.77 
        henke(79,2, 335 ) = 55.328 
        henke(79,3, 335 ) = 14.4348 
        henke(79,1, 336 ) = 1569.65 
        henke(79,2, 336 ) = 55.2197 
        henke(79,3, 336 ) = 14.2264 
        henke(79,1, 337 ) = 1595.04 
        henke(79,2, 337 ) = 55.0224 
        henke(79,3, 337 ) = 13.9403 
        henke(79,1, 338 ) = 1620.84 
        henke(79,2, 338 ) = 54.8606 
        henke(79,3, 338 ) = 13.6537 
        henke(79,1, 339 ) = 1644.49 
        henke(79,2, 339 ) = 54.7161 
        henke(79,3, 339 ) = 13.3951 
        henke(79,1, 340 ) = 1671.09 
        henke(79,2, 340 ) = 54.524 
        henke(79,3, 340 ) = 13.0404 
        henke(79,1, 341 ) = 1698.12 
        henke(79,2, 341 ) = 54.2385 
        henke(79,3, 341 ) = 12.7386 
        henke(79,1, 342 ) = 1725.58 
        henke(79,2, 342 ) = 53.961 
        henke(79,3, 342 ) = 12.4973 
        henke(79,1, 343 ) = 1753.49 
        henke(79,2, 343 ) = 53.6692 
        henke(79,3, 343 ) = 12.2062 
        henke(79,1, 344 ) = 1765.07 
        henke(79,2, 344 ) = 53.5141 
        henke(79,3, 344 ) = 12.0869 
        henke(79,1, 345 ) = 1793.62 
        henke(79,2, 345 ) = 53.1447 
        henke(79,3, 345 ) = 11.9481 
        henke(79,1, 346 ) = 1822.63 
        henke(79,2, 346 ) = 52.89 
        henke(79,3, 346 ) = 11.7352 
        henke(79,1, 347 ) = 1852.11 
        henke(79,2, 347 ) = 52.4935 
        henke(79,3, 347 ) = 11.4654 
        henke(79,1, 348 ) = 1882.06 
        henke(79,2, 348 ) = 52.0502 
        henke(79,3, 348 ) = 11.2923 
        henke(79,1, 349 ) = 1910.6 
        henke(79,2, 349 ) = 51.6659 
        henke(79,3, 349 ) = 11.147 
        henke(79,1, 350 ) = 1941.5 
        henke(79,2, 350 ) = 51.2565 
        henke(79,3, 350 ) = 10.8525 
        henke(79,1, 351 ) = 1972.9 
        henke(79,2, 351 ) = 50.6391 
        henke(79,3, 351 ) = 10.5759 
        henke(79,1, 352 ) = 2004.81 
        henke(79,2, 352 ) = 49.9354 
        henke(79,3, 352 ) = 10.3718 
        henke(79,1, 353 ) = 2037.24 
        henke(79,2, 353 ) = 49.1457 
        henke(79,3, 353 ) = 10.1656 
        henke(79,1, 354 ) = 2040 
        henke(79,2, 354 ) = 49.0741 
        henke(79,3, 354 ) = 10.1467 
        henke(79,1, 355 ) = 2050 
        henke(79,2, 355 ) = 48.8118 
        henke(79,3, 355 ) = 10.0734 
        henke(79,1, 356 ) = 2060 
        henke(79,2, 356 ) = 48.5136 
        henke(79,3, 356 ) = 9.99988 
        henke(79,1, 357 ) = 2070 
        henke(79,2, 357 ) = 48.2142 
        henke(79,3, 357 ) = 9.92662 
        henke(79,1, 358 ) = 2080 
        henke(79,2, 358 ) = 47.8789 
        henke(79,3, 358 ) = 9.85521 
        henke(79,1, 359 ) = 2090 
        henke(79,2, 359 ) = 47.5399 
        henke(79,3, 359 ) = 9.78116 
        henke(79,1, 360 ) = 2100 
        henke(79,2, 360 ) = 47.1578 
        henke(79,3, 360 ) = 9.70603 
        henke(79,1, 361 ) = 2110 
        henke(79,2, 361 ) = 46.7638 
        henke(79,3, 361 ) = 9.63185 
        henke(79,1, 362 ) = 2120 
        henke(79,2, 362 ) = 46.3209 
        henke(79,3, 362 ) = 9.55828 
        henke(79,1, 363 ) = 2130 
        henke(79,2, 363 ) = 45.8589 
        henke(79,3, 363 ) = 9.4851 
        henke(79,1, 364 ) = 2140 
        henke(79,2, 364 ) = 45.3347 
        henke(79,3, 364 ) = 9.40883 
        henke(79,1, 365 ) = 2150 
        henke(79,2, 365 ) = 44.7669 
        henke(79,3, 365 ) = 9.33334 
        henke(79,1, 366 ) = 2160 
        henke(79,2, 366 ) = 44.1305 
        henke(79,3, 366 ) = 9.27955 
        henke(79,1, 367 ) = 2170 
        henke(79,2, 367 ) = 43.4332 
        henke(79,3, 367 ) = 9.20417 
        henke(79,1, 368 ) = 2180 
        henke(79,2, 368 ) = 42.6153 
        henke(79,3, 368 ) = 9.13237 
        henke(79,1, 369 ) = 2185 
        henke(79,2, 369 ) = 42.1579 
        henke(79,3, 369 ) = 9.09387 
        henke(79,1, 370 ) = 2190 
        henke(79,2, 370 ) = 41.6462 
        henke(79,3, 370 ) = 9.0541 
        henke(79,1, 371 ) = 2195 
        henke(79,2, 371 ) = 41.078 
        henke(79,3, 371 ) = 9.02122 
        henke(79,1, 372 ) = 2200 
        henke(79,2, 372 ) = 40.4204 
        henke(79,3, 372 ) = 8.98676 
        henke(79,1, 373 ) = 2205 
        henke(79,2, 373 ) = 39.6202 
        henke(79,3, 373 ) = 8.98507 
        henke(79,1, 374 ) = 2210 
        henke(79,2, 374 ) = 38.7304 
        henke(79,3, 374 ) = 9.13812 
        henke(79,1, 375 ) = 2215 
        henke(79,2, 375 ) = 37.715 
        henke(79,3, 375 ) = 9.38026 
        henke(79,1, 376 ) = 2220 
        henke(79,2, 376 ) = 36.6921 
        henke(79,3, 376 ) = 9.85594 
        henke(79,1, 377 ) = 2225 
        henke(79,2, 377 ) = 35.6061 
        henke(79,3, 377 ) = 10.4937 
        henke(79,1, 378 ) = 2230 
        henke(79,2, 378 ) = 34.2591 
        henke(79,3, 378 ) = 11.1227 
        henke(79,1, 379 ) = 2235 
        henke(79,2, 379 ) = 33.0536 
        henke(79,3, 379 ) = 12.9855 
        henke(79,1, 380 ) = 2240 
        henke(79,2, 380 ) = 32.5161 
        henke(79,3, 380 ) = 14.7769 
        henke(79,1, 381 ) = 2245 
        henke(79,2, 381 ) = 32.7913 
        henke(79,3, 381 ) = 17.0623 
        henke(79,1, 382 ) = 2250 
        henke(79,2, 382 ) = 33.6453 
        henke(79,3, 382 ) = 18.3125 
        henke(79,1, 383 ) = 2255 
        henke(79,2, 383 ) = 34.6485 
        henke(79,3, 383 ) = 19.3367 
        henke(79,1, 384 ) = 2260 
        henke(79,2, 384 ) = 35.2123 
        henke(79,3, 384 ) = 19.3867 
        henke(79,1, 385 ) = 2265 
        henke(79,2, 385 ) = 35.5623 
        henke(79,3, 385 ) = 20.0891 
        henke(79,1, 386 ) = 2270 
        henke(79,2, 386 ) = 36.1366 
        henke(79,3, 386 ) = 20.658 
        henke(79,1, 387 ) = 2275 
        henke(79,2, 387 ) = 36.4533 
        henke(79,3, 387 ) = 20.4893 
        henke(79,1, 388 ) = 2280 
        henke(79,2, 388 ) = 36.5726 
        henke(79,3, 388 ) = 21.1916 
        henke(79,1, 389 ) = 2285 
        henke(79,2, 389 ) = 37.2124 
        henke(79,3, 389 ) = 21.634 
        henke(79,1, 390 ) = 2290 
        henke(79,2, 390 ) = 37.6465 
        henke(79,3, 390 ) = 21.4403 
        henke(79,1, 391 ) = 2295 
        henke(79,2, 391 ) = 37.6558 
        henke(79,3, 391 ) = 21.1536 
        henke(79,1, 392 ) = 2300 
        henke(79,2, 392 ) = 37.2657 
        henke(79,3, 392 ) = 21.1858 
        henke(79,1, 393 ) = 2305 
        henke(79,2, 393 ) = 36.9617 
        henke(79,3, 393 ) = 21.4784 
        henke(79,1, 394 ) = 2310 
        henke(79,2, 394 ) = 36.5778 
        henke(79,3, 394 ) = 21.8761 
        henke(79,1, 395 ) = 2315 
        henke(79,2, 395 ) = 35.9795 
        henke(79,3, 395 ) = 22.0744 
        henke(79,1, 396 ) = 2320 
        henke(79,2, 396 ) = 35.2904 
        henke(79,3, 396 ) = 23.3464 
        henke(79,1, 397 ) = 2325 
        henke(79,2, 397 ) = 35.0279 
        henke(79,3, 397 ) = 24.5113 
        henke(79,1, 398 ) = 2330 
        henke(79,2, 398 ) = 35.3701 
        henke(79,3, 398 ) = 26.5 
        henke(79,1, 399 ) = 2335 
        henke(79,2, 399 ) = 36.4235 
        henke(79,3, 399 ) = 27.5154 
        henke(79,1, 400 ) = 2340 
        henke(79,2, 400 ) = 37.5253 
        henke(79,3, 400 ) = 28.3368 
        henke(79,1, 401 ) = 2345 
        henke(79,2, 401 ) = 38.4117 
        henke(79,3, 401 ) = 28.4065 
        henke(79,1, 402 ) = 2350 
        henke(79,2, 402 ) = 38.988 
        henke(79,3, 402 ) = 28.7257 
        henke(79,1, 403 ) = 2355 
        henke(79,2, 403 ) = 39.661 
        henke(79,3, 403 ) = 29.1296 
        henke(79,1, 404 ) = 2360 
        henke(79,2, 404 ) = 40.0949 
        henke(79,3, 404 ) = 29.0613 
        henke(79,1, 405 ) = 2365 
        henke(79,2, 405 ) = 40.4729 
        henke(79,3, 405 ) = 29.6374 
        henke(79,1, 406 ) = 2370 
        henke(79,2, 406 ) = 41.2825 
        henke(79,3, 406 ) = 30.1604 
        henke(79,1, 407 ) = 2375 
        henke(79,2, 407 ) = 42.1997 
        henke(79,3, 407 ) = 30.0968 
        henke(79,1, 408 ) = 2380 
        henke(79,2, 408 ) = 42.7211 
        henke(79,3, 408 ) = 29.7825 
        henke(79,1, 409 ) = 2390 
        henke(79,2, 409 ) = 43.2848 
        henke(79,3, 409 ) = 29.8701 
        henke(79,1, 410 ) = 2400 
        henke(79,2, 410 ) = 43.9676 
        henke(79,3, 410 ) = 30.1531 
        henke(79,1, 411 ) = 2410 
        henke(79,2, 411 ) = 44.7915 
        henke(79,3, 411 ) = 30.2517 
        henke(79,1, 412 ) = 2420 
        henke(79,2, 412 ) = 45.6264 
        henke(79,3, 412 ) = 30.3987 
        henke(79,1, 413 ) = 2430 
        henke(79,2, 413 ) = 46.3711 
        henke(79,3, 413 ) = 30.0955 
        henke(79,1, 414 ) = 2440 
        henke(79,2, 414 ) = 46.7293 
        henke(79,3, 414 ) = 29.9068 
        henke(79,1, 415 ) = 2450 
        henke(79,2, 415 ) = 47.0795 
        henke(79,3, 415 ) = 30.0104 
        henke(79,1, 416 ) = 2460 
        henke(79,2, 416 ) = 47.588 
        henke(79,3, 416 ) = 30.2209 
        henke(79,1, 417 ) = 2470 
        henke(79,2, 417 ) = 48.1265 
        henke(79,3, 417 ) = 30.0953 
        henke(79,1, 418 ) = 2480 
        henke(79,2, 418 ) = 48.5999 
        henke(79,3, 418 ) = 30.2073 
        henke(79,1, 419 ) = 2490 
        henke(79,2, 419 ) = 49.1771 
        henke(79,3, 419 ) = 30.1297 
        henke(79,1, 420 ) = 2500 
        henke(79,2, 420 ) = 49.6242 
        henke(79,3, 420 ) = 29.934 
        henke(79,1, 421 ) = 2510 
        henke(79,2, 421 ) = 49.9268 
        henke(79,3, 421 ) = 29.7243 
        henke(79,1, 422 ) = 2520 
        henke(79,2, 422 ) = 50.098 
        henke(79,3, 422 ) = 29.6467 
        henke(79,1, 423 ) = 2530 
        henke(79,2, 423 ) = 50.3693 
        henke(79,3, 423 ) = 29.761 
        henke(79,1, 424 ) = 2540 
        henke(79,2, 424 ) = 50.7568 
        henke(79,3, 424 ) = 29.8216 
        henke(79,1, 425 ) = 2550 
        henke(79,2, 425 ) = 51.2088 
        henke(79,3, 425 ) = 29.7469 
        henke(79,1, 426 ) = 2560 
        henke(79,2, 426 ) = 51.5396 
        henke(79,3, 426 ) = 29.5667 
        henke(79,1, 427 ) = 2570 
        henke(79,2, 427 ) = 51.8508 
        henke(79,3, 427 ) = 29.4474 
        henke(79,1, 428 ) = 2580 
        henke(79,2, 428 ) = 52.0714 
        henke(79,3, 428 ) = 29.2483 
        henke(79,1, 429 ) = 2590 
        henke(79,2, 429 ) = 52.2419 
        henke(79,3, 429 ) = 29.0804 
        henke(79,1, 430 ) = 2600 
        henke(79,2, 430 ) = 52.3126 
        henke(79,3, 430 ) = 29.0014 
        henke(79,1, 431 ) = 2610 
        henke(79,2, 431 ) = 52.5325 
        henke(79,3, 431 ) = 29.0098 
        henke(79,1, 432 ) = 2620 
        henke(79,2, 432 ) = 52.7297 
        henke(79,3, 432 ) = 28.9059 
        henke(79,1, 433 ) = 2630 
        henke(79,2, 433 ) = 52.6004 
        henke(79,3, 433 ) = 28.4695 
        henke(79,1, 434 ) = 2640 
        henke(79,2, 434 ) = 52.5201 
        henke(79,3, 434 ) = 29.0275 
        henke(79,1, 435 ) = 2650 
        henke(79,2, 435 ) = 52.9392 
        henke(79,3, 435 ) = 29.1857 
        henke(79,1, 436 ) = 2660 
        henke(79,2, 436 ) = 53.2562 
        henke(79,3, 436 ) = 29.0391 
        henke(79,1, 437 ) = 2670 
        henke(79,2, 437 ) = 53.4162 
        henke(79,3, 437 ) = 28.8747 
        henke(79,1, 438 ) = 2680 
        henke(79,2, 438 ) = 53.4628 
        henke(79,3, 438 ) = 28.7642 
        henke(79,1, 439 ) = 2690 
        henke(79,2, 439 ) = 53.4951 
        henke(79,3, 439 ) = 28.6889 
        henke(79,1, 440 ) = 2700 
        henke(79,2, 440 ) = 53.4811 
        henke(79,3, 440 ) = 28.6482 
        henke(79,1, 441 ) = 2710 
        henke(79,2, 441 ) = 53.4457 
        henke(79,3, 441 ) = 28.5653 
        henke(79,1, 442 ) = 2720 
        henke(79,2, 442 ) = 53.2223 
        henke(79,3, 442 ) = 28.4715 
        henke(79,1, 443 ) = 2730 
        henke(79,2, 443 ) = 52.7713 
        henke(79,3, 443 ) = 28.4443 
        henke(79,1, 444 ) = 2735 
        henke(79,2, 444 ) = 52.252 
        henke(79,3, 444 ) = 28.5401 
        henke(79,1, 445 ) = 2740 
        henke(79,2, 445 ) = 51.4858 
        henke(79,3, 445 ) = 28.9205 
        henke(79,1, 446 ) = 2745 
        henke(79,2, 446 ) = 51.3036 
        henke(79,3, 446 ) = 30.479 
        henke(79,1, 447 ) = 2750 
        henke(79,2, 447 ) = 52.1564 
        henke(79,3, 447 ) = 31.5437 
        henke(79,1, 448 ) = 2755 
        henke(79,2, 448 ) = 52.9767 
        henke(79,3, 448 ) = 31.5357 
        henke(79,1, 449 ) = 2760 
        henke(79,2, 449 ) = 53.3775 
        henke(79,3, 449 ) = 31.5947 
        henke(79,1, 450 ) = 2765 
        henke(79,2, 450 ) = 53.6307 
        henke(79,3, 450 ) = 31.6725 
        henke(79,1, 451 ) = 2770 
        henke(79,2, 451 ) = 54.0875 
        henke(79,3, 451 ) = 32.075 
        henke(79,1, 452 ) = 2775 
        henke(79,2, 452 ) = 54.6471 
        henke(79,3, 452 ) = 32.0035 
        henke(79,1, 453 ) = 2780 
        henke(79,2, 453 ) = 54.998 
        henke(79,3, 453 ) = 31.7835 
        henke(79,1, 454 ) = 2785 
        henke(79,2, 454 ) = 55.1084 
        henke(79,3, 454 ) = 31.6867 
        henke(79,1, 455 ) = 2790 
        henke(79,2, 455 ) = 55.3148 
        henke(79,3, 455 ) = 31.8416 
        henke(79,1, 456 ) = 2795 
        henke(79,2, 456 ) = 55.6531 
        henke(79,3, 456 ) = 31.9335 
        henke(79,1, 457 ) = 2800 
        henke(79,2, 457 ) = 56.0286 
        henke(79,3, 457 ) = 31.8024 
        henke(79,1, 458 ) = 2805 
        henke(79,2, 458 ) = 56.2499 
        henke(79,3, 458 ) = 31.6816 
        henke(79,1, 459 ) = 2810 
        henke(79,2, 459 ) = 56.4783 
        henke(79,3, 459 ) = 31.5694 
        henke(79,1, 460 ) = 2815 
        henke(79,2, 460 ) = 56.5899 
        henke(79,3, 460 ) = 31.4307 
        henke(79,1, 461 ) = 2820 
        henke(79,2, 461 ) = 56.7105 
        henke(79,3, 461 ) = 31.35 
        henke(79,1, 462 ) = 2825 
        henke(79,2, 462 ) = 56.749 
        henke(79,3, 462 ) = 31.3351 
        henke(79,1, 463 ) = 2830 
        henke(79,2, 463 ) = 56.8951 
        henke(79,3, 463 ) = 31.3315 
        henke(79,1, 464 ) = 2850 
        henke(79,2, 464 ) = 57.583 
        henke(79,3, 464 ) = 31.5644 
        henke(79,1, 465 ) = 2870 
        henke(79,2, 465 ) = 58.3964 
        henke(79,3, 465 ) = 31.2695 
        henke(79,1, 466 ) = 2890 
        henke(79,2, 466 ) = 58.9237 
        henke(79,3, 466 ) = 30.9601 
        henke(79,1, 467 ) = 2910 
        henke(79,2, 467 ) = 59.4023 
        henke(79,3, 467 ) = 30.8273 
        henke(79,1, 468 ) = 2930 
        henke(79,2, 468 ) = 59.9176 
        henke(79,3, 468 ) = 30.6463 
        henke(79,1, 469 ) = 2950 
        henke(79,2, 469 ) = 60.4054 
        henke(79,3, 469 ) = 30.3758 
        henke(79,1, 470 ) = 2970 
        henke(79,2, 470 ) = 60.7717 
        henke(79,3, 470 ) = 30.1012 
        henke(79,1, 471 ) = 2990 
        henke(79,2, 471 ) = 61.1487 
        henke(79,3, 471 ) = 29.9374 
        henke(79,1, 472 ) = 3010 
        henke(79,2, 472 ) = 61.5121 
        henke(79,3, 472 ) = 29.6934 
        henke(79,1, 473 ) = 3030 
        henke(79,2, 473 ) = 61.8296 
        henke(79,3, 473 ) = 29.434 
        henke(79,1, 474 ) = 3050 
        henke(79,2, 474 ) = 62.0805 
        henke(79,3, 474 ) = 29.225 
        henke(79,1, 475 ) = 3070 
        henke(79,2, 475 ) = 62.371 
        henke(79,3, 475 ) = 29.0486 
        henke(79,1, 476 ) = 3090 
        henke(79,2, 476 ) = 62.5969 
        henke(79,3, 476 ) = 28.794 
        henke(79,1, 477 ) = 3110 
        henke(79,2, 477 ) = 62.7673 
        henke(79,3, 477 ) = 28.5671 
        henke(79,1, 478 ) = 3130 
        henke(79,2, 478 ) = 62.8227 
        henke(79,3, 478 ) = 28.3876 
        henke(79,1, 479 ) = 3150 
        henke(79,2, 479 ) = 62.7438 
        henke(79,3, 479 ) = 28.2748 
        henke(79,1, 480 ) = 3170 
        henke(79,2, 480 ) = 62.7527 
        henke(79,3, 480 ) = 28.6345 
        henke(79,1, 481 ) = 3190 
        henke(79,2, 481 ) = 63.2585 
        henke(79,3, 481 ) = 29.1007 
        henke(79,1, 482 ) = 3210 
        henke(79,2, 482 ) = 63.8883 
        henke(79,3, 482 ) = 29.0161 
        henke(79,1, 483 ) = 3230 
        henke(79,2, 483 ) = 64.4161 
        henke(79,3, 483 ) = 28.8584 
        henke(79,1, 484 ) = 3250 
        henke(79,2, 484 ) = 64.8073 
        henke(79,3, 484 ) = 28.6182 
        henke(79,1, 485 ) = 3270 
        henke(79,2, 485 ) = 65.1777 
        henke(79,3, 485 ) = 28.4147 
        henke(79,1, 486 ) = 3290 
        henke(79,2, 486 ) = 65.4499 
        henke(79,3, 486 ) = 28.1726 
        henke(79,1, 487 ) = 3310 
        henke(79,2, 487 ) = 65.7286 
        henke(79,3, 487 ) = 27.9717 
        henke(79,1, 488 ) = 3330 
        henke(79,2, 488 ) = 65.9524 
        henke(79,3, 488 ) = 27.8055 
        henke(79,1, 489 ) = 3350 
        henke(79,2, 489 ) = 66.2397 
        henke(79,3, 489 ) = 27.6048 
        henke(79,1, 490 ) = 3370 
        henke(79,2, 490 ) = 66.3962 
        henke(79,3, 490 ) = 27.3835 
        henke(79,1, 491 ) = 3390 
        henke(79,2, 491 ) = 66.6101 
        henke(79,3, 491 ) = 27.2248 
        henke(79,1, 492 ) = 3410 
        henke(79,2, 492 ) = 66.6662 
        henke(79,3, 492 ) = 27.0453 
        henke(79,1, 493 ) = 3430 
        henke(79,2, 493 ) = 66.7039 
        henke(79,3, 493 ) = 26.942 
        henke(79,1, 494 ) = 3450 
        henke(79,2, 494 ) = 66.8393 
        henke(79,3, 494 ) = 27.3119 
        henke(79,1, 495 ) = 3470 
        henke(79,2, 495 ) = 67.491 
        henke(79,3, 495 ) = 27.3842 
        henke(79,1, 496 ) = 3490 
        henke(79,2, 496 ) = 68.0899 
        henke(79,3, 496 ) = 27.1888 
        henke(79,1, 497 ) = 3500 
        henke(79,2, 497 ) = 68.2076 
        henke(79,3, 497 ) = 26.6946 
        henke(79,1, 498 ) = 3510 
        henke(79,2, 498 ) = 68.1432 
        henke(79,3, 498 ) = 26.9653 
        henke(79,1, 499 ) = 3525 
        henke(79,2, 499 ) = 68.6034 
        henke(79,3, 499 ) = 26.4505 
        henke(79,1, 500 ) = 3530 
        henke(79,2, 500 ) = 68.2377 
        henke(79,3, 500 ) = 26.8074 
        henke(79,1, 501 ) = 3550 
        henke(79,2, 501 ) = 68.7985 
        henke(79,3, 501 ) = 26.2376 
        henke(79,1, 502 ) = 3575 
        henke(79,2, 502 ) = 69.1331 
        henke(79,3, 502 ) = 25.9759 
        henke(79,1, 503 ) = 3600 
        henke(79,2, 503 ) = 69.3219 
        henke(79,3, 503 ) = 25.7036 
        henke(79,1, 504 ) = 3625 
        henke(79,2, 504 ) = 69.5128 
        henke(79,3, 504 ) = 25.4699 
        henke(79,1, 505 ) = 3650 
        henke(79,2, 505 ) = 69.74 
        henke(79,3, 505 ) = 25.263 
        henke(79,1, 506 ) = 3675 
        henke(79,2, 506 ) = 69.9318 
        henke(79,3, 506 ) = 24.9735 
        henke(79,1, 507 ) = 3700 
        henke(79,2, 507 ) = 70.1176 
        henke(79,3, 507 ) = 24.7869 
        henke(79,1, 508 ) = 3725 
        henke(79,2, 508 ) = 70.3036 
        henke(79,3, 508 ) = 24.5434 
        henke(79,1, 509 ) = 3750 
        henke(79,2, 509 ) = 70.4896 
        henke(79,3, 509 ) = 24.3364 
        henke(79,1, 510 ) = 3775 
        henke(79,2, 510 ) = 70.6594 
        henke(79,3, 510 ) = 24.1176 
        henke(79,1, 511 ) = 3800 
        henke(79,2, 511 ) = 70.851 
        henke(79,3, 511 ) = 23.9182 
        henke(79,1, 512 ) = 3825 
        henke(79,2, 512 ) = 71.0263 
        henke(79,3, 512 ) = 23.6982 
        henke(79,1, 513 ) = 3850 
        henke(79,2, 513 ) = 71.1995 
        henke(79,3, 513 ) = 23.4602 
        henke(79,1, 514 ) = 3875 
        henke(79,2, 514 ) = 71.3437 
        henke(79,3, 514 ) = 23.2566 
        henke(79,1, 515 ) = 3900 
        henke(79,2, 515 ) = 71.4914 
        henke(79,3, 515 ) = 23.0176 
        henke(79,1, 516 ) = 3925 
        henke(79,2, 516 ) = 71.6171 
        henke(79,3, 516 ) = 22.8426 
        henke(79,1, 517 ) = 3950 
        henke(79,2, 517 ) = 71.7824 
        henke(79,3, 517 ) = 22.6342 
        henke(79,1, 518 ) = 3975 
        henke(79,2, 518 ) = 71.9036 
        henke(79,3, 518 ) = 22.4153 
        henke(79,1, 519 ) = 4000 
        henke(79,2, 519 ) = 72.0321 
        henke(79,3, 519 ) = 22.2106 
        henke(79,1, 520 ) = 4025 
        henke(79,2, 520 ) = 72.14 
        henke(79,3, 520 ) = 22.0297 
        henke(79,1, 521 ) = 4050 
        henke(79,2, 521 ) = 72.2775 
        henke(79,3, 521 ) = 21.8251 
        henke(79,1, 522 ) = 4075 
        henke(79,2, 522 ) = 72.3878 
        henke(79,3, 522 ) = 21.6493 
        henke(79,1, 523 ) = 4100 
        henke(79,2, 523 ) = 72.5151 
        henke(79,3, 523 ) = 21.4211 
        henke(79,1, 524 ) = 4125 
        henke(79,2, 524 ) = 72.5934 
        henke(79,3, 524 ) = 21.2525 
        henke(79,1, 525 ) = 4150 
        henke(79,2, 525 ) = 72.7285 
        henke(79,3, 525 ) = 21.0617 
        henke(79,1, 526 ) = 4175 
        henke(79,2, 526 ) = 72.8069 
        henke(79,3, 526 ) = 20.8765 
        henke(79,1, 527 ) = 4200 
        henke(79,2, 527 ) = 72.9477 
        henke(79,3, 527 ) = 20.672 
        henke(79,1, 528 ) = 4225 
        henke(79,2, 528 ) = 73.095 
        henke(79,3, 528 ) = 20.5249 
        henke(79,1, 529 ) = 4250 
        henke(79,2, 529 ) = 73.024 
        henke(79,3, 529 ) = 19.9608 
        henke(79,1, 530 ) = 4275 
        henke(79,2, 530 ) = 72.9574 
        henke(79,3, 530 ) = 20.1983 
        henke(79,1, 531 ) = 4300 
        henke(79,2, 531 ) = 73.1475 
        henke(79,3, 531 ) = 20.004 
        henke(79,1, 532 ) = 4325 
        henke(79,2, 532 ) = 73.2516 
        henke(79,3, 532 ) = 19.8547 
        henke(79,1, 533 ) = 4350 
        henke(79,2, 533 ) = 73.3425 
        henke(79,3, 533 ) = 19.6848 
        henke(79,1, 534 ) = 4375 
        henke(79,2, 534 ) = 73.4118 
        henke(79,3, 534 ) = 19.4985 
        henke(79,1, 535 ) = 4400 
        henke(79,2, 535 ) = 73.4766 
        henke(79,3, 535 ) = 19.3615 
        henke(79,1, 536 ) = 4425 
        henke(79,2, 536 ) = 73.5459 
        henke(79,3, 536 ) = 19.1851 
        henke(79,1, 537 ) = 4450 
        henke(79,2, 537 ) = 73.6228 
        henke(79,3, 537 ) = 19.0571 
        henke(79,1, 538 ) = 4475 
        henke(79,2, 538 ) = 73.6765 
        henke(79,3, 538 ) = 18.8495 
        henke(79,1, 539 ) = 4500 
        henke(79,2, 539 ) = 73.7173 
        henke(79,3, 539 ) = 18.7332 
        henke(79,1, 540 ) = 4525 
        henke(79,2, 540 ) = 73.7802 
        henke(79,3, 540 ) = 18.5909 
        henke(79,1, 541 ) = 4550 
        henke(79,2, 541 ) = 73.8478 
        henke(79,3, 541 ) = 18.4461 
        henke(79,1, 542 ) = 4575 
        henke(79,2, 542 ) = 73.9081 
        henke(79,3, 542 ) = 18.3023 
        henke(79,1, 543 ) = 4600 
        henke(79,2, 543 ) = 73.9683 
        henke(79,3, 543 ) = 18.1489 
        henke(79,1, 544 ) = 4625 
        henke(79,2, 544 ) = 74.0144 
        henke(79,3, 544 ) = 18.0055 
        henke(79,1, 545 ) = 4650 
        henke(79,2, 545 ) = 74.0696 
        henke(79,3, 545 ) = 17.8662 
        henke(79,1, 546 ) = 4675 
        henke(79,2, 546 ) = 74.1148 
        henke(79,3, 546 ) = 17.7222 
        henke(79,1, 547 ) = 4700 
        henke(79,2, 547 ) = 74.1592 
        henke(79,3, 547 ) = 17.5781 
        henke(79,1, 548 ) = 4725 
        henke(79,2, 548 ) = 74.1972 
        henke(79,3, 548 ) = 17.4518 
        henke(79,1, 549 ) = 4750 
        henke(79,2, 549 ) = 74.2458 
        henke(79,3, 549 ) = 17.3127 
        henke(79,1, 550 ) = 4775 
        henke(79,2, 550 ) = 74.2828 
        henke(79,3, 550 ) = 17.183 
        henke(79,1, 551 ) = 4800 
        henke(79,2, 551 ) = 74.3179 
        henke(79,3, 551 ) = 17.0391 
        henke(79,1, 552 ) = 4825 
        henke(79,2, 552 ) = 74.3483 
        henke(79,3, 552 ) = 16.9293 
        henke(79,1, 553 ) = 4850 
        henke(79,2, 553 ) = 74.3848 
        henke(79,3, 553 ) = 16.7905 
        henke(79,1, 554 ) = 4875 
        henke(79,2, 554 ) = 74.4109 
        henke(79,3, 554 ) = 16.6807 
        henke(79,1, 555 ) = 4900 
        henke(79,2, 555 ) = 74.4527 
        henke(79,3, 555 ) = 16.5631 
        henke(79,1, 556 ) = 4925 
        henke(79,2, 556 ) = 74.4837 
        henke(79,3, 556 ) = 16.4367 
        henke(79,1, 557 ) = 4950 
        henke(79,2, 557 ) = 74.5085 
        henke(79,3, 557 ) = 16.3147 
        henke(79,1, 558 ) = 4975 
        henke(79,2, 558 ) = 74.5307 
        henke(79,3, 558 ) = 16.208 
        henke(79,1, 559 ) = 5000 
        henke(79,2, 559 ) = 74.566 
        henke(79,3, 559 ) = 16.1014 
        henke(79,1, 560 ) = 5025 
        henke(79,2, 560 ) = 74.5781 
        henke(79,3, 560 ) = 15.9729 
        henke(79,1, 561 ) = 5050 
        henke(79,2, 561 ) = 74.6008 
        henke(79,3, 561 ) = 15.8991 
        henke(79,1, 562 ) = 5075 
        henke(79,2, 562 ) = 74.6405 
        henke(79,3, 562 ) = 15.8027 
        henke(79,1, 563 ) = 5100 
        henke(79,2, 563 ) = 74.6853 
        henke(79,3, 563 ) = 15.6929 
        henke(79,1, 564 ) = 5125 
        henke(79,2, 564 ) = 74.7123 
        henke(79,3, 564 ) = 15.5839 
        henke(79,1, 565 ) = 5150 
        henke(79,2, 565 ) = 74.7584 
        henke(79,3, 565 ) = 15.4881 
        henke(79,1, 566 ) = 5175 
        henke(79,2, 566 ) = 74.7805 
        henke(79,3, 566 ) = 15.3559 
        henke(79,1, 567 ) = 5200 
        henke(79,2, 567 ) = 74.8069 
        henke(79,3, 567 ) = 15.2512 
        henke(79,1, 568 ) = 5225 
        henke(79,2, 568 ) = 74.8033 
        henke(79,3, 568 ) = 15.1364 
        henke(79,1, 569 ) = 5250 
        henke(79,2, 569 ) = 74.7637 
        henke(79,3, 569 ) = 15.0179 
        henke(79,1, 570 ) = 5275 
        henke(79,2, 570 ) = 74.801 
        henke(79,3, 570 ) = 15.0975 
        henke(79,1, 571 ) = 5300 
        henke(79,2, 571 ) = 74.9356 
        henke(79,3, 571 ) = 14.9776 
        henke(79,1, 572 ) = 5325 
        henke(79,2, 572 ) = 74.9931 
        henke(79,3, 572 ) = 14.8325 
        henke(79,1, 573 ) = 5350 
        henke(79,2, 573 ) = 75.0219 
        henke(79,3, 573 ) = 14.7085 
        henke(79,1, 574 ) = 5375 
        henke(79,2, 574 ) = 75.0398 
        henke(79,3, 574 ) = 14.5996 
        henke(79,1, 575 ) = 5400 
        henke(79,2, 575 ) = 75.065 
        henke(79,3, 575 ) = 14.4883 
        henke(79,1, 576 ) = 5425 
        henke(79,2, 576 ) = 75.0808 
        henke(79,3, 576 ) = 14.3893 
        henke(79,1, 577 ) = 5450 
        henke(79,2, 577 ) = 75.102 
        henke(79,3, 577 ) = 14.2812 
        henke(79,1, 578 ) = 5475 
        henke(79,2, 578 ) = 75.1135 
        henke(79,3, 578 ) = 14.1907 
        henke(79,1, 579 ) = 5500 
        henke(79,2, 579 ) = 75.1432 
        henke(79,3, 579 ) = 14.097 
        henke(79,1, 580 ) = 5525 
        henke(79,2, 580 ) = 75.1569 
        henke(79,3, 580 ) = 13.9917 
        henke(79,1, 581 ) = 5550 
        henke(79,2, 581 ) = 75.1737 
        henke(79,3, 581 ) = 13.8946 
        henke(79,1, 582 ) = 5575 
        henke(79,2, 582 ) = 75.1867 
        henke(79,3, 582 ) = 13.8103 
        henke(79,1, 583 ) = 5600 
        henke(79,2, 583 ) = 75.2004 
        henke(79,3, 583 ) = 13.698 
        henke(79,1, 584 ) = 5625 
        henke(79,2, 584 ) = 75.2064 
        henke(79,3, 584 ) = 13.6317 
        henke(79,1, 585 ) = 5650 
        henke(79,2, 585 ) = 75.2295 
        henke(79,3, 585 ) = 13.5332 
        henke(79,1, 586 ) = 5675 
        henke(79,2, 586 ) = 75.2389 
        henke(79,3, 586 ) = 13.4513 
        henke(79,1, 587 ) = 5700 
        henke(79,2, 587 ) = 75.261 
        henke(79,3, 587 ) = 13.3645 
        henke(79,1, 588 ) = 5725 
        henke(79,2, 588 ) = 75.2658 
        henke(79,3, 588 ) = 13.267 
        henke(79,1, 589 ) = 5750 
        henke(79,2, 589 ) = 75.2765 
        henke(79,3, 589 ) = 13.1918 
        henke(79,1, 590 ) = 5775 
        henke(79,2, 590 ) = 75.2815 
        henke(79,3, 590 ) = 13.1064 
        henke(79,1, 591 ) = 5800 
        henke(79,2, 591 ) = 75.2996 
        henke(79,3, 591 ) = 13.0381 
        henke(79,1, 592 ) = 5825 
        henke(79,2, 592 ) = 75.3048 
        henke(79,3, 592 ) = 12.949 
        henke(79,1, 593 ) = 5850 
        henke(79,2, 593 ) = 75.3398 
        henke(79,3, 593 ) = 12.9025 
        henke(79,1, 594 ) = 5875 
        henke(79,2, 594 ) = 75.3674 
        henke(79,3, 594 ) = 12.7883 
        henke(79,1, 595 ) = 5900 
        henke(79,2, 595 ) = 75.4008 
        henke(79,3, 595 ) = 12.7016 
        henke(79,1, 596 ) = 5925 
        henke(79,2, 596 ) = 75.3224 
        henke(79,3, 596 ) = 12.5255 
        henke(79,1, 597 ) = 5950 
        henke(79,2, 597 ) = 75.3202 
        henke(79,3, 597 ) = 12.6069 
        henke(79,1, 598 ) = 5975 
        henke(79,2, 598 ) = 75.3921 
        henke(79,3, 598 ) = 12.5599 
        henke(79,1, 599 ) = 6000 
        henke(79,2, 599 ) = 75.3468 
        henke(79,3, 599 ) = 12.3979 
        henke(79,1, 600 ) = 6097.05 
        henke(79,2, 600 ) = 75.454 
        henke(79,3, 600 ) = 12.0802 
        henke(79,1, 601 ) = 6195.66 
        henke(79,2, 601 ) = 75.4744 
        henke(79,3, 601 ) = 11.7707 
        henke(79,1, 602 ) = 6295.87 
        henke(79,2, 602 ) = 75.4861 
        henke(79,3, 602 ) = 11.474 
        henke(79,1, 603 ) = 6397.7 
        henke(79,2, 603 ) = 75.4922 
        henke(79,3, 603 ) = 11.1847 
        henke(79,1, 604 ) = 6501.18 
        henke(79,2, 604 ) = 75.4923 
        henke(79,3, 604 ) = 10.9013 
        henke(79,1, 605 ) = 6606.33 
        henke(79,2, 605 ) = 75.486 
        henke(79,3, 605 ) = 10.625 
        henke(79,1, 606 ) = 6713.18 
        henke(79,2, 606 ) = 75.4735 
        henke(79,3, 606 ) = 10.3546 
        henke(79,1, 607 ) = 6821.76 
        henke(79,2, 607 ) = 75.4558 
        henke(79,3, 607 ) = 10.0911 
        henke(79,1, 608 ) = 6932.1 
        henke(79,2, 608 ) = 75.4327 
        henke(79,3, 608 ) = 9.83345 
        henke(79,1, 609 ) = 7044.22 
        henke(79,2, 609 ) = 75.4044 
        henke(79,3, 609 ) = 9.5823 
        henke(79,1, 610 ) = 7158.15 
        henke(79,2, 610 ) = 75.3708 
        henke(79,3, 610 ) = 9.33656 
        henke(79,1, 611 ) = 7273.93 
        henke(79,2, 611 ) = 75.3323 
        henke(79,3, 611 ) = 9.09708 
        henke(79,1, 612 ) = 7391.58 
        henke(79,2, 612 ) = 75.2889 
        henke(79,3, 612 ) = 8.86356 
        henke(79,1, 613 ) = 7511.13 
        henke(79,2, 613 ) = 75.2411 
        henke(79,3, 613 ) = 8.63596 
        henke(79,1, 614 ) = 7632.62 
        henke(79,2, 614 ) = 75.1884 
        henke(79,3, 614 ) = 8.41342 
        henke(79,1, 615 ) = 7756.07 
        henke(79,2, 615 ) = 75.1309 
        henke(79,3, 615 ) = 8.19661 
        henke(79,1, 616 ) = 7881.52 
        henke(79,2, 616 ) = 75.0688 
        henke(79,3, 616 ) = 7.98532 
        henke(79,1, 617 ) = 8009 
        henke(79,2, 617 ) = 75.0019 
        henke(79,3, 617 ) = 7.77944 
        henke(79,1, 618 ) = 8138.54 
        henke(79,2, 618 ) = 74.9303 
        henke(79,3, 618 ) = 7.57873 
        henke(79,1, 619 ) = 8270.17 
        henke(79,2, 619 ) = 74.8539 
        henke(79,3, 619 ) = 7.38316 
        henke(79,1, 620 ) = 8403.93 
        henke(79,2, 620 ) = 74.7724 
        henke(79,3, 620 ) = 7.19237 
        henke(79,1, 621 ) = 8539.86 
        henke(79,2, 621 ) = 74.6855 
        henke(79,3, 621 ) = 7.00652 
        henke(79,1, 622 ) = 8677.99 
        henke(79,2, 622 ) = 74.5929 
        henke(79,3, 622 ) = 6.82554 
        henke(79,1, 623 ) = 8818.35 
        henke(79,2, 623 ) = 74.4944 
        henke(79,3, 623 ) = 6.64926 
        henke(79,1, 624 ) = 8960.98 
        henke(79,2, 624 ) = 74.3896 
        henke(79,3, 624 ) = 6.47785 
        henke(79,1, 625 ) = 9105.91 
        henke(79,2, 625 ) = 74.2781 
        henke(79,3, 625 ) = 6.31086 
        henke(79,1, 626 ) = 9253.19 
        henke(79,2, 626 ) = 74.1592 
        henke(79,3, 626 ) = 6.14827 
        henke(79,1, 627 ) = 9402.86 
        henke(79,2, 627 ) = 74.0321 
        henke(79,3, 627 ) = 5.98988 
        henke(79,1, 628 ) = 9554.94 
        henke(79,2, 628 ) = 73.8956 
        henke(79,3, 628 ) = 5.83566 
        henke(79,1, 629 ) = 9709.48 
        henke(79,2, 629 ) = 73.7487 
        henke(79,3, 629 ) = 5.68548 
        henke(79,1, 630 ) = 9866.53 
        henke(79,2, 630 ) = 73.5897 
        henke(79,3, 630 ) = 5.53944 
        henke(79,1, 631 ) = 10026.1 
        henke(79,2, 631 ) = 73.4166 
        henke(79,3, 631 ) = 5.39725 
        henke(79,1, 632 ) = 10188.3 
        henke(79,2, 632 ) = 73.2268 
        henke(79,3, 632 ) = 5.25911 
        henke(79,1, 633 ) = 10353.1 
        henke(79,2, 633 ) = 73.017 
        henke(79,3, 633 ) = 5.12467 
        henke(79,1, 634 ) = 10520.5 
        henke(79,2, 634 ) = 72.7827 
        henke(79,3, 634 ) = 4.99433 
        henke(79,1, 635 ) = 10690.7 
        henke(79,2, 635 ) = 72.5173 
        henke(79,3, 635 ) = 4.8673 
        henke(79,1, 636 ) = 10863.6 
        henke(79,2, 636 ) = 72.2104 
        henke(79,3, 636 ) = 4.74345 
        henke(79,1, 637 ) = 11039.3 
        henke(79,2, 637 ) = 71.8462 
        henke(79,3, 637 ) = 4.62305 
        henke(79,1, 638 ) = 11217.8 
        henke(79,2, 638 ) = 71.3983 
        henke(79,3, 638 ) = 4.50609 
        henke(79,1, 639 ) = 11399.3 
        henke(79,2, 639 ) = 70.8145 
        henke(79,3, 639 ) = 4.39238 
        henke(79,1, 640 ) = 11583.7 
        henke(79,2, 640 ) = 69.9708 
        henke(79,3, 640 ) = 4.28184 
        henke(79,1, 641 ) = 11771 
        henke(79,2, 641 ) = 68.4114 
        henke(79,3, 641 ) = 4.17438 
        henke(79,1, 642 ) = 11919.6 
        henke(79,2, 642 ) = 54.2618 
        henke(79,3, 642 ) = 4.09225 
        henke(79,1, 643 ) = 11919.8 
        henke(79,2, 643 ) = 54.2623 
        henke(79,3, 643 ) = 10.2067 
        henke(79,1, 644 ) = 11961.4 
        henke(79,2, 644 ) = 66.0462 
        henke(79,3, 644 ) = 10.1456 
        henke(79,1, 645 ) = 12154.9 
        henke(79,2, 645 ) = 69.4377 
        henke(79,3, 645 ) = 9.86933 
        henke(79,1, 646 ) = 12351.5 
        henke(79,2, 646 ) = 70.5678 
        henke(79,3, 646 ) = 9.60054 
        henke(79,1, 647 ) = 12551.2 
        henke(79,2, 647 ) = 71.2006 
        henke(79,3, 647 ) = 9.33908 
        henke(79,1, 648 ) = 12754.2 
        henke(79,2, 648 ) = 71.5803 
        henke(79,3, 648 ) = 9.08474 
        henke(79,1, 649 ) = 12960.5 
        henke(79,2, 649 ) = 71.7808 
        henke(79,3, 649 ) = 8.83733 
        henke(79,1, 650 ) = 13170.2 
        henke(79,2, 650 ) = 71.8135 
        henke(79,3, 650 ) = 8.59667 
        henke(79,1, 651 ) = 13383.2 
        henke(79,2, 651 ) = 71.6296 
        henke(79,3, 651 ) = 8.36256 
        henke(79,1, 652 ) = 13599.6 
        henke(79,2, 652 ) = 70.9727 
        henke(79,3, 652 ) = 8.13483 
        henke(79,1, 653 ) = 13734.1 
        henke(79,2, 653 ) = 66.1706 
        henke(79,3, 653 ) = 7.99825 
        henke(79,1, 654 ) = 13734.3 
        henke(79,2, 654 ) = 66.1692 
        henke(79,3, 654 ) = 11.1562 
        henke(79,1, 655 ) = 13819.6 
        henke(79,2, 655 ) = 70.2036 
        henke(79,3, 655 ) = 11.0416 
        henke(79,1, 656 ) = 14043.1 
        henke(79,2, 656 ) = 71.0421 
        henke(79,3, 656 ) = 10.7502 
        henke(79,1, 657 ) = 14270.3 
        henke(79,2, 657 ) = 71.8721 
        henke(79,3, 657 ) = 10.4665 
        henke(79,1, 658 ) = 14355.2 
        henke(79,2, 658 ) = 72.393 
        henke(79,3, 658 ) = 10.3635 
        henke(79,1, 659 ) = 14355.4 
        henke(79,2, 659 ) = 72.3956 
        henke(79,3, 659 ) = 11.9115 
        henke(79,1, 660 ) = 14501.1 
        henke(79,2, 660 ) = 73.1761 
        henke(79,3, 660 ) = 11.7365 
        henke(79,1, 661 ) = 14735.6 
        henke(79,2, 661 ) = 73.9335 
        henke(79,3, 661 ) = 11.4636 
        henke(79,1, 662 ) = 14974 
        henke(79,2, 662 ) = 74.4994 
        henke(79,3, 662 ) = 11.1953 
        henke(79,1, 663 ) = 15216.1 
        henke(79,2, 663 ) = 74.9619 
        henke(79,3, 663 ) = 10.9315 
        henke(79,1, 664 ) = 15462.3 
        henke(79,2, 664 ) = 75.354 
        henke(79,3, 664 ) = 10.6722 
        henke(79,1, 665 ) = 15712.3 
        henke(79,2, 665 ) = 75.6941 
        henke(79,3, 665 ) = 10.4175 
        henke(79,1, 666 ) = 15966.5 
        henke(79,2, 666 ) = 75.9935 
        henke(79,3, 666 ) = 10.1675 
        henke(79,1, 667 ) = 16224.7 
        henke(79,2, 667 ) = 76.2597 
        henke(79,3, 667 ) = 9.92199 
        henke(79,1, 668 ) = 16487.1 
        henke(79,2, 668 ) = 76.4982 
        henke(79,3, 668 ) = 9.68114 
        henke(79,1, 669 ) = 16753.8 
        henke(79,2, 669 ) = 76.713 
        henke(79,3, 669 ) = 9.44489 
        henke(79,1, 670 ) = 17024.8 
        henke(79,2, 670 ) = 76.9072 
        henke(79,3, 670 ) = 9.21324 
        henke(79,1, 671 ) = 17300.2 
        henke(79,2, 671 ) = 77.0834 
        henke(79,3, 671 ) = 8.98617 
        henke(79,1, 672 ) = 17580 
        henke(79,2, 672 ) = 77.2436 
        henke(79,3, 672 ) = 8.76366 
        henke(79,1, 673 ) = 17864.3 
        henke(79,2, 673 ) = 77.3895 
        henke(79,3, 673 ) = 8.54567 
        henke(79,1, 674 ) = 18153.3 
        henke(79,2, 674 ) = 77.5224 
        henke(79,3, 674 ) = 8.33218 
        henke(79,1, 675 ) = 18446.9 
        henke(79,2, 675 ) = 77.6437 
        henke(79,3, 675 ) = 8.12315 
        henke(79,1, 676 ) = 18745.2 
        henke(79,2, 676 ) = 77.7542 
        henke(79,3, 676 ) = 7.91854 
        henke(79,1, 677 ) = 19048.4 
        henke(79,2, 677 ) = 77.8551 
        henke(79,3, 677 ) = 7.71831 
        henke(79,1, 678 ) = 19356.5 
        henke(79,2, 678 ) = 77.947 
        henke(79,3, 678 ) = 7.52241 
        henke(79,1, 679 ) = 19669.6 
        henke(79,2, 679 ) = 78.0307 
        henke(79,3, 679 ) = 7.33079 
        henke(79,1, 680 ) = 19987.7 
        henke(79,2, 680 ) = 78.1068 
        henke(79,3, 680 ) = 7.1434 
        henke(79,1, 681 ) = 20311 
        henke(79,2, 681 ) = 78.1759 
        henke(79,3, 681 ) = 6.96019 
        henke(79,1, 682 ) = 20639.5 
        henke(79,2, 682 ) = 78.2385 
        henke(79,3, 682 ) = 6.7811 
        henke(79,1, 683 ) = 20973.4 
        henke(79,2, 683 ) = 78.295 
        henke(79,3, 683 ) = 6.60607 
        henke(79,1, 684 ) = 21312.6 
        henke(79,2, 684 ) = 78.346 
        henke(79,3, 684 ) = 6.43505 
        henke(79,1, 685 ) = 21657.3 
        henke(79,2, 685 ) = 78.3918 
        henke(79,3, 685 ) = 6.26797 
        henke(79,1, 686 ) = 22007.6 
        henke(79,2, 686 ) = 78.4327 
        henke(79,3, 686 ) = 6.10477 
        henke(79,1, 687 ) = 22363.5 
        henke(79,2, 687 ) = 78.4691 
        henke(79,3, 687 ) = 5.94539 
        henke(79,1, 688 ) = 22725.3 
        henke(79,2, 688 ) = 78.5012 
        henke(79,3, 688 ) = 5.78977 
        henke(79,1, 689 ) = 23092.8 
        henke(79,2, 689 ) = 78.5294 
        henke(79,3, 689 ) = 5.63785 
        henke(79,1, 690 ) = 23466.3 
        henke(79,2, 690 ) = 78.554 
        henke(79,3, 690 ) = 5.48955 
        henke(79,1, 691 ) = 23845.9 
        henke(79,2, 691 ) = 78.5751 
        henke(79,3, 691 ) = 5.34482 
        henke(79,1, 692 ) = 24231.6 
        henke(79,2, 692 ) = 78.593 
        henke(79,3, 692 ) = 5.20359 
        henke(79,1, 693 ) = 24623.5 
        henke(79,2, 693 ) = 78.6079 
        henke(79,3, 693 ) = 5.06579 
        henke(79,1, 694 ) = 25021.8 
        henke(79,2, 694 ) = 78.62 
        henke(79,3, 694 ) = 4.93136 
        henke(79,1, 695 ) = 25426.5 
        henke(79,2, 695 ) = 78.6294 
        henke(79,3, 695 ) = 4.80024 
        henke(79,1, 696 ) = 25837.7 
        henke(79,2, 696 ) = 78.6364 
        henke(79,3, 696 ) = 4.67236 
        henke(79,1, 697 ) = 26255.6 
        henke(79,2, 697 ) = 78.6411 
        henke(79,3, 697 ) = 4.54765 
        henke(79,1, 698 ) = 26680.3 
        henke(79,2, 698 ) = 78.6436 
        henke(79,3, 698 ) = 4.42606 
        henke(79,1, 699 ) = 27111.8 
        henke(79,2, 699 ) = 78.6442 
        henke(79,3, 699 ) = 4.30751 
        henke(79,1, 700 ) = 27550.3 
        henke(79,2, 700 ) = 78.6428 
        henke(79,3, 700 ) = 4.19195 
        henke(79,1, 701 ) = 27995.9 
        henke(79,2, 701 ) = 78.6397 
        henke(79,3, 701 ) = 4.07931 
        henke(79,1, 702 ) = 28448.7 
        henke(79,2, 702 ) = 78.635 
        henke(79,3, 702 ) = 3.96953 
        henke(79,1, 703 ) = 28908.9 
        henke(79,2, 703 ) = 78.6287 
        henke(79,3, 703 ) = 3.86255 
        henke(79,1, 704 ) = 29376.5 
        henke(79,2, 704 ) = 78.6209 
        henke(79,3, 704 ) = 3.7583 
        henke(79,1, 705 ) = 29851.6 
        henke(79,2, 705 ) = 78.6119 
        henke(79,3, 705 ) = 3.65674 
        henke(79,1, 706 ) = 30000 
        henke(79,2, 706 ) = 78.6088 
        henke(79,3, 706 ) = 3.62588 
       return
      end
